<?php
/**
 * email-out functions, wrapper around phpmailer
 *
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2008 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 4.0.0
 */



class Mailout{
	/**
	 * @desc return true if mail-out configuration is set
	 *
	 * @return boolean
	 */
	static function isMainConfigurationSet(){
	 	$mailout=@unserialize(cfStoredPasswordDecrypt(cfGGetVar('mailout')));
	 	return isset($mailout['username']);
	}

	/**
	 * @desc return configuration for mail-out stored into general config
	 *
	 * @return array or false if not ok
	 */
	static function getMainConfiguration(){
	 	$mailout=@unserialize(cfStoredPasswordDecrypt(cfGGetVar('mailout')));
	 	if(!isset($mailout['username'])) return false;
	 	return $mailout;
	}

	/**
	 * @desc Set main SMTP configuration for mail-out: update mailout value into general config
	 *
	 * @param string $username
	 * @param integer $host
	 * @param integer $smtpPort
	 * @param string $SMTPSecure: 'ssl', 'tls', false
	 * @param string $authenticationType
	 * @return boolean result
	 */
	static function setMainConfiguration($configuration){
		if(is_array($configuration)) WEnv::config()->updateVar('mailout',cfStoredPasswordCrypt(serialize($configuration)),true);
		else WEnv::config()->updateVar('mailout',false,true);

		return true;
	}

	/**
	 * @desc Try to autoconfigure an email account from an email address
	 *
	 * @param string $email
	 * @param bool $autoCompleteIfUnknown
	 * @return unknown
	 */
	static function autoConfig($email,$autoCompleteIfUnknown=true){
		$host=substr($email,strpos($email,'@')+1);
		$emailTLD=substr($host,strrpos($host,'.')+1);
		$emailHostWithoutTLD=substr($host,0,strrpos($host,'.'));
		$user=substr($email,0,strpos($email,'@'));

		$providers=cfParse_ini_file(cfAppBinDir().'/default/emailProviders.ini',true,false);
		foreach ($providers as $hostList=>$config){
			foreach (explode(',',$hostList) as $configHost){
				if((strpos($configHost,'.') && strtolower($host)==strtolower($configHost)) || (!strpos($configHost,'.') && strtolower($emailHostWithoutTLD)==strtolower($configHost))){
					$autoConfig=$config;
					// Set username
					$autoConfig['username']=(@$config['user']=='name')?$user:$email;

					// If email host matched with a provider without TLD, use TLD from email or use common TLD defined into provider configuration
					if(!strpos($configHost,'.')){
						if(@$config['useEmailTLD']){
							$autoConfig['smtpHost']=substr($autoConfig['smtpHost'],0,strrpos($autoConfig['smtpHost'],'.')).'.'.$emailTLD;
						}
					}
				}
			}
		}

		// Try to set a default configuration if none has been found
		if(!isset($autoConfig)){
			if(!$autoCompleteIfUnknown) return false;
			$autoConfig['email']=$email;
			$autoConfig['smtpHost']='smtp.'.$host;
			$autoConfig['smtpPort']=25;
			$autoConfig['SMTPAuth']='no';
			$autoConfig['SMTPSecure']='no';
		}

		unset($autoConfig['useEmailTLD']);
		unset($autoConfig['user']);

		return $autoConfig;
	}


	 /**
	  * @desc Send an email using a smtp configuration
	  *
	  * @param PHPMailer $mail
	  * @param array $userConfig
	  * @return true if ok or error message if not ok
	  */
	static function send($mail, $userConfig){
	 	if(0) $mail=new PHPMailer(); // Zend IDE WA
	 	$mail->Host=$userConfig['smtpHost'];
	 	if(@$userConfig['smtpPort']) $mail->Port=$userConfig['smtpPort'];
	 	$mail->Username=$userConfig['username'];

	 	// Set password / authentication
	 	if(@$userConfig['SMTPAuth'] && @$userConfig['SMTPAuth']!=='no') {
	 		$mail->SMTPAuth=true;
	 		$mail->Password=$userConfig['password'];
	 	}
	 	// SSL/TLS ciphering
	 	if(@$userConfig['SMTPSecure'] && $userConfig['SMTPSecure']!='no') $mail->SMTPSecure=$userConfig['SMTPSecure'];

	 	// From
		$mail->From=$userConfig['email'];
		$mail->FromName=(@$userConfig['plainName'])?$userConfig['plainName']:$userConfig['email'];

		/**
		 * Send mail
		 */
		$result=$mail->Send();

		// Process result and close
		if(!$result) $result=$mail->ErrorInfo;
		$mail->SmtpClose();
		unset($mail);

		return $result;
	}

	 /**
	  * @Desc Send a file to a recipient using main smtp configuration
	  *
	  * @param string $completeFilename
	  * @param string $destAddress
	  * @return mixed bool/string: true if ok or error message if not ok
	  */
	static function sendFile($completeFilename,$destAddress,$options=array()){
	 	if(!$mailConfig=Mailout::getMainConfiguration()) return false;
	 	if(!file_exists($completeFilename)) return false;

	 	require_once(INCLUDE_DIR.'PHPMailer/class.phpmailer.php');

	 	$mail=new PHPMailer();
	 	if(file_exists(INCLUDE_DIR.'PHPMailer/language/phpmailer.lang-'.cfGGetVar('language').'.php')) $mail->SetLanguage(cfGGetVar('language'));
	 	$mail->IsSMTP();
		$mail->AddAddress($destAddress);
		$mail->AddAttachment($completeFilename,basename($completeFilename));
		$mail->Subject=(@$options['subject'])?$options['subject']:basename($completeFilename);
		$mail->Body=(@$options['message'])?$options['message']:' ';

		return Mailout::send($mail,$mailConfig);
	}

	 /**
	  * @Desc Send a file to a recipient using main smtp configuration
	  *
	  * @param string $destAddress
	  * @param string $subject (utf8 decoded)
	  * @param string $body (utf8 decoded)
	  * @return mixed bool/string: true if ok or error message if not ok
	  */
	static function sendMail($destAddress,$subject,$body){
	 	if(!$mailConfig=Mailout::getMainConfiguration()) return false;

	 	require_once(INCLUDE_DIR.'PHPMailer/class.phpmailer.php');

	 	$mail=new PHPMailer();
	 	if(file_exists(INCLUDE_DIR.'PHPMailer/language/phpmailer.lang-'.cfGGetVar('language').'.php')) $mail->SetLanguage(cfGGetVar('language'));
	 	$mail->IsSMTP();
		$mail->AddAddress($destAddress);
		$mail->Subject=$subject;
		$mail->Body=$body;

		return Mailout::send($mail,$mailConfig);
	}

	 /**
	  * @Desc Send a email for testing
	  *
	  * @param string $destAddress
	  * @return mixed bool/string
	  */
	static function testConfig($mailConfig){
	 	require_once(INCLUDE_DIR.'PHPMailer/class.phpmailer.php');

	 	$mail=new PHPMailer();
	 	$mail->IsSMTP();
		$mail->AddAddress($mailConfig['email']);
		$mail->Subject=APPLICATION_NAME.' - Test';
		$mail->Body=':-)';

		return Mailout::send($mail,$mailConfig);
	}
}



 ?>