<?php
/**
 * Common functions used by scripts displaying mobile devices pages
 *
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2008 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.3.0
 */

// Workaround for Mobile IE display
define('IEMOBILE_TOP_CONTROLS_HEIGHT',50);

// Default bitrate for audio streaming (used only if no "maxAudioBitrate" set at browser-level)
define('MOBILE_DEFAULT_AUDIO_BITRATE',64);

/**
 * @desc Insert header, body and top controls for mobile pages
 *
 * @param array $parameters: array of parameters:
 * 			'context': "login", "menu", "resource", or "view". If not set, automatically determined
 * 			'javascript': javascript code to be embed into <head></head> (without <script> tag
 * 			'commonScripts': include a link to common.js
 * 			'style': css style to be embed into <head></head> (without <style> tag
 * 			'bodyExtraHTML': HTML codeto be embed within <body> tag
 * 			'ping': mixed: true/false to include or not a periodic ping to server, 'auto' to include depending on script
 * 			'noTopControls': true not to include top header
 * 			'topControlsLabel': HTML code to be included into top header label area
 * 			'topControlsExtra': HTML code to be included into top header extra area
 * 			'title': page title
 * 			'noUpdateOrientation': set to indicate orientation update script won't be included
 */
function mfInsertHead($parameters=array()){
	// Asynchronous request: just return XML header
	if(isset($_POST['asyncRequest'])){
		if(isset($_POST['userHasFlash'])) mfInsertFlashDetection(); // Detection of flash player support
		cfAsyncHeader();
		return;
	}
	@header('P3P: policyref="/w3c/p3p.xml",CP="NON COR CURa OUR NOR NAV"');
	@header('Connection: Keep-Alive');
	@header('Keep-Alive: timeout=15, max=2000');
	@header('Proxy-Connection: Keep-Alive');

	if(!isset($parameters['ping'])) $parameters['ping']='auto';

	// Context (login, menu, resource, view)
	if (isset($parameters['context'])) $context=$parameters['context'];
	elseif($_SERVER['SCRIPT_NAME']=='/login.php') $context='login';
	elseif($_SERVER['SCRIPT_NAME']=='/mainFrame.php'||$_SERVER['SCRIPT_NAME']=='/index.php') $context='menu';
	else $context='resource';

	/**
	 * HTML Output
	 * <html manifest="/themes/mobile/cache.manifest.php">
	 */
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html><head>
<meta http-equiv="content-type" content="text/html; charset=utf-8">
<?php

	// Insert extra meta tags
	if(cfRGetVar('meta')&&!cfBGetVar('name')=='iPhone')	echo cfRGetVar('meta');
	if(isset($_ENV['meta']))	echo $_ENV['meta'];
	if(cfBGetVar('extraHead')) echo cfBGetVar('extraHead');

	// Special: ipad apple touch icon
	if(cfBGetVar('name')=='iPad') echo '<link ref="apple-touch-icon" href="/apple-touch-icon72.png" />';

	// Title
	if(isset($parameters['title'])) $title=$parameters['title'];
	elseif ($context=='resource'||$context=='view') $title=cfUTF8Encode(cfRGetVar('name'));
	else $title=cfGGetVar('pageTitle');
	echo '<title>'.$title.'</title>'."\n";

	// Theme
	echo '<link rel="stylesheet" type="text/css" media="all" id="themeCss" href="/themes/'.((cfUGetVar('theme'))?cfUGetVar('theme'):cfGGetVar('theme')).'/theme.css?v='.cfGGetVar('appVersion')."\">\n";

	//echo '<link rel="stylesheet" type="text/css" media="all" href="/themes/mobile/theme.css?v='.cfGGetVar('appVersion').'&browser='.cfBGetVar('name')."\">\n";
	if(cfBGetVar('mobileBrowserTheme')) echo '<link rel="stylesheet" media="all" type="text/css" href="/themes/mobile/'.cfBGetVar('mobileBrowserTheme').'/theme.css?v='.cfGGetVar('appVersion')."\">\n";
	//if(cfBGetVar('name')=='iPhone') echo '<link rel="stylesheet" media="all" type="text/css" href="/themes/mobile/IEMobile/theme.css?v='.cfGGetVar('appVersion').'&rnd='.rand()."\">\n";

	if(@$parameters['commonScripts']) echo cfScriptLink('common.js');

	// Common js functions
	if(!cfBGetVar('inlineJS')) echo cfScriptLink('mCommon.js');
    // JS debug functions
    if(cfGGetVar('jsDebug')) echo cfScriptLink('debug.js');

	// Javascript
	?><script type="text/javascript"><?php
	echo 'var isMobile=1';
	echo ',userLogged='.((@$_SESSION['userLogged'])?1:0);
	echo ',clientCapSet='.((is_array(cfBGetVar('clientCapabilities')))?1:0); // Set if client capabilties have been set through a client-side request since connection (flash / html5 support...)
	echo ';';



	if(cfBGetVar('name')=='iPhone'||cfBGetVar('OS')=='Android') echo 'setTimeout("D.body.onload=W.scrollTo(0,1)",10);';

	if(cfBGetVar('inlineJS')) echo file_get_contents(cfAppDocRoot().'/js/mCommon.js'); // inline javascript (IE Mobile 5)

	// insert javascript resource id (used by async requests)
	if(substr($_SERVER['PHP_SELF'],0,5)=='/res/' && isset($_SESSION['activeResourceId'])) echo 'var resId="'.$_SESSION['activeResourceId']."\";\n";
	// Extra javascript
	if(isset($parameters['javascript'])) echo $parameters['javascript'];

	// Periodic server ping
	if(!isset($parameters['ping']) || $parameters['ping']===true ||
		($parameters['ping']==='auto' && $context!='login' && ($context=='resource' || $context=='view' || ($_SERVER['SCRIPT_NAME']=='/index.php')))
		) {
		echo "var pingInterval=".(max(cfGGetVar('clientPingInterval'),cfBGetVar('clientPingInterval'),10)*1000).";\n";
		echo 'setTimeout("if(window.ping) ping("+pingInterval+")",pingInterval);';
	}

	// iPhone orientation zoom adaptation script
	if(!isset($parameters['noUpdateOrientation']) && cfBGetVar('name')=='iPhone'){?>
function updateOrientation(){
var w,h;if(W.orientation==undefined) return;
if(Math.abs(orientation)==90){w=480;h=268}else{w=320;h=416}
dgn('viewport').setAttribute("content","width="+w+", height="+h+", user-scalable=yes,initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0");
D.body.style.height=h+'px';
}<?php
	}
?></script><?php

	// Extra style
	if(isset($parameters['style'])) echo "<style>\n".$parameters['style']."\n</style>\n";

	if(cfBGetVar('flash')==='auto' && @$parameters['context']!=='login') mfInsertFlashDetection();

	// Close head
	if(isset($parameters['dontCloseHead'])) return;
	if(!isset($parameters['bodyExtraHTML'])) $parameters['bodyExtraHTML']='';
	if(cfBGetVar('OS')=='iOS') $parameters['bodyExtraHTML'].=' onorientationchange="if(W.updateOrientation) updateOrientation()"';
	echo "</head><body ".$parameters['bodyExtraHTML'].">\n";

	//if(cfBGetVar('OS')=='Android') echo '<div id="androidFix"></div>';

	// Resource common top controls
	if(!isset($parameters['noTopControls'])){
		mfInsertTopControls(
			$context,
			isset($parameters['topControlsLabel'])?$parameters['topControlsLabel']:false,
			isset($parameters['topControlsExtra'])?$parameters['topControlsExtra']:false
		);
	}

	// Send to browser
	flush();
}

/**
 * @desc Insert HTML code for resources top controls
 * @param string $context: 'resource' (default), 'menu', 'view', 'login'
 * @param string $capt: caption
 * @param string $extra: extra HTML code
 *
 */
function mfInsertTopControls($context='resource',$capt=false,$extra=false){
?>
<table id="winBar" cellspacing=0 cellpadding=0>
<colgroup><col width="1%"><col width="98%"><col width="1%"></colgroup><tr>
<td id="wbI" style="white-space:nowrap">
<?php

/**
 * Top left
 */

// Logout button for standalone resources
if(WEnv::user()->isStandalone() && $context=='resource') echo mfButton(false,"javascript:void(sendData('logout=1','/index.php?logout'))",outIcon('logout'));

// Application icon for login page
else if($context=='menu'||$context=='login') echo '<b class="icon32 appIcon"></b>'."\n";

// User menu page link for regular resource access
else if($context=='view'||$context=='resource') echo mfButton(false,"/index.php",outIcon("home"))."\n";

if($context=='view') echo '&nbsp;'.mfButton(false,'javascript:if(wl.liSel) wl.liSel(this);document.location=\'/res/'.cfRGetVar('type').'/'.cfRGetVar('subType').'/index.php?resId='.$_SESSION['activeResourceId'].'\'',cfRGetVar('resourceIcon'))."\n";
?>
</td>
<td id="wbC"><?php
// Main caption
if($capt!==false) echo $capt;
elseif ($context=='login') echo cfCaption('loginSelectAccount');
elseif ($context=='menu') echo cfCaption('genResources');
else echo '&nbsp;';
?>
</td><td id="wbE"><?php
	// Extra buttons
	if($extra!==false) echo $extra;

	// Main menu top controls
	elseif ($context=='menu') {
		// Theme button
		if(cfGGetVar('allowUserThemeChange')) echo mfButton(false,'javascript:toggleTheme()',outIcon('themeM'));
		// Logout button
		echo mfButton(false,'javascript:document.logoutForm.submit()',outIcon('logout'));
	}
?></td></tr></table><div id="winBarSpacer"></div>
<?php
}

/**
 * @desc Display a page indicating that resource is not compatible with mobile browsers
 *
 */
function mfDisplayResourceNotCompatiblePage(){
	mfDisplayErrorPage('',outImage(outIcon('mobileNo')),true);
}

/**
 * @desc Display a page indicating that resource is not compatible with mobile browsers
 *
 */
function mfDisplayErrorPage($title,$centerHTML,$blink=false){
	mfInsertHead(array('extraControls'=>mfButton('back')));
	if($blink){
?>
<script type="text/javascript">
W.setInterval(function(){var s=dgi('blinkTd').style;s.display=(s.display=='none')?'':'none'},700)
</script>
<?php
	}
?>
<table style="height:70%;width:100%">
<tr valign="middle">
	<td valign="middle" align="center" id="blinkTd">
<?php echo $centerHTML;?>
	</td>
</tr>
</table>
</body></html>
<?php
	exit;
}

/**
 * @return string: code
 * @param string $caption : button's caption (utf-8 encoded)
 * @param string $action : optional : action (href)
 * @param string $imgSrc : optional : path to button's image
 * @param string $extraHTML : optional : extra HTML code included in button definition
 * @param string $state: false: normal, 'disabled' or 'on'
 * @param array $options: 'rawCaption'=>true: don't replace spaces by &nbsp;, 'extraClass' to add a class to button
 * @desc  Insert HTML code for a button
*/
function mfButton($caption,$href='#',$imgSrc=false,$extraHTML=false,$state=false,$options=array()){
	//Format : <a class="button"><img src="icon"/>text</a>
	$output='<a '.$extraHTML.' class="';
	if($state=='on') $output.='btSel';
	elseif($state=='disabled') $output.='btDisabled';
	else $output.='bt';
	if(isset($options['extraClass'])) $output.=' '.$options['extraClass'];

	$output.='" href="';
	if($state=='disabled') {
		if(substr($href,0,11)=='javascript:') $output.='javascript://'.substr($href,11);
		else $output.='javascript://#'.$href;
	}
	else $output.=$href;
	$output.='"><img src="'.(($imgSrc)?$imgSrc.'" class="ico"':'/gfx/v.gif"').' alt="" />';
	if($caption){
		$caption='<span>'.$caption.'</span>';
		if(!@$options['rawCaption']) $caption=str_replace(' ','&nbsp;',$caption);
	}

	return $output.$caption.'</a>';
}

/**
 * @desc Return HTML code for list table definition
 *
 * @param $extraHTML
 * @param $extraClass
 * @return string HTMl code
 */
function mfListTable($extraHTML='',$extraClass=''){return '<table class="liTable'.(($extraClass)?' '.$extraClass:'').'" cellspacing=0 cellpadding=0 '.$extraHTML.'><colgroup><col width="1"><col width="*"><col width="1"></colgroup>';}

/**
 * @desc List item HTML
 *
 * @param string $extraHTML: HTML inserted into (topmost) tr element
 * @param string $lContent: left-side HTML
 * @param string $lExtraHTML: HTML inserted into left td
 * @param string $cContent: central HTML
 * @param string $cExtraHTML: HTML inserted into central td
 * @param string $rContent: right-side HTML (set "go" for a simple go icon that will turn into a loading icon when li item is selected)
 * @param string $rExtraHTML: HTML inserted into right td
 * @return string HTML code
 */
function mfListItem($extraHTML,$lContent,$lExtraHTML=false,$cContent=false,$cExtraHTML=false,$rContent='',$rExtraHTML=false){
	if(strpos($extraHTML,'class=')!==false) $output='<tr '.$extraHTML.'>'; else $output='<tr class="li" '.$extraHTML.'>';

	if($rContent==='go') {
		$rContent='<b class="goIco"></b>';
		//if(!$rExtraHTML) $rExtraHTML='';
	}

	$output.='<td class="lil" '.$lExtraHTML.(($lContent)?'':' style="overflow:hidden;width:1px"').'>'.(($lContent)?$lContent:'&nbsp;').'</td>';

	if($rContent){
		$output.='<td class="lic" '.$cExtraHTML.'>'.$cContent.'</td>';
		$output.='<td class="lir" '.$rExtraHTML.'>'.$rContent.'</td>';
	}
	else $output.='<td class="lir" colspan="2" '.$cExtraHTML.' style="text-align:left">'.$cContent.'</td>';
	return $output."</tr>";
}

/**
 * @desc Return a list item spacer
 *
 * @return string HTML code
 */
function mfListSpacer($caption=false){
	if(!$caption) return mfListItem('class="liSpacer"','');
	return '<tr><td colspan="3" style="height:1.6em;vertical-align:bottom" class="frame1Header">'.$caption.'</td></tr>';
}

/**
 * Process mobile explorer specific commands
 *
 */
function mfProcessPOST(){
	// Change audio bitrate (values: 32, 64, 128, original)
	if(isset($_POST['outputBitRate'])){
		if(cfRGetVar('outputBitRate') && in_array($_POST['outputBitRate'],array('32','64','128','original'))) cfRSetVar('outputBitRate',cfBitrateMin(cfRGetVar('maxOutputBitRate'),$_POST['outputBitRate']));
        cfAsyncHeader();
        cfAsyncFooter();
	}
}

/**
 * @desc Return code for mobile audio quality controls. Note: limit choice to original, 128 or 64
 *
 * @param string $bitrate: original, 128, 64, 32
 * @return string
 */
function mfAudioQualityControls($bitrate){
	$max=cfBitrateMin(cfBGetVar('maxAudioBitrate'),cfRGetVar('maxOutputBitRate'));
	$bitrate=cfBitrateMin(cfRGetVar('outputBitRate'),$max);

	if($max<128 && $max!='original') return ''; // No possible choice: don't show controls
	$out=mfButton(false,"javascript:setAudioBitrate(64)",outIcon('audioBitrate64'),'id="aQCBt64"',($bitrate==64)?'on':false);
	$out.=mfButton(false,"javascript:setAudioBitrate(128)",outIcon('audioBitrate128'),'id="aQCBt128"',($bitrate==128)?'on':false);
	if($max=='original') $out.=mfButton(false,"javascript:setAudioBitrate('original')",outIcon('audioBitrateOriginal'),'id="aQCBtoriginal"',($bitrate=='original')?'on':false);
	$out.='&nbsp;&nbsp;&nbsp;';
	return $out;
}

/**
 * @desc Insert mobile upload form
 *
 * @param boolean $includeOkButton
 * @param string $hackJSFunction: name of javascript function called on upload completed
 * @return string HTML code
 */
function mfUploadForm($includeOkButton=true,$ackJSFunction=false){
	if(!cfBGetVar('upload')) return ;
	$output='
<form name="uploadForm" method="post" enctype="multipart/form-data" action="upload.php">
<input type="hidden" name="UPLOAD_IDENTIFIER">
<input type="hidden" name="ulDir" id="ulDir">
<input type="hidden" name="postUlFile" id="postUlFile" value="">
<input type="hidden" name="resId" value="'.$_SESSION['activeResourceId'].'">
<input type="hidden" name="ulTransferId" id="ulTransferId">';
	if($includeOkButton) $output.=mfButton(false,'javascript:ul()',outIcon('ok32'),'style="float:right"');
	$output.='<input type="file" id="ubId" name="ulInput" class="textInput" style="width:80%">';
	// ack JS function
	if($ackJSFunction) $output.='<input type="hidden" name="ulAckJSFunction" id="ulAckJSFunction" value="'.$ackJSFunction.'">';



	$output.='</form>';

	return $output;
}

/**
 * @desc insert a dropdown menu attached to a button
 *
 * @param string $iconUrl: url of button's icon
 * @param string $caption: button's caption
 * @param string $items: array of items. item has following properties: [id], [icon], caption, onclick, [selected]
 * @return string HTML code
 */
function mfDropDownMenu($iconUrl,$caption,$items){
	$id=cfGenerateID(4);

	$downArrow='<div class="DDMenuIndic"></div>';

	$out=mfButton($downArrow.$caption,"javascript:wl.DDM.toggle('".$id."')",$iconUrl,'id="'.$id.'" style="z-index:1001"',false,array('rawCaption'=>1));

	$out.='<div id="'.$id.'_content" class="DDMenu aniF" style="display:none;height:1px">';
	$nb=0;
	foreach ($items as $item){
		if(!@$item['id']) $item['id']=$id.'_'.$nb;
		$out.='<div id="'.$item['id'].'" onclick="wl.DDM.itemClick(\''.$item['id'].'\');'.$item['onclick'].'">';

		// Icon
		if(isset($item['icon'])) $out.=outImage($item['icon'],false,false,'vertical-align:middle;margin-right:0.5em');

		// Caption
		$out.=@$item['caption'];

		$out.='<span class="'.((@$item['selected'])?'DDMSelIco':'').'" id="'.$item['id'].'_selIco"></span>';

		$out.='</div>';
		$nb++;
	}
	$out.='</div>';
	return $out;
}


/**
 * @desc Insert and async process flash player detection
 *
 */
function mfInsertFlashDetection(){
	if(cfIsAsync()){
		cfAsyncHeader();
		if(isset($_POST['userHasFlash'])) cfBSetVar('flash',($_POST['userHasFlash'])?1:0);
		die(cfAsyncFooter());
	}
?>
<script type="text/javascript">
wl.asr.send({'userHasFlash':(wl.hasFlash())?1:0});
</script>
<?php
}
?>