<?php
/**
 * Transfers (uploads, remote downloads) visualisation scripts
 * Includes :
 * - transfer class
 * - transfer misc functions
 * - a page display script divided into 2 parts :
 * 	- display in a frame (with head and body stuff), self-refreshed with async requests, for inclusion by explorer pages
 * 	- display in div, for inclusion by administration / transfers page
 *
 * Images : view, slideshow, next, prev, fullSize
 * HTML : view webpage (and not source code)
 * text : inline view
 * other formats : download (Opera) or inline view if possible (IE)
 *
* parameters : POST data1 (file directory),  data2 (file name),  data3 (="view"),  data4 (action (optional)),  data5 (parameters (optional))
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.0.0
 */


/**
 * @desc return XML formated sub single caption
 *
 * @param integer $index: sequential index
 * @param string $text: UTF-8 encoded sub
 * @param long $sT: start time (seconds)
 * @param long $eT: end time (seconds)
 * @return string: XML node
 */
function srtNode($index,$text,$sT,$eT){
	return '<sub id="'.$index.'" start="'.$sT.'" end="'.$eT.'">'.cfXMLEncode(cfUTF8Encode($text,false,false))."</sub>";
}

/**
 * @desc Generate and send to output XML formated subtitles
 *
 * @param string $completeFilename: filename of video file
 */
function sfGenerateXMLSubs($completeFilename){
	$completeFilename=cfFileWithoutExtension($completeFilename);
	foreach (array('.srt','.sub','.txt') as $ext){
		if(!@file_exists($completeFilename.$ext)) continue;
		if(!$fp=fopen($completeFilename.$ext,'r')) continue;
		$line=trim(fgets($fp,1024));
		fclose($fp);
		if($line=='0' || $line=='1') return sfGenerateXMLFromSubRip($completeFilename.$ext);
		if(preg_match("/[0-9]{1,2}[:][0-9]{2}[:][0-9]{2}[:]/",$line))  return sfGenerateXMLFromSub1($completeFilename.$ext);
		if(preg_match("/^\{[0-9]{1,7}\}\{[0-9]{1,7}\}/",$line)) return sfGenerateXMLFromSub2($completeFilename.$ext);
		if($line=='[INFORMATION]') return sfGenerateXMLFromSub3($completeFilename.$ext);
	}
	return false;
}

/**
 * @desc generate XML from SRT formated file
 *
 * @param string $completeFilename
 * @return string: XML
 */
function sfGenerateXMLFromSubRip($completeFilename){
	$text=file_get_contents($completeFilename);
	$index=0;
	$line=strtok($text,"\n\r");

	$out='<subtitles>';
	while(1) {
		if($line===false) break;
		// New block
		if(is_numeric($line) && ($line>=$index)) {
			$index=$line;

			$text='';
			$line=strtok("\n\r");
		}
		else {
			$line=strtok("\n\r");
			continue;
		}
		if($line===false) break;

		// Time
		while(count(explode(' --> ',$line))!=2 || !(list($sT,$eT)=explode(' --> ',$line)) || !preg_match("/([0-9]{1,2}[:]){1,2}[0-9]{1,2}[,][0-9]{1,3}/",$sT) || !preg_match("/([0-9]{1,2}[:]){1,2}[0-9]{1,2}[,][0-9]{1,3}/",$eT)){
			$line=strtok("\n\r");
			if($line===false) break 2;
		}
		list($lp,$ms)=explode(',',$sT); list($h,$m,$s)=explode(':',$lp); $sT=$h*3600+$m*60+$s+$ms/1000;
		list($lp,$ms)=explode(',',$eT); list($h,$m,$s)=explode(':',$lp); $eT=$h*3600+$m*60+$s+$ms/1000;
		$line=strtok("\n\r");

		// Subs
		while(!is_numeric($line) || ($line<$index)) {
			if($line===false) break 2;
			$text.='<br>'.$line;
			$line=strtok("\n\r");
		}

		// Output XML
		$out.=srtNode($index, substr($text,4), $sT, $eT);
	}
	return $out.'</subtitles>';
}

/**
 * generate XML from file formated like :
 * h:mm:ss:text
 *
 * @param string $completeFilename
 * @return string: XML
 */
function sfGenerateXMLFromSub1($completeFilename){
	$text=file_get_contents($completeFilename);
	$index=0;
	$out='<subtitles>';
	set_time_limit(3);
	$line=trim(strtok($text,"\n\r"));
	while($line){
		if(preg_match("/[0-9]{1,2}[:][0-9]{2}[:][0-9]{2}[:]/",$line)){
			list($h,$m,$s,$nText)=explode(':',$line,4);
			$eT=$h*3600+$m*60+$s;
			if($index>0) $out.=srtNode($index, $text, $sT, $eT);
			$text=$nText; $sT=$eT;
			if($text=='|') $text='';
			$line=trim(strtok("\n\r"));
			$index++;
		}
	}
	if($index>0) $out.=srtNode($index, $text,$sT,$sT+10);
	return $out.'</subtitles>';
}

/**
 * generate XML from file formated like :
 * {3739}{3806}text
 *
 * @param string $completeFilename
 * @return string: XML
 */
function sfGenerateXMLFromSub2($completeFilename){
	$text=file_get_contents($completeFilename);
	$index=1;
	$out='<subtitles frames="1">';
	set_time_limit(3);
	$line=trim(strtok($text,"\n\r"));
	while($line){
		if(preg_match("/^\{[0-9]{1,7}\}\{[0-9]{1,7}\}/",$line)){
			$sT=substr($line,1,strpos($line,'}')-1);
			$line=substr($line,strpos($line,'{',2)+1);
			$eT=substr($line,0,strpos($line,'}'));
			$text=substr($line,strpos($line,'}')+1);
			$out.=srtNode($index, $text,$sT,$eT);
			$line=trim(strtok("\n\r"));
			$index++;
		}
	}
	return $out.'</subtitles>';
}

/**
 * generate XML from file formated like :
 * [data1]
 * [data2]
 * ...
 *
 *
 * @param string $completeFilename
 * @return string: XML
 */
function sfGenerateXMLFromSub3($completeFilename){
	$text=file_get_contents($completeFilename);
	$index=0;
	$out='<subtitles>';
	$line=trim(strtok($text,"\n\r"));

//	00:01:25.88,00:01:27.63
	// Seek start
	while($line!==false && !preg_match("/^[0-9]{1,2}[:][0-9]{1,2}[:][0-9]{1,2}[.][0-9]{1,3}[,][0-9]{1,2}[:][0-9]{1,2}[:][0-9]{1,2}[.][0-9]{1,3}$/",$line)) {
		$line=strtok("\n\r");
	}
	while ($line!==false) {
		list($sT,$eT)=explode(',',$line);
		list($h,$m,$s)=explode(':',$sT);
		$sT=$h*3600+$m*60+$s;
		list($h,$m,$s)=explode(':',$eT);
		$eT=$h*3600+$m*60+$s;

		$text='';
		$line=trim(strtok("\n\r"));
		while($line!==false && !preg_match("/^[0-9]{1,2}[:][0-9]{1,2}[:][0-9]{1,2}[.][0-9]{1,3}[,][0-9]{1,2}[:][0-9]{1,2}[:][0-9]{1,2}[.][0-9]{1,3}$/",$line)) {
			if(strlen($line)) $text.='<br>'.str_replace('[br]','<br>',trim($line));
			$line=strtok("\n\r");
		}
		// Output XML
		$out.=srtNode($index, substr($text,4), $sT, $eT);
	}
	return $out.'</subtitles>';
}
?>