<?php
/**
 * Configuration backup / restore script
 *
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2013 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 2.1.0
 */

define('BACKUP_PLUGIN_SCRIPTS',0);
define('BACKUP_TEMP_FILENAME','configBackup.zip');

function configBackupExtension($cfn){
	global $zip;

	if(filemtime($cfn)>$_ENV['configBackupExtensionMTime']) $zip->add_file($cfn, substr($cfn,strlen(cfAppDocRoot())-3));
}


/**
 * @desc Generate backup (weezoBackup.zip) and send to browser
 *
 */
function configBackupPrepare(){
	global $zipFiles;
	global $zipDeflatedSize;

	$zipFiles=array();
	$zipDeflatedSize=0;
	cfMSetVar('backupId',rand()); // Generate a unique id to detect if user requests another generation while current is not completed

	function configBackupExtension2($cfn){
		global $zipFiles;
		global $zipDeflatedSize;

		if(filemtime($cfn)>$_ENV['configBackupExtensionMTime']) addFileToZipList($cfn, substr($cfn,strlen(cfAppDocRoot())-3));
	}

	/**
	 * @desc Add file to list of files to be zipped, and compute total deflated size
	 */
	function addFileToZipList($cfn,$relative){
		global $zipFiles;
		global $zipDeflatedSize;

		if(!isset($zipFiles[$cfn])){
			$zipFiles[$cfn]=$relative;
			$zipDeflatedSize+=filesize($cfn);
		}
	}

	/**
	 * Recursively process folders for config files, add those files to zip
	 * @param string $dir: directory to process (no trailing /)
	 * @param string $baseZipname: path in zip (trailing /)
	 */
	function recurseProcess($dir, $baseZipname){
		global $zipFiles;
		global $zipDeflatedSize;

		static $include=array('','sqlite','txt','db','xml','res','subuser','usr');

		foreach (cfGlob($dir.'/*.*') as $cfn){
			$filename=basename($cfn);

			if(is_dir($cfn)) recurseProcess($cfn,$baseZipname.$filename.'/');
			else{
				$ext=cfFileExtension($filename);
				if(in_array(cfFileExtension($filename),$include)) addFileToZipList($cfn, $baseZipname.$filename);
			}
		}

	}

	$exeptions=array('Thumbs.db', 'filesCache.db','audioCacheV3.db','connectionAttempts.txt','general.ini.bak');


	// Add /data directory content (files) to zip
	foreach (cfGlob(cfAppDataDir().'/*.*') as $cfn){
		$filename=basename($cfn);
		if(is_file($cfn) && !in_array($filename,$exeptions)) addFileToZipList($cfn, 'data/'.$filename);
	}

	// Save resource data
	foreach (cfGlob(cfAppDataDir().'/res/*.*') as $tmpCfn){
		$type=basename($tmpCfn);
		if(is_dir($tmpCfn)) recurseProcess($tmpCfn,'data/res/'.$type.'/');
	}

	recurseProcess(cfAppDataDir().'/groups','data/groups/');
	recurseProcess(cfAppDataDir().'/users','data/users/');
	recurseProcess(cfAppDataDir().'/res','data/res/');
	recurseProcess(cfAppDataDir().'/res','data/mysqldata/');

	// Save extensions uploaded data
	if(0&&cfConstant('BACKUP_EXTENSIONS')) foreach (cfGlob(cfAppDocRoot().'/res/misc/*.*') as $tmpCfn) if(is_file($tmpCfn.'/describer.ini')){
		$_ENV['configBackupExtensionMTime']=filemtime($tmpCfn.'/describer.ini');
		cfRecurseBrowse($tmpCfn,'configBackupExtension2');
	}


	// Add MySQL config
	/*
	if(is_dir(cfAppDataDir().'/mysqldata/data')){
		$exeptions=array('Thumbs.db', 'filesCache.db','audioCacheV3.db','connectionAttempts.txt','general.ini.bak');

		// Add MySQL data dir
		foreach (cfGlob(cfAppDataDir().'/mysqldata/data/*.*') as $dir){
			if(is_dir($dir)){
				$dirBasename=basename($dir);

				foreach (cfGlob($dir.'/*.*') as $cfn){
					$filename=basename($cfn);
					addFileToZipList($cfn, 'MySQL/data/'.$dirBasename.'/'.$filename);
				}
			}
		}

		// Add files located directly into MySQL data dir (must be included after subdir contents, else zip fails)
		foreach (cfGlob(cfAppDataRootDir().'/MySQL/data/*.*') as $file){
			if(!is_dir($file)) addFileToZipList($file, 'MySQL/data/'.basename($file));
		}

		// MySQL config
		addFileToZipList(cfAppDataRootDir().'/MySQL/my.ini', 'MySQL/my.ini');

		// Weezo / MySQL users / passwords
		addFileToZipList(cfAppDataRootDir().'/MySQL/MySQL.ini', 'MySQL/MySQL.ini');
	}
	*/

	// Store for configBackupGenerate()
	cfMSetVar('backupFiles',$zipFiles);
	cfMSetVar('backupProgress',array('total'=>$zipDeflatedSize,'processed'=>0));

	echo cfAsyncJSaction('configBackupStart('.$zipDeflatedSize.')');


	// And launch generation script
	cfPHPAsyncScript('/local/uiConfig.php',50,false,array('post'=>'command=backupGenerate'));

	return;
}

/**
 * @desc Generate backup zip
 *
 */
function configBackupGenerate(){
	ignore_user_abort(true);
	wSession_write_close(false);

	// Create zip object
	include(INCLUDE_DIR.'/zip.php');
	ob_start();
	$zip = new zipfile2();
	$zip->setCompressionLevel(7);

	// Open file for output
	if(!($fp=fopen(cfAppTempDir().'/'.BACKUP_TEMP_FILENAME,'w'))){
		cfMSetVar('backupProgress',array('total'=>-1,'processed'=>0));
		exit;
	}

	// Retrieve files list
	$zipFiles=cfMGetVar('backupFiles');
	$backupProgress=cfMGetVar('backupProgress');
	$zipDeflatedSize=$backupProgress['total'];
	$totalZiped=0;
	$backupId=cfMGetVar('backupId');

	// Start zipping
	foreach ($zipFiles as $cfn=>$rel){
		$zip->add_file($cfn,$rel);

		fwrite($fp,ob_get_contents());
		ob_clean();

		$totalZiped+=filesize($cfn);

		// User requested another zip file generation
		if($backupId!==cfMGetVar('backupId')) {
			fclose($fp);
			exit;
		}

		cfMSetVar('backupProgress',array('total'=>$zipDeflatedSize,'processed'=>$totalZiped));
	}

	$zip->file();
	fwrite($fp,ob_get_clean());

	fclose($fp);

	cfMSetVar('backupProgress',array('total'=>$zipDeflatedSize,'processed'=>$zipDeflatedSize));
}

/**
 * Async monitoring of backup file creation: echo script for updating progress
 *
 */
function configBackupMonitor(){
	$backupProgress=cfMGetVar('backupProgress');
	$zipDeflatedSize=$backupProgress['total'];
	$processed=$backupProgress['processed'];

	if($zipDeflatedSize<0) echo cfAsyncJSaction("configBackupUpdate(-1)");
	else echo cfAsyncJSaction("configBackupUpdate(".(floor(1000*$processed/$zipDeflatedSize)/1000).")");
}

/**
 * @desc Send generated zip file to browser
 *
 */
function configBackupDownload(){
	$zipFile=cfAppTempDir().'/'.BACKUP_TEMP_FILENAME;

	WHeaders::contentType('zip');
	header('Content-Disposition: attachment; filename="Weezo Backup.zip"');
	header('Content-Length: '.filesize($zipFile));

	echo file_get_contents($zipFile);

	cfMUnsetVar('backupProgress');
	cfMUnsetVar('backupId');
	@unlink($zipfile);
	exit;
}

/**
 * @desc Restore a Weezo configutation from a backup file
 * 		Backup file is a zip file containing relevant files from cfAppDataDir /data & /MySQL folders
 *
 * @param string $sourceFile: zip file path & name
 */
function backupRestore(){
	$sourceFile='';
	foreach ($_SERVER['argv'] as $k=>$v) if($k!=0) $sourceFile.=' '.$v;
	$sourceFile=str_replace('\\','/',trim($sourceFile));
	if(!cfCmpLeft($sourceFile,'restore=')) die('<result>'.cfCaption('configInvalidFile').'</result>');
	$sourceFile=substr($sourceFile,8);

	if(!is_file($sourceFile)) die('<result>'.cfCaption('configInvalidFile').'</result>');

	/**
	 * Check zip-file validity
	 */
	if(!($zip=@zip_open($sourceFile))) die('<result>'.cfCaption('configInvalidFile').'</result>');

	$totalSize=0;

	// Search for general.ini file and compute total size (to display progress bar)
	while ($zip_entry = @zip_read($zip)) {
		if(@zip_entry_open($zip, $zip_entry, 'r')) {
			if(zip_entry_name($zip_entry)=='data/general.ini') $found=1;
			zip_entry_close($zip_entry);
			$totalSize+=zip_entry_filesize($zip_entry);
		}
	}
	@zip_close($zip);
	if(!isset($found)) die('<result>'.cfCaption('configInvalidFile').'</result>');


	/**
	 * Clear previous configuration
	 */

	// Empty data dir
	foreach (cfGlob(cfAppDataDir().'/*.*') as $cfn) if(!is_dir($cfn)) @unlink($cfn);
	// Empty sessiondata dir
	foreach (cfGlob(cfAppDataDir().'/sessiondata/*.*') as $cfn) if(!is_dir($cfn)) @unlink($cfn);
	// Empty temp upload dir
	foreach (cfGlob(cfAppDataDir().'/sessiondata/upload_tmp_dir/*.*') as $cfn) if(!is_dir($cfn)) @unlink($cfn);
	// Empty extensions sessions dir
	foreach (cfGlob(cfAppDataDir().'/sessiondata/extensions/*.*') as $cfn) if(!is_dir($cfn)) @unlink($cfn);
	// Empty extensions sessions dir
	foreach (cfGlob(cfAppLogDir().'/*.*') as $cfn) if(!is_dir($cfn)) @unlink($cfn);
	// Empty temp dir
	foreach (cfGlob(cfAppDataDir().'/temp/*.*') as $cfn) if(!is_dir($cfn)) @unlink($cfn);
	// Remove resources data
	foreach (cfGlob(cfAppDataDir().'/res/*.*') as $cfn) if(is_dir($cfn)) cfUnlinkDir($cfn); else @unlink($cfn);

	// Remove groups
	foreach (cfGlob(cfAppLogDir().'/groups/*.*') as $cfn) @unlink($cfn);
	// Remove subUsers
	foreach (cfGlob(cfAppLogDir().'/users/*.*') as $cfn) @unlink($cfn);

	$base=dirname(cfAppDataDir()).'/';

	/**
	 * Unzip
	 */

	// Re-open zip file
	$zip=@zip_open($sourceFile);
	while($zip_entry = @zip_read($zip)) {
		//$i++;updatePage('progress',$i.' '.cfCaption('genFiles'));
		if(@zip_entry_open($zip, $zip_entry, 'r')) {
			$dirname=dirname(zip_entry_name($zip_entry));

			// Create dir if needed
			$dirs=explode('/',$dirname);
			$dirname=$base.$dirname;
			$dir=$base;

			if(!is_dir($dirname)) for($o=0;$o<count($dirs);$o++) {
				$dir.=$dirs[$o].'/';
				if(!is_dir($dir)) mkdir($dir);
			}

			if($handle=fopen($dirname.'/'.basename(zip_entry_name($zip_entry)),'w')){
				@fwrite($handle,zip_entry_read($zip_entry, zip_entry_filesize($zip_entry)));
				fclose($handle);
			}
			zip_entry_close($zip_entry);
		}
	}
	zip_close($zip);
	die('<result>OK</result>');
}

//if(isset($_GET['restore']) && cfIsCLI()) cfDbg($_GET['restore']);
//cfDbg($_GET);

// Restore config
if(isset($_GET['restore']) && cfIsCLI()) backupRestore($_GET['restore']);

// Backup config
if(isset($_GET['save']) && cfIsInApp()) configBackupSend();