<?php
/**
 * User Interface Configuration tab
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 2.1.0F
 */
if(!cfIsInApp()) die('Unauthorized access');

require(INCLUDE_DIR.'outputFunctions.php');
require(INCLUDE_DIR.'resourceConfigFunctions.php');
require('uiConfig/general.php');
require('uiConfig/misc.php');
require('uiConfig/server.php');
require('uiConfig/theme.php');

$resourceData=cfParse_ini_file(cfAppDataDir().'/general.ini');

/**
 * @desc Advanced configuration toggle button
 *
 * @param string $frame: frame's name (general, server, theme, misc)
 */
function uiConfigAdvancedConfigButton($frame){echo outBt(cfCaption('genBack'),outIcon('back'),'javascript:goBack()',$frame.'backBt',false,'style="position:absolute;right:20px;top:5px"');}

/**
 * Echo code for advanced config frame
 *
 * @param string $frame's name
 */
function uiConfigAdvancedFrameHeader($frame){
	global $resourceData;

	echo '<br><br><br>'.outConfigSeparator();
	echo '<div id="acFrame'.$frame.'" class="advancedConfig">';
	echo '<div class="frame2Header">'.outImageIcon('advancedConfig').cfCaption('configAdvanced').'</div><br>';
	//echo '<div id=""acFrameMask'.$frame.' class="acFrameMask"></div>';

}

/**
 * Query registry to get actual context menu integration
 * @return true if context menu set, false if not
 */
function uiConfigCMisSet(){
	if(function_exists('customQueryRegistry')) return ((customQueryRegistry("HKEY_CLASSES_ROOT",".weezoResource",""))?true:false); // Custom function, works
	if(!function_exists('reg_open_key')) return false;
	if($mainKey=@reg_open_key(HKEY_CLASSES_ROOT,'.weezoResource')){ // Doesn't work with VC9 executables
		reg_close_key($mainKey);
		return true;
	}
	return false;
}

/**
 * @desc Display clickable link to application folders
 *
 * @param string $folder
 */
function uiConfigDirLink($name,$returnLinkOnly=false){
	switch ($name){
		case 'bin': $link=cfAppBinDir(); break;
		case 'apache': $link=cfAppServerDir(); break;
		case 'php': $link=cfAppRootDir().'/PHP'; break;
		case 'data': $link=cfAppDataDir(); break;
		case 'www': $link=cfAppDocRoot(); break;
		case 'wallpapers': $link=cfAppDocRoot().'/gfx/wallpapers'; break;
	}
	if($returnLinkOnly) return str_replace('/','\\',$link); else return '<a href="javascript:openFolder(\''.$name.'\')" class="link">'.str_replace('/','\\',$link).'</a>';
}

/**
 * @desc Process commands
 *
 */
function processCommands(){
	if(!isset($_POST['command']) && !isset($_GET['command'])) return;
	$command=(isset($_POST['command']))?$_POST['command']:$_GET['command'];
	if(cfIsAsync()) cfAsyncHeader();

	// Open local folder: path is prefixed by shellOpenFolder:
	if(cfCmpLeft($command,'shellOpenFolder:')) list($command,$folder)=explode(':',$command);

	switch ($command){
		case 'viewLog':
			if($_POST['logName']==HTTPD_ACCESS_LOG_FILE||$_POST['logName']==HTTPD_ERRORS_LOG_FILE){
				cfExecFork('notepad.exe','SW_SHOWNORMAL','"'.str_replace('/','\\',cfAppLogDir().'/'.$_POST['logName']).'"');
			}
			break;
		case 'APCStats':
			header('Location: /local/apc.php');
			exit;
		case 'phpInfo':
			uiConfigPhpInfoPage();
			break;
		case 'shellOpenFolder':
			cfExecFork('explorer','SW_SHOWNORMAL','"'.uiConfigDirLink($folder,true).'"');
			break;
		case 'testServerAccess':
			cfServerSendCmd('testServerAccess');
			break;
		case 'restartServer':
			cfServerSendCmd('restartServer');
			break;
		case 'setSimpleMode':
			cfGUpdateVar('simpleMode',true);
			echo cfAsyncJSaction('top.location.reload()');
			break;
		case 'setNormalMode':
			cfGUpdateVar('simpleMode',false);
			echo cfAsyncJSaction('top.location.reload()');
			break;

		// Create configuration backup and redirect browser to configuration download
		/**
		 * Backup
		 * 1) Generate files list, compute total size (async)
		 * 2) Generate Archive
		 * 3) Download archive (sync)
		 */
		case 'backupStart':
			require(cfAppDocRoot().'/local/configBackup.php');
			configBackupPrepare();
			break;
		// Start generating zip (called as an async PHP script with cfPHPAsyncScript)
		case 'backupGenerate':
			require(cfAppDocRoot().'/local/configBackup.php');
			configBackupGenerate();
			break;
		// Monitor zip progress
		case 'backupMonitor':
			require(cfAppDocRoot().'/local/configBackup.php');
			configBackupMonitor();
			break;
		// (sync) download generated zip
		case 'backupDownload':
			require(cfAppDocRoot().'/local/configBackup.php');
			configBackupDownload();
			break;
	}
	if(cfIsAsync()) die(cfAsyncFooter()); else exit;
}

/**
 * @desc Process updated data
 */
function uiConfigProcessUpdatedData(){
	global $resourceData, $originalResourceData;

	// Correct a few things
	if(@$resourceData['startWithWindows']==='false') $resourceData['startWithWindows']=false;
	if(@$resourceData['startWithWindows']==='true') $resourceData['startWithWindows']=true;

	// Special stuff
	foreach (rcGetUpdatedValues() as $k=>$v){
		switch ($k){
			case 'language':

				// Remove previous language from memory
				cfMUnsetVar('weezoLng'.cfGGetVar('language'));
				cfMUnsetVar('weezoLng'.cfGGetVar('languageUI'));

				// Update ui language value
				cfGUpdateVar('languageUI',$v,'serverOnly');

				// Indicate page must be reloaded
				$_ENV['uiConfigSyncReloadPage']=1;
				break;
			case 'serverPort':
				break;
			case 'audioProfile':
				$v=str_replace('.','',$v);
				if(is_dir(cfAppDocRoot().'/snd/'.$v)) cfServerSendCmd('userModifiedAudioProfile',array('newProfile'=>$v));
				else unset($resourceData[$k]);
				break;
		}
	}

	// Save and update in application
	foreach (rcGetUpdatedValues() as $k=>$v) cfGUpdateVar($k,$v,true,true);
}

/**
 * @desc Show top controls (language & about button)
 *
 */
function topControls(){
	global $resourceData;

	$languages=array();

	// Parse language files
	foreach (cfGlob(cfAppDocRoot().'/includes/lng/*.php') as $cfn){
		$fc=file_get_contents($cfn);
		$languageId=cfFileWithoutExtension(basename($cfn));
		$languages[]=$languageId;
		$pos=strpos($fc,'$w_lng[\'languageName\']=\'')+24;
		$languageName=substr($fc,$pos,strpos($fc,"'",$pos)-$pos);
		$options[]=array($languageId,$languageName,'/includes/lng/'.$languageId.'.gif');
		$values[]=$languageId;
	}

	// Language
	echo '<div id="languageCont" style="position:absolute;bottom:50%;right:33px;margin-bottom:4px">';
	rcProcessData('language',dataList,cfGGetVar('language'),$values,array(
		array(false,cfCaption('configLanguage')),
		$options,
		false),false);

	echo '</div>';
}



/**
 * @desc Display simple configuration frame
 *
 */
function uiConfigFrameSimple(){
	global $resourceData;

	echo outDivframe('frame1',false,'background:white;height:100%');

	/**
	 * Server parameters
	 */

	// Server status (online or online, LAN) (only compute on sync display to save CPU)
	$status=cfCaption('apacheStartedWeb').outHelpTag(cfCaption('startServerWebDet'));
	if(!cfIsAsync())  $onLan=strpos(file_get_contents(cfAppDataDir().'/httpd.conf'),'#onLAN');
	if(@$onLan) $status=cfCaption('apacheStartedLocal').outHelpTag(cfCaption('startServerLocalDet'));
	$status.=outImageIcon('ok',false,'margin-left:0.5em');

	// Restart button
	$serverButtons=outBt(cfCaption('adminRestart'),outIcon('reload2'),"javascript:uiConfigWaitMask();wl.UICommand('serverRestart')",false,false,'style="margin-left:2em"');

	// Server icon and status
	?>
	<div class="frame1Header" style="position:relative"><?php
	echo outImage(outIcon('configServer'),false,false,'margin-right:0.5em;vertical-align:top;cursor:pointer;margin-top:10px');
	echo '<fieldset>'.cfCaption('mainServer').'<br><span style="color:black;font-size:80%"><b>'.cfCaption('genStatus').cfCaption('genSeparator').'</b>'.$status.'</span></fieldset>';
	echo $serverButtons;
	?>
	</div>
	<?php

	if(@$resourceData['UPnPEnabled'] && @$resourceData['UPnPMappingOK']) $UPnPState='ok';
	elseif($resourceData['UPnPEnabled']) $UPnPState='nok';
	else $UPnPState='n/a';


	// UPnP mapping
	echo '<div style="position:absolute;top:3px;right:10px">';
	echo outImageIcon('upnp');
	rcProcessData('UPnPEnabled',dataBoolean,true,false,cfCaption('UPnPUse'),false,false);
	echo outImageIcon('ok','id="UPnPOK"','visibility:'.(($UPnPState=='ok')?'visible':'hidden'));
	echo outImageIcon('loading','id="UPnPLoading"','visibility:hidden');
	echo '</div>';
	echo '<br>';

	// UPnP failure warning
	echo '<div class="extendedWarning" style="text-align:center;display:'.(($UPnPState=='nok')?'block':'none').';margin-bottom:0.4em" id="UPnPWarning">'.outImageIcon('warning').'<b>'.cfCaption('UPnPFailed').'</b><br>'.cfCaption('UPnPFailedDetail').'</div>';


	// MAIN SERVER PORT
	echo '<div class="extendedInfo2" style="margin-bottom:0.4em"><br><span class="bigFont" style="margin-right:4em">';
	rcProcessData('serverPort',dataNumeric, cfGGetVar('serverPort'), array(1,65535), array(cfCaption('configServerPort'),2), false, false,array('apply'=>1));
	echo '</span>';

	// SSL
	echo cfCaption('configSecureWithSSL');
	rcProcessData('protocol',dataList, cfGGetVar('protocol'), array('http','https'),array(
			array(false,'https',cfCaption('genYes')),
			array(false,'http',cfCaption('genNo'))
		)
		,false, false);
	echo '<br>&nbsp;</div><br>';

	// BitTorrent seeder config
	echo outImageIcon('bittorrent');
	rcProcessData('bittorrentEnabled',dataBoolean,true,false,cfCaption('bittorrent'),false,false);
	rcProcessData('bittorrentPort',dataNumeric, 6996, array(1,65535), array(cfCaption('genPort'),2), true, false,array('apply'=>1));
	echo '<br><br>';


	/**
	 * General parameters
	 */
	?>
	<div class="frame1Header" style="position:relative"><?php
	echo outImage(outIcon('appIcon32'),false,false,'margin-right:0.5em;vertical-align:middle').cfCaption('configApplication');
	?></div><br>
	<?php
	echo '<div class="extendedInfo" style="margin-bottom:0.4em"><br>';
	// Weezo start mode
	if(cfUACPresent()) echo outImageIcon('uac');
	rcProcessData('startWithWindows',dataList,false,array(true,false,'service'),array(
		array(false,cfCaption('configApplicationStartMode')),
		array(
			array('true',cfCaption('configStartWindows')),
			array('service',cfCaption('configStartService')),
			array('false',cfCaption('configStartManual'))
		),
		false),false);

	echo outBt(cfCaption('configDefaultTheme'),outIcon('theme'),'javascript:wl.UICommand(\'webPopup:/local/themeSelection.php\');',false,false,'style="margin-left:5em"');

	// Parse language files
	foreach (cfGlob(cfAppDocRoot().'/includes/lng/*.php') as $cfn){
		$fc=file_get_contents($cfn);
		$languageId=cfFileWithoutExtension(basename($cfn));
		$pos=strpos($fc,'$w_lng[\'languageName\']=\'')+24;
		$languageName=substr($fc,$pos,strpos($fc,"'",$pos)-$pos);
		$options[]=array($languageId,$languageName,'/includes/lng/'.$languageId.'.gif');
		$values[]=$languageId;
	}

	// Language
	echo '<span id="languageCont" style="margin-left:7em">';
	rcProcessData('language',dataList,cfGGetVar('language'),$values,array(
		array(false,cfCaption('configLanguage')),
		$options,
		false),false);

	echo '</span>';


	echo '</div>';


	/**
	 * Test server access
	 */
	echo '<div class="extendedInfo2" style="text-align:center;margin-top:1em"><br>';
	echo '<div style="cursor:pointer;width:200px" onclick="wl.UICommand(\'testServerAccess\')">'.outImage(outIcon('UI/configServerTest')).'<br><br><div class="bigFont">'.cfCaption('startTestServerAccess').'</div>';
	echo '</div>';

	echo '</div>';
}

/**
 * @display wrapper around config frames
 *
 * @param string $frameName: name of frame (general, server, theme, misc)
 */
function uiConfigFrame($frameName){
	echo '<div id="'.$frameName.'_outer" class="uiConfigFrame"><div class="configFramePadding">';
	$functionName='uiConfigFrame'.ucfirst($frameName);
	call_user_func($functionName);
	echo '</div>';
	echo '</div>';

}





/**
 * @desc Display wrapper around config options blocks
 *
 * @param string $blockName
 */
function uiConfigBlock($blockName){
	$functionName='uiConfigBlock'.ucfirst($blockName);
	$block=call_user_func($functionName);
?>
<td id="block<?php echo $blockName;?>"><div class="itemUnsel <?php echo $blockName.((isset($block['extraTheme']))?' '.@$block['extraTheme']:'').'"'; if($block['action']){?> onmouseover="mi(this)" onmouseout="mo(this)" onclick="<?php echo $block['action']; ?>"<?php }?>>
	<div class="frame1Header"><?php echo $block['title'];?></div>
	<?php echo $block['content'];?>
</div>
</td>
<?php
}

/**
 * @desc Return data for server access test block
 *
 * @return array(title,content,action)
 */
function uiConfigBlockServerTest(){
	$title='';
	$content='<div style="cursor:pointer;position:absolute;top:35%;left:25%;margin-top:0px;margin-left:0px;width:50%" onclick="wl.UICommand(\'testServerAccess\')"><img src="'.(outIcon('UI/configServerTest2')).'" style="width:100%"><br><br><div class="bigFont">'.cfCaption('startTestServerAccess').'</div></div>';

	// Tmp profile button
	/*
	$content.='<div style="position:absolute;top:3px;left:3px">';
	$content.=outButton(cfCaption('configAccountEdit'),"javascript:wl.UICommand('webPopup:/local/registrationForm.php');",outIcon('appIcon16'));
	$content.='</div>';
	*/

	// About button
	$content.='<div style="position:absolute;top:3px;right:3px">';
	$content.=outBt(cfCaption('mainAbout'),outIcon('appIcon16'),"javascript:void(wl.UIWebPopup('/local/uiConfig/credits.php'))");
	$content.='</div>';
	$action=false;
	$extraTheme="itemLight";

	return array('title'=>$title,'content'=>$content,'action'=>$action,'extraTheme'=>$extraTheme);
}

/**
 * @desc Return data for general block
 *
 * @return array(title,content,action)
 */
function uiConfigBlockPlugins(){
	$title='';
	$content='';
	$content.='<div style="position:absolute;top:50%;left:50%;margin-left:-60px;margin-top:-70px;cursor:pointer;text-align:center" onclick="wl.UICommand(\'webPopup:/local/pluginsManagement.php\')">'.outImage(outIcon('UI/configPlugins')).'<br><br><div class="bigFont">'.cfCaption('resMisc').'</div></div>';
	$action="";
	$extraTheme="itemLight";

	return array('title'=>$title,'content'=>$content,'action'=>$action,'extraTheme'=>$extraTheme);
}

// Process sync & async commands
processCommands();

// Start buffering output for discarding
if(cfIsAsync()) ob_start();

/**
 ***************************************************************************************************************************
 * Display page
 ***************************************************************************************************************************
 */
if(!cfIsAsync()) cfInsertHEAD(false);
?>
<style type="text/css">
#layoutTable{width:100%;height:100%;padding:0;margin:0; border-spacing:0px;table-layout:fixed}
#layoutTable td{height:50%;position:relative;width:33%;vertical-align:middle;cursor:pointer;padding:5px}
#layoutTable .frame1Header{position:absolute;top:10px;left:10px}
.uiConfigFrame{display:none;position:absolute;width:100%;height:100%;overflow:auto;padding:0;margin:0;background:white}
.configFramePadding{margin:10px}
.itemUnsel, .itemSel{text-align:center;position:relative;display:block;height:100%;background:#FAFAFA !important}
.itemUnsel .frame1Header, .itemSel .frame1Header{font-size:170%;font-weight:normal}
.itemLight{background:none !important; border:0px !important;cursor:default !important}
.general{}
.misc{}
.itemSel{background:#EEE !important;border:1px solid #BBB !important}

.simpleModeHandle,.normalModeHandle{padding:0;border:0;vertical-align:bottom !important;text-align:top;font-size:14px}
.simpleModeHandle{background:#1a8134 url("/themes/skins/default/simpleModeHandle.gif");padding:0;border:0;vertical-align:bottom !important;text-align:center}
.simpleModeHandle div, .normalModeHandle div{white-space:nowrap;color:white;font-weight:bold}
.normalModeHandle{background:#ce4726 url("/themes/skins/default/normalModeHandle.gif")}
</style>
<script type="text/javascript">
var uiConfigCMI=[
	ContextMenuItem('<?php echo outIcon('v');?>','<?php echo outImage(outIcon('configSave'),false,false,'width:32px').cfCaption('saveConfiguration');?>',"configBackupPrepare()"),
	ContextMenuItem('<?php echo outIcon('v');?>','<?php echo outImage(outIcon('configRestore'),false,false,'width:32px').cfCaption('restoreConfiguration');?>',"wl.UICommand('restoreconfig')")];
<?php
// Insert up/right/down/left icons
echo cfJSIconURL('left');
echo cfJSIconURL('up');
echo cfJSIconURL('right');
echo cfJSIconURL('down');
echo cfJSIconURL('loading');
?>
</script>
</head>
<body style="margin:0;padding:0;width:100%;height:100%;overflow:hidden" id="uiConfigBody">
	<div class="popup" id="backupProgress" style="display:none;position:absolute;top:40%;left:30%;width:40%;height:100px">
	<div class="popupHeader"><?php echo outImageIcon('save').cfCaption('backup');?></div>
	<br>
	<center>
	<br>
	<?php
	echo outProgressBar(0,'80%','-','backupPB');
	?>
	</center>
	<?php echo outBt(cfCaption('genCancel'),false,'javascript:configBackupDone()','configBackupCancelBt',false,'style="display:none"');?>
	<br>
	</div>

<input type="hidden" id="UIScript" name="UIScript" onkeyup="eval(this.value)">
<?php

// Javascript
echo cfScriptLink('uiConfig.js',true);
echo cfScriptLink('wz_dragdrop.js');

echo outLoadMask(false); if(!cfIsAsync()) flush();

$_ENV['buttonLessConfig']=true; // immediately commit changes
rcInsertScriptAndForm();

/**
 ***************************************************************************************************************************
 * Main layout table
 ***************************************************************************************************************************
 */
// <img style="width:100%;position:absolute;bottom:0;right:0" src="/gfx/UI/uiBg2.jpg" id="uiBgImage">

?>
<div id="blocksDiv" style="position:absolute;width:100%;height:100%">
<table id="layoutTable" border="0">
<tr>
<?php

// Simple mode config
if(cfSimpleMode()){
	echo '<td class="normalModeHandle" onclick="wl.asr.send({\'command\':\'setNormalMode\'})" style="width:24px" '.outToolTip(cfCaption('normalModeDet'),cfCaption('normalMode'),false,true).'><div class="vertical">'.outImageIcon('resources').outImageIcon('users').outImageIcon('contacts').outImageIcon('activity').outImageIcon('gears').cfCaption('normalMode').'</div></td>';
	echo '<td style="vertical-align:top;width:99%;height:100%">';
	echo '<div style="height:100%;overflow:auto;overflow-x:hidden;cursor:auto">';
	uiConfigFrameSimple();
	echo '</div>';
	echo '</td>';
}
// Normal bloc config (except if a given tab is forced through GET parameter)
elseif(!isset($_GET['tab'])){
	uiConfigBlock('general');
	uiConfigBlock('server');
	uiConfigBlock('serverTest');
	echo '<td class="simpleModeHandle" rowspan="2" onclick="wl.asr.send({\'command\':\'setSimpleMode\'})" style="width:24px" '.outToolTip(cfCaption('simpleModeDet'),cfCaption('simpleMode'),false,true).'><div class="vertical">'.outImageIcon('resources').cfCaption('simpleMode').'</div></td>';
	echo '</tr><tr>';
	uiConfigBlock('theme');
	uiConfigBlock('plugins');
	uiConfigBlock('misc');
}
?>
</tr></table>
<?php

// Show top controls (language & about button)
if(!cfSimpleMode()) topControls();
?>
</div>
<div id="waitCursorMask" style="position:absolute; background: white; top:0;left:0;width:99%;height:100%;<?php echo outCssOpacity(1); ?>;cursor:wait; display:none">&nbsp;</div><?php ?>
<?php

if(!cfSimpleMode()){
	/**
	 ***************************************************************************************************************************
	 * General preferences
	 ***************************************************************************************************************************
	 */
	uiConfigFrame('general');

	/**
	 ***************************************************************************************************************************
	 * Server config
	 ***************************************************************************************************************************
	 */
	uiConfigFrame('server');

	/**
	 ***************************************************************************************************************************
	 * Theme & appearance
	 ***************************************************************************************************************************
	 */
	uiConfigFrame('theme');

	/**
	 ***************************************************************************************************************************
	 * Misc. & advanced configuration
	 ***************************************************************************************************************************
	 */
	uiConfigFrame('misc');
}

// Save / cancel hidden buttons
echo rcButtonSaveCancel();

// Process updated data
uiConfigProcessUpdatedData();

cfDragRegisterItems();

// Async processing: discard sync output
if(cfIsAsync()){
	ob_end_clean();
	echo cfAsyncHeader();
	if(@$_ENV['uiConfigSyncReloadPage']) echo cfAsyncJSaction('document.location.reload()');
	die(cfAsyncFooter());
}

// Pre-selected tab: show
if(isset($_GET['tab'])){?><script type="text/javascript">showFrame('<?php echo $_GET['tab'];?>',0,0,true)</script><?php }
?>