<?php
/**
 *
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 2.0.0
 */

define('EVENTS_FRAME_HEIGHT',145); // Height of event config table, in pixels

/**
 * @desc Process POST command
 *
 */
function processPOST(){
	if(cfIsAsync()){

		cfAsyncHeader();
		if(isset($_POST['actionFtp'])) $_POST['action']=$_POST['actionFtp'];
		if(isset($_POST['actionGrowl'])) $_POST['action']=$_POST['actionGrowl'];

		switch (@$_POST['action']){
			/**
			 * Change events / callback associations
			 */
			case 'eventCBApply':
				// Get output / events mapping
				$logEventConfig=array();
				foreach ($_POST as $k=>$v) if(cfCmpLeft($k,'logEvent_')){
					@list($foo,$eventOutput,$eventId)=explode('_',$k);
					$logEventConfig[$eventOutput][$eventId]=$v;
				}
				cfLogEventConfigSave($logEventConfig);
				break;

			/**
			 * Twitter
			 */
			case 'eventTwitterApply':
			case 'twitterCheckAccount':
				// Check Twitter account
				$account=cfUTF8Decode($_POST['twitterAccount'],true,false,false);
				$password=cfUTF8Decode($_POST['twitterPassword'],true,false,false);
				$twitterDisplayIP=$_POST['twitterPassword'];

				// Mandatory data
				if(!$password || !$account) break;

				require_once(INCLUDE_DIR.'twitter.lib.php');
				// Retreive saved config
				@list($prevTwitterAccount, $prevTwitterPassword,$prevTwitterDisplayIP)=twitterGetConnectionData();

				// If config has changed...
				if(@$_POST['action']=='twitterCheckAccount' || $prevTwitterAccount!=$account || $prevTwitterPassword!=$password || @$prevTwitterDisplayIP!=$twitterDisplayIP){
					// Account or password changed: connect to Twitter and check new values
					if(@$_POST['action']=='twitterCheckAccount' || $prevTwitterAccount!=$account || $prevTwitterPassword!=$password){
						if($twitterOK=twitterCheck($account,$password,$tooManyCnx))
							echo cfAsyncXMLJSaction('twitterCheckResult(1)');
						else{
							if($tooManyCnx)
								echo cfAsyncXMLJSaction('twitterCheckResult(-1)');
							else
								echo cfAsyncXMLJSaction('twitterCheckResult(0)');
						}
					}
					else $twitterOK=1;
					// Save twitter account and password
					if($_POST['action']=='eventTwitterApply') twitterSaveConnectionData($_POST['twitterAccount'],$_POST['twitterPassword'],$_POST['twitterDisplayIP']);
				}
				else $twitterOK=1;

			break;


			/**
			 * GROWL
			 */
			case 'eventGrowlApply':
			case 'growlTestConnection':
				$growlConfig['displayIP']=((isset($_POST['growlDisplayIP']))?1:0);
				$growlConfig['password']=@$_POST['growlPassword'];
				if($_POST['action']==='eventGrowlApply') {
					$growlConfig=cfStoredPasswordCrypt(serialize($growlConfig));
					break;
				}
				// Test connection
				try {
					require_once(INCLUDE_DIR.'Net/Growl.php');
					// Notification Type definitions
					define('GROWL_NOTIFY_STATUS', 'GROWL_NOTIFY_STATUS');

					$appName = APPLICATION_NAME;
					$notifications = array(GROWL_NOTIFY_STATUS => array('display' => 'Status'));
					$options  = array('host' => '127.0.0.1','protocol' => 'tcp', 'port' => Net_Growl::GNTP_PORT, 'timeout' => 7,'AppIcon' => cfAppDocRoot().'/gfx/appIcon.png');
				    $growl = Net_Growl::singleton($appName, $notifications, $growlConfig['password'], $options);
				    $growl->register();
				    echo cfAsyncXMLJSaction('eventGrowlTestOK()');
				}
				catch (Net_Growl_Exception $e){
					echo cfAsyncXMLJSaction('eventGrowlTestFailed("'.addslashes($e->getMessage()).'")');
				}
				break;

			/**
			 * FTP
			 */
			case 'eventFTPApply':
			case 'ftpTestConnection':
				$requiredFields=array('ftpHost'=>'host','ftpPort'=>'port','ftpUser'=>'user','ftpPassword'=>'password','ftpPath'=>'path');
				// Verify all fields are here
				foreach ($requiredFields as $rf=>$rfk) {
					if(!isset($rf)) $missing=true; else $ftpConfig[$rfk]=$_POST[$rf];
				}
				$ftpConfig['displayIP']=((isset($_POST['ftpDisplayIP']))?1:0);

				if(!isset($missing)){
					// Check host name
					if(!preg_match("/^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$/",$ftpConfig['host']) && !preg_match("/^(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+(?:[a-z]{2}|com|org|net|gov|mil|biz|info|mobi|name|aero|jobs|museum)$/i",$ftpConfig['host'])){
						echo cfAsyncXMLJSaction('setFieldError("ftpHost")');
						$error=1;
					}
					else echo cfAsyncXMLJSaction('setFieldOK("ftpPort")');
					// Check port
					if(!is_numeric($ftpConfig['port']) || floor($ftpConfig['port'])!=$ftpConfig['port'] || $ftpConfig['port']<1 || $ftpConfig['port']>65535){
						echo cfAsyncXMLJSaction('setFieldError("ftpPort")');
						$error=2;
					}
					// Check path
					if(cfFileExtension($ftpConfig['path'])!='html' && cfFileExtension($ftpConfig['path'])!='htm' && cfFileExtension($ftpConfig['path'])!='php'){
						echo cfAsyncXMLJSaction('setFieldError("ftpPath")');
						$error=3;
					}
					// Check user name - replace by anonymous if not set, raise warning, but don't block on this
					if($ftpConfig['user']==''){
						$ftpConfig['user']='anonymous';
						echo cfAsyncXMLJSaction('dgn("ftpUser").value="anonymous";setFieldError("ftpUser")');
					}

					$ftpConfig=cfStoredPasswordCrypt(serialize($ftpConfig));

					// Update saved data
					if(!isset($error)) cfGUpdateVar('ftpEventConfig',$ftpConfig);
				}
				// If no error and connection test required, proceed to test
				if(isset($error) || $_POST['action']!='ftpTestConnection') break;


			// Test FTP connection
			case 'ftpTestConnection':
				$ftpConfig=@unserialize(cfStoredPasswordDecrypt(cfGGetVar('ftpEventConfig')));

				// Setup FTP connection
				if($ftpConfig['port']=='990') $connId = ftp_ssl_connect($ftpConfig['host'],990);
				else $connId = @ftp_connect($ftpConfig['host'],$ftpConfig['port']);

				if(!$connId){
					echo cfAsyncXMLJSaction('eventFTPTestFailed("'.cfCaption('genError').'<br>Could not connect to '.$ftpConfig['host'].' on port '.$ftpConfig['port'].'")');
					break;
				}

				// Login with username and password
				$loginResult = @ftp_login($connId, $ftpConfig['user'], $ftpConfig['password']);
				if(!$loginResult){
					echo cfAsyncXMLJSaction('eventFTPTestFailed("'.cfCaption('genError').'<br>FTP connection OK, but could not log with user '.$ftpConfig['user'].' and given password")');
					ftp_close($connId);
					break;
				}

				$tmpFile=cfAppTempDir().'/tmp_FTP.html'; file_put_contents($tmpFile,APPLICATION_NAME.' FTP TEST OK');

				// Navigate to remote folder
				$remotePath=str_replace('\\','/',dirname($ftpConfig['path']));
				if($remotePath!='.' && !@ftp_chdir($connId,$remotePath)){
					echo cfAsyncXMLJSaction('eventFTPTestFailed("'.cfCaption('genError').'<br>FTP connection and login OK, but could not navigate to \"'.$remotePath.'\" remote folder")');
					ftp_close($connId);
					break;
				}

				// Put file
				$result1=@ftp_put($connId, basename($ftpConfig['path']), $tmpFile, FTP_ASCII);
				// Put file a second time to check modify rights
				$result2=@ftp_put($connId, basename($ftpConfig['path']), $tmpFile, FTP_ASCII);

				@unlink($tmpFile);

				// Error processing
				if(!$result2){
					if($result1)
						echo cfAsyncXMLJSaction('eventFTPTestFailed("'.cfCaption('genError').'<br>FTP connection and login OK, 1st upload OK, but could not update remote file.<br>Check \"Delete\" rights on remote server")');
					else
						echo cfAsyncXMLJSaction('eventFTPTestFailed("'.cfCaption('genError').'<br>FTP connection and login OK, but could not put test file in remote path \"'.$remotePath.'\".<br> Check \"Write\" rights on remote server.")');
					ftp_close($connId);
					break;
				}

				// Close FTP connection
				ftp_close($connId);
				echo cfAsyncXMLJSaction('eventFTPTestOK()');
				break;

			// Edit FTP template
			case 'ftpEditTemplate':
				$templateFile=str_replace('/','\\',cfAppDocRoot().'/themes/FTP template.html');
				customShellExecute($templateFile,'edit');
				break;

			/**
			 * Change Widget code
			 */
			case 'widgetChange':
				if(preg_match('/^[a-zA-Z0-9]{1,30}$/',$_POST['widgetCode'])) cfGUpdateVar('monitorWidgetAccessCode',$_POST['widgetCode']);
				echo cfAsyncXMLJSaction("wl.button.disable('widgetChangeApplyBt')");
				break;
		}
		die(cfAsyncFooter());
	}
}


/**
 * @desc Display FTP configuration panel
 *
 */
function publishSocialConfigPanelFtp(){
	// Get FTP config
	$ftpConfig=@unserialize(cfStoredPasswordDecrypt(cfGGetVar('ftpEventConfig')));

	// Set default values
	foreach (array('host'=>'','port'=>'21','user'=>'','password'=>'','path'=>'/var/html/index.html','displayIP'=>false) as $k=>$v){
		if(!isset($ftpConfig[$k])) $ftpConfig[$k]=$v;
	}

	// Create template file from default template if not already done
	$templateFile=cfAppDocRoot().'/local/logOutputs/FTP templateV0.html';
	$userTemplateFile=cfAppDocRoot().'/themes/FTP template.html';
	if(!file_exists($userTemplateFile)) copy($templateFile,$userTemplateFile);



	// Insert frame header
	echo outDivFrame('frame3','id="ftpConfigPanel"','display:none;height:'.EVENTS_FRAME_HEIGHT);
	echo '<form id="formFTP" action="'.$_SERVER['PHP_SELF'].'">';
	echo '<input type="text" style="display:none" name="actionFtp" value="eventFTPApply">';
	echo '<div class="frame3Header">'.outImageIcon('UI/ftp').cfCaption('personalWebsite').'</div><div style="line-height:1.3em">';

	// Host
	echo '<span style="width:70px;text-align:right">ftp://</span>&nbsp;&nbsp;<input type="text" name="ftpHost" value="'.$ftpConfig['host'].'" size="14" onkeyup="ftpConfigChanged(this.name)">';
	// Port
	echo '<span style="width:62px;text-align:right">'.cfCaption('genPort').'</span>&nbsp;&nbsp;<input type="text" name="ftpPort" value="'.$ftpConfig['port'].'" size="1" onkeyup="ftpConfigChanged(this.name)"><br>';
	// Username
	echo '<span style="width:70px;text-align:right">'.cfCaption('loginName').'</span>&nbsp;&nbsp;<input type="text" name="ftpUser" value="'.$ftpConfig['user'].'" size="14" onkeyup="ftpConfigChanged(this.name)">';
	// Password
	echo '<span style="width:62px;text-align:right">'.cfCaption('genPassword').'</span>&nbsp;&nbsp;<input type="password" name="ftpPassword" value="'.$ftpConfig['password'].'" size="10" onkeyup="ftpConfigChanged(this.name)"><br>';
	// Path
	echo '<span style="width:70px;text-align:right">'.cfCaption('genDirectory').'</span>&nbsp;&nbsp;<input type="text" name="ftpPath" value="'.$ftpConfig['path'].'" size="14" onkeyup="ftpConfigChanged(this.name)"><br>';

	// Include IP in output
	echo '<input type="checkbox" name="ftpDisplayIP"';
	if($ftpConfig['displayIP']) echo ' checked="checked"';
	echo ' onclick="ftpConfigChanged()"><span onclick="dgn(\'ftpDisplayIP\').checked=!dgn(\'ftpDisplayIP\').checked;ftpConfigChanged()">'.cfCaption('displayServerIP').'</span>';
	echo '<center style="margin-top:0.5em">';
	// Apply button
	echo outButton(cfCaption('explorerAudioApply'),'javascript:eventFTPApply()',outIcon('ok'),false,'eventFTPApplyBt',false,false,true);
	// Test button
	echo outButton(cfCaption('genTest'),'javascript:eventFTPTest()',outIcon('unknown'),false,'eventFTPTestBt','style="margin-left:2em;margin-right:2em"',false);
	// Edit button
	if(cfIsInApp()) echo outButton(cfCaption('genEdit'),'javascript:eventFTPEdit()',outIcon('edit'),false,'eventFTPEditBt',false,false);
	echo '</center>';
	echo "</div>\n</form>\n</div>\n";
?>
<script type="text/javascript">
function ftpConfigChanged(n){
	if(n) setFieldOK(n)
	wl.button.enable("eventFTPApplyBt");
}
function eventFTPApply(){
	wl.button.disable("eventFTPApplyBt")
	asyncSubmitForm('formFTP');
}
function eventFTPEdit(){
	sendData('action=ftpEditTemplate');
}
function eventFTPTest(){
	wl.mask.show(1,0,true);
	wl.button.setIcon('eventFTPTestBt','<?php echo outIcon('loading');?>');
	dgn('actionFtp').value='ftpTestConnection';
	eventFTPApply();
}
function eventFTPTestFailed(str){
	wl.button.setIcon('eventFTPTestBt','<?php echo outIcon('unknown');?>');
	alert(str.replace(/<br>/gi,"\n"));
	wl.mask.hide();
}
function eventFTPTestOK(){
	wl.mask.hide();
	dgn('ftpHost').style.color='green';
	dgn('ftpPort').style.color='green';
	dgn('ftpUser').style.color='green';
	dgn('ftpPassword').style.color='green';
	dgn('ftpPath').style.color='green';
	wl.button.setIcon('eventFTPTestBt','<?php echo outIcon('ok');?>');
}
</script>
<?php
}


/**
 * @desc Display twitter configuration panel
 *
 */
function publishSocialConfigPanelTwitter(){

	// Insert frame header
	echo outDivFrame('frame3','id="twitterConfigPanel"','height:'.EVENTS_FRAME_HEIGHT);
	echo '<div class="frame3Header">'.outImageIcon('UI/twitter').'Twitter</div>';

	// Get account and password
	require_once(INCLUDE_DIR.'twitter.lib.php');
	@list($twitterAccount, $twitterPassword,$twitterDisplayIP)=twitterGetConnectionData();

	echo outTableTransparent();
?>
	<tr>
		<td><div style="width:75"></div></td><td> </td><td><div style="width:90"></div></td>
	</tr>
	<tr>
		<td></div><?php echo cfCaption('genAccount');?></td>
		<td><input class="textInput" name="twitterAccount" value="<?php echo $twitterAccount; ?>" onkeyup="twitterSetButtons()" onchange="twitterSetButtons()"></td>
		<td style="text-align:right"><?php echo outButton(cfCaption('genTest'),'javascript:twitterCheck()',outIcon('UI/twitter'),false,'twitterCheckBt');?></td>
	</tr>
	<tr>
		<td><?php echo cfCaption('genPassword');?></td>
		<td><input class="textInput" name="twitterPassword" value="<?php echo $twitterPassword; ?>" type="password" onkeyup="twitterSetButtons()" onchange="twitterSetButtons()"></td>
		<td style="text-align:right"><?php echo outButton(cfCaption('genClear'),'javascript:twitterClear()',outIcon('eraser'),false,'twitterClearBt');?></td>
	</tr>
	<tr><td colspan="2"><input type="checkbox" name="twitterDisplayIP"<?php if($twitterDisplayIP) echo ' checked="checked"';?> onclick="twitterSetButtons()"><span onclick="dgn('twitterDisplayIP').checked=!dgn('twitterDisplayIP').checked;twitterSetButtons()"><?php echo cfCaption('displayServerIP');?></span></td>
	</tr>
</table>
	<center style="margin-top:0.5em"><?php echo outButton(cfCaption('explorerAudioApply'),'javascript:eventTwitterApply()',outIcon('ok'),false,'eventTwitterApplyBt',false,false,true);?></center>
</div>
<script type="text/javascript">
function twitterSetButtons(init){
	dgn('twitterAccount').style.color='';
	dgn('twitterPassword').style.color='';
	wl.button.enable('twitterClearBt',(dgn('twitterAccount').value!='' || dgn('twitterPassword').value!=''));
	wl.button.enable('twitterCheckBt',(dgn('twitterAccount').value!='' && dgn('twitterPassword').value!=''));
	if(wl.button.isEnabled('twitterCheckBt')) eventOutputEnable('twitter'); else eventOutputDisable('twitter');
	if(!init) wl.button.enable('eventTwitterApplyBt');
}
function twitterCheck(){
	wl.button.setIcon('twitterCheckBt','<?php echo outIcon('loading');?>');
	wl.mask.show(1,0,true);
	sendData('action=twitterCheckAccount&twitterAccount='+encodeURIComponent(dgn('twitterAccount').value)+'&twitterPassword='+encodeURIComponent(dgn('twitterPassword').value)+'&twitterDisplayIP='+dgn('twitterDisplayIP').checked);
}
function twitterCheckResult(res){
	if(res) {
		dgn('twitterAccount').style.color=dgn('twitterPassword').style.color=(res==-1)?'':'green';
		wl.button.enable('eventTwitterApplyBt');
	}
	else {
		dgn('twitterAccount').style.color=dgn('twitterPassword').style.color='red';
		wl.button.disable('eventTwitterApplyBt');
	}
	wl.button.setIcon('twitterCheckBt','<?php echo outIcon('UI/twitter');?>');
	if(res) eventOutputEnable('twitter'); else eventOutputDisable('twitter');
	wl.mask.hide();
}
function twitterClear(){
	dgn('twitterAccount').value=dgn('twitterPassword').value='';
	twitterSetButtons();
	eventOutputDisable('twitter');
}
function eventTwitterApply(){
	wl.button.disable("eventTwitterApplyBt")
	sendData('action=eventTwitterApply&twitterAccount='+encodeURIComponent(dgn('twitterAccount').value)+'&twitterPassword='+encodeURIComponent(dgn('twitterPassword').value)+'&twitterDisplayIP='+dgn('twitterDisplayIP').checked);
}
</script>
<?php
}

/**
 * @desc Display twitter configuration panel
 *
 */
function publishSocialConfigPanelGrowl(){
	// Get FTP config
	$growlConfig=@unserialize(cfStoredPasswordDecrypt(cfGGetVar('growlEventConfig')));

	// Insert frame header
	echo outDivFrame('frame3','id="growlConfigPanel"','display:none;height:'.EVENTS_FRAME_HEIGHT);
	echo '<div class="frame3Header">'.outImageIcon('UI/growl').'Growl</div>';

	echo '<form id="formGrowl" action="'.$_SERVER['PHP_SELF'].'">';
	echo '<input type="text" style="display:none" name="actionGrowl" value="eventGrowlApply">';

	// Password
	echo '<br><span style="width:62px;text-align:right">'.cfCaption('genPassword').'</span>&nbsp;&nbsp;<input type="password" name="growlPassword" value="'.$growlConfig['password'].'" size="10" onkeyup="growlConfigChanged(this.name)"><br>';

	// Include IP in output
	echo '<br><input type="checkbox" name="growlDisplayIP"';
	if($growlConfig['displayIP']) echo ' checked="checked"';
	echo ' onclick="growlConfigChanged()"><span onclick="dgn(\'growlDisplayIP\').checked=!dgn(\'growlDisplayIP\').checked;growlConfigChanged()">'.cfCaption('displayServerIP').'</span>';

	echo '<br><br><center style="margin-top:0.5em">';
	// Apply button
	echo outButton(cfCaption('explorerAudioApply'),'javascript:eventGrowlApply()',outIcon('ok'),false,'eventGrowlApplyBt',false,false,true);
	// Test button
	echo outButton(cfCaption('genTest'),'javascript:eventGrowlTest()',outIcon('unknown'),false,'eventGrowlTestBt','style="margin-left:2em;margin-right:2em"',false);
	echo '</center>';
	echo '<div id="growlTestResult" class="warning"></div>';
	echo '</form></div>';
?>
<script type="text/javascript">
function growlConfigChanged(n){
	if(n) setFieldOK(n)
	wl.button.enable("eventGrowlApplyBt");
}
function eventGrowlApply(){
	wl.button.disable("eventGrowlApplyBt")
	dgn('actionGrowl').value='eventGrowlApply';
	asyncSubmitForm('formGrowl');
}
function eventGrowlTest(){
	wl.mask.show(1,0,true);
	wl.button.setIcon('eventGrowlTestBt','<?php echo outIcon('loading');?>');
	dgn('actionGrowl').value='growlTestConnection';
	asyncSubmitForm('formGrowl');
}
function eventGrowlTestFailed(str){
	wl.button.setIcon('eventGrowlTestBt','<?php echo outIcon('unknown');?>');
	dgi('growlTestResult').innerHTML=str;
	wl.mask.hide();
}
function eventGrowlTestOK(){
	wl.mask.hide();
	dgn('growlPassword').style.color='green';
	wl.button.setIcon('eventGrowlTestBt','<?php echo outIcon('ok');?>');
	dgi('growlTestResult').innerHTML='';
}
</script>
<?php
}

/**
 * @desc Display widget panel
 *
 */
function publishSocialPanelWidget(){
	echo outDivFrame('frame2');
	echo outImage(outIcon('UI/widgetCompatibility'),false,false,'float:right');
	echo '<div class="frame2Header">'.outImageIcon('uwa').'Netvibes - Widget</div>';
	?>
<script type="text/javascript">
function widgetChangeApply(){
	sendData('action=widgetChange&widgetCode='+dgi('widgetCode').value)
}
function widgetChangeCheck(){
	var t=dgi('widgetCode').value;
	var regex = new RegExp("^[a-z0-9]{1,30}$","i");
	if(regex.exec(t)==null) {
		wl.button.disable('widgetChangeApplyBt')
		dgi('widgetCode').style.color='red';
	}
	else{
		wl.button.enable('widgetChangeApplyBt')
		dgi('widgetCode').style.color='';
	}
}
</script>
<center>
<?php echo outImage(outIcon('UI/widget'),false,false,'float:left;margin-right:1em;');?>
</center>
<?php echo cfCaption('configWidgetAccessCode'); ?><br>
<input id="widgetCode" class="textInput" onchange="widgetChangeCheck()" onkeyup="widgetChangeCheck()" value="<?php echo cfGGetVar('monitorWidgetAccessCode')?>">
<?php
	// Widget code apply changes button
	echo outButton(cfCaption('explorerAudioApply'),'javascript:widgetChangeApply()',outIcon('ok'),false,'widgetChangeApplyBt',false,false,true);
	echo '<br>';

	// Install button
	echo outButton(cfCaption('genInstall').'...','http://eco.netvibes.com/widgets/206068/weezo-monitor',outIcon('add'),false,false,'target="_blank"');
	echo "</div>\n";
}


// Indicate an in-application display
$_ENV['configurationEnvironment']='application';


/*
 ***************************************************************************************************************************
 * Process POST commands
 ***************************************************************************************************************************
 */
processPOST();

// Memorize panel selection
cfGUpdateVar('uiResourcePublishPanel',cfFileWithoutExtension(basename($_SERVER['SCRIPT_NAME'])));

require_once(INCLUDE_DIR.'outputFunctions.php');



/**
 * Events loggin
 */

$logEventConfig=cfLogEventConfig();

$logEventDescription=array(
	EVENT_SERVERSTATE=>cfCaption('apacheStartedWeb'),
	EVENT_CONNECTION=>cfCaption('msgNewConnection'),
	EVENT_RESOURCEACCESS=>cfCaption('calResourceAccess')
	);

$logEventOutputs=array(
	'twitter'=>outImageIcon('UI/twitter').'Twitter',
	'ftp'=>outImageIcon('UI/ftp').cfCaption('personalWebsite'),
	'growl'=>outImageIcon('UI/growl').'Growl'
	);
//unset($logEventOutputs['ftp']);

$js='';
foreach ($logEventOutputs as $logEventOutputId=>$discard){
	$js.=',"'.$logEventOutputId.'":Array(';
	$ejs='';
	foreach ($logEventDescription as $eventId=>$eventCaption){
		$ejs.=',"logEvent_'.$logEventOutputId.'_'.$eventId.'"';
	}
	$js.=substr($ejs,1).')';
}
$js='{'.substr($js,1).'}';




/*
 ***************************************************************************************************************************
 * Insert HEAD, JS functions
 ***************************************************************************************************************************
 */
require_once(INCLUDE_DIR.'outputFunctions.php');
require_once(INCLUDE_DIR.'explorerFunctions.php');

cfInsertHEAD(false);
?>
<script type="text/javascript">
var eventsChecks=<?php echo $js;?>;
var logEventOutputs=[<?php $nb=0;foreach ($logEventOutputs as $key=>$value) echo (($nb++>0)?',':'').'"'.$key.'"';?>];

function init(){twitterSetButtons(1);}
function backKD(kc){
	if(kc!==27 || !dgi("backButton")) return;
	if(dgn('path') && dgn('path').value) return;
	parent.slideFrame('publish','/local/uiResources/publish.php','up');
}
wl.setKeycodeListener(D,backKD)

function eventCBClicked(key){
	logEventOutputConfig(key);
	var eC=''
	for(var e in eventsChecks) {
		for(var i=0;i<eventsChecks[e].length;i++) eC+='&'+eventsChecks[e][i]+'='+((dgn(eventsChecks[e][i]).checked)?'1':'0');
	}
	/*
	if(key=='twitter') wl.button.enable('eventTwitterApplyBt');
	if(key=='ftp') wl.button.enable('eventFTPApplyBt');
	*/

	sendData('action=eventCBApply'+eC);
}
function eventOutputDisable(outputId){
	for(var e in eventsChecks) if(e==outputId){
		for(var i=0;i<eventsChecks[e].length;i++) dgn(eventsChecks[e][i]).disabled=true;
		return;
	}
}
function eventOutputEnable(outputId){
	for(var e in eventsChecks) if(e==outputId){
		for(var i=0;i<eventsChecks[e].length;i++) dgn(eventsChecks[e][i]).disabled=false;
		return;
	}
}
function logEventOutputConfig(logEventOutputId){
	for(var i=0;i<logEventOutputs.length;i++) {
		if(logEventOutputId==logEventOutputs[i]){
			dgi(logEventOutputs[i]+'ConfigPanel').style.display='';
			wl.button.disable(logEventOutputId+'ConfigBt');
		}
		else{
			dgi(logEventOutputs[i]+'ConfigPanel').style.display='none';
			wl.button.enable(logEventOutputs[i]+'ConfigBt');
		}
	}
}
function setFieldError(fName){
	dgn(fName).style.color='red';
}
function setFieldOK(fName){
	dgn(fName).style.color='';
}
</script>
</head>
<body onload="init()" onclick="">
<?php
// Back button
echo '<div style="float:right">'.outButton(cfCaption('genBack'),"javascript:parent.slideFrame('publish','/local/uiResources/publish.php','up')",outIcon('backRed'),false,'backButton').'</div>';

// Title
echo '<div class="uiTabTitle">'.cfCaption('publishSocialLabel').'</div>';



/**
 ***************************************************************************************************************************
 * Events / events outputs table
 ***************************************************************************************************************************
 */
echo outDivFrame('frame2');
echo '<div class="frame2Header">'.outImageIcon('events').cfCaption('genEvents').'</div>';
echo '<div class="extendedInfo">'.outImage(outIcon('info2'),false,false,'float:right').cfCaption('eventManagerDesc').'</div><br>';
echo outTableTransparent(false,'table-layout:fixed');

?>
<tr><td style="width:40%">
<div class="frame3" style="height:<?php echo EVENTS_FRAME_HEIGHT;?>px">

<table cellpadding="0" cellspacing="0" style="text-align:left;width:100%">
<?php

// Table header
echo '<tr class="frame3Header"><td style="vertical-align:bottom">'.cfCaption('genEvents').'</td>';
foreach ($logEventOutputs as $logEventOutputId=>$caption) echo '<td style="text-align:center;vertical-align:top;cursor:pointer" onclick="logEventOutputConfig(\''.$logEventOutputId.'\')">'.$caption.'<br>&nbsp;</td>';
echo '</tr>';

// Table content
foreach ($logEventDescription as $eventId=>$eventCaption){
	echo '<tr><td style="font-weight:bold">'.$eventCaption.'</td>';
	foreach ($logEventOutputs as $logEventOutputId=>$discard){
		echo '<td style="border:0px solid #EEE;text-align:center"><input name="logEvent_'.$logEventOutputId.'_'.$eventId.'" type="checkbox" onclick="eventCBClicked(\''.$logEventOutputId.'\')"';
		if(@$logEventConfig[$logEventOutputId][$eventId]) echo ' checked="checked"';
		echo "></td>\n";
	}
	echo "</tr>\n";
}

// Configure buttons
if(count($logEventOutputs)>1){
	echo '<tr><td>&nbsp;</td>';
	foreach ($logEventOutputs as $logEventOutputId=>$caption){
		echo '<td style="border:0px solid #EEE;text-align:center">'.outButton(false,"javascript:logEventOutputConfig('".$logEventOutputId."')",outIcon('gears'),cfCaption('genConfigure'),$logEventOutputId.'ConfigBt').'</td>';
	}
	echo '</tr>';
}
?>
</table>
</div>
</td>
<td style="width:5px">&nbsp;</td>

<td id="logOutputConfigPanel" style="">
<?php


/**
 ***************************************************************************************************************************
 * TWITTER / online status services part
 ***************************************************************************************************************************
 */
publishSocialConfigPanelTwitter();


/**
 ***************************************************************************************************************************
 * FTP / online status services part
 ***************************************************************************************************************************
 */
publishSocialConfigPanelFtp();


/**
 ***************************************************************************************************************************
 * Growl
 ***************************************************************************************************************************
 */
publishSocialConfigPanelGrowl();


echo '</td></tr></table>';

echo '</div>';

echo '<br>';

/**
 * WIDGET PART
 */
publishSocialPanelWidget();

?>
</body>
</html>