<?php
/**
 * Std Explorer main script
 *
 * Display files and directories browser
 * File operations : delete, execute, rename, create directory, upload, remote download, download, view
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.0.0
 */

require_once(INCLUDE_DIR.'explorerFunctions.php');
require_once(INCLUDE_DIR.'outputFunctions.php');
require_once(INCLUDE_DIR.'treeViewClass.php');

define('TRANSFERS_BOX_HEIGHT','130px');

$tree='';

/**
 * @desc init file explorer
 *
 */
function initFileExplorerData(){
	if(!cfRGetVar('resourceParametersInitialized')){
		cfRSetVar('useHTTPXmlRequest',true); // Use HTTPXmlRequest for communication between browser and server
		cfRInitVar('fileTypeFilter',false);// array of file types of displayed files. Set to false if no filter on file type (see mime_type.php for list of file types)
		cfRInitVar('efSortBy','name'); cfRInitVar('efSortOrder','asc');// Use sort options
		cfRSetVar('displayMultipleDownload',true); // Display multiple download box
		cfRSetVar('trackTransfers',true); // track transfers progress


		// iPhone specific
		if(cfBGetVar('name')=='iPhone') cfRSetVar('meta','<meta name="viewport" content="width=480, user-scalable=0">');
		if(!cfBGetVar('drag')) cfRSetVar('maxDragItems',0);

		// Page layout
		if(cfRGetVar('filesLayout')=='resource') cfRSetVar('filesLayout','list'); // V3.0.0I: disable resource layout
		if(cfRGetVar('layout')=='2' || cfRGetVar('layout')=='3' || cfBGetVar('screenSize')!='monitor') cfRInitVar('displayTransfers',false);
		else cfRInitVar('displayTransfers',true);

		if(cfRGetVar('resourceConfigured')) cfRSetVar('resourceParametersInitialized',true); // indicate that parameters have been initialized
		else $errorMessageCritical=cfCaption('configErrorNotConfigured');
	}

	// Update downloadShortcut fileViewAllowed from potentially modified downloadAllowed
	cfRSetVar('userRights_downloadShortcut',cfRGetVar('userRights_downloadAllowed'));// if download allowed, display shortcut
	cfRSetVar('userRights_fileViewAllowed',cfRGetVar('userRights_downloadAllowed')); // If download allowed, allow direct file view

	// Treeview displayed
	if(cfRGetVar('treeViewAvailable') && (cfRGetVar('layout')=='0' || cfRGetVar('layout')=='2')) cfRInitVar('treeViewDisplayed',true); else cfRInitVar('treeViewDisplayed',false);

	// Init treeview
	global $tree;
	if(cfRGetVar('treeViewAvailable')){
		$tree=new treeViewFolder(cfRGetVar('treeViewAvailable'));
		$tree=treeFolderLoad(cfRGetVar('treeViewAvailable'));
		$tree->receiverOnlyNodes=1;
	}
}

// Init common explorer data
cfRInitVar('thumbnailsSizeFactor',0); // Override default thumbnailsSizeFactor
efInit();

// Init file explorer data
initFileExplorerData();


/**
 * If mobile device, redirect to mobile explorer
 */
if(cfIsMobile()) {require(INCLUDE_DIR.'mobileExplorerFunctions.php');mefExplorer();exit;}


/*
 ***************************************************************************************************************************
 * Process POST commands
 ***************************************************************************************************************************
 */
efProcessPOST();
cfAsyncXMLChangePhpVarValue('displayTransfers'); // process hide / show transfers frame dynamic update
cfAsyncXMLChangePhpVarValue('displayMultipleDownload'); // process hide / show multiple download frame dynamic update
cfAsyncXMLChangePhpVarValue(SLIDESHOW_TIMER_CONTROL_NAME,array(1,2,3,4,5,10,15,30)); // process slideshow timeout value change

/*
 ***************************************************************************************************************************
 * Get files and subfolders list, generate thumbnails if needed
 ***************************************************************************************************************************
 */
efDirUpdate(array('includeRights'=>true,'noExtra'=>efFilesListIsResource() && !cfRGetVar('displayExtraData')));

/*
 ***************************************************************************************************************************
 * Insert HEAD, JS functions and form
 ***************************************************************************************************************************
 */
efInsertExplorerHeadAndBody();

if(!$asyncResponse){
?>
<script type="text/javascript" language="javascript">
D.body.style.overflow='hidden';
var focusedInput,framesInitialized=0,treeViewFrame="<?php if(cfRGetVar('treeViewAvailable')) echo $tree->HTMLDivID();?>",multipleViewPopup=1;
function uploadCompleted(result){if(dgi("transfersIFrame")) frames["transfersIFrame"].transfersRefresh(1);}
function setMFResizable(){dd.elements[treeViewFrame].warm();}
function setMFUnresizable(){dd.elements[treeViewFrame].freeze();}
function winResized(w,h){resetFrames();}
function initFrames(){
	var tvf=dd.elements[treeViewFrame]
	wl.autoScrollDivs.add(dgi('filesDiv'));
	if(tvf){
		tvf.setMinWidth(100);
		tvf.setMaxWidth(winMe.getInnerWidth()/2);
		//tvf.resizeTo(200,'auto')
		wl.autoScrollDivs.add(dgi(treeViewFrame));
	}
	framesInitialized=true;
	resetFrames();
}
function resetFrames(){
	if(!framesInitialized) {initFrames();return;}

	dgi('filesDiv').style.marginLeft=getElementStyle(dgi('mainFileDiv'),'padding-left');

	alignBottom(dgi('mainFileDiv'),winMe,5)
	alignBottom(dgi('filesDiv'),dgi('mainFileDiv'),5)

	<?php
	if(cfRGetVar('treeViewDisplayed')){
		echo 'if(dgi("'.$tree->HTMLDivID().'")) alignBottom(dgi("'.$tree->HTMLDivID().'"),dgi("mainFileDiv"),5);';
		echo $tree->JSItem().'.adjustInnerDiv();';
	}
	?>
}
function topBoxToggleCollapseStep(anim){
	if(anim.completed && W.resetFrames) resetFrames()
}
</script>
<?php
}

/*
 ***************************************************************************************************************************
 * Start of resource specific section
 ***************************************************************************************************************************
 */
$efCurrentDirectory=cfRGetVar('efCurrentDirectory');
$dirPermissions=cfFileRights($efCurrentDirectory);
$imgRatio=((cfTGetVar('iconRatio'))?cfTGetVar('iconRatio'):1); // Theme enlarge/shrink ratio


/*
 ***************************************************************************************************************************
 * UPLOAD, DIRECT DOWNLOADS, FILE TRANSFERS AND MULTIPLE DOWNLOAD BOXES
 ***************************************************************************************************************************
 */
if(!$asyncResponse && (cfRGetVar('uploadAllowed') || cfRGetVar('remoteDownloadAllowed') || cfGGetVar('remoteDownloadAllowed') || cfGGetVar('sendAllowed') || cfGGetVar('uploadAllowed') || cfRGetVar('multipleDownloadAllowed'))){
	outShadowBefore('100%');
 	echo outDivFrame('frame1 banner');

 	// Transfers Frame Header
 	echo outFrameHeaderTable('frame1Header',
 		outThemeImage(outIcon('transfers'),false,false,'vertical-align:middle; margin-right:1em;').cfCaption('explorerFileTransfer'),
 		outButtonToggleCollapse2('transfersFrame','displayTransfers',true,"'if(W.resetFrames) resetFrames();'"),'onclick="wl.nodeCollapseToggle(\'transfersFrame\',\'displayTransfers\', topBoxToggleCollapseStep)" onmouseover="if(dd.obj && wl.isCollapsed(\'transfersFrame\')) this.onclick()"',
 		'cursor:pointer');

 	// Collapsable inner frame
 	echo outCollapsableFrame('transfersFrame','displayTransfers',false,true);

 	// Count number of displayed items
 	$nbItems=(int)(cfRGetVar('uploadAllowed'))+(int)cfRGetVar('remoteDownloadAllowed')+(int)cfTGetVar('frames')+(int)cfRGetVar('multipleDownloadAllowed');
 	// 4 items: 2 lines
 	if($nbItems==4){
 		$lineBreak=true;
 		$blockWidth=49.5;
 	}
 	// Less than 4: 1 line
 	elseif($nbItems){
 		$blockWidth=(100-($nbItems-1))/$nbItems;
 		$lineBreak=false;
 	}
 	$spacerWidth='1%';
 	$nb=0;

	echo '<table cellspacing="0" cellpadding="0" border="0" style="width:100%;table-layout:fixed"><tr>';
		// Upload box
		if(cfRGetVar('uploadAllowed')){
			echo '<td class="frame2" style="height:'.TRANSFERS_BOX_HEIGHT.'; vertical-align:top;width:'.$blockWidth.'%">';
			echo outFrameHeaderTable('frame2Header',outThemeImage(outIcon('upload'),false,false,'vertical-align:middle; margin-right:1em;').cfCaption('uploadBoxTitle').'<fieldset id="uploadDDTotalProgress" style="width:50%;position:relative;margin-left:10px;vertical-align:middle"></fieldset>',outHelpButton('helpUpload'));
			echo '<center>';
			echo outUploadForm(10,'uploadCompleted',($dirPermissions['upload'])?'enabled':'disabled',false,false,array('compact'=>true));
			echo '</center></td>';
			if(++$nb<$nbItems) echo '<td style="width:'.$spacerWidth.';padding:0px"></td>';
		}
		// Direct (remote) download box
		if(cfRGetVar('remoteDownloadAllowed')){
			echo '<td class="frame2" style="height:'.TRANSFERS_BOX_HEIGHT.'; vertical-align:top;width:'.$blockWidth.'%">';
			echo outFrameHeaderTable('frame2Header',outThemeImage(outIcon('ddl'),false,false,'vertical-align:middle; margin-right:1em;').cfCaption('genDirectDownload'),outHelpButton('helpDDL')).'<br>';
			echo '<center><br><form name="ddBox" method="post" onsubmit="return false;" action="">';
			echo '<input class="textInput" type="text" id="rdlInput" name="rdName" size="20" value="http://"><br><br>';
			echo '<input type="hidden" name="resId" value="'.$_SESSION['activeResourceId'].'">';
			echo outButton(cfCaption('startButton'),'javascript:rdl(\'rdlInput\');',outIcon('ok'),false,'rdlFormSubmitButton','style="display:'.(($dirPermissions['remoteDownload'])?'inline':'none').'"');
			echo outButtonDisabled(cfCaption('startButton'),false,outIcon('ok'),false,'rdlFormSubmitButtonDisabled','style="display:'.((!$dirPermissions['remoteDownload'])?'inline':'none').'"');
			echo "<br></form></center></td>\n";

			if(!$lineBreak && ++$nb<$nbItems) echo '<td style="width:'.$spacerWidth.'"></td>';
		}

		if($lineBreak) echo '</tr><tr style="height:5px"><td colspan="3"></td></tr><tr>';

		// File transfers box
		if(cfTGetVar('frames')) {
			echo '<td class="frame2" style="height:'.TRANSFERS_BOX_HEIGHT.'; vertical-align:top;width:'.$blockWidth.'%">';
			$r=outButtonSmall('','javascript:void(sendData(\'data2=all&amp;data3=transfersStop\',\'transfers.php\'));',outIcon('del'),cfCaption('explorerClearAll'),false,'style="margin-right:1em;"');
			$r.=outButtonSmall('','javascript:void(sendData(\'data2=all&amp;data3=transfersClear\',\'transfers.php\'));',outIcon('eraser'),cfCaption('explorerClearFinishedTransferts'),false,'style="margin-right:1em;"');
			$r.=outHelpButton('helpTransfers');
			echo outFrameHeaderTable("frame2header",outThemeImage(outIcon('transfers'),false,false,'vertical-align:middle; margin-right:1em;').cfCaption('adminTranfers'),$r);
			echo '<iframe id="transfersIFrame" name="transfersIFrame" frameborder=0 width="100%" src="transfers.php?rnd='.rand().'" style="height:'.((cfGetBrowser()=='ie')?'100%':'8em').'"></iframe></td>'."\n";
			if(++$nb<$nbItems) echo '<td style="width:'.$spacerWidth.'"></td>';
		}

		// Multiple download box
		if(cfRGetVar('multipleDownloadAllowed')){
			echo '<td class="frame2" style="vertical-align:top;width:'.$blockWidth.'%;height:'.TRANSFERS_BOX_HEIGHT.'">';
			echo outMultipleDownloadList('frame2',false,true,false,'margin:0px;',false,false,array('noCollapse'=>1,'noOuterDiv'=>1));
			echo '</td>';
		}
		echo "</tr></table>\n";
	echo "</div></div>\n";
	outFrameShadowAfter();
}

/*
 ***************************************************************************************************************************
 * EXPLORER TABLE
 ***************************************************************************************************************************
 */
if(!$asyncResponse){
	// Style used for icons size
	?><style type="text/css">.eIco{width:<?php echo 16*$imgRatio;?>px; height:<?php echo 16*$imgRatio;?>px;}</style><?php
	outShadowBefore('100%');

	echo outDivFrame('frame1','id="mainFileDiv"','overflow:hidden');

	$l='';$r='';
	if(cfRGetVar('subFoldersIncluded')){//only display this controls if several levels are accessibles
		// Show tree view button
		if(!cfRGetVar('treeViewDisplayed') && cfRGetVar('treeViewAvailable')) $l.=outButton('','javascript:fAS(true,\'toggleTreeFrame\',1,false,\'sync\')', outIcon('treeView'));
		// BACK button
		$l.=outButton('','javascript:goBack()', outIcon('back'),false,'prevDirectoryButton','style="display:'.((cfRGetVar('efPreviousDirectories')!==false && count(cfRGetVar('efPreviousDirectories'))>0)?'inline':'none').'"');
		$l.=outButtonDisabled('',false,outIcon('back'),false,'prevDirectoryButtonDisabled','style="display:'.((!cfRGetVar('efPreviousDirectories') || count(cfRGetVar('efPreviousDirectories'))==0)?'inline':'none').'"');

		// UP button
		$l.=outButton(false,'javascript:go(\'..\')',outIcon('icoUp'),cfCaption('explorerParentDir'),'upDirectoryButton','style="display:'.(($efCurrentDirectory!='computerRoot' && ($authorizedUpperDir=(cfFileRights($efCurrentDirectory."/..",'state')=='authorized')))?'inline':'none').'"');
		$l.=outButtonDisabled(false,false,outIcon('icoUp'),cfCaption('explorerParentDir'),'upDirectoryButtonDisabled','style="display:'.(($efCurrentDirectory=='computerRoot' || !$authorizedUpperDir)?'inline':'none').'"');

		// Clickable path
		$l.='<span id="cPath" style="margin-left:1em" class="smallFont">'.outClickablePath(cfResourceRelativePath($efCurrentDirectory)).'</span>';

		// Direct access
		$l.='<input class="textInput" type="text" id="goDirectInput" size=15 style="margin-left:1em; vertical-align:middle;">'.outButton(false,'javascript:focusedInput=false;goDirect(\'goDirectInput\')',outIcon('goDirect'),cfCaption('explorerDirectAccess'))."\n";


		$r.=outFileSortControls(true).'&nbsp;';

		// Layout selector
		$r.=efFilesListSelector(array('noResourceLayout'=>1/*,'resourceCaption'=>cfCaption('genDefault'),'resourceIcon'=>outIcon('displayFile1')*/)).'&nbsp;&nbsp;'.outThumbnailsSizeButtons(false);

		// New Folder button
		if(cfRGetVar('createFolderAllowed')){
			$r.=outButton(cfCaption('explorerNewFolder'),'javascript:newFolder()',outIcon('newFolder'),false,'newFolderButton','style="display:'.(($authorizedWrite=(cfFileRights($efCurrentDirectory,'write')))?'inline':'none').'"');
			$r.=outButtonDisabled(false,false,outIcon('newFolder'),cfCaption('explorerNewFolder'),'newFolderButtonDisabled','style="display:'.((!$authorizedWrite)?'inline':'none').'"');
		}
		// Search files button
		if(cfRGetVar('searchFiles')) $r.='&nbsp;'.outButton(false,'javascript:searchFiles()',outIcon('search'),cfCaption('genSearch'));
	}
	else {
		$l.=cfCaption('explorerExplorer');
	}

	echo outFrameHeaderTable('frame1Header',$l,$r);

	echo outFilePreviewDiv();
}


/*
 ***************************************************************************************************************************
 *
 * DISPLAY FILES
 *
 ***************************************************************************************************************************
 */

// files & folders table
if(!$asyncResponse) {
	// TREEVIEW FRAME
	if(cfRGetVar('treeViewDisplayed')) {
	echo outTableTransparent(false,'width:100%','id="mainFileTable"');
	if(0) $tree=new treeViewFolder(); // Zend IDE Workaround
?>
	<tr>
	<td id="actionsPanel" style="vertical-align:top" class="vBanner">
	<?php echo $tree->HTML('frame2',true,true);?>
	</td>
	<td id="mainFileRF" style="vertical-align:top;position:relative;width:100%">
		<?php
	}
	echo outDivFrame('frame2','id="filesDiv" '.outEHoverFrameAttr(),'position:relative;top:0px;left:0px;margin:0px;display:block;overflow:auto');
}
// 1st col width
$wl=18;

// Count columns
$nbCols=4;
if(cfRGetVar('displayExtraData')) $nbCols++;


/*
 ***************************************************************************************************************************
 * Computer Root : display drive list
 ***************************************************************************************************************************
 */
$output='';
$scriptOutput='';
$totalSize=0;

if($efCurrentDirectory=='computerRoot') {
	// Display explorer table header (computer root)
	/*
	$output.='<div class="frame2Header">';
	$output.=outTableTransparent('frame2Header');
	$output.='<colgroup><col width="46px"><col width="*"><col width="50px"><col width="100px"><col width="100px"><col width="100px"><col width="90px"></colgroup>';
	$output.='<tr>';
	$output.='<td>&nbsp;</td>';
	$output.='<td>'.cfCaption('explorerDriveName').'</td>';
	$output.='<td>'.cfCaption('explorerDriveReady').'</td>';
	$output.='<td>'.cfCaption('explorerDriveType').'</td>';
	$output.='<td style="text-align:right">'.cfCaption('explorerDriveFileSystem').'</td>';
	$output.='<td style="text-align:right">'.cfCaption('explorerDriveCapacity').'</td>';
	$output.='<td style="text-align:right">'.cfCaption('explorerDriveFreeSpace').'</td>';
	$output.="</tr>\n";
	$output.='</table></div>';
*/

	$scriptOutput='pbStep=0;pbArr=Array(';
	//$output.=outTableTransparent('frame2');
	$output.='<table cellpadding="0" cellspacing="0" class="frame2" style="width:100%"'.outEHoverFrameAttr().'>';
	$output.='<colgroup><col width="46px"><col width="*"><col width="50px"><col width="100px"><col width="100px"><col width="100px"><col width="90px"></colgroup>';
	// Drives
	$i=0;
	foreach($_ENV['weezoResEfFiles'] as $key=>$value) if(isset($value['type']) && $value['type']=='drive'){
		$output.='<tr id="drive'.$i.'" class="eTC '.(($i%2)?'odd':'even').'" eH=1 style="text-align:right'.(($value['driveReady'])?'" onclick="go(\'id'.$i.'\');" ':'; cursor:default"').'>';
		$output.='<td class="eTCLeft">';
		$output.=outImage($value['icon'],false,false,'margin-right:6px').'</td>';
		$output.='<td style="text-align:left;">';
		$output.=cfUTF8Encode($value['volumeName']).' (<span id="id'.$i.'" style="font-weight:bold">'.cfUTF8Encode(str_replace(':/',':',$value['name'])).'</span>)';
		if($value['totalSpace']) $output.=outProgressBar(0.999,'220px','%','drivePB'.$i,false,true).cfCaption('explorerDriveSpace',efFileSizeFormat($value['totalSpace']-$value['freeSpace']),efFileSizeFormat($value['totalSpace']));
		else $output.=outProgressBar(0,'220px','',false,false,false).'&nbsp;';
		$output.='</td>';
		$output.='<td>'.(($value['driveReady'])?cfCaption('genYes'):'<span class="warning">'.cfCaption('genNo').'</span>').'</td>';
		$output.='<td style="text-align:left;padding-left:1em">'.cfUTF8Encode($value['volumeType']).'</td>';
		$output.='<td>'.cfUTF8Encode($value['fileSystem']).'</td>';
		$output.='<td>'.efFileSizeFormat($value['totalSpace']).'</td>';
		$output.='<td class="eTCRight" style="padding-right:1em;">'.efFileSizeFormat($value['freeSpace']).'</td>';
		$output.="</tr>\n";

		if($i) $scriptOutput.=',';
		if($value['totalSpace']) $scriptOutput.=round(100*($value['freeSpace'] / $value['totalSpace'])); else $scriptOutput.='-1';
		$i++;
	}
	$output.="</table>";
	$output.="\n";
	cfRSetVar('prevPathIsComputerRoot',true);
	$scriptOutput.=');setBarProgress();';

	// Send to output
	cfAsyncOutputFlush($output,$asyncResponse,false,'<innerHTML nodeId="filesDiv">',false);

	if(!cfIsAsync()) efFilesList('filesDiv',array('dir'=>1,'commitDraw'=>false,'noSortControls'=>1));
}

/*
 ***************************************************************************************************************************
 * Display subdirs and files
 ***************************************************************************************************************************
 */
else{
	// If not async response or previous path was computer root, insert table header
	if(0 && efFilesListIsResource() && (!$asyncResponse || cfRGetVar('prevPathIsComputerRoot'))){
		// Table header
		$output.='<div class="frame2Header">';
		$output.=outTableTransparent('frame2Header','table-layout:fixed').'<colgroup>';

		// Empty space for left-side icons
		$output.='<tr><td style="width:'.$wl.'px">&nbsp;</td>';
		$output.='<td>';
		// Rating
		if(cfRGetVar('ratingAllowed') && cfGGetVar('ratingAllowed')) $output.='<div style="float:right;vertical-align:bottom">'.cfCaption('rating').outImage(outIcon('sup'),'javascript:srt(\'rating\',\'asc\');',false,'margin-left:5px;'.((cfGetBrowser()=='ie')?'position:relative;top:-6px':'')).outImage(outIcon('sdown'),'javascript:srt(\'rating\',\'desc\');',false,((cfGetBrowser()=='ie')?'position:relative;top:-6px':'')).'</div>';
		// File name
		$output.=cfCaption('explorerFilename').outImage(outIcon('sup'),'javascript:srt(\'name\',\'asc\');',false,'margin-left:5px;'.((cfGetBrowser()=='ie')?'position:relative;top:-6px':'')).outImage(outIcon('sdown'),'javascript:srt(\'name\',\'desc\');',false,((cfGetBrowser()=='ie')?'position:relative;top:-6px':''));
		$output.='</td>';
		// File size
		$output.='<td style="text-align:right;width:80px">'.cfCaption('genSize').outImage(outIcon('sup'),'javascript:srt(\'size\',\'asc\');',false,'margin-left:5px;'.((cfGetBrowser()=='ie')?'position:relative;top:-6px':'')).outImage(outIcon('sdown'),'javascript:srt(\'size\',\'desc\');',false,((cfGetBrowser()=='ie')?'position:relative;top:-6px':'')).'</td>';
		// Extra data
		if(cfRGetVar('displayExtraData')) $output.='<td style="width:90px">&nbsp;</td>';

		// File modification date header
		$output.='<td style="text-align:right;width:80px">'.cfCaption('explorerDate').outImage(outIcon('sup'),'javascript:srt(\'date\',\'asc\');',false,'margin-left:5px;'.((cfGetBrowser()=='ie')?'position:relative;top:-6px':'')).outImage(outIcon('sdown'),'javascript:srt(\'date\',\'desc\');',false,((cfGetBrowser()=='ie')?'position:relative;top:-6px':'')).'</td>';
		$output.="</tr></table></div>\n";


		// Table content
		$output.='<div id="filesTable"></div>';
		$output.='<div id="filesFooter" class="frame2Footer"></div>';

		// Send to output
		cfAsyncOutputFlush($output,$asyncResponse,false,'<innerHTML nodeId="filesDiv">',false);
	}

	cfRSetVar('prevPathIsComputerRoot',false);

	/**
	 * Get a JS array filled with files properties
	 */
	if(efFilesListIsResource()){
		$output=efFilesJSArray('all');
	}
	else{
		if(!cfIsAsync()) efFilesList('filesDiv',array('dir'=>1,'noSortControls'=>1));
	}
}

$i=0;

/**
 * Scripts (sync only)
 */
if(!$asyncResponse){
	echo "</div>\n";
	if(cfRGetVar('treeViewDisplayed'))	echo '</td></tr></table>';// Close treeView / files table
	echo "</div>\n"; // Close mainFileDiv
	outFrameShadowAfter();
	echo '</div>'; // close topDiv

	// Drag'n drop registration
	echo cfDragRegisterItems();
	?>
<script language="javascript" type="text/javascript">
var previousContent;
var pbStep;
var pbArr;
var savedElements=false;
var totalSize="<?php echo addslashes(efFileSizeFormat($totalSize));?>";
var fa=<?php if(strlen($output)) echo $output; else echo '[]';?>;

function tooltipGetContent(nodeId){
	if((W.dragInProgress && dragInProgress) || !dd.elements["previewFrame"]) return false;
	if(nodeId.substr(0,6)=='mDlDiv') {
		fAS('?'+nodeId,'getFileInfo',1);
	}
	else{
		var id=nodeId;
		if(id.substr(0,1)=='_') id=id.substr(1);
		fAS(((dgi(id))?dgi(id).innerHTML:id),'getFileInfo',1);
	}
	document.comForm.target='';
	return '<img id="tooltipLoading" src="">';
}
function preDrag(){
	if(dd.obj.name=='helpFrame') return;
	previousContent=dd.obj.div.innerHTML;
	// File moved
	if(!(W.filesListDisplayed&&filesListDisplayed!='resource') && dd.obj.name.substr(0,1)=='_') {
		dd.obj.write('<img src="/gfx/fi/icoBlank.gif" alt="" style="position:relative; left:-24px; top:0px; vertical-align:middle; margin-right:-16px;width:<?php echo 16*$imgRatio;?>px;height:<?php echo 16*$imgRatio;?>px"/>'+previousContent);
	}
	// Dir moved
	else {
		//dd.obj.write('<img src="/gfx/fi/folder.gif" alt="" style="position:relative; left:-24px; top:0px; vertical-align:middle; margin-right:-<?php echo 16*$imgRatio;?>px"/>'+previousContent);
	}
	return true;
}
function preDrop(){
	if(dd.obj.name.substr(0,3)!='_id' && dd.obj.name.substr(0,2)!='id') return;
	dd.obj.write(previousContent);	dd.recalc();
}
function image(src, extra){
	<?php
	if(cfGetBrowser()=='ie' && stripos(($_SERVER['HTTP_USER_AGENT']), "msie 7.0")==false) echo 'if(src.substr(src.length-4).toLowerCase()==".png") return \'<span style="filter:progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\'\'+src+\'\\\', sizingMethod=\\\'image\\\'); width:'.(16*$imgRatio).'px; height:'.(16*$imgRatio).'px;" \' + extra + \'></span>\';'."\n";
	?>
	return '<img src="'+src+'" '+extra+' alt=""/>';
}
function setButton(buttonName, enabled){
	if(!dgi(buttonName)) return;
	if(enabled){
		dgi(buttonName).style.display="inline";
		dgi(buttonName+"Disabled").style.display="none";
	}
	else{
		dgi(buttonName).style.display="none";
		dgi(buttonName+"Disabled").style.display="inline";
	}
}
function updateButtons(buttons){
	if(buttons.length!=4) return;
	setButton('rdlFormSubmitButton',buttons[0]);
	setButton('prevDirectoryButton',buttons[1]);
	setButton('upDirectoryButton',buttons[2]);
	setButton('newFolderButton',buttons[3]);
}

function setBarProgress(){
	var nbItems=0,animSteps=25,gap=2,step,perc,i;
	pbStep++;
	for(i=0;i<pbArr.length;i++){
		step=pbStep-nbItems*gap;
		if(pbArr[i]!=-1 && step>0 && step<=animSteps && dgi('drivePB'+i+'_inner')) {
			dist=100-pbArr[i];
			if(step*15+1<dist) {
				progressSetPerc('drivePB'+i,100-10*step)
			}
			else{
				preStep=Math.floor((dist-1)/15); preDist=10*preStep;
				nDist=dist-(dist-preDist)/(Math.pow(1.3,step-preStep));
				if(step==animSteps) nDist=dist;
				progressSetPerc('drivePB'+i,100-nDist)
				progressSetText('drivePB'+i,Math.floor(nDist)+'%')
			}
		}
		if(pbArr[i]!=-1 && dgi('drivePB'+i+'_inner')) nbItems++;
	}
	if(pbStep<animSteps+nbItems*gap) window.setTimeout("setBarProgress()",20);
}

function sDF(n,event){
	if(event && event.altKey) return; // On Chrome, pressing alt will trigger ondrag instead of onmousedown for outside-browser drag & drop
	var i=n.id.substr(1);
	if(dd.elements['_id'+i]) return;
	if(fa[i][3]==1) {
		dragItem="_id"+i+ELASTIC+DETACH+CURSOR_HAND+EPHEMERAL+<?php if(cfBGetVar('noScrollDiv')) echo 'SCROLL+';?>CTRLPLUS+PICKDELAY+400;
		if(dd.ie) {try{ADD_DHTML(dragItem,1);} catch(err){};} else ADD_DHTML(dragItem,1);
	}
}
function resetDraggableItems(){
	clearDraggableFiles();
	var di;
	var sc=dgi('filesDiv');
	if(fa.length<<?php echo cfHiGetVar('maxDragItems',80); ?>){
		for(i=0; i<fa.length; i++){
			if(fa[i][1]=='f') continue;
			di=0;
			if(fa[i][3]==1 && fa[i][4]==1) di="id"+i+EPHEMERAL+ELASTIC+DETACH+EASYDROP+RECEIVER+CURSOR_HAND+<?php if(cfBGetVar('noScrollDiv')) echo 'SCROLL+';?>CTRLPLUS+PICKDELAY+400;
			if(fa[i][3]==1 && fa[i][4]==0) di="id"+i+EPHEMERAL+ELASTIC+DETACH+CURSOR_HAND+<?php if(cfBGetVar('noScrollDiv')) echo 'SCROLL+';?>CTRLPLUS+PICKDELAY+400;
			if(fa[i][3]==0 && fa[i][4]==1) di="id"+i+EPHEMERAL+NO_DRAG+DETACH+CURSOR_HAND+EASYDROP+RECEIVER;
			if(di) {
				if(dd.ie) {try{ADD_DHTML(di,1);} catch(err){};} else ADD_DHTML(di,1);
				if(fa[i][1]=='d' && fa[i][4]==1) dd.elements["id"+i].setScrollContainer(sc)
			}
		}
		if(dd.ie) dd.recalc(); else dd.mkWzDom();
	}
}
function clearDraggableFiles(){
	for(var i=dd.elements.length-1; i>=0; i--){
		if(dd.elements[i].name.substr(0,2)=='id' || dd.elements[i].name.substr(0,3)=='_id') dd.elements[i].del(1);
	}
}
function insertFiles(){
	var nbFiles=0,nbFolders=0,adress,totCapt="<?php echo cfCaptionJS('explorerTotalFiles');?>";
	var output='<?php echo addslashes(outTableTransparent('frame2','text-align:center','id="filesTable"')); ?>';
	var to='',f,i, sTop=((W.keepScrollPos)?dgi('filesDiv').scrollTop:0);
	W.keepScrollPos=0;

	for(i=0; i<fa.length; i++){
		f=fa[i];

		// Controls
		ctr='';

		if(f[1]=='d' && f[8]==1) {
			// Directory multiple download
			ctr+=image("<?php echo outIcon('mdl');?>",'class="eIco" title="<?php echo cfCaptionJS('explorerMultipleDownloadAdd');?>" onclick="mAdd(\'id'+i+'\');"');
		}
		if(f[1]=='f'){
			// edit
			 if(f[6]==1) ctr+=image("<?php echo outIcon('edit');?>",'class="eIco" title="<?php echo cfCaptionJS('genEdit');?>" onclick="edit(\'id'+i+'\');"');
			// download & share
			if(f[7]>0) ctr+=
			<?php
			// Bittorrent download
			if(cfRGetVar('downloadShortcut') && cfGGetVar('bittorrentEnabled')){?>
			image("<?php echo outIcon('bittorrent');?>",'class="eIco" title="<?php echo cfCaptionJS('bittorrent');?>" onclick="btDl(\'id'+i+'\');"')+<?php } ?>
			image("<?php echo outIcon('dl');?>",'class="eIco" title="<?php echo cfCaptionJS('genDownload');?>" onclick="dl(\'id'+i+'\');"');
			// multiple download
			if(f[8]==1) ctr+=image("<?php echo outIcon('mdl');?>",'class="eIco" title="<?php echo cfCaptionJS('explorerMultipleDownloadAdd');?>" onclick="mAdd(\'id'+i+'\');"');
			ctr+='<'+'span id="id'+i+'" style="display:none">'+f[2]+'<'+'/span>';
			<?php
			// Share
			if(cfRGetVar('shareAllowed')){?>
			ctr+=image("<?php echo outIcon('share');?>",'class="eIco" title="<?php echo str_replace('...','',cfCaptionJS('doShare'));?>" onclick="share(\'id'+i+'\');"');
			<?php } ?>
		}

		<?php if(cfRGetVar('modifyAllowed')) { ?>

		// Rename
		if(f[13]) ctr+=image("<?php echo outIcon('ren');?>",'onclick="ren(\'id'+i+'\')" title="<?php echo cfCaptionJS('explorerRename');?>"');

		<?php } ?>

		// Execute
		if(f[14]) ctr+=image("<?php echo outIcon('exec');?>",'onclick="exe(\'id'+i+'\')" title="<?php echo cfCaptionJS('explorerExecute');?>"');

		// Suppress
		if(f[12] && <?php if(cfRGetVar('modifyAllowed')) echo 1; else echo 0; ?>) ctr+='&nbsp;&nbsp;&nbsp;'+image("<?php echo outIcon('del');?>",'onclick="sup(\'id'+i+'\')" title="<?php echo cfCaptionJS('genDelete');?>"');

		if(ctr) ctr='<span class="eControls"'+((W.ratingAllowed)?'style="right:80px"':'')+'><div>'+ctr+'</div></span>';


		to+='<'+'tr id="'+((f[1]=='d')?'c'+i:'f'+i)+'" class="eTC '+((i%2)?'odd':'even')+'" eH=1 ';
		if(f[1]=='f') to+='onmousedown="sDF(this,event)"';

		to+='><'+'td class="eTCLeft" style="text-align:right;width:<?php echo $wl;?>px;white-space:nowrap" ';
		// directory icon
		if(f[1]=='d'){
			nbFolders++;
			to+='>';
			if(f[5]==0) to+=image("<?php echo outIcon('fi/folder'); ?>",'class="eIco" style="margin-left:3px" onclick="go(\'id'+i+'\');"');
			if(f[5]==1) to+=image("<?php echo outIcon('fi/lockedFolder'); ?>",'class="eIco" style="margin-left:3px"');
		}
		// File icon
		if(f[1]=='f'){
			nbFiles++;
			to+='id="ic'+i+'">';
			if(f[5]=='/gfx/noX.png') to+=image(f[5],'class="eIco" title=""');
			else to+=image(f[5],'class="eIco" title="<?php echo cfCaptionJS('genView');?>" onclick="view(\'id'+i+'\');"');
		}
		to+='<'+'/td>';

		if(f[1]=='d'){
			// Directory name
			if(f[5]==1) to+='<'+'td style="padding-left:0.5em;text-align:left;cursor:default" class="warning"><'+'span id="_id'+i+'">'+f[2]+'<'+'/span><'+'/td>';
			else to+='<'+'td style="padding-left:0.5em;text-align:left" onclick="go(\'id'+i+'\');"><'+'span <?php if(cfHGetVar('tooltipFileInfo')){?>onmouseover="tooltip(this)" <?php } ?>id="id'+i+'" style="position:relative;width:100%" class="mainCapt">'+f[2]+'<'+'/span><'+'/td>';
		}
		if(f[1]=='f'){
			to+='<'+'td style="padding-left:0.5em;text-align:left" ' + ((f[7]>0 && <?php if(cfGetBrowser()=='ie') echo 'false'; else echo 'true';?>)?'onclick="if(wl.chrono.microtime()-wl.cancelCM<200) return. <?php if(cfBGetVar('download')) echo 'view'; else echo 'alert';?>(\'id'+i+'\');"':'') + '>';
			to+='<'+'span ' + ((f[7]>0)?'onclick="view(\'id'+i+'\');"':'') + 'id="_id'+i+'" style="position:relative;width:100%"';
			<?php if(cfHGetVar('tooltipFileInfo')){?> if(f[5]!='/gfx/noX.png') to+=' onmouseover="tooltip(this)"';<?php } ?>

			// File name
			to+=' class="mainCapt">'+f[2]+'<'+'/span>';
			// Rating
			to+=wl.ratingItem(i,f[15],0,{'extraStyle':'margin-left:1em;float:right'})+'<'+'/td>';
		}
		// Size
		to+='<'+'td style="cursor:default;text-align:right;white-space:nowrap;width:70px">'+ctr+(f[9]?f[9]:'&nbsp;')+'<'+'/td>';


		<?php
		// Extra data
		if(cfRGetVar('displayExtraData')) {
			?>to+='<'+'td style="text-align:right;width:90px">'+(f[11]?f[11]:'&nbsp;')+'<'+'/td>';
		<?php
		}
		?>

		// Date
		to+='<'+'td style="cursor:default;text-align:right;white-space:nowrap;width:80px" class="eTCRight">'+f[10]+'<'+'/td>';

		to+='<'+'/tr>\n';
		output+=to;	to='';
	}

	if(to) output+=to;
	// Min lines
	if(i<10){
		for(;i<10;i++) {
			output+='<'+'tr class="eTC '+((i%2)?'odd':'even')+'">';
			output+='<'+'td class="eTCLeft">&nbsp;<'+'/td><td'+' colspan="<?php echo ($nbCols-2);?>">&nbsp;<'+'/td><'+'td class="eTCRight">&nbsp;<'+'/td><'+'/tr>\n';
		}
	}
	// Total
	if(dgi('filesFooter')) dgi('filesFooter').innerHTML='<'+'table cellpadding="0" cellspacing="0" class="frame2Footer" style="width:100%;padding:0px;margin:0px;background:transparent;table-layout:fixed"><'+'colgroup><'+'tr><'+'td style="width:<?php echo $wl;?>px">&nbsp;<'+'/td><'+'td style="text-align:right">'+ totCapt.replace(/%1/,nbFolders).replace(/%2/,nbFiles)+'<'+'/td><'+'td style="text-align:right;width:80px">'+totalSize+'<'+'/td><'+'td style="width:80px">&nbsp;<'+'/td><?php if(cfRGetVar('displayExtraData')){?><'+'td style="width:90px"><'+'/td><?php } if(cfRGetVar('modifyAllowed')) {?><'+'td style="width:20px">&nbsp;<'+'/td><'+'td style="width:20px">&nbsp;<'+'/td><?php } ?><'+'td style="width:20px">&nbsp;<'+'/td><'+'/tr><'+'/table>';
	// Insert HTML
	dgi('filesTable').innerHTML=output;
	dgi('filesDiv').scrollTop=sTop;

	// Reset frames heights
	resetFrames();

	// reset draggable files and folders
	resetDraggableItems();

	// Chrome outside-browser drag & drop (user must press Alt key to prevent default drag):
	// add an ondragstart event to downloadable nodes, that will add DownloadURL to dataTransfer item
	for(i=0; i<fa.length; i++) if(fa[i][7]) altDragDownloadSet((dgi('_id'+i))?dgi('_id'+i):dgi('id'+i),dlURL('id'+i),fa[i][1]=='d');
}
<?php if($efCurrentDirectory!='computerRoot' && efFilesListIsResource()) echo 'insertFiles();'; else echo $scriptOutput;?>
if(dgi("goDirectInput")) dgi("goDirectInput").onkeypress=function(e){
	if(e) kc=e.which; else {if(window.event) kc=window.event.keyCode; else return;}
	if(kc==13) goDirect('goDirectInput');
}
if(dgi("rdlInput")) dgi("rdlInput").onkeypress=function(e){
	if(e) kc=e.which; else {if(window.event) kc=window.event.keyCode; else return;}
	if(kc==13) rdl('rdlInput');
}
<?php
	// Hide mDlList if toggled frames (in order not to receive ondrop events)
	if(cfRGetVar('multipleDownloadAllowed') && (!cfRGetVar('displayMultipleDownload') || !cfRGetVar('displayTransfers'))) echo 'dd.elements.mDlList.hide();';
?>
initFrames();
if(wl.uploadDragDropCapable()) connect(W,'onload',function(){if(W.setUploadReceiver) setUploadReceiver('filesDiv',1)});
</script>
<?php
// Wii Key manager
outKeysManager();
?>
</body>
</html>
<?php
}
// Async JS
elseif($asyncResponse){

	// Enable / disable upload form
	echo cfAsyncXMLJSaction('uploadFormEnable('.(int)((cfRGetVar('uploadAllowed') && $dirPermissions['upload'])).')');
	// Enable / Disable buttons (upload, remote download, prev dir, up dir, new folder
	echo cfAsyncXMLJSaction('updateButtons(['.
 		((cfRGetVar('remoteDownloadAllowed') && $dirPermissions['remoteDownload'])?'1,':'0,'). // rdlFormSubmitButton
		((cfRGetVar('efPreviousDirectories')!==false && count(cfRGetVar('efPreviousDirectories'))>0)?'1,':'0,'). // prevDirectoryButton
		(($efCurrentDirectory!='computerRoot' && cfFileRights($efCurrentDirectory."/..",'state')=='authorized')?'1,':'0,').// upDirectoryButton
		((cfRGetVar('createFolderAllowed') && cfFileRights($efCurrentDirectory, 'write'))?'1]);':'0])')); // newFolderButton
	// Set Clickable path
	echo cfAsyncXMLInnerHTMLbyId(outClickablePath(cfResourceRelativePath($efCurrentDirectory),false),'cPath');

	// Set files
	if(!$output) $output='[]';

	echo cfAsyncXMLJSaction('fa='.$output);

	if($efCurrentDirectory!='computerRoot'){
		if(efFilesListIsResource()){
			echo cfAsyncXMLJSaction('totalSize="'.addslashes(efFileSizeFormat($totalSize)).'";');
			echo cfAsyncXMLJSaction('insertFiles();');
		}
		else efFilesList('filesDiv',array('dir'=>1,'noSortControls'=>1));
	}
	else {
		echo cfAsyncXMLJSaction('resetDraggableItems();');
		echo cfAsyncXMLJSaction($scriptOutput);
		efFilesList(null,array('dir'=>1,'noSortControls'=>1));
	}
	// Set treeView
	if(cfRGetVar('treeViewDisplayed')) echo cfAsyncXMLJSaction($tree->updateAndSelectScript(cfRGetVar('efCurrentDirectory')).';resetFrames();');
	// Remove progress indicator
	echo cfAsyncXMLJSaction('asyncSetPI(0)');
	cfAsyncFooter();
}