<?php
/**
 * Music explorer configuration file
 *
 * Configuration of music explorer resource
 * this script is included by /res/administration/std/resourceConfig.php
 * this script should never be directly called.
 *
 * resourceConfig.php sets 2 variables :
 * $resourceData (array) which contains resource parameters loaded from user.res file
 * $_ENV['configurationEnvironment'] which indicates if resourceConfig.php has been called from browser ('browser')
 * or from application's embeded browser ('application')
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.0.0
 */

require_once(INCLUDE_DIR.'resourceConfigFunctions.php');
require_once(INCLUDE_DIR.'outputFunctions.php');

/*
 ***************************************************************************************************************************
 * Verify config rights
 ***************************************************************************************************************************
 */
$limitedConfig=rcConfigRights(true);

/*
 ***************************************************************************************************************************
 * Display configuration form
 ***************************************************************************************************************************
 */

// Insert Javascript function needed for save button activation, and <form> with hidden fields.
rcInsertScriptAndForm();

// Resource icon & name
rcInsertIconName($resourceData,true,array('rcSharedFilesBox'=>array('audio',WEnv::host()->specialFolderMusic(),array('noComputerRoot'=>1))));

/**
 * Shared folder or items
 */
//rcSharedFilesBox('audio',WEnv::host()->specialFolderMusic());


/*  Advanced config section
    vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv*/

if(!$limitedConfig){
	rcAdvancedConfigStart(array('noTopSeparator'=>1));
	// Download shortcut
	rcProcessData('downloadShortcut',dataUserRights,'none',false,cfCaption('explorerDownloadShortcut').'&nbsp;&nbsp;&nbsp;'.outHelpButton('helpSDL'), false);

	// Multiple download
	rcProcessData('multipleDownloadAllowed',dataUserRights,'none',false,cfCaption('configAllowMultipleDownload').'&nbsp;&nbsp;&nbsp;'.outHelpButton('helpMD'),false);

	// Allow/Forbid file rating
	if(cfGGetVar('ratingAllowed')) rcProcessData('ratingAllowed',dataUserRights,'all',false,cfCaption('ratingAllowed'),false,false);

	echo '<br>';

	// File view (image, audio,...)
	rcProcessData('fileViewAllowed',dataBoolean,true,false,false); // Allow/forbid user to listen to audio files

	// File access parameters (apply to files and folders located in "path")
	rcProcessData('downloadAllowed',dataBoolean,true,false,false/*do not display control*/); // Allow/forbid read access to files and folders
	rcProcessData('writeAllowed',dataBoolean,false,false,false/*do not display control*/); // Allow/forbid write access to files and folders
	rcProcessData('modifyAllowed',dataBoolean,false,false,false/*do not display control*/); // Allow/forbid modifcation access to files and folders (need writeAllowed to true)
	rcProcessData('executeAllowed',dataBoolean,false,false,false/*do not display control*/); // Allow/forbid execute access to files
	rcProcessData('uploadAllowed',dataBoolean,false,false,false/*do not display control*/); // Allow/forbid file upload
	rcProcessData('remoteDownloadAllowed',dataBoolean,false,false,false/*do not display control*/); // Allow/forbid remote download of files

	rcProcessData('userTempDirAccessAllowed',dataBoolean,false,false,false/*do not display control*/); // Allow/forbid access to user temp directory (data/sessiondata/(session_id)/)
	rcProcessData('resourceDataDirAccessAllowed',dataBoolean,true,false,false/*do not display control*/); // Allow/forbid access to resource directory (data/res/(res type)/(res subType)/(res file name)/)
	rcProcessData('bittorrentEnabled',dataBoolean,false,false,false); // Allow / Forbid bittorrent download
}


echo '<div class="frame3">';
// Default audio player
echo '<b>'.cfCaption('musicCfgDefaultPlayer').'</b><br>';

rcProcessData('audioPlayer',dataList,'flash',array('qt','wmp','flash','external'),array(
	array(false,'flash',array(outIcon('flash'),cfCaption('musicCfgFlash'))),
	array(false,'qt',array(outIcon('qt'),'Quicktime')),
	array(false,'wmp',array(outIcon('wmp'),cfCaption('musicCfgEmbeded'))),
	array(false,'external',array(rcResourceImage('external.gif'),cfCaption('musicCfgExternal')))));


echo '<br>';
echo '<b>'.cfCaption('musicPlayerPosition').'</b><br/>';
rcProcessData('inlinePlayer',dataBoolean,true,false,array(cfCaption('musicInlinePlayer'),cfCaption('musicPopupPlayer')));

// Maximum output bit rate
if(!$limitedConfig){
	echo '<br/>';
	rcProcessData('maxOutputBitRate',dataList,'original',array('original','128','64','32'),array(
	array(rcResourceImage('cfgMaxBitrate.png'),cfCaption('musicCfgMaxBr')),array(
	array('original',cfCaption('musicCfgNoLimit')),
	array('128',cfCaption('explorerAudio128')),
	array('64',cfCaption('explorerAudio64')),
	array('32',cfCaption('explorerAudio32'))),false), false);
	echo outHelpButton('helpAudioMaxBR');
}
echo '</div><br>';

if(!$limitedConfig){
	rcProcessData('flashPlayerBufferLength',dataNumeric,3,false,false/*do not display control*/); // Default buffer time for flash audio player (seconds)
	rcProcessData('flashPlayerDefaultVolume',dataNumeric,70,false,false/*do not display control*/); // Default audio volume for flash audio player (percent)

	rcProcessData('sortField',dataList,'no',array('no','artist','album','artistAlbum'),array(
	array(cfCaption('genGroupBy')),array(
	array('no',cfCaption('genNoGroup')),
	array('artist',cfCaption('explorerAudioArtist')),
	array('album',cfCaption('explorerAudioAlbum')),
	array('artistAlbum',cfCaption('explorerAudioArtist').'/'.cfCaption('explorerAudioAlbum'))),false));

	// Layout
	rcProcessData('filesLayout',dataText,'resource',false,false/*do not display control*/); // Default files layout: resource specific */
	rcProcessData('filesLayoutLocked',dataBoolean,false,false,false/*do not display control*/); // Do not lock files layout (allow user to change) */

	// End of advanced config panel
	rcAdvancedConfigEnd();

	// Comments panel
	echo rcCommentsPanelControl();

	// Theme
	echo rcThemeSelectionControl();
}
// Save / cancel buttons
echo rcButtonSaveCancel();

// If resource need access to resource data dir, create it
rcCreateResourceDataDir();

// Indicate that resource has been initialized
rcProcessData('resourceConfigured',dataBoolean,true,false,false/*do not display control*/);

// Save parameters
rcWriteResourceFile($resourceData, $fileName);
?>
<script language="javascript" type="text/javascript">
function dataChanged(dataName,dataValue){
	if(dataName=="audioPlayer"){
		if(dataValue!='flash') {
			//if(dataValue=='external') document.getElementsByName('inlinePlayer')[0].checked='checked';
			document.getElementsByName('inlinePlayer')[1].checked='checked';
			document.getElementsByName('inlinePlayer')[0].disabled=true;
			document.getElementsByName('inlinePlayer')[1].disabled=true;
		}
		else{
			document.getElementsByName('inlinePlayer')[0].disabled=false;
			document.getElementsByName('inlinePlayer')[1].disabled=false;
		}
	}
	if(dataName=="inlinePlayer"){
		if(dataValue==true){
			document.getElementsByName("audioPlayer")[0].disabled=true;
			document.getElementsByName("audioPlayer")[0].checked='checked';
			document.getElementsByName("audioPlayer")[1].disabled=true;
			document.getElementsByName("audioPlayer")[2].disabled=true;
			document.getElementsByName("audioPlayer")[3].disabled=true;
		}
		else{
			document.getElementsByName("audioPlayer")[0].disabled=false;
			document.getElementsByName("audioPlayer")[1].disabled=false;
			document.getElementsByName("audioPlayer")[2].disabled=false;
			document.getElementsByName("audioPlayer")[3].disabled=false;
		}
	}
}
function dataInitForm(){
	dataChangedNV("audioPlayer");
}
dataInitForm();
</script>