<?php
/**
 * iTunes-based music explorer
 *
 * Display an audio files explorer based on iTunes music database
 * Audio files list
 * Playlist functions
 * Audio player (streaming)
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.4
 */


/**
 * @desc Init mobile specific data
 *
 */
function mmDBInitResourceData(){
	global $db;
	if(cfRGetVar('mobileParametersLoaded')) return;

	// Number of artists / albums / playlists per page
	cfRInitVar('itemsPerPage',20);

	// View
	cfRSetVar('view','search');
	if(dbSingleQuery("SELECT count(id) FROM tracks",$db)<=cfRGetVar('itemsPerPage')) cfRSetVar('view','files');

	// Bitrate
	cfRInitVar('outputBitRate','original');
	cfRSetVar('outputBitRate',cfBitrateMin(cfRGetVar('outputBitRate'),cfRGetVar('maxAudioBitrate')));

	// Done init
	cfRSetVar('mobileParametersLoaded',1);
}

/**
 * @desc Top right explorer-specific controls
 *
 * @return string: HTML code
 */
function mmDBTopControls(){
	$output='';

	$output.=mfAudioQualityControls(cfRGetVar('outputBitRate'));

	// View audio files button
	$output.=mfButton(false,'javascript:setView(\'files\')',outIcon('fi/med/icoMusList'),'id="setViewFiles"',(cfRGetVar('view')=='files')?'on':'');

	// Search files button
	$output.=mfButton(false,'javascript:setView(\'search\')',outIcon('fi/med/icoSearch'),'id="setViewSearch"',(cfRGetVar('view')=='search')?'on':'');

	// Tools (playlist/multiple downloads) button
	if(cfBGetVar('playlistFormat'))
		$output.=mfButton(false,'javascript:setView(\'tools\')',outIcon('fi/med/icoM3U'),'id="setViewTools"',(cfRGetVar('view')=='tools')?'on':'');

	return $output;
}

/**
 * @desc Insert scripts
 *
 */
function mmDBInsertScripts(){
	outInsertStandardComForm($_SERVER['PHP_SELF'],cfUTF8Encode(cfResourceRelativePath(cfRGetVar('efCurrentDirectory'))));
	// Common explorer js functions
	if(!cfBGetVar('inlineJS')) echo cfScriptLink('mExplorer.js');
	if(!cfBGetVar('inlineJS')) echo cfScriptLink('mMusicDB.js');
?>
<script type="text/javascript">
<?php
// Inline explorer scripts
if(cfBGetVar('inlineJS')) echo file_get_contents(cfAppDocRoot().'/js/mExplorer.js');
if(cfBGetVar('inlineJS')) echo file_get_contents(cfAppDocRoot().'/js/mMusicDB.js');
?>
var eV="<?php echo cfRGetVar('view'); ?>",
supportsPlaylist=<?php echo (cfBGetVar('playlistFormat'))?1:0;?>,
searchValue,
lPID="<?php echo cfRGetVar('Library Persistent ID');?>",
coverTemplate="<?php echo cfExtImage('*resourceBasePath*/IMAGEPATH',FULLVIEW_COVER_WIDTH,FULLVIEW_COVER_WIDTH,true,0,array('utf8Decode'=>true),true);?>",
coverSmallTemplate=coverTemplate,
hasPlaylist=<?php echo (cfBGetVar('playlistFormat'))?1:0;?>,
inlinePlayer=<?php echo (int)(cfRGetVar('inlinePlayer')||cfBGetVar('flash'));?>,
hmsCaption="<?php echo cfCaptionJS('javascriptHourMinSecFormat');?>",
msCaption="<?php echo cfCaptionJS('javascriptMinSecFormat');?>",
defaultCoverSrc='<?php echo dirname($_SERVER['PHP_SELF']);?>/cover.png',
fvCoverWidth=<?php echo FULLVIEW_COVER_WIDTH;?>,defAudioWidth=<?php echo DEFAULT_AUDIO_WINDOW_WIDTH;?>,defAudioHeight=<?php echo DEFAULT_AUDIO_WINDOW_HEIGHT;?>,
sourceType="<?php echo SOURCE_TYPE; ?>";
html5AP.vol=<?php echo (int)cfUGetVar('audioVolume');?>
</script>
<?php
}

/**
 * @desc display filter area HTML code
 * @return void
 *
 */
function mmDBDisplayFilter(){
	global $itemsPerPageList;

	$output='';

	/**
	 * Group by
	 */
	$output.='<div class="frame1Header">'.cfCaption('genGroupBy').'</div>';

	$output.=mfListTable();
	// Group by artist
	$output.=mfListItem('name="selGroup" '.((0&&cfRGetVar('groupBy')=='Artist')?' class="liSel"':'').' onclick="wl.liGrSel(this);groupBy(\'Artist\')"',outImage(outIcon('user'),false,'class="frLi2"'),false,'<span class="lit">'.cfCaption('explorerAudioArtist').'</span>',false,'<b class="goIco"></b>');

	// Group by album
	$output.=mfListItem('name="selGroup" '.((0&&cfRGetVar('groupBy')=='Album')?' class="liSel"':'').' onclick="wl.liGrSel(this);groupBy(\'Album\')"',outImage(outIcon('medCover'),false,'class="frLi2"'),false,'<span class="lit">'.cfCaption('explorerAudioAlbum').'</span>',false,'<b class="goIco"></b>');

	// Group by playlist
	$output.=mfListItem('name="selGroup" '.((0&&cfRGetVar('groupBy')=='Playlist')?' class="liSel"':'').' onclick="wl.liGrSel(this);groupBy(\'Playlist\')"',outImage(outIcon('fi/med/icoM3U'),false,'class="frLi2"'),false,'<span class="lit">'.cfCaption('explorerAudioPlaylist').'</span>',false,'<b class="goIco"></b>');

	$output.='</table>';

	/**
	 * Search
	 */
	$output.='<br><div class="frame1Header">'.cfCaption('genSearch').'</div>';
	$output.=mfListTable();
	$textInput='<input class="textInput lit" cols="1" id="searchInput" autocorrect="off" autocapitalize="off" value="'.((cfRGetVar('groupBy')=='Search')?str_replace('%','',cfRGetVar('searchValue')):'').'" onchange="wl.liGrSel(dgi(\'liSearch\'));search(this.value)">';
	$output.=mfListItem('name="selGroup" id="liSearch" '.((cfRGetVar('groupBy')=='Search')?' class="liSel"':''),outImage(outIcon('search'),false,'class="frLi16"'),'onclick="wl.liGrSel(dgi(\'liSearch\'));search(dgi(\'searchInput\').value)"',$textInput);

	$output.='</table>';

	/**
	 * Display options
	 */

	// Items per page
	$output.='<br><div class="frame1Header">'.cfCaption('explorerItemsPerPage').'</div>';
	$output.=mfListTable();
	foreach ($itemsPerPageList as $value){
		$output.=mfListItem((($value==cfRGetVar('itemsPerPage'))?'class="liSel" ':'').'name="ippGroup" onclick="wl.liGrSel(this);changeItemsPerPage(\''.$value.'\')"',
		outImage(outIcon('go'),false,'class="frLi16"'),false,
		'<span class="lit">'.(($value==0)?cfCaption('genAll').' ':$value).'</span>',false);
	}
	$output.='</table>';

	// Compact / Full display
	$output.='<br><div class="frame1Header">'.cfCaption('genDisplay').'</div>';
	$output.=mfListTable();
	$output.=mfListItem('name="dGroup" '.((cfRGetVar('displayType')!=='displayCompact')?' class="liSel"':'').' onclick="wl.liGrSel(this);changeDisplayType(\'displayFull\')"',outImage(outIcon('displayFull'),false,'class="frLi16"'),false,'<span class="lit">'.cfCaption('activityLogDetailDet').'</span>',false,'&nbsp;');
	$output.=mfListItem('name="dGroup" '.((cfRGetVar('displayType')=='displayCompact')?' class="liSel"':'').' onclick="wl.liGrSel(this);changeDisplayType(\'displayCompact\')"',outImage(outIcon('displayList'),false,'class="frLi16"'),false,'<span class="lit">'.cfCaption('activityLogDetailInf').'</span>',false,'&nbsp;');


	// Database update
	if(cfRGetVar('databaseUpdateMethod')=='manual'){
		$output.=mfListSpacer();
		$output.=mfListItem('onclick="updateDatabase()"',outImage(outIcon('change'),false,'class="frLi16"'),false,'<span class="lit">'.cfCaption('genDataUpdate').'</span>');
	}

	return $output.'</table>';
}


// Initialize mobile specific data
mmDBInitResourceData();

require_once(INCLUDE_DIR.'mobileFunctions.php');

$itemsPerPageList=array('0','10','20','50','100','200','500');

// Process mobile-specific posts
mfProcessPOST();

/*
 ***************************************************************************************************************************
 * Insert HEAD, JS functions and form
 ***************************************************************************************************************************
 */
mfInsertHead(array('topControlsExtra'=>mmDBTopControls()));

// Scripts
if(!cfIsAsync()) mmDBInsertScripts();

// Flash / HTML5 player
if((cfRGetVar('inlinePlayer') || cfBGetVar('flash')) && !cfIsAsync()){
	require_once('viewFunctions.php');
	echo '<span id="playerDiv" style="margin-right:1em">'.vfInsertAudioPlayer('','normal',false,'95%',40).'</span>';
}

// Album/artists/playlists templates
if(!cfIsAsync()) require(dirname(__FILE__).'/mobileTemplates.php');

/**
 * Tools (playlist / multiple downloads)
 */
if(cfRGetVar('view')=='tools'){
	require_once(INCLUDE_DIR.'mobileExplorerFunctions.php');
	mefDisplayTools(array('noMAddAll'=>1));
	if(cfIsAsync()) echo(cfAsyncFooter(false));
}

/**
 * Artists / Albums / Playlists
 */
elseif(cfRGetVar('view')=='files'){
	// If view changed to files, simulate a display update
	if(isset($_POST['data3']) && $_POST['data3']=='setView') {
		$_POST['data3']='refreshDisplay';
		mDBprocessPost();
		exit;
	}
	$output='<div class="frame2" style="line-height:10em;text-align:center;vertical-align:middle"><br/>'.outImage(outIcon('loading')).'<br/></div>';
	if(cfIsAsync()) {
		echo cfAsyncXMLInnerHTMLbyId($output,'mainDiv');
		echo(cfAsyncFooter(false));
	}
	else echo('<div id="mainDiv">'.$output.'</div></body></html>');
}


/*
 ***************************************************************************************************************************
 * FILTER AREA
 ***************************************************************************************************************************
 */
else{
	$output=mmDBDisplayFilter(true);
	if(cfIsAsync()) {
		echo cfAsyncXMLInnerHTMLbyId($output,'mainDiv');
		echo cfAsyncFooter(false);
	}
	else echo('<div id="mainDiv">'.$output.'</div></body></html>');
}
dbClose($db);
// Init page (not put into body onload as it seems not to fire sometime...
if(!cfIsAsync()){?><script type="text/javascript">init()</script><?php }
exit;