<?php
/**
 * iTunes-based music explorer
 *
 * Display an audio files explorer based on iTunes music database
 * Audio files list
 * Playlist functions
 * Audio player (streaming)
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.0.5
 */

require(INCLUDE_DIR.'outputFunctions.php');
require(INCLUDE_DIR.'explorerFunctions.php');
require_once(INCLUDE_DIR.'databaseFunctions.php');
require(INCLUDE_DIR.'musicDBFunctions.php');

// Constants
define('DEFAULT_AUDIO_WINDOW_WIDTH',350);
define('DEFAULT_AUDIO_WINDOW_HEIGHT',425);
define('DEFAULT_PLAYLIST_WINDOW_HEIGHT',465);
define('DEFAULT_INLINEPLAYER_WIDTH',((cfIsWII())?400:250));
define('DEFAULT_INLINEPLAYER_HEIGHT',((cfIsWII())?'165px':'115px'));
define('DEFAULT_INLINE_COVER_WIDTH',((cfIsWII())?130:80));
if(cfIsWII()) define('FULLVIEW_COVER_WIDTH',120);
elseif(cfIsMobile()) define('FULLVIEW_COVER_WIDTH',48);
else define('FULLVIEW_COVER_WIDTH',80);

define('FULLVIEW_COVEREXT_WIDTH',160);

$itemsPerPageList=array('0','10','20','50','100','200','500');

// Init resource data
initResourceData();

// Open database
$newDB=openMusicDb();

// Debug
if(isset($_GET['debug']) && $_SERVER['REMOTE_ADDR']=='127.0.0.1') {cfInsertHEAD();mDBDumpBase();exit;}

// Update database if needed
$updateDBRequested=(@$_POST['data3']=='updateDatabase') || isset($_GET['updateDatabase']) || $newDB;
if($updateDBRequested || !isset($_POST['asyncRequest'])){

	if(@$_POST['data3']=='updateDatabase' && $_POST['data4']==1 && cfIsOnLAN()) cfRSetVar('debug',true);

	if(SOURCE_TYPE=='iTunes') updateDBITunes ($updateDBRequested);
	if(SOURCE_TYPE=='folder') updateDBFolders($updateDBRequested);
	if(SOURCE_TYPE=='winamp') updateDBWinamp ($updateDBRequested);
}

// Init iTunes specific data (requires populated DB)
if(SOURCE_TYPE=='iTunes') {
	// Get Library Persistent ID
	if(!cfRGetVar('Library Persistent ID')) cfRSetVar('Library Persistent ID',dbSingleQuery('SELECT value FROM library WHERE property="Library Persistent ID"',$db));
	// Set albums artwork path
	if(!cfRGetVar('path')) {
		if(is_dir(cfRGetVar('musicITunesFolder').'/Album Artwork/Cache/'.cfRGetVar('Library Persistent ID')))
			cfRSetVar('path',cfRGetVar('musicITunesFolder').'/Album Artwork/Cache/'.cfRGetVar('Library Persistent ID'));
		else
			cfRSetVar('path',cfRGetVar('musicITunesFolder').'/Album Artwork/Local/'.cfRGetVar('Library Persistent ID'));
	}
}

/*
 ***************************************************************************************************************************
 * Process POST
 ***************************************************************************************************************************
 */
mDBprocessPost();
cfAsyncXMLChangePhpVarValue('displayPlayer'); // process hide / show player and playlist (deprecated ???)
cfAsyncXMLChangePhpVarValue('displayMultipleDownload'); // process hide / show player and playlist
cfAsyncXMLChangePhpVarValue('outputBitRate',array('32','64','128','original')); // Update reencoded bitrate
cfAsyncXMLChangePhpVarValue('forceHTML5AudioPlayer'); // Use HTML5 audio player instead of flash player

//cfRSetVar('displayMultipleDownload',cfRGetVar('displayPlayer')); // Link playlist and player collapse states


/**
 * If mobile device, redirect to mobile explorer
 */
if(cfIsMobile()) {require(cfAppDocRoot().'/res/explorer/music2/mobileMusicDBView.php'); exit;}


/*
 ***************************************************************************************************************************
 * Insert HEAD, JS functions and form
 ***************************************************************************************************************************
 */
efInsertExplorerHeadAndBody('onresize="if(W.resizeDivs) resizeDivs()"');

echo '<div id="pageHeightDiv" style="position:absolute;top:0px;width:1px;height:100%;"></div>';


echo outTableTransparent(false,'vertical-align:top','id="explorerTable"');
echo '<tr><td id="explorerTd" style="width:100%;height:100%;vertical-align:top">';

/*
 ***************************************************************************************************************************
 * INLINE PLAYER AREA
 ***************************************************************************************************************************
*/
if(cfRGetVar('inlinePlayer')) {
	echo '<table class="banner" style="width:100%;margin:0;border-bottom:0"><colgroup><col width="'.DEFAULT_INLINEPLAYER_WIDTH.'"><col width="*"></colgroup><tr valign="top"><td style="padding-right:0.5em">';
	outDisplayInlineAudioPlayer();
	echo '</td><td>';
}
/*
 ***************************************************************************************************************************
 * PLAYLIST AREA
 ***************************************************************************************************************************
 */
echo outMultipleDownloadList('frame1','db',true,false,'padding-bottom:0px;'.((cfBGetVar('playlistFormat') || cfBGetVar('download'))?false:'display:none'),false,false,array('m3u'=>1,'inlinePlayerFold'=>1));

//outFrameShadowAfter();

if(cfRGetVar('inlinePlayer')) echo '</td></tr></table>';
echo '</div>';

/*
 ***************************************************************************************************************************
 * BOTTOM HALF
 ***************************************************************************************************************************
 */
echo '<table class="banner" style="width:100%;margin:0;border-top:0"><tr valign="top"><td>';
/*
 ***************************************************************************************************************************
 * MAIN AREA (SELECTION)
 ***************************************************************************************************************************
 */
echo outDivFrame('frame1','id="explorerDiv"','overflow:hidden;margin-bottom:0');
echo outFrameHeaderTable('frame1Header',((cfBGetVar('playlistFormat'))?outButton(false,'javascript:plAddAllShuffle()',outIcon('randomAll'),false,false,'style="vertical-align:middle;right-margin:0.5em"'):'').cfCaption('musicSelection'),'<div id="selectionRange"></div>')."\n";

echo outDivFrame('','id="selectionDiv"'.outEHoverFrameAttr(),'min-height:200px;margin:0;overflow:auto');
list($lw, $lh, $type, $attr) = getimagesize(cfAppDocRoot().'/'.outIcon('loadingBig'));
echo outImage(outIcon('loadingBig'),false,false,'position:absolute;top:50%;left:50%;margin-left:-'.($lw/2).'px;margin-top:-'.($lh/2).'px');
echo "</div>\n"; // selectionDiv
echo "</div>\n"; // Frame1
echo '</td></tr></table>';
echo "</td>\n\n";

// Right-panel collapse handle
echo outCollapsableTD('filterTd','right',array('class'=>'vBanner','postToggleJS'=>'resizeDivs()'));

/*
 ***************************************************************************************************************************
 * FILTER AREA
 ***************************************************************************************************************************
 */
echo '<td class="vBanner" id="filterTd" style="height:100%;vertical-align:top;'.((cfIsWII())?'width:1px;overflow:hidden;display:none':'').'">';
echo displayFilter();


echo '</td></tr></table>';
//outFrameShadowAfter();
echo "</div>\n\n";
dbClose($db);



/*
 ***************************************************************************************************************************
 * SCRIPTS
 ***************************************************************************************************************************
 */
$scriptDir=str_replace('\\','/',substr(dirname(__FILE__),strlen(cfAppDocRoot())));
// Immediately resize divs
?>
<script type="text/javascript">
function resizeDivs(){
	alignBottom(dgi('explorerDiv'),winMe,5);
	alignBottom(dgi('selectionDiv'),dgi('explorerDiv'),0);
	alignBottom(dgi('filterDiv'),dgi('explorerDiv'));
	if(W.mDBDestId && W.mDBDisplayType=='covers') coversDetailSetMargins(mDBDestId)
}
resizeDivs();
</script>
<?php

// Then insert other scripts
displayJavascript();

/*
 ***************************************************************************************************************************
 * TEMPLATES
 ***************************************************************************************************************************
 */
require(dirname(__FILE__).'/templates.php');
?>
<script type="text/javascript">
function preInit(){init(<?php echo efPlayListContentArray();?>)}
wl.imgPreload("<?php echo $scriptDir;?>/artistBg.png");
wl.imgPreload("<?php echo $scriptDir;?>/albumBg.png",preInit,preInit);
<?php echo cfJSCaptionVar('storePlaylistDesc');?>
<?php echo cfJSCaptionVar('explorerFilename');?>
<?php cfDragRegisterItems('',false);?>;
monitorMousePosition();
</script>
</body>
</html>