<?php
/**
 * Control access to scripts
 *
 * This script is automatically prepend to scripts (php.ini)
 * Verify before each script execution that user is allowed,
 * start session and include commonFunctions.php
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.0.0
 */

define('DISPLAY_ERROR_STACK',1);

if(substr($_SERVER['PHP_SELF'],0,13)=='/testDiag.php') return;

/**
 * @desc Trace incoming connections
 *
 */
function securityDebugRequest(){
	// Synchronous page debuging
	if(cfMGetVar('debugSync')===@$_SERVER['REMOTE_ADDR'] && !cfIsAsync() && !isset($_GET['asyncRequest']) && $_SERVER['PHP_SELF']!='/ping.php') {
		ob_start();
		register_shutdown_function('cfSyncDebugShutdown');
	}
	//cfMUnsetVar('threadsDebugSem');
	if(cfMGetVar('debugThreads')) cfThreadsDebugInit();

	//if(!cfIsAsync() && (substr(@$_SERVER['REQUEST_URI'],0,5)=='/res/' || substr(@$_SERVER['REQUEST_URI'],0,7)=='/local/')) cfDebugSetBuffer('sync',$_POST,@$_SERVER['HTTP_USER_AGENT']);
	//if(!cfIsAsync() && (substr(@$_SERVER['REQUEST_URI'],0,6)!=='/local')) cfDbg('>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> RID='.cfRequestId().' >> '.$_SERVER['REQUEST_URI']);
}

/**
 * @desc Initialize chrono, base include directory and load commonFunctions.php
 *
 */
function securityInit(){
	// Fix PHP 5.3+ date issue
	date_default_timezone_set(@date_default_timezone_get());

	// Start profiling chrono
	$_ENV['chrono'][0]=array('label'=>'Start','time'=>microtime(true));
	$_ENV['configurationEnvironment']='browser';
	$_ENV['requestID']=rand();

	// Set document root
	define('DOCUMENTROOT_DIR',(@$_SERVER['DOCUMENT_ROOT'])?$_SERVER['DOCUMENT_ROOT'].'/':str_replace('\\','/',dirname(__FILE__)).'/');
	define('INCLUDE_DIR',DOCUMENTROOT_DIR.'includes/');
	define('W_THEMES_DIR',DOCUMENTROOT_DIR.'themes/');

	// Treeview class autoload
	if(substr($_SERVER['PHP_SELF'],0,9)!='/res/misc' && substr($_SERVER['PHP_SELF'],0,7)!='/alias.' && substr($_SERVER['PHP_SELF'],0,4)!='/pub'){
		function __autoload($class_name) {
			if($class_name=='treeView' || $class_name=='treeViewFolder')  require_once(INCLUDE_DIR.'treeViewClass.php');
		}
	}

	// Include common functions
	require(INCLUDE_DIR.'commonFunctions.php');
	set_error_handler('securityErrorHandler');
	$_ENV['weezoScriptId']=rand();

	// PHP5.3 IPV6->IPV4 conversion
	if(@$_SERVER['REMOTE_ADDR']=='::1') $_SERVER['REMOTE_ADDR']='127.0.0.1';

}
/**
 ***************************************************************************************************************************
 * Dump PHP errors into /data/log/phpErrors.txt
 ***************************************************************************************************************************
 */
function securityErrorHandler($errno, $errstr, $errfile, $errline){
	static $hideErrors;
	if (error_reporting() == 0) return true; // No err report for @ prefixed functions
	if(!isset($hideErrors)) $hideErrors=(bool)cfGGetVar('phpHideErrors');

	// If errors must be logged
	if ((error_reporting() | $errno) == error_reporting() && cfGGetVar('phpLogErrors')) {
		$errorType = array (E_ERROR=>'ERROR',E_WARNING=>'WARNING',E_PARSE=>'PARSINGERROR',E_NOTICE=>'NOTICE',E_CORE_ERROR=>'COREERROR',E_CORE_WARNING=>'COREWARNING',E_COMPILE_ERROR=>'COMPILEERROR',E_COMPILE_WARNING=>'COMPILEWARNING',E_USER_ERROR=>'USERERROR',E_USER_WARNING=>'USERWARNING',E_USER_NOTICE=>'USERNOTICE',E_STRICT=>'STRICTNOTICE',E_RECOVERABLE_ERROR=>'RECOVERABLEERROR');
		if (array_key_exists($errno, $errorType)) $err = $errorType[$errno]; else $err = 'CAUGHT EXCEPTION';
		cfAppendTextToFile(date('d/m-H:i:s').':'."$err [$errno] $errstr in $errfile on line $errline ".$_SERVER['PHP_SELF'],cfAppLogDir().'/'.PHP_ERRORS_LOG_FILE,false);
	}
	if(DISPLAY_ERROR_STACK && (error_reporting() | $errno) == error_reporting() && !$hideErrors) {
		static $label=array(1=>'ERROR',2=>'WARNING',4=>'PARSE ',8=>'NOTICE',2048=>'STRICT',8192=>'DEPRECATED');
		echo '<div style="font-size:9px;font-family:arial;color:#448;padding:5px;border:1px solid #AAA;background:#F5F5F5"><div  style="color:black;font-size:110%"><b>'.((isset($label[$errno]))?$label[$errno]:$errno).'</b> - '.$errstr.' in <b>'.$errfile.'</b> on line <b>'.$errline.'</b></div>';
		$stack=debug_backtrace();
		foreach ($stack as $errn=>$err) if($errn){
			echo "<b>[".$errn."]</b> ".@$err['file']." at line <b>".@$err['line'].'</b> in function <b>'.$err['function'].'</b>(';
			if(isset($err['args'])) foreach ($err['args'] as $k=>$v) echo (($k===0)?'':',').((is_object($v))?'[Object]':$v).' ';
			echo ')'.(($errn!=count($stack)-1)?'<br>':'');
		}
		echo '</div><br>';
		return true;
	}
	// If errors must be displayed
    return $hideErrors;
}

/**
 * @desc write log event, display error page if needed and exit() so called script is not executed
 *
 * @param string $logString : log text
 * @param intenger $logLevel
*/
function securityRejectConnection($logString=false, $logLevel=LOG_DBG){
	if($logString) cfLog('security.php:'.$logString ,$logLevel);

	// Normal GET/POST request
	if(!cfIsAsync()){
		// Published / direct resource access: weezo session has expired due to use inactivity, but cookie token is still in cookie: re-log.
		if(isset($_COOKIE['weezoPublishToken']) || isset($_COOKIE['weezoDirectResourceAccessToken']))	{
			if(isset($_COOKIE['weezoPublishToken'])) $_ENV['publishTokenBeforeLogoutURI']=$_SERVER['REQUEST_URI'];
			if(isset($_COOKIE['weezoDirectResourceAccessToken'])) $_ENV['directResourceAccessTokenBeforeLogoutURI']=$_SERVER['REQUEST_URI'];
			require_once(cfAppDocRoot().'/login.php');
		}
		else if($_SERVER['PHP_SELF']=='/index.php') {
			$securityEvent=$logString;
			require_once(cfAppDocRoot().'/login.php');
		}
		else{
			// Insert script for reloading page after 2secs in highest possible frame
			$logString.='<script language="javascript" type="text/javascript">function reloadIndex(){';

			$logString.='var l,f=window; while(1){try{if(f.parent && f!=f.parent && f.parent.location) f=f.parent; else break;} catch(e){break}}';
			$logString.='f.location="/index.php"}';
			$logString.='setTimeout("reloadIndex()",2000);';
			$logString.='</script>';
			require_once(INCLUDE_DIR.'outputFunctions.php');
			outDisplayErrorPage($logString);
		}
	}
	// Async request
	else{
		cfAsyncHeader();
		echo cfAsyncXMLJSaction('setTimeout(function(){document.location.href="/index.php"},1000)');
		cfAsyncFooter();
	}
	exit();
}

/**
 * Preprocess POST & GET
 *
 */
function securityPreprocessArgs(){
	// Transforms command-line args into GET args
	if(isset($_SERVER['argv'])) {foreach ($_SERVER['argv'] as $expr) if(strpos($expr,'=')) $_GET[substr($expr,0,strpos($expr,'='))]=substr($expr,strpos($expr,'=')+1);}
	// Transform async GET request into POST (backward compatibility)
	if(isset($_GET['asyncRequest']) && $_GET['asyncRequest']==true) $_POST=$_GET;
	// Correct POST parameters sent by HTTPXmlRequest
	if(isset($_POST['asyncRequest']) && $_POST['asyncRequest']=='true'){
		foreach ($_POST as $key=>$value) $_POST[$key]=str_replace('$weezoPlus$','+', $_POST[$key]);
	}
	// Correct GET parameters
	else foreach ($_GET as $key=>$value) $_GET[$key]=str_replace('$weezoPlus$','+', $_GET[$key]);

	// Convert $_GET['reloadPostData'] into actual $_POST data
	if(isset($_POST['reloadPostData']) && $_POST['reloadPostData']) {
		foreach (explode('&',$_POST['reloadPostData']) as $d) {
			list($k,$v)=explode('=',$d,2); $_POST[$k]=base64_decode($v);
		}
	}
}

/**
 ***************************************************************************************************************************
 * Script access control function
 ***************************************************************************************************************************
 */
function securityResourceVerifyAccessRight(){
	global $w_lng;

	$exeptionsListBeforeSessionStart=array(
		'/dummy.php',
		'/api.php',

		'/404.php',
		'/empty.html',
		'/UWA.php',
		'/index.php',
		'/login.php',
		'/ping.php',
		'/local/ping.php',
		'/forbidden.php',
		'/ext/video.php',
		'/ext/videoIPhone.php',
		'/ext/image.php',
		'/ext/fileIcon.php',
		'/ext/audio.php',
		'/ext/download.php',
		'/ext/publishedVideo.php',
		'/bittorrentSeeder.php',
		'/bittorrentTracker.php',
		'/widgets/monitor.php',
		'/servDbg.php',
		'/themes/mobile/cache.manifest.php',
		'/local/tmp.php'
	);
	$exeptionsListBeforeLogin=array(
		'/themes/themePreview.php',
		'/themes/themePreviewMenu.php',
		'/themes/themePreviewBody.php',
		'/help.php'
	);
	$exeptionsListAfterLogin=array(
		'/menuFrame.php',
		'/mainFrame.php',
		'/noResource.php',
		'/imgGen.php',
		'/themes/wallpaperSelection.php',
		'/gfx/ext/ext.php',
		'/ext/flvVolume.php',
		'/ext/qrCode.php'
	);

	// Block weezo proxy
	if(isset($_SERVER['HTTP_USER_AGENT']) && substr($_SERVER['HTTP_USER_AGENT'],-10)=='weezoProxy') die(cfCaption('genNoAccess'));

	// Disable controls for CLI scripts
	if(cfIsCLI())  return true;

	// Disable control for IU scripts
	if(substr($_SERVER['PHP_SELF'],0,5)=='/tmp_') return true;

	// Disable control for JS & CSS
	if(substr($_SERVER['PHP_SELF'],-3)=='.js' || substr($_SERVER['PHP_SELF'],-4)=='.css') {
		WHeaders::cache();
		if(substr($_SERVER['PHP_SELF'],-3)=='.js') die(file_get_contents(cfAppDocRoot().str_replace('..','.',$_SERVER['PHP_SELF']))); // Note: letting PHP parse file sometime results into an apache failure
		if(substr($_SERVER['PHP_SELF'],-4)=='.css')  return true;
	}

	// Disable controls for tests and scripts located in pub folder
	if(substr($_SERVER['PHP_SELF'],0,5)=='/test' || substr($_SERVER['PHP_SELF'],0,5)=='/pub/' || substr($_SERVER['PHP_SELF'],0,5)=='/incl') return true;

	// Allow 1st server initialization
	if($_SERVER['PHP_SELF']=='/local/serverManagement.php' && isset($_GET['setWeezoKey'])){
		if(!cfServerKeyIsset() || cfServerKeyCheck($_GET['setWeezoKey'])) return true;
		die('invalid key '.$_SERVER['PHP_SELF'].' get='.@$_GET['setWeezoKey']);
	}

	// IE token login workaround (cookie sometimes not set by login process)
	if(isset($_GET['WSESSID']) && !@$_COOKIE['WSESSID']) $_COOKIE['WSESSID']=$_GET['WSESSID'];

	// If script belongs to exeptionsListBeforeSessionStart (scripts that doesn't need external authentication), authorize
	if(in_array($_SERVER['PHP_SELF'], $exeptionsListBeforeSessionStart) ||
		substr($_SERVER['PHP_SELF'],0,18)=='/local/logOutputs/' ||
		substr($_SERVER['PHP_SELF'],0,15)=='/local/daemons/') return true;

	// Temp script
	if(substr($_SERVER['PHP_SELF'],0,10)=='/local/tmp' && cfServerKeyCheck($_GET['weezoKey'])) return true;

	// Start session
	if(isset($_GET['readOnlySession']) || isset($_POST['readOnlySession'])) wSession_start_nowrite(); else wSession_start();

	// Flash player upload workaround (WSESSID cookie not sent).
	if(!count($_SESSION)){
		if(isset($_POST['WSESSID']) && file_exists(cfAppDataDir().'/sessiondata/sess_'.$_POST['WSESSID'])) $wSessId=$_POST['WSESSID'];
		elseif(isset($_GET['WSESSID']) && file_exists(cfAppDataDir().'/sessiondata/sess_'.$_GET['WSESSID'])) $wSessId=$_GET['WSESSID'];
		if(isset($wSessId)){
			wSession_write_close();
			wSession_id($wSessId);
			if(isset($_GET['readOnlySession']) || isset($_POST['readOnlySession'])) wSession_start_nowrite(); else wSession_start();
		}
	}


	// If script belongs to exeptionList (scripts that doesn't need external authentication (but need session start)), authorize
	if(in_array($_SERVER['PHP_SELF'], $exeptionsListBeforeLogin)) return true;

	// Restore get parameters stored in session (used for transporting authentication data for third-party config scripts)
	if(cfGGetVar('resourceConfigOriginalGET')) {
		parse_str(cfGGetVar('resourceConfigOriginalGET'),$get);
		$_GET+=$get;
	}

	// Exeption for script launched by UI
	$weezoKey=(isset($_GET['weezoKey']))?$_GET['weezoKey']:((isset($_SESSION['weezoKey']))?$_SESSION['weezoKey']:0);

	while ($weezoKey && !cfServerKeyIsset()) usleep(1000);
	if($weezoKey && $_SERVER['REMOTE_ADDR']=='127.0.0.1' && cfServerKeyCheck($weezoKey)){
		$_SESSION['weezoKey']=$weezoKey;
		cfGSetVar('configurationEnvironment','application');
		cfGSetVar('resourceConfigScript','1'); // Backward compatibility for phpMyAdmin
		$_ENV['configurationEnvironment']='application';
		return true;
	}

	// if not "userLogged" (means that user didn't log in), go to index.php (this should happend when a session expires)
	if (!isset($_SESSION['userLogged'])) securityRejectConnection($_SERVER['PHP_SELF'].' redirected to login (unauthorized access or session expired)');

	// if session IP adress doesn't match with remote adress, go to login page (unless disableClientSessionIPControl general var is set)
	if (!isset($_SESSION['userId']) || ($_SESSION['accountIP'] != $_SERVER['REMOTE_ADDR'] && cfGGetVar('disableClientSessionIPControl')!=true && !isset($_SERVER['HTTPS']))) {
		if($_SERVER['PHP_SELF']=='/index.php') unset($_SESSION);
		securityRejectConnection('Redirected to login (unauthorized access : IP doesnt match with session ID)').$_SERVER['REMOTE_ADDR'].$_SESSION['accountIP'];
	}

	// If script belongs to exeptionsListAfterLogin (scripts that need external authentication but that are not resources), authorize
	if(in_array($_SERVER['PHP_SELF'], $exeptionsListAfterLogin)) return true;


	/**
	 * Ressource scripts only below this point
	 */
	$_ENV['isResource']=1;


	// If script is not located within /res/ directories, refuse connection
	if(substr($_SERVER['PHP_SELF'],0,5)!='/res/') {
		// Check for website/html resources
		if(substr($_SERVER['REQUEST_URI'],0,7)!='/alias.') securityRejectConnection('Unauthorized script access');
		$alias=substr($_SERVER['REQUEST_URI'],1); $alias=substr($alias,0,strpos($alias,'/'));
		foreach ($_SESSION['res'] as $k=>$v) if(@$v['type']=='website' && @$v['subType']=='html'){
			$resData=cfMGetVar('weezoResData'.@$v['id']);
			// Matching resource found: write_close weezo session and proceed
			if($alias==@$resData['alias']){
				cfPingUpdate();
				wSession_write_close();
				unset($resData);unset($_SESSION);
				return true;
			}
		}
		securityRejectConnection('Unauthorized script access');
	}

	// Exception: configuration script
	if(cfCmpLeft($_SERVER['PHP_SELF'],'/res/administration/config') && strpos($_SERVER['PHP_SELF'],'..')===false) return true;

	// Check if resource Id (resId) has been transmitted
	if(isset($_GET ['resId'])&& is_numeric($_GET ['resId']) && isset($_SESSION['res'][$_GET ['resId']]) && is_array($_SESSION['res'][$_GET ['resId']])) $resId=$_GET ['resId'];
	if(isset($_POST['resId'])&& is_numeric($_POST['resId']) && isset($_SESSION['res'][$_POST['resId']]) && is_array($_SESSION['res'][$_POST['resId']])) $resId=$_POST['resId'];
	if(!isset($resId)){$h=getallheaders();if(isset($h['resId']) && is_numeric($h['resId']) && isset($_SESSION['res'][$h['resId']]) && is_array($_SESSION['res'][$h['resId']])) $resId=$h['resId'];} // Get resId from HTTP headers (Drag & Drop file upload)

	// resource id provided
	if(isset($resId)){
		if(substr($_SERVER['PHP_SELF'],0,strlen('/res/'.$_SESSION['res'][$resId]['type'].'/'.$_SESSION['res'][$resId]['subType']))=='/res/'.$_SESSION['res'][$resId]['type'].'/'.$_SESSION['res'][$resId]['subType']){
			$_SESSION['activeResourceId']=$resId;// set activeResourceId

			// Log first connection
			if(!cfRGetVar('resFirstSelection')) {
				cfLog(cfCaption('logResourceSelection',cfUTF8Encode(cfRGetVar('name'))),LOG_DET);
				cfLogEvent(cfCaption('logResourceSelection',cfUTF8Encode(cfRGetVar('name')),false,false,true).' ('.cfUTF8Encode(cfUGetVar('name')).')',EVENT_RESOURCEACCESS,0,cfUGetVar('id').'/'.cfRGetVar('id'));
				cfRSetVar('resFirstSelection',true);
			}
			// Log information in statistics database
			if(cfGGetVar('logUserActivity') && !isset($_POST['noSt']) && !isset($_POST['asyncRequest'])) {
				require_once(INCLUDE_DIR.'databaseFunctions.php');
				dbLogResourceAccess();
			}
			cfPingUpdate(); // Ping app if no ping since a too long time
			return true;
		}
		else {//resource doesn't exist, load standard login page
			securityRejectConnection('Redirected to login (unauthorized access : require access to unauthorized resource)');
		}
	}
	// if no resource id is received, verify that one of the user's resources matches
	else{
		// 1st verify if active resource matches
		$resourceDir="/res/".cfRGetVar('type')."/".cfRGetVar('subType');
		if(substr($_SERVER['PHP_SELF'],0,strlen($resourceDir))==$resourceDir) {

			// Log information in statistics database
			if(cfGGetVar('logUserActivity') && !isset($_POST['noSt']) && !isset($_POST['asyncRequest'])){
				require_once(INCLUDE_DIR.'databaseFunctions.php');
				dbLogResourceAccess();
			}
			cfPingUpdate(); // Ping app if no ping since a too long time
			return true;
		}
		//if activeResourceId doesn't match, checks all the other user's resources
		for ($i=0;$i<count($_SESSION['res']);$i++){
			$resourceDir = "/res/".$_SESSION['res'][$i]['type']."/".$_SESSION['res'][$i]['subType'];
			if(substr($_SERVER['PHP_SELF'],0,strlen($resourceDir))==$resourceDir){//current resource belongs to authorized resources
				$_SESSION['activeResourceId']=$i;//set to activeResourceId
				// WARNING : an error may occure when an user opens 2 windows with 2 different resources of the same type.
				cfLog('Authorized (on non active resource)',LOG_DBG);
				// Log information in statistics database
				if(cfGGetVar('logUserActivity') && !isset($_POST['noSt']) && !isset($_POST['asyncRequest'])){
					require_once(INCLUDE_DIR.'databaseFunctions.php');
					dbLogResourceAccess();
				}
				cfPingUpdate(); // Ping app if no ping since a too long time

				return true;
			}
		}
	}
	securityRejectConnection('Access control unsuccessfull');
}

// Initialize chrono, base include directory and load commonFunctions.php
securityInit();

// Trace incoming requests
securityDebugRequest();

// Preprocess POST & GET
securityPreprocessArgs();

/*****************************************************************************************
 * Server initialization
 *****************************************************************************************/
//cfMUnsetVar('weezoInitInProgress'); if(0) cfDbg();

// Wait until server initalization complete (done by another thread)
while(cfMIssetVar('weezoInitInProgress')) usleep(10000);

// Load general.ini parameters (should happend only once per server launch), except for CLI scripts, and reset sessions files
if((!cfMIssetVar('weezoGeneral')) && isset($_SERVER['SERVER_NAME']) && $_SERVER['REQUEST_URI']!='/local/tmp.php') {
	require_once(INCLUDE_DIR.'initFunctions.php');
	ifInitializeServer();
}

// Store those parameters into an $_ENV array for faster access
elseif(isset($_SERVER['SERVER_NAME'])) $_ENV['weezoGeneral']=cfMGetVar('weezoGeneral');

// If UI embeded script, force session id to sess_UI_+weezoKey
if(isset($_GET['weezoKey']) && $_SERVER['REMOTE_ADDR']=='127.0.0.1' && !cfIsCLI()){
	while (!cfServerKeyIsset() && !isset($_GET['setWeezoKey'])) usleep(1000);
	if(cfServerKeyCheck($_GET['weezoKey'])) wSession_id('UI_'.$_GET['weezoKey']);
}


/*****************************************************************************************
 * Verify access rights
 *****************************************************************************************/
securityResourceVerifyAccessRight();

/*****************************************************************************************
 * Post-processing: extensions session management
 *****************************************************************************************/

// CSS / HTML: send correct headers
$ext=strtolower(substr($_SERVER['PHP_SELF'],strrpos($_SERVER['PHP_SELF'],'.')+1));
if($ext=='css' || $ext=='html' || $ext=='htm' || $ext=='js') {
	if($ext=='js') header('Content-Type: application/javascript'); else header('Content-Type: text/'.(($ext=='css')?'css':'html'));
	WHeaders::cache();
	// HTML: bypass normal treatments, to prevent html file to be processed by PHP (and so generating a parse error)
	if(substr($_SERVER['PHP_SELF'],-5)=='.html'||substr($_SERVER['PHP_SELF'],-4)=='.htm') die(file_get_contents($_SERVER['SCRIPT_FILENAME']));
	// Extensions javascript: don't process
	if(cfIsSubDir(cfAppDocRoot().'/res/misc',$_SERVER['SCRIPT_FILENAME'])) die(file_get_contents($_SERVER['SCRIPT_FILENAME']));
	return;
}


// If resource starts session by itself, close started session
if(isset($_SESSION['activeResourceId'])	&& cfRGetVar('definition','resourceStartsSession') && cfIsResource()) {
	wSession_write_close();
	$_ENV['weezoSession']=$_SESSION; $_SESSION=array();
}

if($_ENV['configurationEnvironment']=='application'){
	// New resource configuration script called: load resource data into $_SESSION so cfRgetVar can be used
	if($_SERVER['SCRIPT_NAME']=='/res/administration/std/resourceConfig.php' && isset($_GET['resourceConfigScript']) && isset($_GET['resourceConfigFilename'])){
		// Resolve resource UID from config filename
		if($id=array_search($_GET['resourceConfigFilename'],cfMGetVar('weezoResourcesList'))){
			// Copy resource data into $_SESSION
			$_SESSION['activeResourceId']=0;
			$_SESSION['res'][0]=cfMGetVar('weezoResData'.$id);
			//wSession_write_close();
		}
	}
	// Extensions configuration: if resource config use it's own sessions, put $_SESSION into $_ENV['weezoSession'] so cfRGetVar can work, and close weezo session
	elseif((cfCmpLeft($_SERVER['SCRIPT_NAME'],'/res/misc/') || cfCmpLeft($_SERVER['SCRIPT_NAME'],'/res/administration/phpMyAdmin')) && @$_SESSION['res'][0]['definition']['describer']['configStartsSession']){
		wSession_write_close(false); // Don't save weezo session (as $_SESSION might be altered by resource)
		$_ENV['weezoSession']=$_SESSION;
		$_SESSION=array(); // Reset session data
	}
}

// Microsoft / apple webdav workaround
if(stripos(@$_SERVER['HTTP_USER_AGENT'],'webdav')!==false||strpos(@$_SERVER['HTTP_USER_AGENT'],'BitKinex')!==false) require_once(INCLUDE_DIR.'webDAV.php');
?>