<?php
/**
 * Common functions used by scripts
 *
 * Add several "all purpose" functions used by resource scripts
 * - read / write general/user/resource variables
 * - files access rights
 * - log/debug
 * - data exchange with main application
 * - misc...
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2008 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.0.0
 */


define('LOG_NON',-1);     /** Information */
define('LOG_INF',0);     /** Information */
define('LOG_DET',2);     /** Detailed information */
define('LOG_ERROR',1);     /** Error: note: use of PHP LOG_ERR also works */
define('LOG_DBG',3);     /** Debug information */

// Type of logged event
define('LOG_EVENT_UNKNOWN',0);     /** Information */
define('LOG_EVENT_APP_INTERNAL',1);     /** Event emitted by application */
define('LOG_EVENT_LOGIN',1);     /** New connection */
define('LOG_EVENT_LOGOUT',2);     /** Disconnection */



// Log files
define('MAIN_LOG_FILE','appLog.txt');
define('PHP_ERRORS_LOG_FILE','phpErrors.txt');
define('HTTPD_ERRORS_LOG_FILE','httpdErrors.log');
define('HTTPD_ACCESS_LOG_FILE','httpdAccess.log');
define('HTTPD_ACCESS_LOG_FILE_UI','httpdUIAccess.log');


// Defines max time (x 10ms) a script may lock a session. Above that time, old script looses its rights over the session
// Used to prevent a hanged script blocks whole session
define('SESSION_MAX_LOCK_TIME',500);

define('TRANSFERS_REFRESH','10');
define('ADRESS_MAXLENGHT','60');
define('DEFAULT_JPG_QUALITY',70);
define('DEFAULT_RESIZE_METHOD',2);
define('IMAGE_COMMENTS_EDIT_COLS','53');
define('IMAGE_COMMENTS_EDIT_ROWS','4');
define('IMAGE_COMMENTS_EDIT_HEIGHT','75');
define('DEFAULT_SLIDESHOW_INTERVAL','4');

define('APPLICATION_NAME','Weezo');
define('DOWNLOAD_SITE','http://download.weezo.net');
define('APP_SITE','http://www.weezo.net');
define('DNS_SITE','http://weezo.net');

$_ENV['W_ALT_HOSTS']=array('weezo.net','weezo.eu','weezo.info','weezo.fr','weezo.us','weezo.me','p2w.fr');

define('FILE_CONTACTS', '/contacts.txt');
define('FILE_UPLOADS', '/data/uploads.txt');
define('FILE_TRANSFERS', '/data/transfers.txt');
define('FILE_GENERAL', '/data/general.ini');

define('OGG_AUDIO_EXT','.convert.ogg'); // Note: this one is also hardcoded into html5AudioPlayer.js
define('MP3_AUDIO_EXT','.convert.mp3'); // Note: this one is also hardcoded into html5AudioPlayer.js
define('WMP_MOBILE_AUDIO_EXT','.convert.asf');
define('WMP_MOBILE_VIDEO_EXT','.convert.wmv');

define('EVENT_CONNECTION',0);
 define('S_EVENT_LOGIN',1);
 define('S_EVENT_LOGOUT',2);
define('EVENT_SERVERSTATE',1);
 define('S_EVENT_OFF',1);
 define('S_EVENT_LAN',2);
 define('S_EVENT_WEB',3);
define('EVENT_RESOURCEACCESS',2);

// Max time two "registered streamed process" can run simultaneously. Used to prevent problems with process (ffmpeg actually...) streaming not detecting client connection has closed.
define('STREAMED_PROCESS_MAX_FREAD_TIME',15);


define('CONNECTION_ATTEMPTS_CLEANUP_TIME', 10); // connectionAttempts.txt entries cleanup time (in days)

define('COMMENTS_BANNER_WIDTH',250); // Facebook comments banner width

define('MAIN_DAEMON_LIFETIME',3600); // Main daemon lifetime, used to restart daemon every x seconds


/**
 ***************************************************************************************************************************
 * In-Memory data functions  (In-memory data is data shared between all scripts)
 ***************************************************************************************************************************
 */

/**
 * @desc Set opCode cache method
 *
 */
function cfMOpCodeSet(){
	if(function_exists('customSetData')) $_ENV['opCode']='custom';
	elseif(function_exists('apc_fetch')) $_ENV['opCode']='apc';
	elseif(function_exists('xcache_set')) $_ENV['opCode']='xcache';
	else die('no op cache');
}


/**
 * @desc set In-memory data
 *
 * @param string $key : data name
 * @param mixed $value : data value
 */
function cfMSetVar($key,$value,$raw=false){
	if(!isset($_ENV['opCode'])) cfMOpCodeSet();
	switch ($_ENV['opCode']){
		case 'custom':
			customSetData($key,(($raw)?$value:serialize($value)));
			break;
		case 'apc':
			apc_store($key,$value);
			break;
		case 'xcache':
			xcache_set($key,(($raw)?$value:serialize($value)));
	}
}
/**
 * @desc get In-memory data value
 *
 * @param string $key : data name
 * @return mixed $value : data value
 */
function cfMGetVar($key=false,$raw=false){
	if(!isset($_ENV['opCode'])) cfMOpCodeSet();
	switch ($_ENV['opCode']){
		case 'custom':
		    if($key===false) {
		        $r=array();
		        foreach (customGetData('') as $key=>$value) $r[$key]=unserialize($value);
		        return $r;
		    }
		    if($raw) return customGetData($key);
		    return @unserialize(customGetData($key));
		case 'apc':
			if ($key===false) return;
			return apc_fetch($key);
		case 'xcache':
			if ($key===false) return;
			if($raw) return xcache_get($key);
			return @unserialize(xcache_get($key));
	}
}
/**
 * @desc check if In-memory data is set
 *
 * @param string $key : data name
 * @return  boolean : true if data is set, false if not set
 */
function cfMIssetVar($key){
	if(!isset($_ENV['opCode'])) cfMOpCodeSet();
	switch ($_ENV['opCode']){
		case 'custom':
			return customIssetData($key);
		case 'apc':
			return apc_exists($key);
		case 'xcache':
			return xcache_isset($key);
	}
}
/**
 * @desc unset if In-memory data
 *
 * @param string $key : data name
 */
function cfMUnsetVar($key){
	if(!isset($_ENV['opCode'])) cfMOpCodeSet();
	switch ($_ENV['opCode']){
		case 'custom':
    		customUnsetData($key);
    		return;
    	case 'apc':
    		apc_delete($key);
    		return;
    	case 'xcache':
    		xcache_unset($key);
    		return;
	}
}

/**
 * Return dataName=>dataName array of all mvar data
 *
 * @return array
 */
function cfMGetVarList(){
	$list=array();
	if(function_exists('customGetDataList')) return customGetDataList();

	if(function_exists('apc_store')){
	  $it=new APCIterator('user','/./',APC_ITER_VALUE);
	  $it->rewind();
	  while($it->valid()){
		  $list[$it->key()]=$it->key();
		  $it->next();
	  }
	  return $list;
	}

	return array();
}

/**
 ***************************************************************************************************************************
 * Server / application shared secret key management. Used for in-app detection & security
 ***************************************************************************************************************************
 */

/**
 * @desc Return true if server key (weezoKey) is set
 *
 * @return boolean
 */
function cfServerKeyIsset(){
	if(function_exists('customIssetKey')) return customIssetKey();
	// if specific function not available, use default memory storage for key
	return cfMIssetVar('weezoKey');
}
/**
 * @desc Set server key
 *
 * @param string $keyValue: key value
 * @return void
 */
function cfServerKeySet($keyValue){
	if(function_exists('customSetKey')) return customSetKey($keyValue);
	// if specific function not available, use default memory storage for key
	return cfMSetVar('weezoKey',$keyValue);
}
/**
 * @desc Check server key
 *
 * @param string $keyValue: key value
 * @return boolean
 */
function cfServerKeyCheck($keyValue){
	if(function_exists('customCheckKey')) return customCheckKey($keyValue);
	// if specific function not available, use default memory storage for key
	return $keyValue && cfMGetVar('weezoKey')===$keyValue;
}



/**
 ***************************************************************************************************************************
 * PHP Session replacement
 ***************************************************************************************************************************
 */

function wSession_save_path(){return dirname(session_save_path());}
function wSession_start($readOnly=false,$apiMode=false){
    $_SESSION=false;
    // If session-less request, set readOnly to false
    if(isset($_GET['noSession'])) $readOnly=false;

    // If session is already opened, abort
    if(@$_ENV['wSession']['state']==='opened') return;

    // Get id from wSession_id then from cookie, and restore session
    $id=(isset($_ENV['wSession']['id']))?$_ENV['wSession']['id']:((isset($_COOKIE['WSESSID']))?$_COOKIE['WSESSID']:0);

    if($id){
        // Wait until session is not locked by any other process
        $nb=0; while((!$readOnly) && cfMIssetVar('wSessionLocked_'.$id) && ($nb++<SESSION_MAX_LOCK_TIME)) usleep(10000);

        // Re-lock session
        if(!$readOnly) {
        	cfMSetVar('wSessionLocked_'.$id,$_ENV['requestID']);
        }
        // Get session data from session file
        $_SESSION=unserialize(@file_get_contents(wSession_save_path().'/sess_'.$id));

        // XSRF protection: if user is logged and referer doesn't match with this site, exit
        if(cfGGetVar('XSRFProtection') && isset($_SESSION['userLogged']) && WHeadersIn::get('Referer')) {
            $refererURL=parse_url(WHeadersIn::get('Referer'));

            $host=$_SERVER['HTTP_HOST']; if(strpos($host,':')) $host=substr($host,0,strpos($host,':'));

            // If referer differs from actual host, reject
            if(isset($refererURL['host']) && $refererURL['host']!==$host){

                // Except if it comes from weezo.net (remove POST & GET data in this case)
            	foreach ($_ENV['W_ALT_HOSTS'] as $hostName) if(cfCmpRight($refererURL['host'],$hostName)){
                	$exceptions=array('directResourceAccessToken','publishToken');
                	foreach ($_GET as $k=>$v) if(!in_array($k,$exceptions)) unset($_GET[$k]);
                	foreach ($_POST as $k=>$v) if(!in_array($k,$exceptions)) unset($_POST[$k]);
                	break;
            	}
            	if(!isset($exceptions)){
                    cfMUnsetVar('wSessionLocked_'.$id);
                    die('Unauthorized access: '.WHeadersIn::get('Referer').' != '.$_SERVER['HTTP_HOST'].' ('.$host.')');
            	}
            }
        }
    }

    if(!$_SESSION){
        if(isset($_ENV['wSession']['id'])) $id=$_ENV['wSession']['id'];
        else {
            $id=''; for ($i=0;$i<26;$i++) $id.=chr(rand(0,255));
            $id=substr(str_replace(array('/','=','+'),'',base64_encode($id)),0,22);
        }
        if(!$readOnly) {
        	cfMSetVar('wSessionLocked_'.$id,$_ENV['requestID']);
        }
        $_SESSION=array();
    }
    // Send cookie to browser (except for API mode where cookie should be sent another way)
    if($id && !$readOnly && !$apiMode) {
    	setcookie('WSESSID',$id,null,'/');
    }
    $_ENV['wSession']=array('id'=>$id,'state'=>(($readOnly)?'closed':'opened'));

    register_shutdown_function('wSession_write_close');
}
function wSession_start_nowrite(){wSession_start(true);}
function wSession_opened(){return @$_ENV['wSession']['state']==='opened';}
/**
 * @desc Restart a closed session
 *
 */
function wSession_restart(){
	if(@$_ENV['wSession']['state']==='opened') return;
	$_ENV['wSession']['state']='opened';
    register_shutdown_function('wSession_write_close');
}
function wSession_id($newId=false){
    if($newId) $_ENV['wSession']['id']=$newId;
    return (string)@$_ENV['wSession']['id'];
}
/**
 * @desc Destroy session
 *
 * @param string $otherSessionId: if set, destroy this session instead of current session
 */
function wSession_destroy($otherSessionId=false){
    $id=($otherSessionId)?$otherSessionId:wSession_id();
    if(substr($id,0,3)=='UI_') return ;
    @unlink(wSession_save_path().'/sess_'.$id);
    cfMUnsetVar('wSessionLocked_'.$id);

    if(!$otherSessionId){
	    @setcookie('WSESSID',null,time()-3600,'/');
	    $_ENV['wSession']['state']='destroyed';
    }
}
/**
 * @write close session
 *
 * @param boolean $commitToFile: set to false not to update session file
 */
function wSession_write_close($commitToFile=true){
    if(@$_ENV['wSession']['state']!='opened') return;
    $id=$_ENV['wSession']['id'];
    if(isset($_ENV['wSessionBeforeWriteClose'])) call_user_func($_ENV['wSessionBeforeWriteClose']);

    // Check that request has actually opened and locked session before saving if not, discard changes
    if($commitToFile && cfMGetVar('wSessionLocked_'.$id)==$_ENV['requestID']){
    	file_put_contents(wSession_save_path().'/sess_'.$id,serialize($_SESSION));
    }

    $_ENV['wSession']['state']='closed';
    cfMUnsetVar('wSessionLocked_'.$id);
}
/**
 * @desc Set a function to be called before closing session (so far used only for cfSetSavedRVarC()
 *
 * @param string $function: function name
 */
function wSession_setBeforeWriteClose($function){$_ENV['wSessionBeforeWriteClose']=$function;}

function cfRequestId(){return $_ENV['requestID'];}

/*
 ***************************************************************************************************************************
 * Genera/User/Resource data management,
 * Special directories management
 ***************************************************************************************************************************
 */

/**
 * @return true if non-existent directory or successfully unlinked directory, else if dir couldn't be unlinked
 * @desc unlink logged user temporary data directory (if exists)
*/
function cfAppUserTempDirUnlink() {
    $userTempDir=cfAppDataDir()."/sessiondata/".wSession_id();
    if(file_exists($userTempDir)) return cfUnlinkDir($userTempDir); else return true;
}

/**
 * @return mixed required data
 * @param string $dataName name of data
 * @param string $notFound : (optional) returned value when not found * @param string $notFound : (optional) returned value when not found
 * @desc return data named $dataName, red in general.ini file,
 *             and stored in $_SESSION['weezoGeneral'] array (1st) or $_ENV['weezoGeneral'] (if not in session)
*/
function cfGGetVar($dataName=false,$subDataName=false, $notFound=false){
    //@$_ENV['call'][$dataName]++;
    if(!$dataName) return (array)@$_ENV['weezoGeneral']+(array)@$_SESSION['weezoGeneral'];
    if    ($subDataName===false && isset($_SESSION['weezoGeneral'][$dataName])) $data=$_SESSION['weezoGeneral'][$dataName];
    elseif($subDataName!==false && isset($_SESSION['weezoGeneral'][$dataName][$subDataName])) $data=$_SESSION['weezoGeneral'][$dataName][$subDataName];
    elseif($subDataName===false && isset($_ENV['weezoGeneral'][$dataName])) $data=$_ENV['weezoGeneral'][$dataName];
    elseif($subDataName!==false && isset($_ENV['weezoGeneral'][$dataName][$subDataName])) $data=$_ENV['weezoGeneral'][$dataName][$subDataName];
    else return $notFound;
    if(!is_array($data) && strtolower($data)=='false') return false;
    if(!is_array($data) && strtolower($data)=='true') return true;
    return $data;
}
/**
 * @return true
 * @param string $dataName
 * @param mixed $value
 * @param bool $save: true to update in-memory value
 * @desc put $value in general data named $dataName : $_SESSION['weezoGeneral'][$dataName]=$value
*/
function cfGSetVar($dataName,$value,$save=false){
    if($save) cfMSetVar('weezoGeneral',array($dataName=>$value)+cfMGetVar('weezoGeneral'));
    $_SESSION['weezoGeneral'][$dataName]=$value;
    return true;
}
/**
 * @param string $dataName
 * @desc unset a general var (user defined only, not common vars)
*/
function cfGUnsetVar($dataName){unset($_SESSION['weezoGeneral'][$dataName]);}
/**
 * @desc Update G value in session and into UI
 *
 * @param string $dataName
 * @param mixed $value
 * @param mixed $immediateCommit:
 *             true to request app to save to general.ini on reception, false to update on app, 'serverOnly' to update only on server
 * @param boolean $force: set to true to force update even if value has not been modified. Used by uiConfig as a bug workaround when weezoGeneral memory var is not correct
 */
function cfGUpdateVar($dataName,$value,$immediateCommit=false, $force=false){
    // Retreive current memory data
    $mem=cfMGetVar('weezoGeneral');

    if($value===@$mem[$dataName] && !$force) return ;

    // Update for this session (in $_SESSION)
    //if(!wSession_opened()) wSession_restart();
    cfGSetVar($dataName,$value,true);

    // Update in memory
    $mem[$dataName]=$value; cfMSetVar('weezoGeneral',$mem);

    // If immediate commit to app
    if($immediateCommit!=='serverOnly'){
        $args=array('name'=>$dataName,'value'=>$value);
        if(!$immediateCommit) $args+=array('noCommit'=>1);
        cfServerSendCmd('changeParameter',$args); // Apply to app
    }
}
/**
 * @desc Reload G vars from in-memory array (used for long-lasting scripts such as bittorrent seeder)
 *
 */
function cfGReloadVars(){$_ENV['weezoGeneral']=cfMGetVar('weezoGeneral');}

/**
 * @desc Return the value for a constant defined into bin/default/constants.txt
 *
 * @param string $constantName
 * @return string
 */
function cfConstant($constantName){
	if(cfMIssetVar('__CONSTANT__'.$constantName)) return cfMGetVar('__CONSTANT__'.$constantName);
	//throw new Exception('Inexisting constant: '.$constantName);
}

/**
 * @return mixed required data
 * @param string $dataName name of data
 * @param string $notFound : (optional) returned value when not found
 * @desc return user data named $dataName, red in user .usr file, and stored in $_SESSION['user'] array
*/
function cfUGetVar($dataName=false,$notFound=false){
    if(@$_ENV['weezoSession']['user']) {
        if($dataName) return @$_ENV['weezoSession']['user'][$dataName];
        return @$_ENV['weezoSession']['user'];
    }
    if($dataName===false) return $_SESSION['user'];
    if (isset($_SESSION['user'][$dataName])) return $_SESSION['user'][$dataName];
    return $notFound;
}
/**
 * @return true
 * @param string $dataName
 * @param mixed $value
 * @desc put $value in current user data named $dataName : $_SESSION['user'][$dataName]=$value
*/
function cfUSetVar($dataName,$value){
    $_SESSION['user'][$dataName]=$value;
    return true;
}

/**
 * @desc Create a fake resource context so cfRGetVar / cfRSetVar functions can be used out of resource context
 *         (User Interface, administration...)
 *
 */
function cfRCreateFakeResource($resData=false,$resId=false){
	if(!$resId) $resId='foo';
    $_SESSION['activeResourceId']=$resId;
    if(is_array($resData)) $_SESSION['res'][$resId]=$resData;
    $_SESSION['res'][$resId]['id']=(($resId)=='foo')?'fooId':$resId;
}

/**
 * @return true if var set, false if var couldn't be set (because array specified by $arg1 [,$arg2]... doesn't exist)
 * @param string $arg1
 * @param string $arg2
 * @param string $arg3
 * @param string $arg4
 * @desc Set resource level var
 *         Using this function to store resource session variable ensure there will be no collision with variables used by other resources
 *         var is stored in $_SESSION['res'][active resource id] array and sub arrays
 *         if only $arg1 and $arg2 are passed, then store $arg2 value in $_SESSION['res'][active resource id][$arg1]
 *         if only $arg3 is provided, then store $arg3 value in $_SESSION['res'][active resource id][$arg1][$arg2]
 *         if $arg4 is provided, then store $arg4 value in $_SESSION['res'][active resource id][$arg1][$arg2][$arg4]
*/
function cfRSetVar($arg1, $arg2, $arg3='_Parameter_not_set_', $arg4='_Parameter_not_set_',$resourceId=false){
    if($resourceId===false) $resourceId=$_SESSION['activeResourceId'];
    if(!isset($_SESSION['res'][$resourceId])) $_SESSION['res'][$resourceId]=array();
    if(!($arg4==='_Parameter_not_set_')){
        if(!isset($_SESSION['res'][$resourceId][$arg1])) $_SESSION['res'][$resourceId][$arg1]=array();
        if(!isset($_SESSION['res'][$resourceId][$arg1][$arg2])) $_SESSION['res'][$resourceId][$arg1][$arg2]=array();
        $_SESSION['res'][$resourceId][$arg1][$arg2][$arg3]=$arg4; return true;
    }
    if(!($arg3==='_Parameter_not_set_')){
        if(!isset($_SESSION['res'][$resourceId][$arg1])) $_SESSION['res'][$resourceId][$arg1]=array();
        $_SESSION['res'][$resourceId][$arg1][$arg2]=$arg3; return true;
    }
    $_SESSION['res'][$resourceId][$arg1]=$arg2; return true;
}
/**
 * @desc Return var defined for current resource
 *        if only arg1 is passed, return var named "arg1" ($_SESSION['res'][$currentResource][$arg1]
 *         if arg1 and arg2 are passed, return "arg2" index from "arg1" array ($_SESSION['res'][$currentResource][$arg1][$arg2] (use cfRSetVarArray to define array)
 *         if arg1, arg2 and arg3 are passed, return "arg3" index from "arg1" / "arg2" array ($_SESSION['res'][$currentResource][$arg1][$arg2][$arg3] (use cfRSetVarArray to define array)
 * @param string $arg1 : var or array name
 * @param string $arg2 : (optional) var or array name
 * @param string $arg3 : (optional) var name
 * @param string $notFound : (optional) returned value when not found
 * @return mixed value
*/
function &cfRGetVar($arg1=false, $arg2=false, $arg3=false, $notFound=false){
    static $memCached=false;
    static $resourceId=false;

    if($arg1==='*weezoResetCache*') return $memCached=false;

    // If session not started or no active resource, return false
    $false=$notFound;
    if(!isset($_SESSION) || !isset($_SESSION['activeResourceId'])) {
        // Workaround to allow cfRGetVar in extensions using genuine PHP sessions
        if(isset($_ENV['weezoSession']['activeResourceId'])){
            $resourceId=0;
            $_SESSION['res'][0]=$_ENV['weezoSession']['res'][$_ENV['weezoSession']['activeResourceId']];
        }
        else return $false;
    }
    else{
        // If resource id changed, reset cache
        if($resourceId!==$_SESSION['activeResourceId']) $memCached=false;
        $resourceId=$_SESSION['activeResourceId'];
    }

    // Load resource unmodified data
    if(!$memCached) {
        if(!isset($_SESSION['res'][$resourceId]['id'])) return $false;
        $memCached=cfMGetVar('weezoResData'.$_SESSION['res'][$resourceId]['id']);
    }

    // return requested data
    if($arg1===false){ // All data (debug or rcInitLimitedConfig)
        $tmp=$_SESSION['res'][$resourceId]+$memCached;
        return $tmp;
    }

    if($arg3!==false){
        if(isset($_SESSION['res'][$resourceId][$arg1][$arg2][$arg3])) {
        	if($_SESSION['res'][$resourceId][$arg1][$arg2][$arg3]==="**weezoUnset**") return $false;
        	return $_SESSION['res'][$resourceId][$arg1][$arg2][$arg3];
        }
        if(isset($memCached[$arg1][$arg2][$arg3])) return $memCached[$arg1][$arg2][$arg3];
    }
    elseif($arg2!==false){
        if(isset($_SESSION['res'][$resourceId][$arg1][$arg2])) {
        	if($_SESSION['res'][$resourceId][$arg1][$arg2]==="**weezoUnset**") return $false;
        	return $_SESSION['res'][$resourceId][$arg1][$arg2];
        }
        if(isset($memCached[$arg1][$arg2])) return $memCached[$arg1][$arg2];
    }
    else {
        if(isset($_SESSION['res'][$resourceId][$arg1])) {
        	if($_SESSION['res'][$resourceId][$arg1]==="**weezoUnset**") return $false;
        	return $_SESSION['res'][$resourceId][$arg1];
        }
        if(isset($memCached[$arg1])) return $memCached[$arg1];
    }
    return $false;
}
/**
 * @desc Return true if variable is set (see cfRGetVar for args)
 * @return boolean
 */
function cfRIssetVar($arg1,$arg2=false,$arg3=false){
	return (cfRGetVar($arg1,$arg2,$arg3,null)===null)?false:true;
}
/**
 * @desc set an array bound to current resource ($_SESSION['res'][$currentResource][$arg1] or $_SESSION['res'][$currentResource][$arg1][$arg2])
 * @param string $arg1 : array name
 * @param string $arg2 : (optional) 2nd level array name
 * @return true if OK, false if array cannot be creates
*/
function cfRSetVarArray($arg1, $arg2=false, $resourceId=false){
    if($resourceId===false) $resourceId=$_SESSION['activeResourceId'];
    if($arg2!==false){
        if(!isset($_SESSION['res'][$resourceId][$arg1])) return false;
        $_SESSION['res'][$resourceId][$arg1][$arg2]=array(); return true;
    }
    $_SESSION['res'][$resourceId][$arg1]=array(); return true;
}
/**
 * @return true if success
 * @param Name of array or 1st level of array $arg1
 * @param optional: 2nd level of array $arg2
 * @param optional: 3rd level of array $arg3
 * @desc unset a variable / array of resource level data ($_SESSION['res']
*/
function cfRUnsetVar($arg1, $arg2=false, $arg3=false){
    if($arg3!==false) {
    	$_SESSION['res'][$_SESSION['activeResourceId']][$arg1][$arg2][$arg3]="**weezoUnset**";
    }
    if($arg2!==false) {
    	$_SESSION['res'][$_SESSION['activeResourceId']][$arg1][$arg2]="**weezoUnset**";
    }
    else {
    	$_SESSION['res'][$_SESSION['activeResourceId']][$arg1]="**weezoUnset**";
    }
    // apply change to in-memory resource data *** no: don't, as it would impact other sessions
    // cfMSetVar('weezoResData'.$_SESSION['res'][$_SESSION['activeResourceId']]['id'], $memCached);
    // Reset cfRGetVar function's static cache
    cfRGetVar('*weezoResetCache*');
    return true;
}
/**
 * @desc Initialize r var if not already set
 *
 * @param string $varName
 * @param mixed $value
 */
function cfRInitVar($varName,$defaultValue,$allowedValues=false){
    if(cfRGetVar($varName,false,false,null)===null || ($allowedValues && !in_array(cfRGetVar($varName),$allowedValues))) cfRSetVar($varName,$defaultValue);
}

/**
 * @desc Initialize a boolean variable from a list of allowed groups
 *
 * @param string $varName
 */
function cfRInitUserRightsVar($varName){
	if(!($ur=cfRGetVar('userRights_'.$varName))) return; // If no user rights definition, stick on original variable
	list($range,$display,$list)=@explode(';',$ur,3);

	if($range==='all' || ($range=='admin' && WEnv::user()->isAdministrator())) cfRSetVar($varName,true);
	elseif($range==='list' && in_array(WEnv::user()->id(),@explode(';',$list))) cfRSetVar($varName,true);
	else cfRSetVar($varName,false);
}

/**
 * @desc Insert JS code for defining a var using PHP RVar
 *
 * @param string varName
 * @param string $param1
 * @param string $param2
 */
function cfJSRVar($varName,$arg2=false,$arg3=false){
	$var=cfRGetVar($varName,$arg2,$arg3);
	// Var is an array: json_encode
	if(is_array($var)) return 'wl.rVar.'.$varName.'='.json_encode($var).';';
	// Numeric
	if(is_numeric($var)) return 'wl.rVar.'.$varName.'='.$var.';';
	// Boolean
	if(is_bool($var)) return 'wl.rVar.'.$varName.'='.(($var)?'true':'false').';';
	// String
	return 'wl.rVar.'.$varName.'="'.addslashes($var).'"';
}

/**
 * @desc return an array of all connected-user's resources
 *
 * @return array(nonUniqueId=>data)
 */
function cfResourcesGetUser(){
    $resources=array();
    foreach ($_SESSION['res'] as $id=>$res) if(isset($res['id'])) $resources[$id]=$res+cfMGetVar('weezoResData'.$res['id']);
    return $resources;
}

/**
 * @desc Return an array of all defined resources (user independant)
 *
 * @return array(resourceUniqueID=>resourceData)
 */
function cfResourcesGetAll(){
    foreach (cfMGetVar('weezoResourcesList') as $id=>$filename)    $resources[$id]=cfMGetVar('weezoResData'.$id);
    return $resources;
}

/**
 * @desc set (context-appliable) theme-level data
 *
 * @param string $dataName: name of variable
 * @param string $value: value
 */
function cfTSetVar($dataName,$value){
    $themes=cfMGetVar('weezoThemes');
    $themes[cfActualTheme()][$dataName]=$value;
    cfTGetVar(false,'reset'); // Reset theme data
}
/**
 * @desc return (context-appliable) theme-level data
 *
 * @param srting $dataName: name of variable
 * @param string $notFound : (optional) returned value when not found
 * @return mixed value
 */
function cfTGetVar($dataName=false, $notFound=false){
    static $themes;
    if($notFound=='reset') {$themes=false;return;}// Reset theme data
    if(!$themes) $themes=cfMGetVar('weezoThemes');
    if(!$dataName) return $themes[cfActualTheme()];
    if(isset($themes[cfActualTheme()][$dataName])) return $themes[cfActualTheme()][$dataName];
    return $notFound;
}
/**
 * @desc "Heritable" variable :
 *             seek for variable at resource-level, then user-level, then general-level, and if not found, use $defaultValue
 *
 * @param string $dataName : name of variable
 * @param mixed $defaultValue : value if not defined at resource / user / general levels
 * @return mixed : value
 */
function cfHGetVar($dataName, $defaultValue=false){
    if(cfIsResource() && ($ret=cfRGetVar($dataName,false,false,null))!==null) return $ret;
    if(($ret=cfUGetVar($dataName,null))!==null) return $ret;
    if(($ret=cfGGetVar($dataName,false,null))!==null) return $ret;
    return $defaultValue;
}
/**
 * @desc "Heritable" variable, inverted order (general-level highest priority) :
 *             seek for variable at general-level, then user-level, then resource-level, and if not found, use $defaultValue
 *
 * @param string $dataName : name of variable
 * @param mixed $defaultValue : value if not defined at resource / user / general levels
 * @return mixed : value
 */
function cfHiGetVar($dataName, $defaultValue=false){
    if(($ret=cfGGetVar($dataName,false,null))!==null) return $ret;
    if(($ret=cfUGetVar($dataName,null))!==null) return $ret;
    if(cfIsResource() && ($ret=cfRGetVar($dataName,false,false,null))!==null) return $ret;
    return $defaultValue;
}
/**
 * @desc get browser capability
 *
 * @param string $dataName, set to *weezoResetCache* to reset function's local data cache
 */
function cfBGetVar($dataName=false){
    static $cache;
    if(cfIsInApp() && !cfGGetVar('browserCaps')) cfSetBrowserCaps();
    if(!isset($cache)||$dataName=='*weezoResetCache*') $cache=array();
    if(!$dataName) return cfGGetVar('browserCaps');
    if(!isset($cache[$dataName])) $cache[$dataName]=cfGGetVar('browserCaps',$dataName);
    return $cache[$dataName];
}
/**
 * @desc Set browser capability
 *
 * @param string $dataName
 * @param string $dataValue
 */
function cfBSetVar($dataName,$dataValue){
	cfBGetVar('*weezoResetCache*'); // Reset cfBGetVar's cache and load browser cache if needed
    $caps=cfGGetVar('browserCaps');
    $caps[$dataName]=$dataValue;
    cfGSetVar('browserCaps',$caps);
}

/**
 * Close current session to perform long tasks, before restarting it with cfSessionRestart
 *
 */
function cfSessionPause(){
    $_ENV['activeResourceId']=@$_SESSION['activeResourceId'];
    wSession_write_close();
}
/**
 * Restart session paused by cfSessionPause
 *
 */
function cfSessionRestart(){
    wSession_start();
    $_SESSION['activeResourceId']=$_ENV['activeResourceId'];
}
/**
 * @desc Detect if a session is started and not write_closed (i.e. locked)
 *
 * @return boolean
 */
function cfSessionIsStarted(){
    if(!wSession_id()) return false;
    $f=cfAppDataDir().'/sessiondata/sess_'.wSession_id();
    if(!file_exists($f)) return false;
    if(function_exists('customFileSize')) return customFileSize($f)==8589934591;
    return @rename($f,$f);
}

/**
 * @return string
 * @desc returns application root directory
*/
function cfAppRootDir() {
	static $rd=false;
	if(!$rd) $rd=str_replace('\\','/',dirname(dirname(ini_get('extension_dir'))));
	return $rd;
}
/**
 * @return string application data root directory (= application root directory for compact installations,
 *             or CSIDL_APPDATA/weezo for Vista-like installs
 *             data root directory includes www, data and shared directories
 * @desc returns application data root directory
*/
function cfAppDataRootDir() {
	static $adrd=false;
	if($adrd) return $adrd;
	return $adrd=dirname(DOCUMENTROOT_DIR);
    //if($_SERVER['DOCUMENT_ROOT']) $adrd=substr($_SERVER['DOCUMENT_ROOT'],0,strlen($_SERVER['DOCUMENT_ROOT'])-4);
    //else $adrd=str_replace('\\','/',substr(__FILE__,0,strlen(__FILE__)-33));
    //return $adrd;
}

/**
 * @return string
 * @desc returns application bin (executables) directory
*/
function cfAppBinDir() {
	if(is_dir(cfAppRootDir().'/bin')) return cfAppRootDir().'/bin';
	return dirname(cfAppRootDir()).'/MacOS';
}
/**
 * @return string
 * @desc returns application bin (executables) directory
*/
function cfAppServerDir() {
	static $sd=0;
	if(!$sd){
		$sd=cfAppRootDir().((strtolower(basename(dirname(ini_get('extension_dir'))))=='phpvc9')?'/apacheVC9':'/apache');
	}
	return $sd;
}
/**
 * @return string
 * @desc returns PHP directory
*/
function cfAppPHPDir() {return dirname(ini_get('extension_dir'));}
/**
 * @return string
 * @desc returns application data directory
*/
function cfAppDataDir() {return cfAppDataRootDir().'/data';}
/**
 * @return string
 * @desc returns logs directory
*/
function cfAppLogDir() {return cfAppDataDir().'/log';}
/**
 * @return string application data directory
 * @desc returns application data directory
*/
function cfAppTempDir() {return cfAppDataRootDir().'/data/temp';}
/**
 * @return string document root (www) directory
 * @desc returns document root (www) directory
*/
function cfAppDocRoot() {return cfAppDataRootDir().'/www';}
/**
 * @return string default shared directory
 * @desc returns default shared directory
*/
function cfAppSharedDir() {return cfAppDataRootDir().'/shared';}
/**
 * @return string theme directory
 * @param boolean $docRootRelative : set to true to return path from doc root
 * @desc returns theme directory
*/
function cfAppThemeDir($docRootRelative=false){
    if($docRootRelative) return cfTGetVar('path'); else return cfTGetVar('dir');
}
/**
 * @desc return actually applied theme
 *
 * @return strin : theme name
 */
function cfActualTheme(){
	static $theme=false;
    // if launched from weezo UI, load application skin theme
    // if resource theme exists, load it else
    // if user theme exists, load it else
    // if general test exists, load it, else
    // load default theme

    // Use cached value first
    if($theme) return $theme;

    if(cfIsInApp()) $theme='skins/'.cfGGetVar('skin');

    //elseif(cfBGetVar('theme')) $theme=cfBGetVar('theme');
    elseif(!cfIsMobile() && substr($_SERVER['PHP_SELF'],0,5)=='/res/' && isset($_SESSION['activeResourceId']) && cfRGetVar('theme') && file_exists(cfAppDocRoot().'/themes/'.cfRGetVar('theme').'/theme.css') && $_SERVER['PHP_SELF']!='/menuFrame.php' && $_SERVER['PHP_SELF']!='/mainFrame.php') $theme=cfRGetVar('theme');
    elseif(cfUGetVar('theme') && file_exists(cfAppDocRoot().'/themes/'.cfUGetVar('theme').'/theme.css')) $theme=cfUGetVar('theme');
    elseif(cfGGetVar('theme') && file_exists(cfAppDocRoot().'/themes/'.cfGGetVar('theme').'/theme.css')) $theme=cfGGetVar('theme');
    else $theme='simple';

    return $theme;
}
/**
 * @return string directory
 * @param bool $createIfDoesntExist if set to true, create temp directory in non-existant
 * @desc returns logged user temporary data directory (located in /data/sessiondata)
          temporary data directory name is session id
          this dir should be used to store private stuff (out of apache document root) specific to an user (temp images...)
*/
function cfAppUserTempDir($createIfDoesntExist=true, $sessionId=false) {
    static $userTempDir;
    if(!$sessionId && isset($userTempDir)) return $userTempDir; // Cache result (except if a specific session id is requested


    $tmp=cfAppDataDir()."/sessiondata/".(($sessionId)?$sessionId:wSession_id());

    if(!file_exists($tmp)){
        if($createIfDoesntExist && (!mkdir($tmp))) $tmp=false;
        if(!$createIfDoesntExist) $tmp=false;
    }

    if(!$sessionId) $userTempDir=$tmp; // Cache result only if no session id passed

    return $userTempDir;
}


/**
 * @desc returns current resource's data directory (located in /data/res/"resourceType"/"resourceSubType"/"resourceName")
          this dir should be used to store private stuff (out of apache document root) specific to a resource (temp images...)
          if dir doesn't exist, try to create it
 * @param string resourceId: unique resource ID
 * @return string directory
*/
function cfAppResourceDir($resourceId=false) {
    static $return;
    // Use/set cache
    if(isset($return[$resourceId])) return $return[$resourceId];
    $return[$resourceId]=cfRGetVar('resourceDataDir',false,false,$resourceId);

    // Try to create resource directory if needed
    if(!is_dir($return[$resourceId])) @mkdir($return[$resourceId]);
    return $return[$resourceId];
}
/**
 * @desc return relative path from resource base path (cfRGetVar('path'))
 *         returned path is formed like : "*resourceBasePath* /relativePath"
 * @param string $absolutePath: path to processs
 * @param string $topPath: if passed, overrides cfRGetVar('path') and list mode
 * @param boolean $skipResourceBasePath: true to include *resourceBasePath* / , false not to.
 */
function cfResourceRelativePath($absolutePath, $skipResourceBasePath=false, $topPath=false){
	if(!$topPath) $topPath=cfRGetVar('path');

    if(cfSharedMode()==='list'){
        if(cfCmpLeft($absolutePath,'*resourceBasePath*')) return (($skipResourceBasePath)?substr($absolutePath,18):$absolutePath);
        foreach (cfRGetVar('sharedItemsList') as $cfn=>$type) {
            if($cfn==$absolutePath) return(($skipResourceBasePath)?'':'*resourceBasePath*').'/'.basename($cfn);
            if($type=='d' && cfIsSubDir($cfn,$absolutePath)){
                $cfn=dirname($cfn);
                if($skipResourceBasePath) return substr($absolutePath,strlen($cfn)+1);
                return cfJoinPathFile('*resourceBasePath*',substr($absolutePath,strlen($cfn)));
            }
        }
        return false;
    }

    if($absolutePath=='*resSpecific*') return $absolutePath;
    if(!cfIsSubDir($topPath,$absolutePath)) return false;
    if($topPath=='computerRoot') return $absolutePath;
    if($skipResourceBasePath) return substr($absolutePath,strlen($topPath)+1);
    return '*resourceBasePath*'.substr($absolutePath,strlen($topPath));
}
/**
 * @desc return relative path from resource base path (cfAppDataDir())
 *         returned path is formed like : "*resourceBasePath* /relativePath"
 *
 * @param string $absolutePath
 */
function cfResourceDataDirRelativePath($absolutePath){
    if(!cfIsSubDir(cfAppDataDir(),$absolutePath)) return false;
    return '*resourceDataDirBasePath*'.substr($absolutePath,strlen(cfAppResourceDir()));
}
/**
 * @return boolean result of check
 * @param string $path
 * @desc Check if $path is a path or subpath of one of the general protected dirs array
*/
function cfIsGeneralProtected($path,$protectedDirArray=false){
    static $cache;

    $path=strtolower(cfCleanPathName($path));
    if(!is_array($protectedDirArray)){
        if(!isset($cache)) $cache=cfGGetVar('protectedDirs');
        foreach ($cache as $protDir) {if ($protDir && cfIsSubDir($protDir, $path)) return true;}
    }
    else{
        foreach ($protectedDirArray as $protDir) {if (cfIsSubDir($protDir, $path)) return true;}
    }
    return false;
}

/**
 * @return unknown
 * @param string $path
 * @desc Check if $path includes a path of one of the general protected dirs array
*/
function cfIncludesGeneralProtectedDir($path){
    static $protectedDirs;
    if(!isset($protectedDirs)) $protectedDirs=cfGGetVar('protectedDirs');

    $path=strtolower(cfCleanPathName($path));
    foreach ($protectedDirs as $protDir) {if (cfIsSubDir($path,$protDir)) return true;}
    return false;
}

/**
 * @return mixed array of file or dir 's rights or string right of selected item
 *            'state' : synthetic result : 'out of resource path', 'invalid', 'authorized', 'protected'
             'read' : read files and subdirs authorisation (dir only)
             'download' : download authorisation (file or dir)
             'write' : write authorisation (dir only)
             'modify' : modify/overwrite authorisation (file or dir)
             'search' : search authorisation (dir) (not yet implemented)
             'execute'  serverside execute authorisation (file only)
             'upload' : upload authorisation (dir only)
             'remoteDownload' : remoteDownload authorisation (dir only)
             'send' : send authorisation through P2P app (dir or file)
 * @param string $completeFilename : name of dir or file
 * @param string $item : right to check ('read', 'download'...), leave to false to retrieve full rights array;
 * @param boolean $unsafeDir: set to false to indicate than file or folder's directory is clean and allowed, set to true to perform full check
 * @param boolean $itemInSubDir: used only for "list" sharedMode with $unsafeDir=true: true to indicate that item is in a subdir, false if item is directly within shared items
 * @desc Return an array of given file or dir rights. If $item is provided, only right corresponding to item is returned,
*/
function cfFileRights($completeFilename, $item=false, $unsafeDir=true, $itemInSubDir=NULL){
    static $cache;

    // Cache function main data
    if(!isset($cache)){
        $cache=array();

        // Resource specific file rights functions : create function
        if(cfRGetVar('fileRightsFunction')) $cache['fileRightsFunction'] = create_function('$completeFilename,$item,$unsafeDir', cfRGetVar('fileRightsFunction'));
        else $cache['fileRightsFunction'] = false;

        $cache['path']=cfRGetVar('path');
        $cache['subFoldersIncluded']=cfRGetVar('subFoldersIncluded');
        $cache['sharedMode']=cfSharedMode();
        $cache['protectedFilesExtensions']= array_flip(array_merge(
            explode(',',cfRGetVar('protectedFilesExtensions')),    explode(',',cfGGetVar('protectedFilesExtensions'))));
        unset($cache['protectedFilesExtensions']['']);

        // Build allowed extensions list
        $cache['extensions']=cfRGetVar('extensionFilter');
        if($ftf=cfRGetVar('fileTypeFilter')) {
        	require_once(INCLUDE_DIR.'mime_typeI.php');
        	if(!is_array($cache['extensions'])) $cache['extensions']=array();
        	foreach ($ftf as $k=>$ft) $cache['extensions']+=$_ENV["weezoMimeI"][$ft];
        }

        $cache['downloadAllowed']=((cfGGetVar('generalDownloadProtection'))?false:cfRGetVar('downloadAllowed'));
        $cache['writeAllowed']=((cfGGetVar('generalWriteProtection'))?false:cfRGetVar('writeAllowed'));
        $cache['modifyAllowed']=((cfGGetVar('generalModifyProtection'))?false:cfRGetVar('modifyAllowed'));
        $cache['executeAllowed']=((cfGGetVar('generalExecuteProtection'))?false:cfRGetVar('executeAllowed'));

        $cache['searchAllowed']=cfHiGetVar('searchAllowed',false);
        $cache['remoteDownloadAllowed']=cfHiGetVar('remoteDownloadAllowed',false);
        $cache['uploadAllowed']=cfHiGetVar('uploadAllowed',true);
        $cache['sendAllowed']=cfHiGetVar('sendAllowed',false);
        $cache['userTempDirAccessAllowed']=cfRGetVar('userTempDirAccessAllowed');
        $cache['resourceDataDirAccessAllowed']=cfRGetVar('resourceDataDirAccessAllowed');
        $cache['resourceDataDir']=cfRGetVar('resourceDataDir');
        $cache['protectSensitiveFiles']=cfHiGetVar('protectSensitiveFiles');
        $cache['sharedItems']=cfRGetVar('sharedItemsList');

        if(cfGGetVar('generalShowHiddenFiles')=='all' || (cfGGetVar('generalShowHiddenFiles')=='admin' && cfUGetVar('administrator'))) $cache['showHiddenFiles']=true; else $cache['showHiddenFiles']=false;
        if(cfGGetVar('generalShowSystemFiles')=='all' || (cfGGetVar('generalShowSystemFiles')=='admin' && cfUGetVar('administrator'))) $cache['showSystemFiles']=true; else $cache['showSystemFiles']=false;
        if(cfGGetVar('generalAllowReadOnlyFilesOverwrite')=='all' || (cfGGetVar('generalAllowReadOnlyFilesOverwrite')=='admin' && cfUGetVar('administrator'))) $cache['protectReadOnly']=false; else $cache['protectReadOnly']=true;
    }
    // Init rights
    $rights=array('state'=>'authorized', 'read'=>false, 'download'=>false, 'write'=>false, 'modify'=>false, 'search'=>false, 'execute'=>false, 'upload'=>false, 'remoteDownload'=>false, 'send'=>false);

    // Hide weezoAccess files
    if(basename($completeFilename)=='weezoAccess.txt') {
        $rights['state']='protected';
        $rights['reason']='weezoAccess protected';
        if($item) return $rights[$item]; else return $rights;
    }

    // corrects c:/.. or c:.. complete file names
    if(substr($completeFilename,-4)==':/..' || substr($completeFilename,-3)==':..') $completeFilename='computerRoot';

    // computer root specific rights
    if($completeFilename=='computerRoot'){
        // Return resource specific file rights
        if($cache['fileRightsFunction']) {
			if(($fileRightsFunctionResult=$cache['fileRightsFunction']($completeFilename, $item, $unsafeDir))!==null) return $fileRightsFunctionResult;
        }

        if($cache['path']=='computerRoot') {
            $rights['read']=true;
            if($cache['searchAllowed']) $rights['search']=true;
        }
        else $rights['state']='out of resource path';
        $rights['reason']='computer root out of path';
        if($item) return $rights[$item]; else return $rights;
    }

    // Clean file name. if $completeFilename doesn't exist, exit
    if(!$completeFilename || ($unsafeDir && !($completeFilename=cfCleanPathName($completeFilename)))){
    	$rights['reason']='error cleaning file name';
        $rights['state']='invalid'; if($item) return $rights[$item]; else return $rights;
    }

    if(is_dir($completeFilename) || $completeFilename==='*resourceBasePath*'){$isdir=true; $dir=$completeFilename;}
    else{$isdir=false;$dir=(cfDirname($completeFilename));if(strlen($dir)==3 && substr($dir,1)==':/') $dir=substr($dir,0,2);$ext=cfFileExtension($completeFilename);}

    // As userDir is a subdir of installation directory (which is a protected dir), access rights are granted through 'userTempDirAccessAllowed' resource data
    // If userTempDirAccessAllowed is set to true, user may read/write data located in his temp dir (data/sessionData/"session ID"), (no modify...)
    if($unsafeDir || $isdir){
        if($cache['userTempDirAccessAllowed'] && cfIsSubDir(cfAppUserTempDir(false),$completeFilename)){// if user may access his temp dir
            if($isdir) {$rights['read']=true; $rights['write']=true; return $rights;}
            if(!$isdir) {$rights['read']=true; $rights['download']=true; return $rights;}
        }
    }
    // as resource Dir is a subdir of installation directory (which is a protected dir), access rights are granted through 'resourceDataDirAccessAllowed' resource data
    // if resourceDataDirAccessAllowed is set to true, user may read data located in resource datadir (data/sessionData/"session ID"), (no modify...)
    if($cache['resourceDataDirAccessAllowed'] && cfIsSubDir($cache['resourceDataDir'],$completeFilename)){// if user may access resource data dir
        if($isdir) {$rights['read']=true;  return $rights;}
        if(!$isdir) {$rights['read']=true; $rights['download']=true; return $rights;}
    }

    // Resource specific file rights functions
    if($cache['fileRightsFunction']) {
        //if file belongs to general protectedDir[] (or is a subdir of a general protectedDir) or has a protected extension
        if(cfIsGeneralProtected($completeFilename) || ($cache['protectSensitiveFiles'] && isset($cache['protectedFilesExtensions'][$ext]))) {
			$rights['reason']='file belongs to a general protected dir or has a protected extension';
        	$rights['state']='protected';  if($item) return $rights[$item]; else return $rights; //$file protected : exit
        }
        // Return resource specific file rights
        if(($fileRightsFunctionResult=$cache['fileRightsFunction']($completeFilename, $item, $unsafeDir))!==null) return $fileRightsFunctionResult;

    }

    // Check file extension (note: this test must be placed after special folders test as file extension filter is only appliable to shared files, not to cached/weezo stuff)
	if(!$isdir && $cache['extensions'] && !isset($cache['extensions'][$ext])) {
		$rights['state']='protected';
		$rights['reason']='file extension protected';
		return ($item)?$rights[$item]:$rights;
	}

    // Check folder rights
    if($unsafeDir || $isdir){
        if(cfIsGeneralProtected($completeFilename)) {//if file belongs to general protectedDir[] (or is a subdir of a general protectedDir)
        	$rights['reason']='file belongs to a general protected dir';
            $rights['state']='protected';  if($item) return $rights[$item]; else return $rights; //$file protected : exit
        }
        // Forbid all access to application directory
        if(!cfGGetVar('PHPDebug') && (
        	($isdir && ((cfIsSubDir(cfAppDataRootDir(),$completeFilename) || cfIsSubDir(cfAppRootDir(),$completeFilename)) && !cfIsSubDir(cfAppDataRootDir().'/shared',$completeFilename)))
        	||
        	(!$isdir && ((cfIsSubDir(cfAppDataRootDir(),$dir) || cfIsSubDir(cfAppRootDir(),$dir)) && !cfIsSubDir(cfAppDataRootDir().'/shared',$dir)))
        	)){
        	$rights['reason']='file belongs to '.APPLICATION_NAME.' directories';
            $rights['state']='protected';  if($item) return $rights[$item]; else return $rights; //$file protected : exit
        }
    }
    // If unsafe dir, verify that file/folder is contained into an authorized folder
    if($unsafeDir){
        if($cache['sharedMode']=='list'){
        	$rights['state']='protected';
        	if($completeFilename==='*resourceBasePath*') $rights['state']='authorized';

            // 1st look in sharedItems list
            foreach ($cache['sharedItems'] as $cfn=>$type) if($cfn==$completeFilename) $rights['state']='authorized';
            // If not OK, look in subdirectories
            if($rights['state']!='authorized'){
                foreach ($cache['sharedItems'] as $cfn=>$type) if($type=='d' && cfIsSubDir($cfn,$completeFilename)){
                    // Apply upper directory rights
                    $rights['state']=cfFileRights(dirname($completeFilename),'state',true);
                }
            }
        }
        else{
            $resourcePath=strtolower($cache['path']);
            // if not directly in path folder
            if(strtolower($dir)!=$resourcePath){
                if(!$cache['subFoldersIncluded']) $rights['state']='out of resource path';
                else {
                    if($cache['path']!='computerRoot'){
                        if(substr(strtolower($dir),0,strlen($resourcePath))==$resourcePath){
                            if(substr(strtolower($dir),strlen($resourcePath),1) && substr(strtolower($dir),strlen($resourcePath),1)!='/' && substr(strtolower($dir),strlen($resourcePath),1)=='\\') $rights['state']='out of resource path';
                        }
                        else $rights['state']='out of resource path';
                    }
                    // Check that all upper directories are authorized
                    if($rights['state']=='authorized' && strlen($dir)>3){
                        $rights['state']=cfFileRights(dirname($dir),'state',true);
                    }
                }
            }
        }

        //$file out of resource path : exit
        if($rights['state']!='authorized') {
        	$rights['reason']='file probably out of resource path';
        	if($item) return $rights[$item]; else return $rights;
        }
    }
    // safe dir but file directly in sharedItemsList: check that it's one of those items
    elseif ($itemInSubDir===false){
        if(cfSharedMode('list')){
            $found=false;
            foreach ($cache['sharedItems'] as $cfn=>$type) if($cfn==$completeFilename) $found=true;
            if(!$found) {
                $rights['state']='invalid';
                $rights['reason']='file is not one of top-level shared items';
                if($item) return $rights[$item]; else return $rights;
            }
        }
    }
    // $itemInSubDir hint not passed, search in whole items list
    elseif ($itemInSubDir===NULL && cfSharedMode('list')){
        $found=false;
        foreach ($cache['sharedItems'] as $cfn=>$type) if($cfn==$completeFilename) $found=true;
        if(!$found) {
            foreach ($cache['sharedItems'] as $cfn=>$type) if($type=='d' && cfIsSubDir($cfn,$completeFilename)) $found=true;
            if(!$found) {
                $rights['state']='invalid';
                $rights['reason']='file not found in shared items';
                if($item) return $rights[$item]; else return $rights;
            }
        }
    }

    // Get "HSR" file attirbutes
    if($completeFilename=='*resourceBasePath*') $fileAttr='   '; else $fileAttr=cfFileAttributes($completeFilename);

    // If system or hidden
    if((!$cache['showHiddenFiles'] && $fileAttr[0]=='H') || (!$cache['showSystemFiles'] && $fileAttr[1]=='S')){
        $rights['state']='invalid';
        $rights['reason']='file is hidden or system protected: '.$fileAttr;
        if($item) return $rights[$item]; else return $rights;
    };

    // if belongs to protected file types
    if(!$isdir && $cache['protectSensitiveFiles'] && isset($cache['protectedFilesExtensions'][$ext])) {
        $rights['state']='protected';
        $rights['reason']='protected extension';
        if($item) return $rights[$item]; else return $rights;
    }
    // Check that folder access is not forbidden by a weezoAccess file
    elseif ($isdir && file_exists($completeFilename.'/weezoAccess.txt')) {
        $weezoAccess=file_get_contents($completeFilename.'/weezoAccess.txt')."\n";
        if(preg_match('/exclude(\s)*=(\s)*('.cfUGetVar('name').'|all)(\s)*\n/',$weezoAccess)){
            $rights['state']='protected';
            $rights['reason']='weezoAccess protected folder';
            if($item) return $rights[$item]; else return $rights;
        }
    }
    if($item=='state') return $rights[$item];

    // GET OTHER FILE/FOLDER RIGHTS
    $sharedListBaseDir=($completeFilename=='*resourceBasePath*' && $cache['sharedMode']);

    // dir and file view right
    $rights['read']=true;

    // file download right
    if($cache['downloadAllowed']) $rights['download']=true;

    // Read-only files (not directories as it seems not to be reliable)
    if($cache['protectReadOnly'] && $fileAttr[2]=="R" && !@is_dir($completeFilename)){
        $rights['write']=false;
        $rights['modifyAllowed']=false;
    }
    else{
        // dir write (of files inside dir) right
        if($cache['writeAllowed'] && $isdir && !$sharedListBaseDir) $rights['write']=true;

        // dir or file modify right
        if($cache['modifyAllowed'] && ($rights['write'] || !$isdir)) $rights['modify']=true;
    }
    // dir search right
    if($cache['searchAllowed'] && $isdir && !$cache['sharedMode']) $rights['search']=true;

    // file execute right
    if($cache['executeAllowed'] && !$isdir) $rights['execute']=true;

    // dir upload (of files inside dir) right
    if($cache['uploadAllowed'] && $isdir && !$sharedListBaseDir) $rights['upload']=true;

    // dir direct download (of files inside dir) right
    if($cache['remoteDownloadAllowed'] && $isdir && !$sharedListBaseDir) $rights['remoteDownload']=true;

    //if $dir includes a protected dir, modify some of access rights:
    if($isdir && cfIncludesGeneralProtectedDir($dir)){$rights['modify']=false;}
    if($item) return $rights[$item]; else return $rights; // return result
}

/**
 * @desc Check a file
 *
 * @param string $filename: name of file (path not mandatory)
 * @return boolean result
 */
function cfFileRightsFiltersOK($filename){
	require_once(INCLUDE_DIR.'explorerFunctions.php');

	// If resource sets an extension filter, verify that file matches
	if(cfRGetVar('extensionFilter') && !in_array(cfFileExtension($filename),cfRGetVar('extensionFilter'))) return false;

	// If resource sets an file type filter, verify that file matches
	if(cfRGetVar('fileTypeFilter') && !in_array(efFileType($filename),cfRGetVar('fileTypeFilter'))) return false;

	return true;
}

/**
 * @desc Return "HSR" attributes of a file
 *
 * @param string $cfn file
 * @return string 3 chars rights
 */
function cfFileAttributes($cfn){
	static $custom,$rootId;
	if(!isset($custom)) $custom=function_exists('customFileAttributes');
	if($custom) return customFileAttributes($cfn);
	if(!isset($rootId)) $rootId=((function_exists('posix_getpwnam'))?cfArrayItem(posix_getpwnam('root'),'uid'):-1); // Get root user id to check wether it's a system file
	return " ".((@fileowner($cfn)==$rootId)?'S':' ').((is_readable($cfn))?'R':' ');
}

/**
 * @desc return sharedMode
 * @param $string isMode: if set, return true if this mode is set
 * @return string: "list" or "folder" or boolean if $isMode supplied
 */
function cfSharedMode($isMode=false){
	$sm=cfRGetVar('sharedMode');
	if(!$sm) $sm='folder';
	return (($isMode)?$sm===$isMode:$sm);
}

/**
 * @desc return array of shared items
 * @return array(cfn=>"d" (dir) or "f" (file))
 */
function cfSharedItems(){return cfRGetVar('sharedItemsList');}

/**
 * @desc Convert a *resourceBasePath* /path or file into actual filename (exception for upper dir which is returned as *resourceBasePath* anyway
 *
 * @param string $protectedFilename
 * @return string: actual filename, false if not in shared items
 */
function cfSharedCompleteFilename($protectedFilename){
    if($protectedFilename==='*resourceBasePath*') return $protectedFilename;
    if(!cfCmpLeft($protectedFilename,'*resourceBasePath*/')) return false;
    $f=substr($protectedFilename,19);

    if(substr($f,-3)=='/..'){
        $f=cfStrShorten($f,3);
        $f=substr($f,0,strrpos($f,'/'));
    }
    if(!$f) return '*resourceBasePath*';


    // in subdir
    if(strpos($f,'/')!==false){
        $dirName=substr($f,0,strpos($f,'/'));
        foreach (cfRGetVar('sharedItemsList') as $cfn=>$type) if($type=='d' && basename($cfn)==$dirName) {
            return $cfn.substr($f,strpos($f,'/'));
        }
        return false;
    }

    // In items
    foreach (cfRGetVar('sharedItemsList') as $cfn=>$type){
        if(basename($cfn)==$f) return $cfn;
    }
    return false;
}

/**
 * @desc Return true if simple mode is selected
 *
 * @return boolean
 */
function cfSimpleMode(){return cfGGetVar('simpleMode');}



/**
 * @desc transform an IP mask with "*" by an httpd formated IP mask
 *
 * @param strin $address : ip adress matching cfIsIP rule
 * @return string : mask
 */
function cfHttpdIpMask($address){
	if(strpos($address,'*')===false) return $address;
	$mask=str_replace('*','1',$address).'/';
	$bytes=explode('.',$address);
	foreach ($bytes as $byte) {
		if($byte=='*') $mask.='.0'; else $mask.='.255';
	}
	return str_replace('/.','/',$mask);
}

/**
 * @desc write document root .htaccess with general included or excluded adresses,
 * 		 also build an HTML/PHP websites resources aliases list to simplify main UI's work
 *
 */
function cfHtaccessMainWrite(){
	$aliases='';
	$directories='';

	// Build aliases list
	foreach (WEnv::resConfigs() as $id=>$value){
		if(0) $value=new WConfig(); // Zend IDE WA
		if($value->getVar('alias') && $value->getVar('path') && is_file($value->getVar('path'))) {
			$aliases.='	Alias /'.$value->getVar('alias').' "'.cfUTF8Encode(dirname($value->getVar('path')))."\"\n";
			$directories.='<Directory "'.cfUTF8Encode(dirname($value->getVar('path'))).'">'."\n";
        	//$directories.="	    Require all granted\n";
			$directories.="	    AllowOverride None\n";
			$directories.="	    Allow from all\n";
        	$directories.="</Directory>\n\n";
		}
	}

	$aliases="<IfModule alias_module>\n".$aliases."</IfModule>\n";

	// Apache 2.4: add explicit access rights to aliased directories
	if(WEnv::host()->apacheVersion()>2.2) $aliases.=$directories;

	// Put in aliases file (even if empty, this file is mandatory)
	file_put_contents(cfAppDataDir().'/aliases.conf',$aliases);

	// No need for a .htaccess, just remove
	if(cfGGetVar('IPFilter')=='no') return @unlink(cfAppDocRoot().'/.htaccess');

	// Write file

	// general-level IP filter
	$out='';
	if(cfGGetVar('IPFilter')=='include'){
		$IPFilterIncluded=explode(';',cfGGetVar('IPFilterIncluded'));
		if(count($IPFilterIncluded)){
			foreach ($IPFilterIncluded as $key => $value) if($value!='') {
				$out.='Allow from '.cfHttpdIpMask($value)."\n";
			}
			if($out) $out="Order deny,allow\nDeny from all\n".$out; // Add directive only if any addresses found
		}
	}
	elseif(cfGGetVar('IPFilter')=='exclude'){
		$IPFilterExcluded=explode(';',cfGGetVar('IPFilterExcluded'));
		if(count($IPFilterExcluded)){
			foreach ($IPFilterExcluded as $key => $value) if($value!='') $out.='Deny from '.cfHttpdIpMask($value)."\n";
			if($out) $out="Order allow,deny\nAllow from all\n".$out; // Add directive only if any addresses found
		}
	}
	if($out!=''){
		$out="<LIMIT GET POST>\n".$out."</LIMIT>";
		file_put_contents(cfAppDocRoot().'/.htaccess',$out);
	}
}

/**
 * @desc Grant / remove access right to a given directory inside document root through htaccess. DEPRECATED
 *
 * @param string $path : doc root relative path, or false to remove session's all granted access (with action set to 'remove')
 * @param string $action : 'add' or  'remove'
 * @return true if success, false if failed
 */
function cfHtaccessGrant($path, $action='add'){
    $htaccessGranted=cfUGetVar('htaccessGranted');

    // Remove all granted access for session
    if(!$path && $action=='remove' && is_array($htaccessGranted)){
        foreach ($htaccessGranted as $path => $foo) cfHtaccessGrant($path,$action);
        cfUSetVar('htaccessGranted',false);
    }
    if(!$path) return true;
    if(!is_dir(cfAppDocRoot().$path)) return false;

    // Read .htaccess file
    $access=array();
    if(file_exists(cfAppDocRoot().$path.'/.htaccess') && $fp=fopen(cfAppDocRoot().$path.'/.htaccess','r')){
        while (!feof($fp)){
            $line=fgets($fp,1024);
            if(substr($line,0,1)=='#' && strpos($line,'=')){
                $line=explode('=',trim(substr($line,1)),2);
                if(count($line)==2) $access[$line[0]]=$line[1];
            }
        }
        fclose($fp);
    }

    // Remove inexistant sessions and and current session if requested
    foreach ($access as $sess=>$ip) if(!file_exists(cfAppDataDir().'/sessiondata/sess_'.$sess) || $sess==wSession_id()) unset($access[$sess]);
    if($action=='remove' && isset($htaccessGranted[$path])) unset($htaccessGranted[$path]);

    // Add current session if requested
    if($action=='add') {
        $access[wSession_id()]=$_SERVER['REMOTE_ADDR'];
        $htaccessGranted[$path]=1;
    }

    // Write htaccess file
    @unlink(cfAppDocRoot().$path.'/.htaccess');
    if(count($access)){
        $htaccess='';
        foreach ($access as $session => $ip) $htaccess.="# ".$session.'='.$ip."\n";
        $htaccess.="<LIMIT GET POST>\n";
        $htaccess.="Order deny,allow\nAllow from";
        foreach ($access as $ip) $htaccess.=' '.$ip;
        $htaccess.="\nDeny from all\n";
        $htaccess.="</LIMIT>";
        file_put_contents(cfAppDocRoot().$path.'/.htaccess',$htaccess);
    }

    cfUSetVar('htaccessGranted',$htaccessGranted);
    return true;
}

/**
 * @desc Check wether direct connections from out-of-LAN, without passing through centralized authentication are allowed
 *
 * @return boolean
 */
function cfDirectWebConnectionsAllowed(){
    return !(($regData=cfRegistrationData()) && isset($regData['externalAuth']) && $regData['externalAuth'] && isset($regData['directWebConnectionsAllowed']) && !$regData['directWebConnectionsAllowed']);
}

/*
 ***************************************************************************************************************************
 * I/O Functions
 ***************************************************************************************************************************
 */

/**
 * @return string $cleanString
 * @param string $string : string to clean
 * @desc transform < and > signs into their HTML equivalent. if $keepBasicHTMLformat, keep <b>, <u>...
*/
function cfHTMLSafeString($string, $keepBasicHTMLformat=true){
    $cleanString=htmlspecialchars($string);
    if($keepBasicHTMLformat){
        $cleanString=str_replace('&lt;b&gt;','<b>',$cleanString);
        $cleanString=str_replace('&lt;/b&gt;','</b>',$cleanString);
        $cleanString=str_replace('&lt;u&gt;','<u>',$cleanString);
        $cleanString=str_replace('&lt;/u&gt;','</u>',$cleanString);
        $cleanString=str_replace('&lt;i&gt;','<i>',$cleanString);
        $cleanString=str_replace('&lt;/i&gt;','</i>',$cleanString);
        $cleanString=str_replace('&lt;h1&gt;','<h1>',$cleanString);
        $cleanString=str_replace('&lt;/h1&gt;','</h1>',$cleanString);
        $cleanString=str_replace('&lt;h2&gt;','<h2>',$cleanString);
        $cleanString=str_replace('&lt;/h2&gt;','</h2>',$cleanString);
        $cleanString=str_replace('&lt;h3&gt;','<h3>',$cleanString);
        $cleanString=str_replace('&lt;/h3&gt;','</h3>',$cleanString);
        $cleanString=str_replace('&lt;br /&gt;','<br/>',$cleanString);
        $cleanString=str_replace('&lt;br/&gt;','<br/>',$cleanString);
        $cleanString=str_replace('&lt;br&gt;','<br/>',$cleanString);
        $cleanString=str_replace("\r",'<br />',str_replace("\n",'<br />',str_replace("\r\n",'<br />',$cleanString)));
    }
    return $cleanString;
}

/**
 * @return string : encoded string
 * @param string $string : string to encode
 * @desc Encode a string into an XML compatible format (replace "&" by &amp; and &lt; by "<"
*/
function cfXMLEncode($string){return str_replace('<','&lt;',str_replace('&','&amp;',$string));}
function cfXMLEncodeProperty($string){return str_replace('<','&lt;',str_replace('&','&amp;',str_replace('"','&quot;',$string)));}

/**
 * @return string utf-8 encoded string
 * @param string $string : string to encode
 * @param bool $check : if true, verify that $string is not already utf-8 encoded
 * @param bool $protectAmp : if true, protect amp char
 * @desc Encode an $_ENV['weezoLng']['_CHARSET_'] encoded string into utf-8 encoded string.
*/
function cfUTF8Encode($string, $check=false, $protectAmp=true){
    static $encoding=0;
    if($protectAmp) $string=str_replace('&', '&amp;',$string);
    if(!$encoding) $encoding=cfMGetVar('systemCodepage');
    if($check) {if(@iconv($encoding,'UTF-8',@iconv('UTF-8',$encoding,$string))==$string) return $string;}
    return @iconv($encoding,'UTF-8',$string);
}

/**
 * @return string $_ENV['weezoLng']['_CHARSET_'] encoded string
 * @param string $string : string to encode
 * @param bool $utf8Decode : true if string must be utf-8 decoded : default true
 * @param bool $stripSlashes : true if string must be stripslashed : default true
 * @param bool $cleanHTML : remove HTML tags (except basic ones (<br>, <b>...)) : default true
 * @param integer $truncate : max len of string (0 means unlimited), default 8196
* @desc Process an UTF-8 encoded user typed string : default action : strip slashes, remove HTML tags (except basic ones (<br>, <b>...))
*/
function cfUTF8Decode($string, $utf8Decode=true, $stripSlashes=true, $cleanHTML=true, $truncate=8196){
    static $encoding=0;
    if(!$encoding) $encoding=cfMGetVar('systemCodepage');
    $string=str_replace('&amp;','&',str_replace("\0",'',$string));

    if($stripSlashes) $string=(stripcslashes($string));
    if($cleanHTML) $string=cfHTMLSafeString($string);
    if($utf8Decode) $string=@iconv('UTF-8',$encoding,$string);
    if($truncate) $string=cfStrTruncate($string,$truncate);
    return $string;
}
function cfCodePageDecode($string,$codePage){
    return @iconv($codePage,cfMGetVar('systemCodepage'),$string);
    return $string;
}

/**
 * @desc Protect a file name for inclusion in HTML code and return in form
 *
 * @param string $filename : system-encoded file name
 * @return string : protected filename
 */
function cfProtectFilename($filename){
    //return rawurlencode($filename);
    //$filename=str_replace('+','*weezoPlus*',$filename);
    $filename=htmlspecialchars(cfUTF8Encode($filename,false,false),ENT_QUOTES,'UTF-8');
    return $filename;
}

/**
 * @desc Protect text placed into inline javascript function's args (onclick="javascript:my_fn('$s')")
 *
 * @param string $s
 * @return string
 */
function cfProtectInlineScriptTextArg($s){return addslashes(str_replace('"','&quot',$s));}

/**
 * @desc : convert back filename received through post or get (and protected with cfProtectFilename)
 *
 * @param string $filename
 * @return string : original filename
 */
function cfUnprotectFilename($filename,$utf8Decode=true){

	// Special: file is just base 64 encoded
	if(substr($filename,0,4)=='b64.') return cfBase64_url_decode(substr($filename,4));

	// remove file. prefix
	else if(substr($filename,0,5)=='file.') $filename=substr($filename,5);

    $filename=str_replace(chr(194).chr(160),' ',$filename);
    $filename=str_replace('*weezoAmp*','&',$filename);
    $filename=str_replace('*weezoPlus*','+',$filename);
    $filename=str_replace('\\','/',$filename);
    $filename=str_replace('&#039;',"'",$filename);
    $filename=str_replace('*weezoSharp*','#',$filename);

    // Replace chr(160) by spaces if not part of utf8 encoding
    if(strpos($filename,chr(160))!==false){
        for($i=0;$i<strlen($filename);$i++) if($filename[$i]==chr(160) && $i>0 && ord($filename[$i-1])<128) $filename[$i]=' ';
    }
    $filename=str_replace('&amp;','&',str_replace('&gt;','>',str_replace('&lt;','<',$filename)));

    if($utf8Decode) $filename=cfUTF8Decode($filename,true,true,false);
    return $filename;
}

/**
 * @desc Protect a file name for inclusion in URL (to be used with ext/... .php)
 *
 * @param string $filename : system-encoded file name
 * @return string : protected filename (
 */
function cfProtectFilenameURL($filename){
    $filename=rawurlencode(cfUTF8Encode($filename,false,false));
    return $filename;
}

/**
 * @desc : convert back filename received through post or get (and protected with cfProtectFilename)
 *
 * @param string $filename
 * @return string : original filename
 */
function cfUnprotectFilenameURL($filename){
    return cfUTF8Decode(rawurldecode($filename),true,false,false);
}

/**
 * @desc Resolve resource base path relative or specific folder relative file name into actual filename
 *
 * @param string $completeFilename
 * @param boolean $checkFile: true to check file's existance
 * @return mixed: resolved filename if ok, false else
 */
function cfFilenameResolve($completeFilename,$checkFile=true){
	if(cfCmpLeft($completeFilename,'*resourceBasePath*')){
		$completeFilename=(cfSharedMode('list'))?cfSharedCompleteFilename($completeFilename):str_replace('*resourceBasePath*',cfRGetVar('path'),$completeFilename);
	}
	elseif (cfCmpLeft($completeFilename,'*resourceDataDirBasePath*')) $completeFilename=str_replace('*resourceDataDirBasePath*',cfAppResourceDir(),$completeFilename);
	if($checkFile && !file_exists($completeFilename)) return false;

	return $completeFilename;
}

/**
 * @desc Load language into $_ENV['weezoLng'] array
 *          If not already loaded into memory, load-it from file
 *
 * @param string $lng: language name (not used)
 */
function cfLoadLanguage($lng=false){
    // If language is already loaded into ENV array, done
    if(isset($_ENV['weezoLng'])) return;
    if(!$lng) $lng=cfGGetVar('language');

    // Load into ENV array from memory
    if(!($_ENV['weezoLng']=cfMGetVar('weezoLng'.$lng))){
        // If language not loaded into memory, load now
        if(!$lng) $lng='en';
        require_once(INCLUDE_DIR.'lng/'.$lng.'.php');
        if(isset($w_lng)){
            cfMSetVar('weezoLng'.$lng,$w_lng);
            // Then commit to ENV array
            $_ENV['weezoLng']=$w_lng;
            unset($w_lng);
        }
    }
}

/**
 * @return string
 * @param string $captionName
 * @param string $param1: 1st utf-8 encoded replace arg
 * @param string $param2: 2nd utf-8 encoded replace arg
 * @param string $param3: 3rd utf-8 encoded replace arg
 * @param string $forceUILanguage: true to use UI language instead of client's. Used to send alerts to UI or to log events
 * @desc return utf-8 encoded $captionName in current language (if provided replace %1 by $param1, %2 by $param2...)
*/
function cfCaption($captionName,$param1=false,$param2=false,$param3=false,$forceUILanguage=false,$upperCase=false){
    if(($forceUILanguage||cfIsInApp()) && cfGGetVar('language')!=cfGGetVar('languageUI')){
        $lng=cfMGetVar('weezoLng'.cfGGetVar('languageUI'));
        $c=@$lng[$captionName];
        unset($lng);
    }
    else{
        cfLoadLanguage();
        $c=@$_ENV['weezoLng'][$captionName];
    }

    if(!$c) return '# '.$captionName.' #';
    $textToWrite=str_replace('&', '&amp;',$c);
    if($param1!==false) $textToWrite=str_replace('%1',($param1),$textToWrite);
    if($param2!==false) $textToWrite=str_replace('%2',($param2),$textToWrite);
    if($param3!==false) $textToWrite=str_replace('%3',($param3),$textToWrite);

    return $textToWrite;
}

/**
 * Convert an UTF8 text to upper case (or only 1st letter if firstLetterOnly) with accented letters
 *
 * @param string $utf8Txt: utf8 in text
 * @param string $firstLetterOnly: true to emulate UCfirst
 * @return string utf8 out text
 *
 */
function cfStrToUpper($utf8Text, $firstLetterOnly=false){
	return mb_convert_case($utf8Text, ($firstLetterOnly)?MB_CASE_TITLE:MB_CASE_UPPER, "UTF-8");
}

/**
 * @desc return true if caption is defined
 *
 * @param strin $captionName : caption
 * @return bool
 */
function cfCaptionExist($captionName){cfLoadLanguage();if(isset($_ENV['weezoLng'][$captionName])) return true; else return false;}

/**
 * @return string
 * @param string $captionName
 * @param string $param1 1st optional item to include in return caption (replace %1)
 * @param string $param2 2nd optional item to include in return caption (replace %2)
 * @param string $param3 3rd optional item to include in return caption (replace %3)
 * @param string $param4 4st optional item to include in return caption (replace %4)
 * @desc return $captionName in current language (if provided replace %1 by $param1, %2 by $param2...), formated for JavaScript
*/
function cfCaptionJS($captionName=false,$param1=false,$param2=false){
    cfLoadLanguage();
    if(!$captionName) $textToWrite='%1';
    else{
        if(!isset($_ENV['weezoLng'][$captionName])) return '# '.$captionName.' #';
        $textToWrite=str_replace('&', '&amp;',$_ENV['weezoLng'][$captionName]);
    }
    if($param1) $textToWrite=str_replace("%1",cfUTF8Encode($param1),$textToWrite);
    if($param2) $textToWrite=str_replace("%2",cfUTF8Encode($param2),$textToWrite);
    return addslashes($textToWrite);
}

/**
 * @desc Insert JS code for defining a caption using PHP caption name
 *
 * @param string $captionName
 * @param string $param1
 * @param string $param2
 */
function cfJSCaptionVar($captionName,$param1=false,$param2=false){
	return 'wl.capt.'.$captionName.'="'.cfCaptionJS($captionName,$param1=false,$param2=false).'";';
}

/**
 * @desc Generate mailto: link
 *
 * @param mixed $dest: email address or array of email addresses
 * @param string $subject: UTF8 encoded subject
 * @param string $body: UTF8 encoded body
 * @return unknown
 */
function cfMailTo($dest='',$subject='',$body=''){
	if(cfIsInApp()){
		$body=str_replace('+','%20',str_replace("\n",'<br>',$body));
		$subject=str_replace('+','%20',$subject);
		return "javascript:wl.popup('/local/sendMail.php?subject=".urlencode($subject)."&body=".urlencode($body)."','".cfCaption('genEMail')."');";
	}
	else{
		$out='mailto:';
		// Recipient
		if(is_array($dest)) foreach ($dest as $singleDest) $out.=(($out=='mailto:')?'':',').$singleDest;
		elseif ($dest) $out.=$dest;
		$args='';
		// Subject
		if($subject) $args.='subject='.str_replace('+',' ',urlencode(cfUTF8Decode($subject)));
		// Body
		if($body) $args.=(($args)?'&':'').'body='.str_replace('+',' ',urlencode(cfUTF8Decode($body,true,true,false)));
		//$args=str_replace(array("\r\n","\n","\r","<br>","<br/>","<br />"),"%0d%0a",$args);

		return $out.(($args)?'?'.$args:'');
	}
}

/**
 * @desc Insert JS code for defining an icon url
 *
 * @param string $iconName
 * @return string
 */
function cfJSIconURL($iconName){return 'wl.ico.'.basename($iconName).'="'.outIcon($iconName).'";';}

/*
 ***************************************************************************************************************************
 * Async HTTPXmlRequest Functions
 ***************************************************************************************************************************
 */

/**
 * @desc return true if asynchronous request
 *
 */
function cfIsAsync(){return isset($_POST['asyncRequest']);}

/**
 * @desc echo header and xml stuff for async response
 *
 * @param string $responseNodeAttributes: attributes added to <response> node
 * @param boolean $cacheRequest: true to indicate browser to cache request
 */
function cfAsyncHeader($responseNodeAttributes='',$cacheRequest=false){
    if(isset($_ENV['cfAsyncHeader'])) return;
    $_ENV['cfAsyncHeader']=1;
    if(cfMGetVar('debugAsync') && $_SERVER['SCRIPT_NAME']!='/index.php' && $_SERVER['SCRIPT_NAME']!='/ping.php' && $_SERVER['SCRIPT_NAME']!='/pub/tools.php') {
        $_ENV['debugAsync']=microtime(true);
        ob_start();
    }
    // Classic browser async request
    if(!isset($_GET['XMLHttpScriptRequest'])){
        header('Content-Type:text/xml');
        header('P3P: policyref="/w3c/p3p.xml",CP="NON COR CURa OUR NOR NAV"');
        if($cacheRequest){
            header("Pragma:"); // Do not remove, required by IE in SSL mode
            header('Cache-Control: private');
            header('Expires: '.gmdate("D, d M Y H:i:s",time()+3600).' GMT');
        }
        else{
            header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
        }
        echo "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response".(($responseNodeAttributes!='')?' '.$responseNodeAttributes:'').">\n";
    }
    // Script inclusion async request
    else {
        header('P3P: policyref="/w3c/p3p.xml",CP="NON COR CURa OUR NOR NAV"');
        header('Content-Type: text/html');
        header('Expires: Mon, 26 Jul 1997 15:00:00 GMT');
        header('Cache-Control: no-cache, must-revalidate');
        header('Pragma: no-cache');
    }
}
/**
 * @desc return async response footer
 *
 * @param boolean $die: set to true to echo result and die, false to return result
 * @return string
 */
function cfAsyncFooter($exit=true){
    // Debug
    if(isset($_ENV['debugAsync'])){
        // Filter
        $debug=0;
        if($daf=cfMGetVar('debugAsyncFilter')){
            if(stripos(ob_get_contents(),$daf)!==false) $debug=1;
            else foreach ($_POST as $k=>$v){
                if(strpos($k.$v,$daf)!==false) $debug=1;
            }
        }
        // No filter
        elseif ($_SERVER['PHP_SELF']!='/ping.php' && basename($_SERVER['PHP_SELF'])!='transfers.php') $debug=1;
        if($debug){
            $resp=substr(ob_get_contents(),50);
            cfDebugSetBuffer('async',$_POST,$resp);
        }
        ob_end_flush();
    }
    if(!isset($_GET['XMLHttpScriptRequest'])) $af='</response>'; else $af='<script type="text/javascript">parent.mcRIP=0;</script>';
    if($exit) die($af);
    return $af;
}

/**
 * @desc send xml data
 *
 * @param string $XMLTag : tag AND attributes : '<tag value="foo">'
 * @param string $data
 * @return xml code
 */
function cfAsyncXMLNode($XMLTag,$data){
    $blockSize=3500;
    $output='';
    if(substr($XMLTag,0,1)=='<') $XMLTag=substr($XMLTag,1);if(substr($XMLTag,-1)=='>') $XMLTag=substr($XMLTag,0,strlen($XMLTag)-1);
    if(strpos($XMLTag,' ')) $tagName=substr($XMLTag,0,strpos($XMLTag,' ')); else $tagName=$XMLTag;
    // if not gecko or output size < $blockSize
    if(strlen($data)<=$blockSize || cfGetBrowser()!='gecko') return '<'.$XMLTag.'>'.cfXMLEncode($data).'</'.$tagName.'>';

    // slice response in $blockSize bytes blocks
    while (strlen($data)>$blockSize) {
    	$i=1; while(ord(substr($data,$blockSize-$i,1))>127) $i++; // (try to?) avoid cutting an cft8 encoded character in 2
        $output.='<addToBuffer>'.cfXMLEncode(substr($data,0,$blockSize-$i))."</addToBuffer>\n";
        $data=substr($data,$blockSize-$i);
    }
    if(strlen($data)) $output.='<addToBuffer>'.cfXMLEncode($data)."</addToBuffer>\n";
    $output.='<'.$XMLTag.' commitBuffer="true"/>';
    return $output;
}
/**
 * @desc : Return XML code that will trigger execution of a javascript function when returned to XMLHttpRequest
 *
 * @param string $script: utf-8 encoded javascript
 * @param bool $realTime: set to true to ask browser to execute commands ASAP
 * @return XML node
 */
function cfAsyncXMLJSaction($script,$realTime=false){
    if(!isset($_GET['XMLHttpScriptRequest'])) return cfAsyncXMLNode(($realTime)?'<JSRT>':'<JSAction>',$script);
    else return '<script type="text/javascript">parent.asEval(\''.addslashes($script).'\')</script>';
}
/**
 * @desc Alias for cfAsyncXMLJSaction
 *
 * @param string $script: utf-8 encoded javascript
 * @param bool $realTime: set to true to ask browser to execute commands ASAP
 * @return XML node
 */
function cfAsyncJSaction($script,$realTime=false){
    if(!isset($_GET['XMLHttpScriptRequest'])) return cfAsyncXMLNode(($realTime)?'<JSRT>':'<JSAction>',$script);
    else return '<script type="text/javascript">parent.asEval(\''.addslashes($script).'\')</script>';
}
/**
 * @desc : Return XML code that will trigger execution of a javascript alert displaying $text
 *
 * @param string $text : non-utf-8 encoded text to display
 * @return XML node
 */
function cfAsyncXMLDebug($text){return cfAsyncXMLJSaction('alert("'.addcslashes($text,'"\\').'")');}
/**
 * @desc : Return XML code that will trigger replacement of innerHTML content of HTML node with $id id attribute
 *
 * @param string $html : utf-8 innerHTML content
 * @param string $id : id of node whose innerHTML will be replaced
 * @param boolean $add : true if $html must be added to node content, false to replace
 * @return XML node
 */
function cfAsyncXMLInnerHTMLbyId($html,$id,$add=false){
    if(!isset($_GET['XMLHttpScriptRequest'])) return cfAsyncXMLNode('<innerHTML nodeId="'.$id.'"'.(($add)?' add="true"':'').'>',$html);
    else return '<script type="text/javascript">parent.dgi("'.$id.'").innerHTML'.(($add)?'+=':'=')."'".str_replace("\n",'',addcslashes($html,"'\\"))."';</script>\n";
}

/**
 * @desc : Return XML code that will trigger replacement of innerHTML content of HTML node(s) named $name
 *
 * @param string $html : utf-8 innerHTML content
 * @param string $name : name of node(s) whose innerHTML will be replaced
 * @param boolean $add : true if $html must be added to node content, false to replace
 * @return XML node
 */
function cfAsyncXMLInnerHTMLbyName($html,$name,$add=false){
    if(!isset($_GET['XMLHttpScriptRequest'])) return cfAsyncXMLNode('<innerHTML nodeName="'.$name.'"'.(($add)?' add="true"':'').'>',$html);
    else return 'parent.dgn("'.$name.'").innerHTML'.(($add)?'+=':'=')."'".str_replace("\n",'',addcslashes($html,"'\\"))."';\n";
}
/**
 * @desc : Return XML code that will trigger replacement of innerHTML content of HTML node(s) with $tagName tag
 *
 * @param string $html : utf-8 innerHTML content
 * @param string $tagName : tag of node(s) whose innerHTML will be replaced
 * @param boolean $add : true if $html must be added to node content, false to replace
 * @return XML node
 */
function cfAsyncXMLInnerHTMLbyTagName($html,$tagName,$add=false){
    if(!isset($_GET['XMLHttpScriptRequest'])) return cfAsyncXMLNode('<innerHTML nodeTagName="'.$tagName.'"'.(($add)?' add="true"':'').'>',$html);
    else return '<script type="text/javascript">parent.getElementsByTagName("'.$tagName.'")[0].innerHTML'.(($add)?'+=':'=')."'".str_replace("\n",'',addcslashes($html,"'\\"))."';</script>\n";
}
/**
 * @desc : Update a resource php variable value from async post
 *
 * @param string $phpVarName: name of resource var to update
 * @param string $constraints: array of possible values
 */
function cfAsyncXMLChangePhpVarValue($phpVarName,$constraints=false){
    // Change variable value
    if(isset($_POST[$phpVarName])){
        $res=cfUTF8Decode($_POST[$phpVarName]);
        if(strtolower($res)=='true') $res=true;  if(strtolower($res)=='false') $res=false;
        if(!$constraints) cfRSetVar($phpVarName,$res);
        else foreach ($constraints as $v) if($res==$v) {
           	cfRSetVar($phpVarName,$res);break;
        }
        // Send async response
        cfAsyncHeader();
        cfAsyncFooter();

    }
    // Async controls
    elseif (isset($_POST['asUpdtName']) && $_POST['asUpdtName']==$phpVarName) {
        $_POST['asUpdtValue']=cfUTF8Decode($_POST['asUpdtValue']);
        if(!$constraints) cfRSetVar($phpVarName,$_POST['asUpdtValue']);
        else{
            foreach ($constraints as $v) if($_POST['asUpdtValue']==$v) {cfRSetVar($phpVarName,$_POST['asUpdtValue']);break;}
        }
        // Send async response
        cfAsyncHeader();
        cfAsyncFooter();
    }
}
/**
 * @desc : depending on asyncResponse, echo $output and reset, or echo $output in XML format
 *         if $asyncResponse is in $condition array (or if $condition is false), echo <$xmlTag>$output</$xmlTag>
 *        (note : XML tag may include attributes)
 *            if $exitIfXMLFlush is true, close async response and exit
 *        else just echo $output and set it to empty string.
 *
 * @param string $output
 * @param string $asyncResponse
 * @param array $condition
 * @param string $XMLTag
 * @param boolean $exitIfXMLFlush
 */
function cfAsyncOutputFlush(&$output, $asyncResponse=1, $condition, $XMLTag, $exitIfXMLFlush=true){
    if(!$asyncResponse) echo $output;
    elseif(!$condition || in_array($asyncResponse,$condition)){
        if(isset($_GET['XMLHttpScriptRequest'])){
            if(substr($XMLTag,0,19)=='<innerHTML nodeId="') echo cfAsyncXMLInnerHTMLbyId($output,substr($XMLTag,19,strlen($XMLTag)-21));
            if(substr($XMLTag,0,20)=='<innerHTML tagName="') echo cfAsyncXMLInnerHTMLbyId($output,substr($XMLTag,20,strlen($XMLTag)-22));
            if(substr($XMLTag,0,20)=='<innerHTML name="') echo cfAsyncXMLInnerHTMLbyId($output,substr($XMLTag,17,strlen($XMLTag)-19));
        }
        else echo cfAsyncXMLNode($XMLTag,$output);
        if($exitIfXMLFlush) die(cfAsyncFooter());
    }
    $output='';
}

/**
 * Real-time execute script for synchronous or asynchronous actions
 *
 * @param string $script
 */
function cfRTScript($script){
    if(cfIsMobile()) return;
    if(cfIsAsync()) echo cfAsyncXMLJSaction($script,true)."\n"; else echo '<script type="text/javascript">'.$script.'</script>';
    flush();
}

/**
 ***************************************************************************************************************************
 * Drag'n drop functions
 ***************************************************************************************************************************
 */

/**
 * @desc set JS function called when an object is dragged onto another
 *
 * @param string $dropFunctionName : name of JS function
 * @return string HTML JS code
 */
function cfDragSetDropFunction($dropFunctionName){
    $output="<script type=\"text/javascript\">\n<!--\n";
    $output.='setDropFunction("'.$dropFunctionName."\");\n";
    return $output."\n//-->\n</script>\n";
}
/**
 * @desc add an item (image or div) to draggable items list
 *             added items list must be commited with cfDragRegisterItems (sync) or cfDragAsyncRegisterDiv (async)
 *
 * @param string $name: name (for images) or id (for div) of draggable item node
 * @param string $properties: properties of draggable item
 * @param string $initCommands: JS commands called after SET_DHTML function
 */
function cfDragAddItem($name, $properties=false, $initCommands=false){
    //if(isset($_SESSION['activeResourceId'])) cfRSetVar('dragItems',$name,$properties); else
    $_ENV['weezo']['dragItems'][$name]=$properties;
    if($initCommands){
        if(!isset($_ENV['weezo']['dragItemsInitCommands'])) $_ENV['weezo']['dragItemsInitCommands']='';
        $_ENV['weezo']['dragItemsInitCommands'].=$initCommands.";\n";
    }
}
/**
 * @desc launch JS function that creates draggable items from draggable items list
 *
 * @return string HTML JS code
 */
function cfDragRegisterItems($defaultOptions='SCROLL',$includeScriptTag=true){
    $receiverOnly='';
    if($includeScriptTag) $output="<script type=\"text/javascript\">\n"; else $output='';
    $output.="SET_DHTML(".((!$defaultOptions)?'""':$defaultOptions);
    if (isset($_ENV['weezo']['dragItems'])){
        foreach ($_ENV['weezo']['dragItems'] as $key=>$value){
            if(strpos($value,'+RECEIVER_ONLY')!==false) {
                $receiverOnly.='drec.addElt(dgi("'.$key.'"));';
                $value=str_replace('+RECEIVER_ONLY','',$value);
                if(strpos($value,'+HIGHLIGHT_FUNC')!==false) $receiverOnly.='drec.setHighlightFunction(dgi("'.$key.'"),'.substr($value,15).');';

            }
            else $output.=",\n\"".$key.'"'.$value;
        }
    }
    $output.=");\n";
    $output.=$receiverOnly;
    if(isset($_ENV['weezo']['dragItemsInitCommands'])) $output.=$_ENV['weezo']['dragItemsInitCommands'];
    if($includeScriptTag) return $output."</script>\n"; else return $output;
}
/**
 * @desc launch JS function that creates draggable items from draggable items list (for async use, only works with div, not with img)
 *
 * @return string HTML JS code
 */
function cfDragAsyncRegisterDiv(){
    if(!isset($_ENV['weezo']['dragItems'])) return '';
    $js='';    foreach ($_ENV['weezo']['dragItems'] as $key=>$value)    $js.='ADD_DHTML("'.$key.'"'.$value.");\n";
    return cfAsyncXMLJSaction($js);
}


/*
 ***************************************************************************************************************************
 * Misc. Functions
 ***************************************************************************************************************************
 */

/**
 * @desc Return a link to ip address map location page
 *
 * @param string $ip
 * @return string
 */
function cfIPLocatorLink($ip){return '/local/ipLocator.php?ip='.$ip.'&WSESSID='.wSession_id();}

/**
 * @desc require_once a script, but don't execute code, just get access to included functions.
 * 			Script must include a "cfRequiredFunctionsEnd()" call after functions definition.
 *
 * @param string $scriptPath: path of script (same arg as require_once function)
 */
function cfRequireFunctions($scriptPath){
	$_ENV['includedForFunctions']=true;
	require_once($scriptPath);
	unset($_ENV['includedForFunctions']);
}

/**
 * @desc Indicate in a script that functions that may be included have been defined and only executable code is below this point.
 * 		For use with cfRequireFunctions;
 *
 */
function cfRequireFunctionsEnd(){
	if(isset($_ENV['includedForFunctions'])) return true; else return false;
}

/**
 * @desc Update last user connection time
 * @param mixed $step: perform test once out of $step times (to reduce execution time when called numerous times)
 *                 set to 0 not to perform test
 *                 set to 'force' to force sending, even if last ping was sent less than clientPingInterval seconds ago
 * @param integer $newDisconnectionInterval: if set, change app's disconnection interval
 *             (used not to disconnect while playing media on devices using "standaloneMediaPlayer")
 *
 * @return true if ping sent, false if ping not needed, null if error
 */
function cfPingUpdate($step=0, $newDisconnectionInterval=0){
	// Ping limitation, used when this function is called very frequently (several times per second) without consuming CPU: only one call out of $step is actually processed
    if(is_numeric($step) && $step>0){
        global $cfPingUpdate;
        if(!isset($cfPingUpdate)) $cfPingUpdate=0;
        if((++$cfPingUpdate)%$step) return false;
    }

    // Get session id
    if(!isset($_ENV['weezoSessionId'])){
        if(wSession_id()) $_ENV['weezoSessionId']=wSession_id();
        elseif(isset($_COOKIE['WSESSID']) && $_COOKIE['WSESSID']) $_ENV['weezoSessionId']=$_COOKIE['WSESSID'];
        else return NULL;
    }

    // Get in-memory list of last pings to get last ping time and avoid too frequent pings.
    // Note: threads collisions are not important as they may only result into an extra ping
    if(!cfMIssetVar('weezoPings')) cfMSetVar('weezoPings',array()); $pings=cfMGetVar('weezoPings');
    if($step==='force') $len=0; else $len=2; // Set a minimum interval of 2secs between 2 pings

    // Check if ping is needed
    if(!isset($pings[$_ENV['weezoSessionId']]) || (time()-$pings[$_ENV['weezoSessionId']]>$len)) {
        if($newDisconnectionInterval>0) $newDisconnectionInterval=max($newDisconnectionInterval,cfGGetVar('inactivityTimeBeforeDisconnect'));

        // Update last user ping time into user's session
        WEnv::usersLogged()->pingUser($_ENV['weezoSessionId'],$newDisconnectionInterval);

        $pings=@cfMGetVar('weezoPings');
        $pings[$_ENV['weezoSessionId']]=time();
        cfMSetVar('weezoPings',$pings);
        return true;
    }
    return false;
}

/**
 * @return string
 * @param string $file
 * @desc return file extension
*/
function cfFileExtension($file){
    if(strrpos($file,'.')===false) return '';
    return strtolower(substr($file,strrpos($file,'.')+1));
}

/**
 * @return string
 * @param string $file
 * @desc return file name without extension
*/
function cfFileWithoutExtension($file){
    if(strrpos($file,'.')===false) return $file;
    return substr($file,0,strrpos($file,'.'));
}

/**
 * @desc Return file size
 *
 * @param string $completeFilename
 * @return int
 */
function cfFileSize($completeFilename){
	if(function_exists('customFileSize')){
	    $size=customFileSize($completeFilename);
	    if($size==8589934591 || $size>8E+17) return @filesize($completeFilename); else return $size;
	}

	return @filesize($completeFilename);
}

/**
 * @desc Read $len bytes of given file at given position: Works with files larger than 2GB
 *
 * @param string $cfn: filename
 * @param double $pos: offset from start
 * @param long $len: read length
 * @return string (or false)
 */
function cfFread($cfn,$pos,$len){
    // Below 2GB limit: use PHP functions
    if($pos<2147483648){
        if(!($fp=fopen($cfn,'rb'))) return false;
        fseek($fp,$pos);
        $data=fread($fp,$len);
        fclose($fp);
        return $data;
    }
    // Over 2GB: use custom
    return customFread($cfn,$pos,$len);
}

/**
 * @desc returns a clean lowercase file or path name. return false if doesn't exist
 * @param string $dir: directory or file name
 * @param bool $checkFileExists: set to true to return false if file/dir doesn't exist
 * @return string
*/
function cfCleanPathName($dir,$checkFileExists=true){
	static $resolveSymbolicLinks;

	// Resolve symbolic links (on non-windows system)
	if(!isset($resolveSymbolicLinks)) $resolveSymbolicLinks=(cfGGetVar('resolveSymbolicLink') || WEnv::host()->isWindows());

    // Shared list
    if($dir=='*resourceBasePath*') return $dir;
    elseif (substr($dir,0,19)=='*resourceBasePath*/'){
        $subDir=substr($dir,19);
        if(strpos($subDir,'/')) $dirName=substr($subDir,0,strpos($subDir,'/')); else $dirName=$subDir;

        // Browse shared items
        foreach (cfRGetVar('sharedItemsList') as $cfn=>$type) {
            // Look in subdirs
            if($type=='d' && basename($cfn)==$dirName) {
            	// Check file/dir existance
            	if($checkFileExists)
                	$dir=($resolveSymbolicLinks)?realpath(dirname($cfn).'/'.$subDir):cfRealpathNoSymbolicLinkResolve(dirname($cfn).'/'.$subDir);
                else
                	$dir=dirname($cfn).'/'.$subDir;

                $dir=(strtr($dir,"\\","/"));

                if(cfIsSubDir($cfn,$dir)) return $dir;
                elseif ($dir==dirname($cfn)) return '*resourceBasePath*'; // detect *resourceBasePath*/path/..
            }
            // Look for files
            if($type=='f' && basename($cfn)==$subDir) return $cfn;
        }
        return false;
    }
    // Shared list but with real path instead of *resourceBasePath*, and going up with ..
    elseif (substr($dir,-3)=='/..' && cfSharedMode('list')){
    	$dir=substr($dir,0,strlen($dir)-3); // Remove /..
        // Browse shared items to see if dir is one of top-level directories
        foreach (cfRGetVar('sharedItemsList') as $cfn=>$type) {
            // Look in top-level directories, and if found, return top level
            if($type=='d' && $cfn===$dir) return '*resourceBasePath*';
        }
        // Not found: it's a regular up-level => reappend /.. and proceed
        $dir.='/..';
    }
//cfDbgOnce($dir);
    if(substr($dir,0,14)=='*resSpecific*/') return $dir; // No operation on resource specific filenames
    if($dir=='..' || $dir=='.') return false;
    if($dir=='computerRoot') return $dir;

    // Check file/dir existance
	if($checkFileExists) $dir=($resolveSymbolicLinks)?realpath($dir):cfRealpathNoSymbolicLinkResolve($dir);


    $dir=(strtr($dir,"\\","/"));
    if(substr($dir,-1)=='/' && $dir!="/") return substr($dir,0,strlen($dir)-1); else return $dir;
}


/**
 * @desc glob working with UNC
 *
 * @param string $mask : glob parameter
 * @return array
 */
function cfGlob($mask){
    if(substr($mask,-1)=='/') $mask.='*';
    $dir=str_replace('\\','/',dirname($mask)); $mask=basename($mask);
    if(!$mask || $mask=='*' || $mask=='*.*') $mask=false; else $mask='/^'.str_replace('*',".*",str_replace('?','.',str_replace('.','\\.',$mask))).'$/i';
    $res=array(); if(!$fp=@opendir($dir)) return $res;
    if(substr($dir,-1)!='/') $dir.='/';
    while (($file=readdir($fp))!==false) if($file!='.' && $file!='..') {
        if(!$mask || preg_match($mask,$file)) $res[]=$dir.$file;
    }
    closedir($fp);
    return $res;
}

/**
 * @desc corrects existing filename case
 *
 * @param strint $completeFilename
 * @return string
 */
function cfCorrectFilenameCase($completeFilename,$processPath=false){
    if($completeFilename=='computerRoot') return $completeFilename;
    if(strlen($completeFilename)<4) return strtoupper($completeFilename);
    $completeFilename=str_replace('\\','/',$completeFilename);
    $dir=str_replace('\\','/',dirname($completeFilename)); if(substr($dir,-1)=='/') $dir=substr($dir,0, strlen($dir)-1);
    if($processPath) $dir=cfCorrectFilenameCase($dir,true);
    $filename=strtolower(basename($completeFilename));
    foreach (cfGlob($dir.'/*') as $key=>$value) if(strtolower(basename($value))==$filename) {
        return strtoupper($value[0]).substr($value,1);
    }
    return $completeFilename;
}

/**
 * @return string
 * @param string $cfn
 * @desc returns the dir part of $cfn (same as PHP dirname exepted for root directories returned with a '/'
*/
function cfDirName($cfn){
    if($cfn=='*resourceBasePath*') return $cfn;
    return strtr(dirname($cfn),"\\","/");
}

/**
 * @return string
 * @param string $path
 * @desc returns the basename part of $path (same as PHP dirname exepted for root directories returned with a '/'
*/
function cfBasename($cfn){
    if($cfn=='*resourceBasePath*') return '.';
    if(substr($cfn,-1)==':'||substr($cfn,-2,1)==':') return '';
    return strtr(basename($cfn),"\\","/");
}

/**
 * @return string
 * @param string $path
 * @param string $file
 * @desc joins a path and a file (used to prevent '//' problems)
*/
function cfJoinPathFile($path,$file){
    if(strlen($path)==0) return $file;
    if(strlen($file)==0||$file=='.') return $path;
    if($path=='computerRoot') return $file;
    if(substr($file,0,1)=='/' || substr($file,0,1)=='\\') $file=substr($file,1);
    if(substr($path,-1)=='/') return $path.$file;
    if(substr($path,-1)=='\\') return substr($path,0,strlen($path)-1).'/'.$file;
    return $path.'/'.$file;
}

/**
 * @desc Ensure browser-passed filename is not tricky
 *
 * @param string $file
 * @return string
 */
function cfSanitizeFile($file){
	if(strpos($file,'/') || strpos($file,'\\') || strpos($file,'\0')) return false;
	return $file;
}

/**
 * @return boolean
 * @param string $upperDir
 * @param string $lowerDir
 * @desc return true if $lowerDir is $upperDir or a subdirectory of $upperDir or a file included in $upperDir (or in one of it's subdirectories)
*/
function cfIsSubDir($upperDir, $lowerDir){
    if($upperDir=='computerRoot') return true;
    $upperDir=strtolower($upperDir); $lowerDir=strtolower($lowerDir);
    if(substr($upperDir,-1)=='/'||substr($upperDir,-1)=='\\') $upperDir=substr($upperDir,0,strlen($upperDir)-1);
    if(cfCmpLeft($lowerDir,$upperDir)){
        if(strlen($lowerDir)==strlen($upperDir) || substr($lowerDir,strlen($upperDir),1)=='/' || substr($lowerDir,strlen($upperDir),1)=='\\') return true;
    }
    return false;
}

/**
 * Do as realpath function, but without resolving symbolic links
 *
 * @param string $path
 */
function cfRealpathNoSymbolicLinkResolve($path){
	while($p=strpos($path,'/..')) $path=dirname(substr($path,0,$p)).'/'.substr($path,$p+3);
	if(strpos($path,'../')===0) return false;
	$path=str_replace('./','/',$path);
	if($path!='/' && $path!='//' && substr($path,-1)=='/') $path=substr($path,0,strlen($path)-1);
	return (file_exists($path))?$path:false;
}

/**
 * @return result of unlink
 * @param string $dir name of dir
 * @desc unlink a non-empty dir (which possibly includes files and subdirs) : NO ACCESS RIGHTS CHECKED !!!
*/
function cfUnlinkDir($dir){
    $folder=@opendir($dir);
    if(!$folder) return false;
    while (($file = @readdir($folder))!==false) {
        if ($file!='.' && $file!='..'){
            if (is_dir($dir.'/'.$file)) $result=cfUnlinkDir($dir.'/'.$file); else $result=@unlink($dir.'/'.$file);
            if(!$result) return false;
        }
    }
    @closedir($folder);
    return @rmdir($dir);
}

/**
 * @return string dir created or false if failed
 * @param string $dir name of dir
 * @desc create a new folder. Folder parents are created if needed : NO ACCESS RIGHTS CHECKED !!!
*/
function cfMkdir($dir){
    if(!$dir || is_dir($dir)) return $dir;
    if(substr($dir,-1)=='/') $dir=substr($dir,0,strlen($dir)-1);
    $parentDir=dirname($dir);
    if(!is_dir($parentDir)){
        if(!cfMkdir($parentDir)) return false;
    }
    return @mkdir($dir);
}

/**
 * @desc Copy or move a dir and all its content to another location
 *
 * @param string $source : source directory
 * @param string $target : target directory
 * @param boolean $move : set to true to move instead of copy
 * @return boolean : true if all files successfully copied/moved
 */
function cfCopyDir($source, $target, $move=false){
    $err=false;
    if(is_dir($source )){
        @mkdir($target);
        $d=dir($source);
        while (($entry=$d->read())!==false){
            if ($entry == '.' || $entry == '..') continue;
            if (is_dir($Entry=$source.'/'.$entry)){
                cfCopyDir($Entry, $target.'/'.$entry,$move);
                continue;
            }
            if($move) {
                $err|=@unlink($target.'/'.$entry);
                $err|=@rename($Entry, $target.'/'.$entry);
            }
            else $err|=@copy($Entry, $target.'/'.$entry);
        }
        $d->close();
        if($move) rmdir($source);
    }
    else {
        if($move) {
            $err|=@unlink($target);
            $err|=@rename($source, $target);
        }
        else $err|=@copy($source, $target);
    }
    return $err;
}

/**
 * @desc Recrusively browse a folder and its subfolders and call a function with each file (or return an array of files)
 *
 * @param string $dir: top directory
 * @param string $callbackFunction: name of function to call or 'return' to get an array of files as return parameter
 * @param string $pattern: mask pattern, empty for directories
 * @param int $level: recurse level
 */
function cfRecurseBrowse($dir,$callbackFunction,$pattern='*',$level=0){
	$list=array();

	// Browse files
	if($pattern) foreach (cfGlob($dir.'/'.$pattern) as $cfn) if(is_file($cfn)) {
		if($callbackFunction=='return') $list[]=$cfn;
		else call_user_func($callbackFunction,$cfn,$level);
	}

	// Browse dirs
	foreach (cfGlob($dir.'/*') as $cfn) if(is_dir($cfn)) {
		if(!$pattern) {
			if($callbackFunction=='return') $list[]=$cfn;
			else call_user_func($callbackFunction,$cfn,$level);
		}

		if($callbackFunction=='return') $list=array_merge($list,cfRecurseBrowse($cfn,$callbackFunction,$pattern,$level+1));
		else cfRecurseBrowse($cfn,$callbackFunction,$pattern,$level+1);
	}
	if($callbackFunction=='return') return $list;
}

/**
 * @return string name of expected response file
 * @param string $command command to send
 * @param boolean $asyncMessage: true to send message asynchronously, false to send synched, "auto" to set according to command
 * @param boolean $customSessionId: true to specify that session id has been set by application and must not be retreived from actual session
 * @desc write a command file to application for processing
*/
function cfServerSendCommand($command, $asyncMessage='auto',$customSessionId=false){

    // If async set to auto, determine from command
    if($asyncMessage==='auto'){
        $mcmd=substr($command,0,strpos($command,' '));
        If($mcmd == "rDesk" || $mcmd == "webcam" || /*$mcmd == "refreshResource" || $mcmd == "refreshUser" ||*/ $mcmd == "deleteUser") $asyncMessage=false; else $asyncMessage=true;
    }
    // Add client IP
    if(isset($_SESSION['accountIP'])) $command .=' ip="'.$_SESSION['accountIP'].'"'; else $command .=' ip="'.$_SERVER['REMOTE_ADDR'].'"';
    // Add in-app info
    $command .=' inApp="'.((int)cfIsInApp()).'"';

    // Set session Id of user
    if(!$customSessionId){
        if(wSession_id()) $command .=' sessionId="'.wSession_id().'"';
        elseif (isset($_COOKIE['WSESSID'])) $command .=' sessionId="'.$_COOKIE['WSESSID'].'"';
    }

    // Log exchanges with app
    if(substr($command,0,5)!='ping ') cfDebugSingle('Command PHP->UI    '.(($asyncMessage)?'A':'S').'    '.$command);

    // Persistent connection communication
   	if(!function_exists('customSendCommand') || cfGGetVar('appType')=='Qt'){
   		while (cfMIssetVar('UICommandReading')) usleep(10);
   		cfMSetVar('UICommandWriting',1);
   		cfMSetVar('UICommand',cfMGetVar('UICommand').'<UICommand>'.$command.'</UICommand>');
   		cfMUnsetVar('UICommandWriting');
   		return true;
   	}


    // Send command to applicationz
    $try=-1; while(!customSendCommand($command, (int)$asyncMessage, (string)cfMGetVar('mailslotIndex')) && ++$try<3) sleep(1);;
    if(cfGGetVar('UIDebug')) cfAppendTextToFile('PHP->UI (ms:'.(string)cfMGetVar('mailslotIndex').') '.(($try===3)?'!!!NOK':'    ok'.$try).'/'.$command,cfAppDataRootDir().'/exchanges.txt',false);

    // If failure
    if($try==3){
    	// 1st check if weezo executable is still here
        $wok=null;

        // Windows env
        $procs=cfProcList();
        if($procs) foreach ($procs as $proc) {
            $wok=false;
            if(strtolower(basename($proc['exe']))=='weezo.exe') {$wok=true;break;}
        }

        // If weezo.exe is not here, restart (if crash monitor enabled)
        if($wok===false){
        	if(cfGGetVar('weezoCrashMonitor') && !cfMGetVar('appExited')) cfExecFork(cfAppBinDir().'/weezoReboot.exe','SW_HIDE','restart');
        	return false;
    	}

    	// Try other method
    	$asyncMessage=!$asyncMessage;

    	if(cfGGetVar('UIDebug')) cfAppendTextToFile('PHP->UI    '.(($asyncMessage)?'a':'s').' TRY ALTERNATE SYNC '.$command,cfAppDataRootDir().'/exchanges.txt',false);
    	$res=customSendCommand($command, (int)$asyncMessage, (string)cfMGetVar('mailslotIndex'));
    	if(cfGGetVar('UIDebug')) cfAppendTextToFile('PHP->UI '.((!$res)?'!!!NOK':'    ok'),cfAppDataRootDir().'/exchanges.txt',false);
    }

    return true;
}
function cfServerSendCmd($command, $args=false, $asyncMessage='auto',$customSessionId=false){
    if($args) {
    	foreach ($args as $k=>$v) {
    		if($v===true) $v='true';
    		elseif($v===false) $v='false';
    		$command.=' '.$k.'="'.addslashes($v).'"';
    	}
    }
    return cfServerSendCommand($command,$asyncMessage,$customSessionId);
}

/**
 * @desc Synchronously send a command to UI and wait for a response
 *
 * @param string $command
 * @param array $args: key=>value arguments
 * @return string response
 */
function cfServerSendRequest($command, $args=false, $customSessionId=false){
	$response=false;

    if($args) {
    	foreach ($args as $k=>$v) {
    		if($v===true) $v='true';
    		elseif($v===false) $v='false';
    		$command.=' '.$k.'="'.addslashes($v).'"';
    	}
    }
    // Set info that we need a response
    $command.=' responseId="'.($commandId=cfGenerateID(6)).'"';

    // Persistent connection communication
	while (cfMIssetVar('UICommandReading')) usleep(10);
	cfMSetVar('UICommandWriting',1);
	cfMSetVar('UICommand',cfMGetVar('UICommand').'<UICommand>'.$command.'</UICommand>');
	cfMUnsetVar('UICommandWriting');

	// Wait for response (that will be sent back to server through serverManagement.php?commandResponse= )
	while (!cfMIssetVar('UICommandResponse'.$commandId)) usleep(1000);
	$response=cfMGetVar('UICommandResponse'.$commandId);
	cfMUnsetVar('UICommandResponse'.$commandId);
	return $response;
}

/**
 * @desc Show a translucid popup on server
 *
 * @param string $title
 * @param string $message1
 * @param string $message2
 * @param string $iconPath
 * @param string $topColor: #RRGGBB or #RGB top color
 * @param string $bottomColor: #RRGGBB or #RGB bottom color
 */
function cfServerShowMessageForm($title,$message1,$message2,$iconPath,$topColor,$bottomColor){
	cfServerSendCmd('messageWindow',array('title'=>$title,'message1'=>$message1,'message2'=>$message2,'iconPath'=>$iconPath,'topColor'=>$topColor,'bottomColor'=>$bottomColor));
}

/**
 * @desc Read a packed item entry
 *
 * @param string $index: utf8 encoded file name
 * @param string $completeFilename: pack file name & path
 * @param bool $memCacheHeader
 * @return string file content
 */
function cfPackedFileRead($index,$completeFilename,$memCacheHeader=false){
	if(!($fp=fopen($completeFilename,'rb'))) return false;

	// Check if header is cached
	if($memCacheHeader && ($header=cfMGetVar('packedFile'.$completeFilename))){
		$headerSize=strlen($header)+9;
		$header=unserialize($header);
	}
	else{
		$header=fread($fp,9);
		if(substr($header,0,5)!='wpack') {fclose($fp); return false;}
		$headerSize=unpack("N",substr($header,5,4));
		$headerSize=$headerSize[1];
		if($headerSize>=filesize($completeFilename)) {fclose($fp); return false;}
		$header=unserialize(fread($fp,$headerSize-9));
		if($memCacheHeader) cfMSetVar('packedFile'.$completeFilename,serialize($header)); // Cache header
	}
	if(!isset($header[$index])) {fclose($fp); return false;}
	@list($pos,$size)=$header[$index];


	if(!$size || $pos+$size>filesize($completeFilename)) {fclose($fp); return false;}
	fseek($fp,$pos+$headerSize,SEEK_SET);
	$content=fread($fp,$size);
	fclose($fp);

	return $content;
}

/**
 * @desc Read a packed file index
 *
 * @param string $completeFilename: pack file name & path
 * @param bool $memCacheHeader
 * @return array index
 */
function cfPackedFileReadIndex($completeFilename,$memCacheHeader=false){
	// Check if header is cached
	if($memCacheHeader && ($header=cfMGetVar('packedFile'.$completeFilename))) $header=unserialize($header);
	else{
		if(!($fp=fopen($completeFilename,'rb'))) return false;
		$header=fread($fp,9);
		if(substr($header,0,5)!='wpack') {fclose($fp); return false;}
		$headerSize=unpack("N",substr($header,5,4));
		$headerSize=$headerSize[1];
		if($headerSize>=filesize($completeFilename)) {fclose($fp); return false;}
		$header=fread($fp,$headerSize-9);
		if($memCacheHeader) cfMSetVar('packedFile'.$completeFilename,$header); // Cache header
		$header=unserialize($header);
		fclose($fp);
	}
	return $header;
}



/**
 * @return void
 * @param bool $closeHEAD inserts </HEAD> tag only if closeHEAD==true (generaly used to add js code)
 * @param array $options:
 * 			'noCommon.js': do not include common.js script,
 * 			'icon','title','size' for UI specific meta properties, 'title' to force title
 * 			'noTheme': just include common.css stylesheet
 * @desc Inserts complete HTML stuff and HEAD of page : doctype, html, head, title, charset, CSS
 *       CSS file name is obtained from user configuration
*/
function cfInsertHEAD($closeHEAD=true,$options=array()){
	if(cfIsAsync()) return;
    @header('P3P: policyref="/w3c/p3p.xml",CP="NON COR CURa OUR NOR NAV"');
    @header('Keep-Alive: timeout=15, max=2000');
    @header('Proxy-Connection: Keep-Alive');
    @header('Cache-Control: no-cache');

    /**
     * HTML Output
     */
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html><head><?php
    if(isset($_SERVER['HTTPS'])) echo '<link rel="shortcut icon" href="gfx/lock.ico"/>';// else echo '<link rel="shortcut icon" href="/favicon.ico">';

    // Charset
    echo '<meta http-equiv="content-type" content="text/html; charset=utf-8">'."\n";

    // Windows skin
    if(cfIsInApp() && WEnv::host()->isWindows()) echo '<meta http-equiv="MSThemeCompatible" CONTENT="Yes">'."\n";

    // UI meta
    $uiMeta=array('icon'=>1,'title'=>1,'size'=>1,'closable'=>1,'sizable'=>1);
    foreach ($options as $k=>$v)if(isset($uiMeta[$k])) cfUIMeta($k,$v);

    // IE9 CSS3 Support
    if(cfGetBrowser()=='ie+') echo '<meta http-equiv="X-UA-Compatible" content="IE=edge" >'."\n";

    // Insert extra meta tags
    if(!@$options['noMeta']){
	    echo cfRGetVar('meta');
	    if(isset($_ENV['meta'])) echo $_ENV['meta'];
	    if(isset($options['meta'])) echo $options['meta'];
    }

    // Title
    if(isset($options['title'])) echo '<title>'.$options['title'].'</title>'."\n";
    elseif(cfIsResource()) echo '<title>'.cfUTF8Encode(cfRGetVar('name')).'</title>'."\n";
    else echo '<title>'.cfUTF8Encode(cfGGetVar('pageTitle')).'</title>'."\n";

    // Theme
    $theme=cfAppThemeDir(true);
    if(isset($options['noTheme'])) $theme='';

    // Use Content Delivery Network (RUF)
    if(cfCDNPrefix())
        echo '<link id="cssLink" rel="stylesheet" type="text/css" href="'.cfCDNPrefix().'/themes/'.basename($theme)."-theme.css\" />\n";
    // Direct files access
    else
        echo '<link id="cssLink" rel="stylesheet" type="text/css" href="/themes/common.css?v='.WHostInfo::appVersion().'&amp;theme='.str_replace('/','%2F',$theme)."\" />\n";

    // Javascript vars
	?><script type="text/javascript"><?php
    echo 'var phpBrowser="'.cfGetBrowser().'"';
    echo ',bBrowser="'.cfBGetVar('name').'"';
    echo ',appType="'.cfGGetVar('appType').'"';
    echo ',isMobile='.(int)cfIsMobile();
    echo ',appVersion="'.WHostInfo::appVersion().'"';
    echo ',userLogged='.((@$_SESSION['userLogged'])?1:0);
    echo ',clientCapSet='.((is_array(cfBGetVar('clientCapabilities')))?1:0); // Set if client capabilties have been set through a client-side request since connection (flash / html5 support...)
    echo ',winFrames='.((cfTGetVar('frames'))?'1':'0');
    echo ',pingInterval='.(max(cfGGetVar('clientPingInterval'),cfBGetVar('clientPingInterval'),1)*1000);
    echo ',PHP_SELF="'.$_SERVER['PHP_SELF'].'"';
    echo ',rID="'.cfRGetVar('id').'"';
    echo ',wSession_id="'.wSession_id().'"';
    echo ',isApp='.((cfIsInApp())?'1':'0');
    if(cfIsInApp()) echo ',WSESSID="'.wSession_id().'"'; // In app page: as IE cookies may be disabled, insert session id in js so it can be sent in sync/async requests
    echo ',simpleMode='.((cfSimpleMode())?'1':'0');
    echo ',noPopup='.((cfHGetVar('noPopup'))?'1':'0');
    echo ',imgFadeSteps='.(int)(cfBGetVar('imgFadeSteps'));
    echo ',dragNLaunchThreshold='.((cfGGetVar('dragNLaunchThreshold')!==false)?cfGGetVar('dragNLaunchThreshold'):'100');
    echo ',dragNLaunchFriction='.((cfGGetVar('dragNLaunchFriction')!==false)?cfGGetVar('dragNLaunchFriction'):'0.005');
    echo ',loadingIconURL="/gfx/loading.gif";';
    if(cfGGetVar('PHPDebug')) echo "var PHPDebug=1;\n";

    // insert javascript resource id (used by async requests)
    if(substr($_SERVER['PHP_SELF'],0,5)=='/res/' && isset($_SESSION['activeResourceId'])) echo 'var resId="'.$_SESSION['activeResourceId']."\";\n";
    echo "noAsyncJSError=0;\n";

    // Post data used for window reload
    if(count($_POST)) {
        echo 'var reloadPostData="';
        $i=0;foreach ($_POST as $k=>$v) echo (($i++)?'&':'').$k.'='.base64_encode($v);
        echo "\";\n";
    }

    if(cfIsInApp()){
        //echo 'var W=window;document.onmousemove=function(event){return (W.event && W.event.srcElement && (W.event.srcElement.tagName=="INPUT"||W.event.srcElement.tagName=="TEXTAREA"));}'."\n";
        echo 'var W=window;document.onselectstart=function(event){var s;return (W.event && (s=W.event.srcElement) && (s.tagName=="INPUT"||s.tagName=="TEXTAREA"||$(s).e.parentHasAttribute("uiSelectable")));}'."\n";
        if(!cfGGetVar('UIDebug')) echo 'function onrightclick(e){return (W.event && W.event.srcElement && (W.event.srcElement.tagName=="INPUT"||W.event.srcElement.tagName=="TEXTAREA"));}'."\n";
    }
    ?></script><?php

    // Common js functions
    if(!isset($options['noCommon.js'])) echo cfScriptLink('common.js');
    // JS debug functions
    if(cfGGetVar('jsDebug')) echo cfScriptLink('debug.js');

    // Insert theme specific stuff
    if(cfTGetVar('extraHeader') && !isset($options['noExtraHeader'])) echo cfTGetVar('extraHeader');

    // Insert window client scripts
    if(substr($_SERVER['PHP_SELF'],0,5)=='/res/') {
        echo cfScriptLink('winClient.js');
        // Set resource to ping server if frameless theme or published resource (if standalone, set bar hidden)
        if((!cfTGetVar('frames') && !isset($_ENV['winNoBar']) &&!isset($options['winNoBar']) && !cfIsInApp()) || cfUGetVar('id')=='standalone') {
            echo '<script type="text/javascript">if(winMe&&winMe.setBar) winMe.setBar("'.addcslashes(cfUTF8Encode(cfRGetVar('name')),'"\\').'","'.cfUTF8Encode(cfRGetVar('resourceIcon')).'","'.((isset($_ENV['winCloseURL']))?$_ENV['winCloseURL']:'/index.php').'",'.((int)(cfUGetVar('id')=='standalone')).');';
            echo 'var pingInt = setInterval("ping()",pingInterval)';
            echo "</script>\n";
        }
    }

    // Close head
    if ($closeHEAD) echo "</head>\n";

    if(isset($_ENV['debugTagsStack'])) echo $_ENV['debugTagsStack'];

    // Send to browser
    flush();
}

/**
 * @return void
 * @param bool $closeHEAD inserts </HEAD> tag only if closeHEAD==true (generaly used to add js code)
 * @desc Inserts Minimal HTML stuff and HEAD of page : doctype, html, head, title, charset
*/
function cfInsertHEADBasic($closeHEAD=true, $isFrameset=false){
    @header('P3P: policyref="/w3c/p3p.xml",CP="NON COR CURa OUR NOR NAV"');
    @header('Connection: Keep-Alive');
    @header('Keep-Alive: timeout=15, max=2000');
    @header('Proxy-Connection: Keep-Alive');

    echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 '.(($isFrameset)?'Frameset':'Transitional').'//EN">'."\n";
    echo '<HTML><HEAD>'."\n";
    echo '<meta http-equiv="content-type" content="text/html; charset=utf-8">'."\n";
    echo '<TITLE>'.cfGGetVar('pageTitle').'</TITLE>'."\n";
    // Scripts
    echo "<script type=\"text/javascript\" language=\"javascript\">\n";
    echo "var W=window, D=document;function dgi(oid){return document.getElementById(oid);}\n";
    // Insert javascript resource id (used by async requests)
    if(substr($_SERVER['PHP_SELF'],0,5)=='/res/') if(isset($_SESSION['activeResourceId'])) echo 'var resId="'.$_SESSION['activeResourceId']."\";";
    echo "</script>\n";

    if ($closeHEAD) echo "</HEAD>\n";
}

/**
 * @desc Insert meta tag for application UI
 *
 * @param string $property: "size", "icon", "title"
 * @param string $value: (size: widthxheight, icon: png file name without extension & path (/www/gfx)
 * @param bool $return: set to true to return result instead of echoing it
 */
function cfUIMeta($property,$value,$return=false){
	$m='<meta name="X-UI-'.$property.'" content="'.$value."\"></meta>\n";
	if($return) return $m;
	echo $m;
}

/**
 * @desc Return body attributes required to cancel right-click menu except if in debug mode
 *
 * @return string
 */
function cfBodyRightClick(){
	if(!cfGGetVar('JSDebug')) return ' oncontextmenu="return false"';
}

/**
 * @desc swap values of paramters
 *
 * @param mixed $a
 * @param mixed $b
 */
function cfSwap(&$a,&$b){$c=$a;$a=$b;$b=$c;unset($c);}

/**
 * @desc Check if $a & $b are set, and if $a=$b. Must be used with @
 *
 * @param mixed $a
 * @param mixed $b
 * @return boolean
 */
function cfIsEq($a,$b){
    if(!isset($a)||!isset($b)) return false;
    return $a===$b;
}

/**
 * @desc Return item of an array. used to retreive unique item of a function returning an array, without setting temporary var
 *
 * @param array $f
 * @param string $key
 * @param string $key2
 * @return mixed
 */
function cfArrayItem($f,$key,$key2=null){
    if($key2) return @$f[$key][$key2];
    return @$f[$key];
}

/**
 * @desc Explodes a 2 level string into a 2 dimensional array
 *         Ex: "a=b,c=d" returns array('a'=>'b','c'=>'d');
 *
 * @param string $sepMain: 1st separator (, in sample)
 * @param string $sep: 2nd separator (= in sample)
 * @param string $str: string to explode
 * @param bool $trim: true to trim items
 * @return array
 */
function cfExplode2Levels($sepMain,$sep,$str,$trim=1){
    $r=array();
    foreach (@explode($sepMain,$str) as $v){
        if($trim) $v=trim($v);
        if($pos=@strpos($v,$sep)){
            $k=substr($v,0,$pos); if($trim) $k=trim($k);
            $v=substr($v,$pos+1); if($trim) $v=trim($v);
            $r[$k]=$v;
        }
        else $r[$v]=false;
    }
    return $r;
}

/**
 * @desc Compare left-side of strings
 *
 * @param string $str
 * @param string $needle
 * @return boolean
 */
function cfCmpLeft($str, $needle, $caseSensitive=true){
	if($caseSensitive) return substr($str,0,strlen($needle))===$needle;
	return substr(strtolower($str),0,strlen($needle))===strtolower($needle);
}

/**
 * @desc Compare right-side of strings
 *
 * @param string $str
 * @param string $needle
 * @return boolean
 */
function cfCmpRight($str, $needle){return substr($str,-strlen($needle))===$needle;}

/**
 * @desc Shorten string
 *
 * @param string $str
 * @param int $len: nb chars
 */
function cfStrShorten($str, $len){return substr($str,0,strlen($str)-$len);}

/**
 * @Analyze txt and return line break/carriage return patern
 *
 * @param string $txt
 * @return string "\n", "\r", "\n\r", "\r\n"
 */
function cfStrLBPattern(&$txt){
    if(($r=strpos($txt,"\r"))===false) return "\n";
    if(($n=strpos($txt,"\n"))===false) return "\r";
    return ($r<$n)?"\r\n":"\n\r";
}

/**
 * @desc Return an array of lines from raw text
 *
 * @param string $txt
 * @return array
 */
function cfLinesFromText($txt){return preg_split("/(\r\n|\n|\r)/", $txt);}

/**
 * @desc unpack replacement for single response
 *
 * @param char $a
 * @param mixed $b
 * @return mixed
 */
function cfUnpack($a,$b){$u=unpack($a,$b);return $u[1];}

/**
 * @desc Plug-and-Play fastimagecopyresampled function replaces much slower imagecopyresampled
 *
 * @author: Tim Eckel - Date: 12/17/04 - Project: FreeRingers.net - Freely distributable.
 */
function fastimagecopyresampled(&$dst_image, $src_image, $dst_x, $dst_y, $src_x, $src_y, $dst_w, $dst_h, $src_w, $src_h, $quality = 3) {
  //
  // Optional "quality" parameter (defaults is 3).  Fractional values are allowed, for example 1.5.
  // 1 = Up to 600 times faster.  Poor results, just uses imagecopyresized but removes black edges.
  // 2 = Up to 95 times faster.  Images may appear too sharp, some people may prefer it.
  // 3 = Up to 60 times faster.  Will give high quality smooth results very close to imagecopyresampled.
  // 4 = Up to 25 times faster.  Almost identical to imagecopyresampled for most images.
  // 5 = No speedup.  Just uses imagecopyresampled, highest quality but no advantage over imagecopyresampled.

	if (empty($src_image) || empty($dst_image)) return false;
	if ($quality <= 1) {
		$temp = imagecreatetruecolor ($dst_w + 1, $dst_h + 1);
		imagecopyresized ($temp, $src_image, $dst_x, $dst_y, $src_x, $src_y, $dst_w + 1, $dst_h + 1, $src_w, $src_h);
		imagecopyresized ($dst_image, $temp, 0, 0, 0, 0, $dst_w, $dst_h, $dst_w, $dst_h);
		imagedestroy ($temp);
	}
	elseif ($quality < 5 && (($dst_w * $quality) < $src_w || ($dst_h * $quality) < $src_h)) {
		$tmp_w = $dst_w * $quality;
		$tmp_h = $dst_h * $quality;
		$temp = imagecreatetruecolor ($tmp_w + 1, $tmp_h + 1);
		imagecopyresized ($temp, $src_image, $dst_x * $quality, $dst_y * $quality, $src_x, $src_y, $tmp_w + 1, $tmp_h + 1, $src_w, $src_h);
		imagecopyresampled ($dst_image, $temp, 0, 0, 0, 0, $dst_w, $dst_h, $tmp_w, $tmp_h);
		imagedestroy ($temp);
	} else {
		imagecopyresampled ($dst_image, $src_image, $dst_x, $dst_y, $src_x, $src_y, $dst_w, $dst_h, $src_w, $src_h);
	}
	return true;
}

/**
 * @desc Wrapper for createJPG exe
 *
 * @param string $sourceFile: source image
 * @param string $destFile: destination file
 * @param integer $destMaxWidth
 * @param integer $destMaxHeight
 * @param integer$jpgQuality: 0 for default value
 */
function cfCreateJPG($sourceFile,$destFile,$destMaxWidth, $destMaxHeight,$jpgQuality=false,$resampleQuality=false,$square=false){
	// Round width & height values as createJPG fails on non-integers
    $destMaxWidth=round($destMaxWidth); $destMaxHeight=round($destMaxHeight);

    // Resize image using GDI or Qt, and if GDI method fails, use createJPG
	if(!@customResizeJPG($sourceFile,$destFile,$destMaxWidth,$destMaxHeight,$jpgQuality,$resampleQuality,(int)$square)){
	/*
	'CreateJPG Command line arguments :
	'1: images path (if .jpg, process single image)
	'2: thumbnail(s) path (if source is .jpg, filename of output) or "check" to see if a thumbnail can be generated
	'3: max width
	'4: max height
	'5: filter ("images" for imgas only or "all" to try to generate thumbnails from all files or "check" to see if a thumbnail can be generated) (default: images)
	'6: extra processing : "crop" (for crop with external zoom factor), "square" (for 1/1 crop) or "no" to preserve input ratio
	'7: enlarge ratio for cropped thumbnails
	'8: jpg quality (0-100)
	 *
	 */
        cfExecNoFork(cfAppBinDir().'\createJPG.exe','SW_HIDE','"'.$sourceFile.'" "'.$destFile.'" '.$destMaxWidth.' '.$destMaxHeight.' images '.(($square)?'crop':'no').' 1'.(($jpgQuality)?$jpgQuality:cfHGetVar('thumbnailJPGQuality',DEFAULT_JPG_QUALITY)));
    }
}

/**
 * @return boolean : result of operation, or jpg file if $destFile=='return'
 * @param string $sourceFile : source filename
 * @param int $sourceWidth (optional) : width of source image (if not present, this value is obtained from source file), in px
 * @param int $sourceHeight (optional) : height of source image (if not present, this value is obtained from source file), in px
 * @param string $destFile (optional) : created image filename.
 *                 If not given send image to Apache output. If given and extension!=".jpg" && !=".jpeg", add ".jpg"
 *                 if "return", return as function result
 * @param int $destMaxWidth (optional) : max width of created image in px. If not given, don't resize the image
 * @param int $destMaxHeight (optional) : max height of created image in px. If not given, don't resize the image
 * @param int $resampleQuality (optional) : 1 (fast, bad quality) to 5 (slow, good quality)
 * @param int $JPGQuality (optional) : jpg quality (1-100)
 * @param int $angle (optional) : image rotation angle
 * @param bool $square (optional) : create a square image by croping source
 * @param int $stretchSmallImages (optional) : stretch images if smaller than $destMaxWidth && $destMaxHeight
 * @desc creates a jpg resized (or not) image, send it to file or to browser output
*/
function cfCreateResizedJPG($sourceFile, $sourceWidth=0, $sourceHeight=0, $destFile='', $destMaxWidth=0, $destMaxHeight=0, $resampleQuality=false, $JPGQuality=false, $angle=0, $square=false, $stretchSmallImages=true){
    if(!file_exists($sourceFile)) return false;

    $result=true;
    $ext=cfFileExtension($sourceFile);

    // default resize method: 1 (worst,fastest) - 5 (better, slowest)
    if($resampleQuality===false || !is_numeric($resampleQuality)) {
        $resampleQuality=cfHGetVar('imageResampleQuality',DEFAULT_RESIZE_METHOD);
        $resampleQuality=((cfRGetVar('imageResampleQuality'))?cfRGetVar('imageResampleQuality'):((cfGGetVar('imageResampleQuality'))?cfGGetVar('imageResampleQuality'):DEFAULT_RESIZE_METHOD));
    }

    // Default output jpg quality (0-100)
    if($JPGQuality===false || !is_numeric($JPGQuality)){
        $JPGQuality=cfHGetVar('thumbnailJPGQuality',DEFAULT_JPG_QUALITY);
    }
    if($destFile!='' && $destFile!='return'){
        if (strtolower(substr(strrchr($destFile,"."),1))!="jpg" && strtolower(substr(strrchr($destFile,"."),1))!="jpeg") $destFile=$destFile.".jpg";
        if (!is_dir(dirname($destFile))) return false;
    }

    // Get source width & height
    if($sourceWidth==0 || $sourceHeight==0) {
        if($ext=='itc' || $ext=='itc2'){
        	// itc2 format (which has a itc file extension under osx)
            if($ext=='itc2' || WEnv::host()->isOSX()){
	            if(!($sourceImage=@imagecreatefromstring(substr(file_get_contents($sourceFile),492)))) return false;
	            $sourceWidth=imagesx($sourceImage); $sourceHeight=imagesy($sourceImage);
            }
        	else{
	        	if(!($sourceImage=imagecreatefromstring(substr(file_get_contents($sourceFile),500)))) return false;
	            $sourceWidth=imagesx($sourceImage); $sourceHeight=imagesy($sourceImage);
        	}
        }
        else list($sourceWidth, $sourceHeight, $type, $attr) = @getimagesize($sourceFile);
    }
    if($angle!=0 && $angle!=180) cfSwap($sourceWidth,$sourceHeight);

    if($destMaxWidth && !$destMaxHeight) $destMaxHeight=3*$destMaxWidth/4;
    if(!$destMaxWidth && $destMaxHeight) $destMaxWidth=4*$destMaxHeight/2;

    // If no resize or processing needed, directly send to output / return
    if(((!$destFile||$destFile=='return') && !$angle) && (!$destMaxHeight || !$destMaxWidth || ($destMaxWidth==$sourceWidth && $destMaxHeight==$sourceHeight) || ($sourceWidth < $destMaxWidth && $sourceHeight < $destMaxHeight && !$stretchSmallImages))){
        cfLog('send unresized image to output '.$sourceFile, LOG_DBG);
        if($ext=='itc'){
            if($destFile=='return') return substr(file_get_contents($sourceFile),500);
            header("Content-type: image/png");
            echo substr(file_get_contents($sourceFile),500);
        }
        elseif($ext=='itc2'){
            if($destFile=='return') return substr(file_get_contents($sourceFile),492);
            header("Content-type: image/png");
            echo substr(file_get_contents($sourceFile),492);
        }
        else{
            if($destFile=='return') return @readfile($sourceFile);
            header("Content-type: ".mime_content_type($sourceFile)); //XXXX
            @readfile($sourceFile);
        }
        if(isset($sourceImage)) imagedestroy($sourceImage);
        return true;
    }

    // Alternate method: use createJPG to resize images
    if(($ext=='jpg'||$ext=='bmp'||$ext=='gif'||$ext=='png') && $angle==0 && $destMaxWidth>0 && $destMaxHeight>0){
        if(!$destFile || $destFile=='return'){
            $tmpFile=cfAppTempDir().'/tmp_'.rand().'.jpg';
            cfCreateJPG($sourceFile,$tmpFile,$destMaxWidth,$destMaxHeight,$JPGQuality,$resampleQuality,$square);
            if(!$destFile) {echo file_get_contents($tmpFile); $result=true;}
            else $result=file_get_contents($tmpFile);
            @unlink($tmpFile);
            return $result;
        }
        else{
            cfCreateJPG($sourceFile,$destFile,$destMaxWidth,$destMaxHeight,$JPGQuality,$resampleQuality,$square);
            return true;
        }
    }

    // if destMaxWidth && destMaxHeight are provided or if rotation or if write to file, process image
    switch($ext) {
        case 'jpg':
        case 'jpeg':
            if(!($sourceImage=@imagecreatefromjpeg($sourceFile))) return false;
        break;
        case 'gif':
            if(!($sourceImage=@imagecreatefromgif($sourceFile))) return false;
        break;
        case 'wbmp':
            if(!($sourceImage=@imagecreatefromwbmp($sourceFile)) || !(imagetypes() & IMG_WBMP)) return false;
        break;
        case 'bmp':
        require_once(INCLUDE_DIR.'bmp.php');
            if(!($sourceImage=@imagecreatefrombmp($sourceFile))) return false;
        break;
        case 'png':
            if(!($sourceImage=@imagecreatefrompng($sourceFile)) || !(imagetypes() & IMG_PNG)) return false;
        case 'itc':
        case 'itc2':
        break;
        default:
        return false; // unsupported image format
    }

    // rotate source image if needed
    if($angle) $sourceImage=imagerotate($sourceImage,-$angle,0);

    // if destMaxWidth && destMaxHeight are provided, resize
    if($destMaxWidth>0 && $destMaxHeight>0){
        if(false && $destMaxWidth>=$sourceWidth && $destMaxHeight>=$sourceHeight) // Don't resize small images
            {$width=$sourceWidth; $height=$sourceHeight;}
        else{
            if($square) {$height=$width=$destMaxWidth;}
            elseif(($destMaxWidth/$destMaxHeight)>($sourceWidth/$sourceHeight)) {$width=$sourceWidth*$destMaxHeight/$sourceHeight; $height=$destMaxHeight;}
            else {$width=$destMaxWidth; $height=$sourceHeight*$destMaxWidth/$sourceWidth;}
        }

        // Create destination image
        $destImage = imagecreatetruecolor($width,$height);

        // If image must be squared
        $srcX=$srcY=0;
        if($square){
            if($sourceWidth>$sourceHeight) $srcX=($sourceWidth-$sourceHeight)/2; else $srcY=($sourceHeight-$sourceWidth)/2;
        }

        // Resize / resample
        if($resampleQuality>1) fastimagecopyresampled($destImage, $sourceImage, 0, 0, $srcX, $srcY, $width, $height, $sourceWidth-2*$srcX, $sourceHeight-2*$srcY,$resampleQuality);
        else imagecopyresized($destImage, $sourceImage, 0, 0, $srcX, $srcY, $width, $height, $sourceWidth-2*$srcX, $sourceHeight-2*$srcY);
        imagedestroy($sourceImage);

        // directly send to output
        if($destFile=='') {
            cfLog('send resized image to output '.$sourceFile, LOG_DBG);
            header("Content-type: image/jpeg");
            imagejpeg($destImage,null,$JPGQuality);
        }
        // Return image as function return
        elseif ($destFile=='return'){
            // Activate outupt buffering
            ob_start(); if(ob_get_length())    $tmp=ob_get_clean(); else $tmp=false;
            // Output image
            imagejpeg($destImage,null,$JPGQuality);
            // Get image from buffer
            $result=@ob_get_clean(); if($tmp) echo $tmp;
        }
        // send to file
        else imagejpeg($destImage,$destFile,$JPGQuality);

        imagedestroy($destImage);
    }
    //no resize
    else{
        cfLog('write unresized image to file '.$destFile, LOG_DBG);

        // Return image
        if($destFile=='return'){
            // Activate outupt buffering
            ob_start(); if(ob_get_length()) $tmp=ob_get_clean(); else $tmp=false;
            // Output image
            imagejpeg($sourceImage,null,$JPGQuality);
            // Get image from buffer
            $result=@ob_get_clean(); if($tmp) echo $tmp;
        }
        // directly send to output
        elseif($destFile=='') {
            cfLog('send resized image to output '.$sourceFile, LOG_DBG);
            header("Content-type: image/jpeg");
            imagejpeg($sourceImage,null,$JPGQuality);
        }
        // send to file
        else
            imagejpeg($sourceImage,$destFile,$JPGQuality);

        imagedestroy($sourceImage);
    }

    return $result;
}


/**
 * @desc Return dimensions of size constrained thumbnail
 *
 * @param int $sourceWidth
 * @param int $sourceHeight
 * @param int $destMaxWidth
 * @param int $destMaxHeight
 * @param bool $stretch
 * @return array(width, height)
 */
function cfThumbnailDimensions($sourceWidth,$sourceHeight,$destMaxWidth,$destMaxHeight=0,$stretch=false){
    if($sourceHeight*$sourceWidth==0) return array(0,0);
    if($destMaxHeight==0) $destMaxHeight=999999;

    if(($destMaxWidth/$destMaxHeight)>($sourceWidth/$sourceHeight)) {$width=$sourceWidth*$destMaxHeight/$sourceHeight; $height=$destMaxHeight;}
    else {$width=$destMaxWidth; $height=$sourceHeight*$destMaxWidth/$sourceWidth;}
    if((!$stretch)&&$width>$sourceWidth) return array($sourceWidth,$sourceHeight);
    return array(floor($width),floor($height));
}

/**
 * @desc return protocol://host:port of server
 *
 * @return string
 */
function cfHostName(){
    if(cfGGetVar('hostName')) return cfGGetVar('hostName');
    $host=(isset($_SERVER['HTTP_HOST']) && !cfIsOnLAN($_SERVER['HTTP_HOST']))?$_SERVER['HTTP_HOST']:$_SERVER['SERVER_NAME'];
    // If port is not already included in host name, add it
    if(!strpos($host,':')){
    	$port=$_SERVER['SERVER_PORT'];
    	if((isset($_SERVER['HTTPS']) && $port==443) || (!isset($_SERVER['HTTPS']) && $port==80)) $port=''; else $port=':'.$port;
    	$host.=$port;
    }
    return ((isset($_SERVER['HTTPS']))?'https':'http').'://'.$host;
}

/**
 * @desc return protocol://host:port of localhost, false if called from CLI
 *
 * @return string
 */
function cfLocalhostName($noSSL=false){
	if(cfGGetVar('protocol')=='https' && $noSSL) return 'http://127.0.0.1:'.cfGGetVar('alternatePortNoSSL');
	return cfGGetVar('protocol').'://127.0.0.1'.((cfGGetVar('serverPort')==80||cfGGetVar('serverPort')==443)?'':':'.cfGGetVar('serverPort'));
}

/**
 * @desc return protocol://IP:port of server, where IP is external IP (initialized by setExternalIP in serverManagement.php, by UI
 *
 * @return string
 */
function cfExternalHostName(){
    return cfGGetVar('protocol').'://'.cfGGetVar('externalIP').((cfGGetVar('serverPort')==80||cfGGetVar('serverPort')==443)?'':':'.cfGGetVar('serverPort')).'/';
}

/**
 * @desc Return site's public URL (http://weezo.net/account_name or IP address if not registered)
 *
 * @return string
 */
function cfPublicURL(){
	if($reg=cfRegistrationData()) return cfSiteLink($reg['regName']);
	elseif (cfGGetVar('externalIP')) {
		$port=cfGGetVar('serverPort');
		return (($port==443)?'https':'http').'://'.cfGGetVar('externalIP').(($port!=80 && $port!=443)?':'.$port:'');
	}
}

function cfSiteLink($userName=false,$includeSlashOrQuestionMark=false){
	if(!$userName){
		$reg=cfRegistrationData();
		$userName=@$reg['regName'];
	}
	$c='';
	if($includeSlashOrQuestionMark) $c=(cfGGetVar('preferedUrlFormat')=='host')?'/':'?';

	if(cfGGetVar('preferedUrlFormat')=='host') return 'http://'.$userName.'.weezo.me'.$c;
	return DNS_SITE.'/'.$userName.$c;
}

/**
 * @desc reture true if given IP matches with LAN mask (also works for 'localhost')
 *
 * @param string $ip
 * @return bool
 */
function cfIsOnLAN($ip=0){
    if(!$ip) $ip=$_SERVER['REMOTE_ADDR'];
    if($ip=='localhost') return true; // prod
    $ip_long=ip2long($ip);
    foreach (cfExplode2Levels(' ','/',cfGGetVar('httpdLANFilter')) as $net=>$mask){
        $net=ip2long($net);
        $mask=ip2long($mask);
        if (($ip_long & $mask) == $net) return true;
    }
    return $ip==='127.0.0.1';
}

/**
 * @desc : check if is IP adress
 *
 * @param string $address : adress to check
 * @return boolean : result
 */
function cfIsIP($address){
    return (@ereg('^((([*]|25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]{1}[0-9]|[1-9]).){1}(([*]|25[0-5]|2[0-4][0-9]|[1]{1}[0-9]{2}|[1-9]{1}[0-9]|[0-9]).){2}(([*]|25[0-5]|2[0-4][0-9]|[1]{1}[0-9]{2}|[1-9]{1}[0-9]|[0-9]){1}))$',$address));
}

/**
 * @desc Add an IP to banned IPs list
 *
 * @param string $ip
 */
function cfIPBan($ip){
	// Don't ban localhost
	if($ip==='127.0.0.1' || !cfIsIP($ip)) return;

	// Add this IP to connectionAttempts.txt file, with a 0 before, indicating this is a forever-ban
	if($fp=fopen(cfAppDataDir().'/connectionAttempts.txt','a')){
		fwrite($fp,'0='.$ip."\n");
		fclose($fp);
	}
}

/**
 * @desc Return true if ip matches with an official weezo server
 *
 * @param string $ip: IP address, leave empty to use remote_addr
 * @return bool
 */
function cfIsWeezoServer($ip=false){
	if(!$ip) $ip=$_SERVER['REMOTE_ADDR'];
	if($ip=='87.106.108.74') return true;
	foreach ($_ENV['W_ALT_HOSTS'] as $hostName) if($ip==cfGethostbyname($hostName)) return true;
	return false;
}

/**
 * @desc check if user's IP is within exessive connections attempts list, stored in data/connectionAttempts.txt file
 * 		 update $nbWrongPasswordTyped global var
 * @return boolean : true if IP has typed more than passwordCheckMaxAttempts wrong passwords in passwordCheckBanPeriod minutes IPs list,
 * 		 false if not
 *
 */
function cfIPBanned($checkedIP=false){
	global $nbWrongPasswordTyped;
	static $passwordCheckMaxAttempts;

	if(!isset($passwordCheckMaxAttempts)) {
		$passwordCheckMaxAttempts=cfGGetVar('passwordCheckMaxAttempts');
		$passwordCheckBanPeriod=cfGGetVar('passwordCheckBanPeriod');
	}

	if(!cfGGetVar('passwordCheckMaxAttempts') || !file_exists(cfAppDataDir().'/connectionAttempts.txt')) return false;

	if(!$checkedIP) $checkedIP=$_SERVER['REMOTE_ADDR'];

	$needSave=false; $nbWrongPasswordTyped=0;

	// Browse history
	$ipList=cfParse_ini_file(cfAppDataDir().'/connectionAttempts.txt',false);
	foreach ($ipList as $time=>$ip){
		// Clean old entries{
		if($time!==0 && floor($time)+CONNECTION_ATTEMPTS_CLEANUP_TIME*3600*24<time()) {
			unset($ipList[$time]);
			$needSave=true;
		}

		// Count appliable entries
		if($passwordCheckMaxAttempts>0 && $ip==$checkedIP && (floor($time)+$passwordCheckBanPeriod*60>time())) $nbWrongPasswordTyped++;

		// Definitively banned IPs
		if($ip==$checkedIP && $time==0) $nbWrongPasswordTyped+=999999999;

		// Reset counter on successfull password typed
		if($ip=='OK'.$checkedIP) $nbWrongPasswordTyped=0;
	}
	// Save changes if cleaned items
	if($needSave) cfWriteIniFile($ipList,cfAppDataDir().'/connectionAttempts.txt',false);
	if($nbWrongPasswordTyped>=cfGGetVar('passwordCheckMaxAttempts')) return true;
	return false;
}

/**
 * @desc generate "encoded" URL to a file out of document root, using /ext/download.php
 * @return void
 * @param string $urlEncodedfileName
 * @param array $complement : extra information included in URL, to be used by ext/download.php:
 *             key values: q
 *             reencoded bitrate: q[quality]size[width]x[height]offset[offset]source
 *             still image (screenshot): image/w[width]/x[height]/
 * @param string $addressMode : $addressMode == "relative" : generate adress without host name,
                     $addressMode == "absolute" : generate adress with host name (used for files accessed by external programs (winamp, media player...))
 * @param string $preUTF8Encode :
*/
function cfExtDownload($completeFilename, $addressMode="relative"){
    $sep='.';
    if(substr($completeFilename,0,14)=='*resSpecific*/'){}
    else $completeFilename=rawurlencode(cfResourceRelativePath($completeFilename));

    // Generate tokenId
    $tokenId=''; for($i=0;$i<strlen($completeFilename);$i++) $tokenId.=ord($completeFilename[$i]);
    // Protect filename (apache rewrite URL regular expression used doesn't work with %2F...
    $completeFilename=str_replace('%2F','/',$completeFilename);
    // Base URI
    $uri='/dl/dlToken'.$tokenId.'/resId'.$_SESSION['activeResourceId'].'/';

    // Add filename
    $uri.=$completeFilename;

    if($addressMode=='relative') return $uri;
    if($addressMode=='absolute') return cfHostName().$uri;
}

/**
 * @desc generate "encoded" URL to a video file out of document root, using /ext/video.php
 * @return void
 * @param string $urlEncodedfileName
 * @param array $complement : extra information included in URL, to be used by ext/video.php:
 *             key values: q=>source, high, medium, low,
 *                         h=>height, w=>width,
 *                         image=>1 (if still image),
 *                         offset=>nbSeconds,
 *                         format=>wmv,flashFlv,flashF4f,webm,ogv,m3u8
 * 								(iPod, m3u8 file for given bitrate)/m3u8sa (iPod, m3u8 file pointing to bitrate-specific m3u8 files), ts (ipod streaming format (transport stream))
 *                         debug=>1
 * @param string $addressMode : $addressMode == "relative" : generate adress without host name,
                     $addressMode == "absolute" : generate adress with host name (used for files accessed by external programs (winamp, media player..., which don't have session cookie))
 * @param string $preUTF8Encode : true to utf8 encode complete filename, b64 to base64 encode, false not to encode
*/
function cfExtVideo($completeFilename, $complement=array(), $addressMode="relative", $preUTF8Encode=true){
    $sep='.';

    if(!is_array($complement)) $complement=array();
    // replace # by *weezoSharp* (Media player problem with # symbol...)
    $completeFilename=str_replace('#', '*weezoSharp*',$completeFilename);
    // Special: if complete file name should be handled by resource (iTunes file ID), keep it unchanged
    if(substr($completeFilename,0,14)=='*resSpecific*/'){}
    // Special: if complete file name should be handled by resource (webcam), keep it unchanged
    elseif(substr($completeFilename,0,7)=='webcam:'){}
    // Special: if complete file name is music resource internal playlist (*playlist*.m3u[.xml]) or a numeric index (webTV2), keep it unchanged
    elseif($completeFilename=='*playlist*.m3u' || $completeFilename=='*playlist*.m3u.xml' || $completeFilename=='*singleMP3*.m3u' || $completeFilename=='*singleMP3*.m3u.xml' || $completeFilename=='*singleVideo*.xml' || is_numeric($completeFilename)) {
        // Opera cache problem workaround
        $complement+=array("rnd"=>str_pad(rand(),7,'X'));
    }
    // If filename is an external stream
    elseif(strpos($completeFilename,'://')){
    	if($preUTF8Encode==='b64') $completeFilename=cfBase64_url_encode($completeFilename);
        elseif($preUTF8Encode) $completeFilename=rawurlencode(cfUTF8Encode($completeFilename));
        else $completeFilename=rawurlencode($completeFilename);
    }
    // File located into resource data directory
    elseif(cfIsSubDir(cfAppResourceDir(),$completeFilename) && cfRGetVar('resourceDataDirAccessAllowed')){
        $completeFilename=rawurlencode(cfUTF8Encode(cfResourceDataDirRelativePath($completeFilename)));
    }
    // File located into resource files directory
    else {
        if($preUTF8Encode==='b64') $completeFilename=cfBase64_url_encode(cfResourceRelativePath($completeFilename));
        elseif($preUTF8Encode) $completeFilename=rawurlencode(cfUTF8Encode(cfResourceRelativePath($completeFilename)));
        else $completeFilename=rawurlencode(cfResourceRelativePath($completeFilename));
    }
    $completeFilename=str_replace('%2F','/',$completeFilename);

    // Base URI
    $uri='/video/sess'.$sep.'sess_'.wSession_id().'/resId'.$sep.$_SESSION['activeResourceId'].'/';

    // Add extra parameters
    foreach ($complement as $k=>$v) /*if($k!='format')*/ $uri.=$k.$sep.$v.'/';

    // Add filename
    if(isset($complement['wmv'])) $completeFilename.=WMP_MOBILE_VIDEO_EXT;

    $uri.=(($preUTF8Encode==='b64' && $completeFilename[0]!='*')?'b64':'file').$sep.$completeFilename;

    if($addressMode=='relative') return $uri;
    if($addressMode=='absolute') return cfHostName().$uri;
}

/**
 * @desc generate "encoded" URL to an audio file out of document root, using /ext/audio.php
 * @return void
 * @param string $urlEncodedfileName
 * @param string $complement : extra information included in URL, to be used by /ext/audio.php (reencoded bitrate: /audio/original, /audio/64 ...)
 * @param string $addressMode : $addressMode == "relative" : generate adress without host name,
                     $addressMode == "absolute" : generate adress with host name (used for files accessed by external programs (winamp, media player...))
 * @param string $preUTF8Encode: false to leave as is, true to utf8 encode before protecting, b64 to protect with base64 encoding
*/
function cfExtAudio($completeFilename, $complement="", $addressMode="relative", $preUTF8Encode=true){
	$sep='.'; // separator between data name & data value
	$encoding='file'; // Indicate encoding used (file or b64)

    // Special : if complete file name should be handled by resource (iTunes file ID), keep it unchanged
    if(substr($completeFilename,0,14)=='*resSpecific*/'){}
    // Special : if complete file name is music resource internal playlist (*playlist*.m3u[.xml]), keep it unchanged
    elseif($completeFilename=='*playlist*.m3u' || $completeFilename=='*playlist*.m3u.xml' || $completeFilename=='*tmp*playlist*.m3u.xml' || $completeFilename=='*tmp*playlist*.m3u' || $completeFilename=='*singleMP3*.m3u' || $completeFilename=='*singleMP3*.m3u.xml' || $completeFilename=='*singleVideo*.xml') {
        // Opera cache problem workaround
        $completeFilename="rnd".str_pad(rand(),7,'X').$completeFilename;
    }
    // File is located below resource data directory
    elseif(cfIsSubDir(cfAppResourceDir(),$completeFilename) && cfRGetVar('resourceDataDirAccessAllowed')){
    	if($preUTF8Encode==='b64') {
    		$completeFilename=cfBase64_url_encode(cfResourceDataDirRelativePath($completeFilename));
    		$encoding='b64';
    	}
        else $completeFilename=rawurlencode(cfUTF8Encode(cfResourceDataDirRelativePath($completeFilename)));
    }
    // File is located below path
    else {
    	if($preUTF8Encode==='b64') {
    		$completeFilename=cfBase64_url_encode(cfResourceRelativePath($completeFilename));
    		$encoding='b64';
    	}
        elseif($preUTF8Encode) $completeFilename=rawurlencode(cfUTF8Encode(cfResourceRelativePath($completeFilename)));
        else $completeFilename=rawurlencode(cfResourceRelativePath($completeFilename));
    }
    $completeFilename=str_replace('%2F','/',$completeFilename); // Apache mod_rewrite doesn't seems to like %2F

    // Standalone WMP player (mobile), add WMP_MOBILE_AUDIO_EXT extension
    if(cfBGetVar('audioFormat')=='wma' || (cfBGetVar('wmp') && !cfBGetVar('flash'))) $completeFilename.=WMP_MOBILE_AUDIO_EXT;

    // Prepend file or b64 depending on encoding
    $completeFilename=$encoding.$sep.$completeFilename;

    // replace # by *weezoSharp* (Media player problem with # symbol...)
    $completeFilename=str_replace('#', '*weezoSharp*',$completeFilename);

    $rp='/audio/s.sess_'.wSession_id().'/resId.'.$_SESSION['activeResourceId'].'/'.$complement.$completeFilename;

    if($addressMode=='relative') return $rp;
    if($addressMode=='absolute') return cfHostName().$rp;
}

/**
 * @desc return URL of image (out of document root) to use with extImage.php
 * @param string $completeFilename: path & file name of image, enclosed with "
 * @param int $width: max output width - non numeric value can be used for javascript search and replace
 * @param int $height: max output height - non numeric value can be used for javascript search and replace
 * @param boolean $cache: set to true to request caching from browser, false to prevent caching
 * @param integer $rotation: image rotation angle (degrees)
 * @param array $options: extra options array (icon=>1 to extract icon of file,'noDC'=>1 not to get audio cover from dir,'crop'=>1 to crop image to get a square)
 * @param array $rawFilename: set to true not to b64 encode filename (used to generate a javascript modifiable address)
 * @return string: URL
*/
function cfExtImage($completeFilename,$width=false,$height=false, $cache=true, $rotation=0, $options=false, $rawFilename=false){
    $sep='.';

    /**
     * Get image src
     */
    // If image is (generated from) thumbnail
    if(cfIsSubDir(cfAppResourceDir(),$completeFilename)) $completeFilename=cfResourceDataDirRelativePath($completeFilename);
    // Shared files list
    elseif(cfSharedMode('list')) $completeFilename=cfResourceRelativePath($completeFilename);
    // Shared directory ?!?
    elseif (cfRGetVar('path') && cfIsSubDir(cfRGetVar('path'),$completeFilename)) $completeFilename=cfResourceRelativePath($completeFilename);

    $o='/img';
    // Width & height
    $o.='/w'.$sep.((is_numeric($width))?floor($width):$width).'/h'.$sep.((is_numeric($height))?floor($height):$height);
    // Rotation
    if($rotation) $o.='/rot'.$sep.$rotation; else $o.='/rot'.$sep.'0';
    // Browser cache
    if($cache) $o.='/cache'.$sep.'1'; else $o.='/cache'.$sep.'0';
    // Extra data
    if(is_array($options)) foreach ($options as $k=>$v) $o.='/'.$k.$sep.$v;
    // Resource id
    $o.='/resId'.$sep.$_SESSION['activeResourceId'];
    // dump filename (to be replaced by JS function)
    if($rawFilename) $o.='/file.'.$completeFilename;
    // B64 encoded filename
    else $o.='/b64'.$sep.cfBase64_url_encode($completeFilename).'.'.cfFileExtension($completeFilename);
    return $o;
}

/**
 * return URL of resized image located into /www/gfx directory
 *
 * @param string $path: gfx path (ex: /gfx/icons/default.jpg)
 * @param int $width
 * @param int $height
 */
function cfExtGFX($path,$width,$height){
    $sep='.';
    if((substr($path,0,5)!='/gfx/' && substr($path,0,5)!='/res/') || strpos($path,'..')) return;
    return '/img/w'.$sep.(floor($width)).'/h'.$sep.(floor($height)).'/rot'.$sep.'0/cache'.$sep.'1/resId'.$sep.'0/file'.$sep.$path;
}

/**
 * @desc Return a link to a resized / colored / alphaed / unsatured image, located in document root. Image is generated by /ext/image.php
 *
 * @param string $path: document root relative path
 * @param integer $width resized width (0 for unresized)
 * @param integer $height: resized height (0 for unresized)
 * @param array $colour: r, g, b (0-255), p (0-100)
 * @param integer $alpha: alpha (0-255)
 * @param integer $desaturation (0-100): percentage of desaturation
 * @param array $options: outputFormat=>'png', 'gif' or false to keep source format / noAlpha=>true: set opaque background
 */
function cfFilteredImage($path,$width=0,$height=0,$colour=array(),$alpha=255, $desaturation=0,$options=array()){
    $sep='.';
    if((substr($path,0,5)!='/gfx/' && substr($path,0,5)!='/res/') || strpos($path,'..')) return;
    $uri='/img/w'.$sep.(floor($width)).'/h'.$sep.(floor($height));
    if(is_array($colour) && count($colour)==4) $uri.='/cr'.$sep.$colour['r'].'/cg'.$sep.$colour['g'].'/cb'.$sep.$colour['b'].'/cp'.$sep.$colour['p'];
    if($alpha<255) $uri.='/alpha'.$sep.$alpha;
    if($desaturation>0) $uri.='/desat'.$sep.$desaturation;
    if(@$options['outputFormat']) $uri.='/format'.$sep.$options['outputFormat'];
    if(@$options['noAlpha']) $uri.='/noAlpha'.$sep.'1';
    return $uri.'/cache'.$sep.'0/resId'.$sep.'0/file'.$sep.$path;
}

/**
 * @desc Parse REQUEST_URI as used by /ext/... scripts:
 *         /property1.value1/property2.value2/property3.value3.../file/filename
 *
 * @return array if OK, false if format not OK;
 */
function cfParseExtURI(){
    $sep='.';
    $uri=stripcslashes(rawurldecode($_SERVER['REQUEST_URI']));

    if(!strpos($uri,'/file'.$sep) && !strpos($uri,'/b64'.$sep)) return false;
    $items=explode('/',substr($uri,1));

    //$items=explode('/',substr($uri,1,strpos($uri,'/file'.$sep)-1));
    $parsed=array();
    foreach ($items as $value) {
        if(strpos($value,$sep)) {
            list($k,$v)=explode($sep,$value,2);
            if($k=='file') break;
            if($k=='b64'){
                if($k=='b64') $v=cfFileWithoutExtension($v);
                if($k=='file') $v=cfUnprotectFilename($v);
                else{$k='file';$v=cfBase64_url_decode($v);}
                $parsed[$k]=$v;
                break;
            }
            $parsed[$k]=$v;
        }
        else $parsed[$value]=true;
    }
    if(!isset($parsed['file']))
        $parsed['file']=cfUnprotectFilename(substr($uri,strpos($uri,'/file'.$sep)+6));

    return $parsed;
}

/**
 * @return void
 * @param string $logString, string to log
 * @param int $msgLogLevel, level of log (LOG_INF>LOG_DET>=LOG_ERROR>LOG_DBG)
 * @param string $logType: 'auto' to compute automatically, 'res' for a resource-specific log or 'usr' for a user-level log
 * @param string $eventType: type of logged event (see top of this file for values)
 * @desc log event to application log
*/
function cfLog($logString, $msgLogLevel=LOG_DBG, $logType='auto',$eventType=LOG_EVENT_UNKNOWN){
    // Set log level
    if($msgLogLevel==LOG_ERR) $msgLogLevel=LOG_ERROR;
    $fll=array('non'=>LOG_NON,'inf'=>LOG_INF,'err'=>LOG_ERROR,'det'=>LOG_DET,'dbg'=>LOG_DBG);
    if(($fileLogLevel=@$fll[cfGGetVar('applicationLogDetail')])===null) return; // Incorrect log level

	$fll=array_flip($fll);

    if($msgLogLevel<=$fileLogLevel){
        $logFileName=cfAppLogDir().'/'.MAIN_LOG_FILE;
        // If file size exeed max allowed file size, archive file
        if(file_exists($logFileName) && cfGGetVar('fileLogMaxSize') && filesize($logFileName)>cfGGetVar('fileLogMaxSize')){
            @unlink($logFileName.'.old');
            rename($logFileName, $logFileName.'.old');
        }

        // Set IP
        if(isset($_SERVER['REMOTE_ADDR'])) $ip=$_SERVER['REMOTE_ADDR']; else $ip='0.0.0.0';

        // Set log source
        if($logType=='usr') $source='usr'.WEnv::user()->id();
        elseif(($logType=='res' || $logType=='auto') && cfIsResource()) $source='res'.cfRGetVar('id');
        else $source='php';

        // Write to log file
        if($fp=@fopen($logFileName,'a')) {
        	fwrite($fp,time().'/'.$source.'/'.$eventType.'/'.$fll[$msgLogLevel].'/'.$ip.'/'.cfUTF8Decode($logString)."\n");
        	fclose($fp);
        }
    }
}

/**
 * @desc Return
 *
 * @param string $logOutput
 * @param integer $eventType: EVENT_CONNECTION, ... (see defines above)
 * @return mixed: array if $logOutput or $eventType set, boolean else
 */
function cfLogEventConfig($logOutput=false,$eventType=false){
    $logEventsConfig=@unserialize(cfGGetVar('logEventsConfig'));
    if(!$logOutput) return $logEventsConfig;
    if(!$eventType) return @$logEventsConfig[$logOutput];
    return @$logEventsConfig[$logOutput][$eventType];
}

/**
 * @desc Save logEvent config
 *
 * @param array $config
 */
function cfLogEventConfigSave($config){cfGUpdateVar('logEventsConfig',serialize($config));}

/**
 * @desc Send event to differents log methods
 *
 * @param string $eventString: utf8 event description
 * @param integer $eventType: type of event
 * @param integer $eventSubType: subtype of event
 * @param string $eventExtraData: for user connections: id of group, for resource access: if of user/id of resource
 */
function cfLogEvent($eventString, $eventType, $eventSubType='',$eventExtraData=''){
	if(!function_exists('cfLogEventCommand')){
	    function cfLogEventCommand($logOutput,$eventString,$eventType,$eventSubType,$eventExtraData){
	        cfPHPAsyncScript('/local/logOutputs/'.$logOutput.'.php?eventType='.$eventType.'&eventSubType='.$eventSubType.'&b64LogString='.urlencode(base64_encode($eventString)).'&b64ExtraData='.urlencode(base64_encode($eventExtraData)),(($eventType==EVENT_SERVERSTATE && $eventSubType==S_EVENT_OFF)?5000:50));
	    }
	}

    if(!is_array($logConfig=cfLogEventConfig())) return ;

    // Server state
    /*
    if($eventType==EVENT_SERVERSTATE){
        if($eventSubType==S_EVENT_LAN) $eventSubType=S_EVENT_OFF; // Don't display server as online when on LAN
        if(cfGGetVar('lastBroadcastedServerState')==$eventSubType) return; // Don't send twice
        cfGUpdateVar('lastBroadcastedServerState',$eventSubType);
    }
    */

    // Browse event receivers to find ones needing this one
    foreach ($logConfig as $logOutput=>$logOutputConfig) if(@$logOutputConfig[$eventType]){
        // Twitter: Add IP address to log string if requested by user configuration
        if($logOutput=='twitter' && $eventType==EVENT_SERVERSTATE && $eventSubType!==S_EVENT_OFF){
            require_once(INCLUDE_DIR.'/twitter.lib.php');
            @list($account,$password,$displayedIP)=twitterGetConnectionData();
            if($displayedIP) $eventString.=" (".cfExternalHostName().')';
        }
        // Async call log script
        cfLogEventCommand($logOutput,$eventString,$eventType,$eventSubType,$eventExtraData);
    }
}

/**
 * @desc Log into /data/temp scripts that doesn't terminate properly: create a text file for each script and remove it when script is finished
 * 			File contains URL and POST data
 * 			If called multiple times, $extraData is appened into file
 *
 * @param string $extraData: extra data to put into file
 * @param boolean $automatic: true to delete file on script end, false to delete by calling function with 'delete' parameter
 */
function cfDbgInterruptedScripts($extraData=false,$automatic=true){ // prod
	if($extraData==='delete') return cfDbgInterruptedScriptsSF(); // prod
	if(!function_exists('cfDbgInterruptedScriptsSF')) { // prod
		function cfDbgInterruptedScriptsSF(){unlink(cfAppTempDir().'/_int.'.$_ENV['weezoScriptId'].'.txt');} // prod
		cfDbg($_SERVER['REQUEST_URI'],cfAppTempDir().'/_int.'.$_ENV['weezoScriptId'].'.txt'); // prod
		cfDbg($_POST,cfAppTempDir().'/_int.'.$_ENV['weezoScriptId'].'.txt'); // prod
		if($automatic) register_shutdown_function('cfDbgInterruptedScriptsSF'); // prod
	}
	if($extraData!==false) cfDbg($extraData,cfAppTempDir().'/_int.'.$_ENV['weezoScriptId'].'.txt'); // prod
}

/**
 * @desc Append text to file (debug purposes)
 *
 * @param string $text : text to write
 * @param string $completeFilename : path and file name of file, set to "1" to display in a msgbox
 * @return true if success, false if file couldn't be opened
 */
function cfAppendTextToFile($text, $completeFilename=false,$prependTime=true){
    if(!$completeFilename) $completeFilename=cfAppLogDir().'/debugLog.txt';
    elseif ($completeFilename==1||$completeFilename==2) $prependTime=false;

    if($completeFilename!=1 && $completeFilename!=2 && !($handle=@fopen($completeFilename,'a'))) return false;

    if(is_array($text)){
        if($prependTime) $out=date('H:i:s')."\n"; else $out='';
        foreach ($text as $key=>$value) {
            if($value===true) $value='TRUE'; elseif($value===false) $value='FALSE';
            $out.=$key.'='.((is_array($value))?'Array ('.count($value).')':((is_object($value))?'Object':$value))."\n";
            if(is_array($value)){
                foreach ($value as $key2=>$value2) {
                    if($value2===true) $value2='TRUE'; elseif($value2===false) $value2='FALSE';
                    $out.=chr(9).$key2.'='.((is_array($value2))?'Array ('.count($value2).')':((is_object($value2))?'Object':$value2))."\n";
                }
            }
        }
    }
    else {
        if($prependTime) {
            $ms=microtime(true); $ms=floor(1000*($ms-floor($ms)));
            $out=date('H:i:s').'.'.$ms.'>';
        }
        else $out='';
        if($text===true) $out.='TRUE';
        elseif($text===false) $out.='FALSE';
        else $out.=$text;
    }
    if($completeFilename==1 && function_exists('customMsgbox')) customMsgbox($out);
    elseif($completeFilename==1) {
    	$exe=cfAppBinDir().'/dbg'; if(!file_exists($exe)) $exe.='.exe';
    	cfExecNoFork($exe.' '.$out);
    }
    elseif($completeFilename==2) {
    	$exe=cfAppBinDir().'/dbg'; if(!file_exists($exe)) $exe.='.exe';
        cfExecNoFork($exe,'SW_SHOW_NORMAL',str_replace("\r",'\\r',str_replace("\n",'\\n',str_replace("\r\n",'\n',$out))));
    }
    else{
        fwrite($handle,$out."\n");
        fclose($handle); return true;
    }
}

/**
 * @desc Debug to msgbox, php output or /log.txt text file
 *
 * @param string $text : text to output
 * @param string $completeFilename : filename of output, or false for /log.txt or 0 for output, or 1 for message box
 * @param boolean $prependTime : set to true to prepend time to text (file only)
 */
function cfDbg($text=null, $completeFilename=2,$prependTime=false){ // prod
    if(isset($_ENV['noDebug'])) return;
    if($text===null) {$completeFilename=1;$txt=__FILE__.'/'.__FUNCTION__.'/'.__LINE__;}
    if(is_numeric($completeFilename)) $prependTime=false;
    if($completeFilename===0) cfVarDump($text); // prod
    else cfAppendTextToFile($text,$completeFilename,$prependTime);
}
/**
 * @desc Debug call stack
 *
 * @param string $completeFilename
 * @param bool $prependTime
 */
function cfDbgT($completeFilename=2,$prependTime=false){ // prod
	$stack=debug_backtrace();
	$t='';
	foreach ($stack as $i=>$call) if($i) {
		$t.=$call['file'].' ('.$call['line'].'): '.$call['function'].'(';
		$nb=0;
		foreach ($call['args'] as $arg){
			$t.=(($nb++)?';':'');
			if($arg===true) $t.='TRUE';
			elseif($arg===false) $t.='FALSE';
			elseif($arg===null) $t.='NULL';
			elseif(is_numeric($arg)) $t.=$arg;
			else $t.='"'.$arg.'"';
		}
		$t.=")\n";
	}
	if($completeFilename=='return') return $t;
	cfDbg($t,$completeFilename,$prependTime); // prod
}
/**
 * Call cfDbg only once
 *
 */
function cfDbgOnce($text=null, $completeFilename=2,$prependTime=false){ // prod
	static $c=0;
	if($c++==0) cfDbg($text,$completeFilename,$prependTime); // prod
}

function cfDbgDate($text=null, $completeFilename=2,$prependTime=false){cfDbg(date('d/m/Y H:i:s',$text), $completeFilename,$prependTime);} // prod

/**
 * @debug a timestamp
 *
 * @param int $timestamp
 * @param string $format: format for date, false for _FULL_DATE_FORMAT, true for _DATE_FORMAT
 */
function cfFixedDate($timestamp=false, $format=false){
	if($format===false) $format=cfCaption('_FULL_DATE_FORMAT');
	elseif($format===true) $format=cfCaption('_DATE_FORMAT');

	if(!$timestamp) $timestamp=time();
	return date($format,$timestamp+(int)cfMGetVar('timezoneShift'));
}

/**
 * @desc Display ascii values of chars
 *
 * @param string $txt
 * @param int $asciiOnly: 0 (only ascii value), 1 (ascii & txt), 2 (txt only, skip non-displayable chars)
 * @return string
 */
function cfDbgTxt($txt,$asciiOnly=2){// prod
	$output='';
	for($i=0;$i<strlen($txt);$i++){
		if($asciiOnly==2)  $output.=((ord($txt[$i])<32)?'('.ord($txt[$i]).')':$txt[$i]).'';
		else  $output.=ord($txt[$i]).(($asciiOnly)?' ':((ord($txt[$i])>23)?'('.$txt[$i].')':'')).' ';
	}
	return $output;
}
function cfDbgUrl($comp=''){cfDbg(cfHostName().$_SERVER['REQUEST_URI'].$comp);} // prod

function cfPhpDebug(){static $a; if(!isset($a))	$a=cfMGetVar('PHPDebug'); return $a;}
/**
 * @desc Echoes a sync/async debug tag. Call with an unique ID so source can easily be found
 *
 * @param string $tagId
 * @param bool $includeStack
 */
function cfDebugTag($tagId,$includeStack=true){
	static $debugTags;
	if(!isset($debugTags)) $debugTags=cfMGetVar('tagDebug');
	if(!$debugTags) return;
	$stack='';
	if($includeStack){
		$s=debug_backtrace();
		for ($i=count($s)-1;$i>0;$i--){
			$c=$s[$i];
			$stack.=basename($c['file']).' ('.$c['line'].') '.$c['function'].'(';
			if(count($c['args'])) {
				foreach ($c['args'] as $k=>$v) $c['args'][$k]=json_encode($v);
				$stack.=implode(',',$c['args']);
			}
			$stack.=')';
			if($i>1) $stack.=' => ';
		}
		$stack.='<br>';
	}
	$tag='cfDbg("<"+"b style=\\"color:red\\">'.((cfIsAsync())?'Async':'Sync').' debugTag:'.str_replace('"',"''",$tagId.'</b> stack:'.$stack).'",1);'; // prod
	if(cfIsAsync()) $tag=cfAsyncJSaction($tag);
	else $tag='<script type="text/javascript">'.$tag.'</script>';
	if(headers_sent()) echo $tag;
	else {
		if(!cfIsAsync()) $tag.='setTimeout(function(){'.$tag.'},100);'; // Sync: add a timeout to let body time to load
		$_ENV['debugTagsStack']=@$_ENV['debugTagsStack'].$tag; // If header has not yet been sent, just add to stack so it's sent by cfInsertHEAD or cfAsyncHeader
	}
}


/**
 * @return void
 * @param mixed array $var : var to dump
 * @desc "HTML visual" version of var_dump
*/
function cfVarDump($var){ // prod
    echo "\n<pre>\n";
    var_dump($var);
    echo "</pre>\n";
}

/**
 * @desc Set input/output info into debug buffer. See /pub/debugAsync for details
 *
 * @param string $type ('async','image','audio'...)
 * @param array $req: request arguments ($_POST...)
 * @param string $resp: response output
 */
function cfDebugSetBuffer($type=false,$req=false,$resp='...'){
    if(!cfMGetVar('debugAsync') || $_SERVER['SCRIPT_NAME']=='/pub/debugAsync.php' || isset($_POST['noDebug'])) return;

    $buff=cfMGetVar('debugAsyncBuffer');

    if(!is_array($buff)) $buff=array();
    if(!is_array($req)) $req=array('?'=>$req);

    // Add buffer updates sent before cfDebugSetBuffer call
    if(isset($_ENV['debugAsyncExtraBuffer']) && is_array($_ENV['debugAsyncExtraBuffer'])) foreach ($_ENV['debugAsyncExtraBuffer'] as $k=>$v) $resp.="\n".$k.'='.$v;

    // Set default type
    if(!$type)	$type=(cfIsAsync())?'async':'sync';

    // Set default request args
    if(!$req){
    	foreach ($_GET  as $k=>$v) $req['GET:'.$k]=$v;
    	foreach ($_POST as $k=>$v) $req['POST:'.$k]=$v;
    }

    $buff[]=array($_ENV['weezoScriptId'],$type,
        array('SCRIPT'=>$_SERVER['REQUEST_URI'])+$req,
        $resp,
        array('UA'=>@$_SERVER['HTTP_USER_AGENT'])+getallheaders(),
        headers_list(),
        array($_ENV['chrono'][0]['time'],microtime(true)));

    cfMSetVar('debugAsyncBuffer',$buff);
    $_ENV['debugAsyncBufferSet']=1;
}

/**
 * @desc Update debug buffer with script output
 *
 * @param string $resp: string to be sent to debug output
 * @param bool $concatenate: true to concatenate instead of replace
 */
function cfDebugUpdateBuffer($resp,$concatenate=1){
	if(!cfMGetVar('debugAsync')) return ;
    if(!isset($_ENV['debugAsyncBufferSet'])){
        if(!isset($_ENV['debugAsyncExtraBuffer'])) $_ENV['debugAsyncExtraBuffer']=array();
        if(!is_array($resp)) $resp=array('?'=>$resp);
        $_ENV['debugAsyncExtraBuffer']=$_ENV['debugAsyncExtraBuffer']+$resp;
        return;
    }
    $buff=cfMGetVar('debugAsyncBuffer');
    if(!is_array($buff)) $buff=array();
    if(is_array($resp)){
        $tmp='';
        foreach ($resp as $k=>$b) $tmp.=$k.'='.(($v)?''+$v:(($v===0)?'0':"VOID"))."\n";
        $resp=$tmp;
    }
    $buff[]=array($_ENV['weezoScriptId'],$_ENV['chrono'][0]['time'],(($concatenate)?'+':'=').$resp,microtime(true),headers_list());
    cfMSetVar('debugAsyncBuffer',$buff);
}

/**
 * @desc Set input/output info into debug buffer. See /pub/debugAsync for details
 *
 * @param mixed $mixed: data sent to debug (string or array)
 */
function cfDebugSingle($mixed='...',$class='simple'){
    if(!cfMGetVar('debugAsync') || substr($_SERVER['REQUEST_URI'],0,19)=='/pub/debugAsync.php') return;
    $buff=cfMGetVar('debugAsyncBuffer'); if(!is_array($buff)) $buff=array();
    if(is_array($mixed)) {
    	$tmp='';foreach ($mixed as $k=>$v) $tmp.="\n".$k.' = '.$v;
    	$mixed=substr($tmp,1);
    }
    $buff[]=array($_ENV['weezoScriptId'],$mixed,$class);
    cfMSetVar('debugAsyncBuffer',$buff);
}

/**
 * @desc Save synchronous html page to file and open file (used for mobile debuging)
 *
 */
function cfSyncDebugShutdown(){
	$page=ob_get_clean();
	echo $page;
	if(isset($_ENV['syncDebugCancel']) || cfFileExtension($_SERVER['PHP_SELF'])=='js' || cfFileExtension($_SERVER['PHP_SELF'])=='css') return;

	file_put_contents(cfAppDataRootDir().'/syncHTML.html',$_SERVER['REQUEST_URI']."\n".$page);
	cfExecFork("C:/Program Files (x86)/Notepad++/Notepad++.exe",'SW_SHOW_NORMAL',cfAppDataRootDir().'/syncHTML.html');
}

/**
 * @desc Initialize threads/process debug
 *
 */
function cfThreadsDebugInit(){
	register_shutdown_function('cfThreadsDebugShutdown');
	// Semaphore
	while (cfMIssetVar('threadsDebugSem')) usleep(1000); cfMSetVar('threadsDebugSem',1);
	// Add thread to list
	$running=cfMGetVar('threadsDebug'); $running[$_ENV['requestID']]=array('time'=>microtime(true),'uri'=>$_SERVER['REQUEST_URI'],'post'=>serialize($_POST));
	cfMSetVar('threadsDebug',$running);
	// Free semaphore
	cfMUnsetVar('threadsDebugSem');
	unset($running);
}

/**
 * @desc Basic Semaphore Acquire
 *
 * @param string $id
 * @param integer $maxWaitTime: max wait time (millisec) before forcing entry
 */
function cfSemaphoreAcquire($id, $maxWaitTime=0){
	$in=microtime(true);
	$maxWaitTime/=1000;
	while(cfMIssetVar('semaphore_'.$id) && (!$maxWaitTime || microtime(true)-$in<$maxWaitTime)) usleep(1000);
	cfMSetVar('semaphore_'.$id,1);
}

/**
 * @desc Release Semaphore created with cfSemaphoreAcquire
 *
 * @param string $id
 */
function cfSemaphoreRelease($id){cfMUnsetVar('semaphore_'.$id);}

/**
 * @desc Update memory consumption and last access time of current thread/process
 *
 */
function cfThreadsDebugUpdate(){
	static $lastCallTime=0;
	// Velocity limit: limit to a call every 3s
	if($lastCallTime && (microtime(true)-$lastCallTime < 3)) return;

	if(!cfMGetVar('debugThreads')) return;

	$lastCallTime=microtime(true);

	// Semaphore
	while (cfMIssetVar('threadsDebugSem')) usleep(1000); cfMSetVar('threadsDebugSem',1);
	// Add memory consumption and last access time to this function
	$running=cfMGetVar('threadsDebug');
	// Initialization not done (may happend): init now
	if(!isset($running[$_ENV['requestID']])) cfThreadsDebugInit();
	$running[$_ENV['requestID']]['lastUpdate']=microtime(true);
	$running[$_ENV['requestID']]['mem']=memory_get_usage(true);
	cfMSetVar('threadsDebug',$running);
	// Free semaphore
	cfMUnsetVar('threadsDebugSem');
	unset($running);}

/**
 * @desc Threads debug: on script exit, remove from list
 *
 */
function cfThreadsDebugShutdown(){
	while (cfMIssetVar('threadsDebugSem')) usleep(1000);
	cfMSetVar('threadsDebugSem',1);
	$running=cfMGetVar('threadsDebug');
	unset($running[$_ENV['requestID']]);
	cfMSetVar('threadsDebug',$running);
	cfMUnsetVar('threadsDebugSem',$running);
}

/**
 * @desc Generate a file name for a temporary file in temp dir
 *
 */
function cfTmpFile(){
	$i=0;
	while (file_exists(cfAppTempDir().'temp_'.$i)) $i++;
	return $i;
}

/**
 * @desc Start output buffering for responding to a (potential) HTTP Range request
 *
 */
function cfRangeAccessibleOutputStart(){ob_start();}

/**
 * @desc Send header and output for (potential) HTTP Range request.
 *             cfRangeAccessibleOutputStart() must have been called before output start
 *
 */
function cfRangeAccessibleOutputSend(){
    $buff=ob_get_clean();

    $h=getallheaders();
    // No range required: just send output
    if(!isset($h['Range'])) {
        header('Content-Length: '.strlen($buff));
        header("Accept-Ranges: bytes");
        echo $buff;
        return;
    }

    // Range required: parse request and send only requested range
    header('HTTP/1.1 206 Partial Content');
    $h['Range']=substr($h['Range'],6);
    list($from,$to)=explode('-',$h['Range']);
    header("Content-Range: bytes $from-$to/".strlen($buff));
    header("Content-Length: ".(1+$to-$from));
    header("Accept-Ranges: bytes");

    echo substr($buff,$from,1+$to-$from);
}

/**
 * @return boolean : true if success, false if user file couldn't be opened
 * @param string $completeFilename : path & file name of file to download / stream
 * @param int $isTransfer : true to set download as (monitored) transfer, or transfer object to reuse an existing transfer (multiple download)
 * @param int $speedLimit : max download speed (kBytes per second), 'auto' to retreive user configuration, 0 for unlimited, or speed limitation object to use existing speed limitation object
 * @param mixed $range: ('from'=>, 'to'=>) only stream bytes from/to, or 'auto' to retreive $from/$to from in-headers
 * @param array $options: ('noHeaders'=>1,'noSessionClose'=>1)
 * @desc stream file to output (no header sent)
*/
function cfStreamFile($completeFilename, $isTransfer=false, $speedLimit = 'auto', $range=false, $options=false){

    if(!function_exists('cfStreamFileBlock')){
    	/**
    	 * echo $outBufferSize bytes of data
    	 * @param $handle: handle on file
    	 * @param $from: start position in file
    	 * @param $to: end position in file (false/0 to limit to file size)
    	 * @param $sent: return data: total sent bytes
    	 * @param $limit: transfer speed limitation object
    	 * @param $transfer: transfer object
    	 */
    	function cfStreamFileBlock(&$handle, $from=0, $to=0, &$sent=null, &$limit=null, &$transfer=null){
		    static $inBufferSize=65536;
		    static $outBufferSize=32768;

		    static $pos=0;
		    static $inBuffer="";
		    static $inBufferPos=0;
		    static $inBufferContentSize=0;
		    static $initialized=false;

		    // (re)init function (usefull when calling twice cfStreamFile)
		    if($handle===false) {
				$pos=$inBufferContentSize=$inBufferPos=0;
				$inBuffer="";
				$initialized=false;
				return ;
			}


		    if(!$initialized){
		    	if($from>0) fseek($handle,$from);
		    	$initialized=true;
		    	$pos=$from;
		    }

    		$toSend=$outBufferSize;
    		$sent=0;
    		if(!$to) $to=9999999999;

    		// If max size
    		if($pos+$toSend>$to) $toSend=$to-$pos;

		    // If all requested data is not present in buffer
		    if($inBufferPos+$toSend>$inBufferContentSize){
		    	// Echo available data
		    	echo substr($inBuffer,$inBufferPos);
		    	$sent+=($tmpSent=$inBufferContentSize-$inBufferPos);
		    	$pos+=$sent;
		    	$toSend-=$sent;

		    	// and refill
		    	if(!feof($handle)) {
		    		$inBuffer=fread($handle,$inBufferSize);
			    	$inBufferContentSize=strlen($inBuffer);
			    	$inBufferPos=0;
			    	// Echo remaining data
		    		echo substr($inBuffer,0,$toSend);
			    	$tmpSent+=$toSend;
		    		$inBufferPos=$toSend;
		    		$pos+=$toSend;
		    		$sent+=$toSend;
		    	}
		    }
		    // All data is cached, just send
		    else{
		    	echo substr($inBuffer,$inBufferPos,$toSend);
		    	$tmpSent=$toSend;
		    	$inBufferPos+=$toSend;
		    	$pos+=$toSend;
		    	$sent+=$toSend;
		    }
		    // Update  speed limitation and transfer objects
	    	if($limit) $limit->addData($tmpSent);
	    	if($transfer) $transfer->updateSentData($tmpSent);

	    	// flush();
		    return $pos;
    	}
    }
    //Re-init function
    else cfStreamFileBlock($false=false);

    if(!isset($options['noSessionClose'])) wSession_write_close();
    if(!isset($_ENV['cfStreamFileNoLog'])) cfLog('cfStream file : '.$completeFilename,LOG_DBG);
    if(!@file_exists($completeFilename)) return false;
    if(!($handle = @fopen ($completeFilename, "rb"))) return false;
    set_time_limit(0);

    $fileSize=cfFileSize($completeFilename);

    // Get speed limitation from user-level value
    if($speedLimit==='auto') $speedLimit=(int)cfUGetVar('downloadSpeedLimit');

    // Process automatic range: read and process 'Range' header
    if($range==='auto'){
    	list($from,$to)=WHeadersIn::getRange();
    	if(!$from && !$to)
    		$range=false;
    	else{
    		// Send HTTP/1.1 206 Partial Content, Content-Length & Content-Range headers
    		if(!isset($options['noHeaders'])) WHeaders::contentRange($fileSize);
    		$range=array('from'=>$from,'to'=>$to);
    	}
    }

    $pos=0; // Absolute position in input file

    // no dowload monitoring and no speed limit : send file to output
    if($speedLimit===0 && !$isTransfer && !$range) {
        while ($pos<$fileSize) {
			//cfDbg('stream '.$bufferSize.' bytes (no speed limit)',cfAppDocRoot().'/zipDDL.log',true);
            $pos=cfStreamFileBlock($handle);
            cfPingUpdate(900);// Ping app
        }
    }
    // Speed limit or monitoring
    else{
        require_once(INCLUDE_DIR.'transferFunctions.php');
        // Monitor download as transfer

        // Download is a (new) transfer: create transfer
        if($isTransfer===true){
            $t=tAddDownload($completeFilename);
            $lastRefresh=time();
        }
        // download is part of an existing transfer (multiple download (zip)): reuse existing transfer
        elseif (is_object($isTransfer)){
        	$t=$isTransfer;
            $lastRefresh=time();
        }

        // Set-up transfer speed limitation
        if(is_object($speedLimit)) $limit=$speedLimit;
        else if($speedLimit) {
        	$limit=new transferLimitation($speedLimit*1024);

        }
        else $limit=false;

        $transferedSize=0;

        // Set range
        if(isset($range['from']))	$from=$range['from'];	else $from=0;
        if(isset($range['to']))		$to=$range['to'];		else $to=$fileSize;

        // Stream file
        while ($pos<$to && (!$isTransfer || ($t->exists() && $t->status!=9))) { // (stop streaming if transfer status is 9 = "stopped")

        	// Stream data and update position
        	$sent=0;
        	// Loop 10 times through cfStreamFileBlock to reduce CPU (by avoiding all transfers & speed limit controls)
        	$loop=10; while ($pos<$to && $loop-->0) $pos=cfStreamFileBlock($handle,0,0,$sent,$limit,$t);

            cfPingUpdate(30);// Ping app


            // Download monitoring
            if($isTransfer && (time()-$lastRefresh)>=$t->updateInterval && $fileSize>0){
                // Transfert stopped : quit
                if(!$t->exists() || $t->status==9) break;

                // Update transfert progress
                //$t->updateProgress($pos/$fileSize,true);
                $t->updateSentData(0,true); // Might behave incorrectly for some range requests
                $t->commitToFile(false,false);

                $lastRefresh=time();
            }
            // Speed limitation
            if($speedLimit) $limit->addData($sent);
        }
        // Download monitoring: set upload complete
        if($isTransfer && $t->type=="download") {$t->updateProgress(1,false);$t->updateStatus(4,true);}
        if($speedLimit && !is_object($speedLimit)) unset($limit);
    }
    fclose($handle);

    //if(!$isTransfer || $t->status!=9) cfLog('Download of : '.$completeFilename.' completed',LOG_DBG);
    return  true;
}

/**
 * @desc stream string to output applying speed limitation
 *
 * @param string $string: string to stream
 * @param integer $speedLimit: speed limitation (kBytes per second), false to use user's
 */
function cfStreamString(&$string, $speedLimit=false){
    // If speed limit not set, set user speed limit
    if($speedLimit===false) $speedLimit=cfUGetVar('downloadSpeedLimit');
    // No speed limit : output string
    if(!$speedLimit) echo $string;
    else{
        $speedLimit*=1024; // Set limit in B/s
        $bufferSize=$speedLimit; // Set buffer size
        $pos=0;    $l=strlen($string);
        require_once(INCLUDE_DIR.'transferFunctions.php');
        $limit=new transferLimitation($speedLimit);
        do{
            echo substr($string,$pos,$bufferSize);
            flush();
            $limit->addData($bufferSize);
            $pos+=$bufferSize;
        } while ($pos<$l);
    }
}

/**
 * @desc Streamed Process monitoring
 * 		 Monitors process streamed with cfStreamProc as the function may in some cases hang on fread function
 * 		 cfStreamProcMonitor is called with pid & maxDuration once before fread, and montitoring is canceled just after fread by
 * 		 calling this function with $maxDuration=0
 * 		 cfStreamProcMonitor is also called by ping.php to periodically check if some streamed process have hanged. If so, terminate them
 *
 * @param $pid: process id to monitor/stop monitoring. Leave blank to just check all monitored process
 * @param $maxDuration: max time (s) before process is killed at next cfStreamProcMonitor call
 */
function cfStreamProcMonitor($pid=false,$maxDuration=0){
	$monitored=cfMGetVar('cfStreamProcMonitorPIDs');
 	$t=time();

	// Start monitoring a PID
	if($pid&&$maxDuration){
		$monitored[$pid]=array($t,$maxDuration);
		$update=1;
	}

	// Stop monitoring a PID
	elseif ($pid && ($maxDuration==0)){
		unset($monitored[$pid]);
		$update=1;
	}

	// Check if a process has hanged
	if($monitored) foreach ($monitored as $kpid=>$proc){
		// If overtime, kill process (except if it's monitored one)
		if ($kpid!==$pid && $t-$proc[0]>=$proc[1]) {
			unset($monitored[$kpid]);
			$update=1;
			cfTerminateProcess($kpid);
		}
	}

	// Save list of monitored process
	if(isset($update)) cfMSetVar('cfStreamProcMonitorPIDs',$monitored);
}



/**
 * @desc stream stdout or stderr of a process to php output, or return it as function's return
 *         kill process if user aborts
 *
 * @param string $commandLine: full path/exe args command line
 * @param array $std: keys: 'stdout' and/or 'stderr'. See $outputProcess for values
 * @param string $outputProcess (optional, use only if $std is a string (backward compatibility)):
 *             'stdout' to send proc output to stdout,
 *             'return' to return as function's return
 *             false to discard
 *             function name : named function is called at every stream cycle (with buffer data as parameter)
 * 								function should return processed data in order cfStreamProc to be compatible with range requests
 * 								else function may echo data
 * @param array $extraOptions: other options
 *             'bufferSize'=>bufferSize: set buffer size, in bytes
 *             'speedLimit'=>speed limitation, max download speed (kBytes per second)
 *             'timeout'=>max time in seconds to start receiving info
 *             'haltOnSeq'=>string that will halt streaming if found at end of buffer (workaround to hanging in some case...)
 *             'writeStdin'=>string that will be sent to in pipe
 *             'ignoreConnectionAbort': set to indicate that function should return even if connection aborted
 *             'range': array('from'=>, 'to'=>) : only output bytes from/to
 * @param integer $streamedLength: total data streamed from process (but not sent to output if range)
 * @param integer $$outputLength: total length of data echoed / returned
 *
 * @return mixed: string result if $outputProcess=='return', else void
 */
function cfStreamProc($commandLine, $std=array('stdout'=>false), $extraOptions=array(),&$streamedLength=-1,&$outputLength=-1){
    $getTotal=($streamedLength===-1||$outputLength===-1)?0:1; // Set to 1 if total streamed data length must be computed
    if(isset($extraOptions['initialBuffer'])) $getTotal=1;

    $streamedLength=0; // Total length of received data
    $outputLength=0; // Total length of returned / output data


    // Range processing
    $range=false;

    // Max time before receiving data
    if(isset($extraOptions['timeout']) && is_numeric($extraOptions['timeout'])) $timeout=time()+$extraOptions['timeout'];

    if(isset($extraOptions['range'])){
	    // Auto range
	    if($extraOptions['range']==='auto'){
	    	list($from,$to)=WHeadersIn::getRange();
		    if($from||$to){
		    	$from=(int)$from;
		    	//if($to===false) $to=1263794; // Why ???
		    	if($to===false) $to=999999999999;
	    		$range=array('from'=>$from,'to'=>$to);
		    }
	    }
	    // Passed range
    	elseif(is_array($extraOptions['range']) && isset($extraOptions['range']['from']) && isset($extraOptions['range']['to'])) {
    		$range=$extraOptions['range'];
    		$from=$range['from'];$to=$range['to'];
    	}
    	// Turn into $to-boundary exclusive range
    	@$to+=1;
    }

    $bufferSize=32384; // Higher values will likely result in system hang
    $bufferSize=8196; // Higher values will likely result in system hang

    // Close session if started (as cfStreamProc might in some cases hang, doesn't block user...)
    if(cfSessionIsStarted()) {
        // Mem active resource so it's not "hijacked" by another resource during streaming
        if(isset($_SESSION['activeResourceId'])) $activeResourceId=$_SESSION['activeResourceId'];

        wSession_write_close();
        $restartSession=1;
    }

    // Backward compatibility
    if(!is_array($std)) $std=array($std=>$outputProcess);

    if(!isset($std['stdout']) && !isset($std['stderr'])) {
        trigger_error('cfStreamProc: wrong $std parameter, must be "stdout" or "stderr"',E_ERROR);
        return;
    }

    // Clean command line
    $commandLine=trim($commandLine);
    if($commandLine[0]=='"') {
        $fullPath=substr($commandLine,1,strpos($commandLine,'"',1)-1);
        $args=substr($commandLine,strpos($commandLine,'"',1)+1);
    }
    else{
        $fullPath=substr($commandLine,0,strpos($commandLine,' ',1));
        $args=substr($commandLine,strpos($commandLine,' ',1));
    }
    $commandLine='"'.str_replace('\\','/',$fullPath).'"'.$args;

    // Set-up transfer speed limitation
    if(isset($extraOptions['speedLimit'])) $speedLimit=$extraOptions['speedLimit']; else $speedLimit=0;
    if($speedLimit) {
        $speedLimit*=1024;
        $bufferSize=min($bufferSize,$speedLimit);
        require(INCLUDE_DIR.'transferFunctions.php');
        $limit=new transferLimitation($speedLimit);
    }

    // Force buffer size
    if(isset($extraOptions['bufferSize'])) $bufferSize=$extraOptions['bufferSize'];

    // Stop on given char at end of buffer (used as a workaround to random blocking on fread)
    if(isset($extraOptions['haltOnSeq'])) $haltOnSeq=$extraOptions['haltOnSeq'];

    $transferedSize=0;    $buffer='';

    $desc= array(0 => array("pipe", "r"), 1 => array("pipe", "w"),  2 => array("pipe", "w"));

    // Open process
    $process=@proc_open($commandLine, $desc, $pipes, getcwd(), null, array('binary_pipes'=>TRUE,'bypass_shell'=>TRUE));

    // Get PID (used for process monitoring, as script may hang on fread function when connection is aborted)
    $pid=cfArrayItem(@proc_get_status($process),'pid');

    $noCmd=true; // Indicate that process is not run with an extra CMD window
    if(!$process){
        $process=@proc_open($commandLine, $desc, $pipes, getcwd(), null, array('binary_pipes'=>TRUE));
        $noCmd=false;
        if(!$process){
            trigger_error('cfStreamProc: cannot open process',E_USER_WARNING);
            return;
        }
    }

    set_time_limit(0);
    ignore_user_abort(1);

    // Write in stdin
    if(isset($extraOptions['writeStdin'])) fwrite($pipes[0],$extraOptions['writeStdin']);

    /**
     * Close unused pipes
     */

    // Close stdin
    if(!isset($std['stdin'])) fclose($pipes[0]);
    // Close stderr
    if(!isset($std['stderr'])) fclose($pipes[2]);
    // Close stdout
    if(!isset($std['stdout'])) fclose($pipes[1]);

    /********************************
     * STREAM STDOUT and/or STDERR (start by stdout)
     ********************************/
    while(isset($std['stdout'])||isset($std['stderr'])){
        // Select stdout/stderr pipe
        if(isset($std['stdout'])) {
            $pipe=$pipes[1];
            $outputProcess=$std['stdout'];
        }
        else {
            $pipe=$pipes[2];
            $outputProcess=$std['stderr'];
        }
        stream_set_blocking($pipe, 0);

        // Get output processing function name (if any)
        $outputProcessFunction=($outputProcess && $outputProcess!=='stdout' && $outputProcess!=='return' && function_exists($outputProcess)?$outputProcess:false);
        if($outputProcessFunction) $outputProcess='stdout';

        /**
         * Stream loop
         */
        while (!feof($pipe)) {
            if(connection_aborted() && !isset($extraOptions['ignoreConnectionAbort'])) break(2);

            // Start checking this script doesn't hang on fread function below
			cfStreamProcMonitor($pid,STREAMED_PROCESS_MAX_FREAD_TIME);

            // Read pipe
            $buff=fread($pipe, $bufferSize);

            // fread returned, so stop monitoring
			cfStreamProcMonitor($pid,0);

            // Output is processed by a function: replace buffer with processed output
            if($outputProcessFunction!==false) {
            	$buff=call_user_func($outputProcessFunction,$buff);
            	if($buff===true) break(2);
            }

            // Compute buffer length only if needed
            if($getTotal||$range||isset($timeout)) $streamedLength+=($bl=strlen($buff));

            // Timeout detection
            if(isset($timeout) && $streamedLength==0 && time()>$timeout) break;

            // Range slicing
            if($range){
            	$touched=true;
            	// $from not yet reached: clear buffer
                if($streamedLength<=$from) $buff='';
                // Got beyond $from for the 1st time
                elseif ($streamedLength>$from && $streamedLength-$bl<$from){
                	// Remove data before $from
                	$buff=substr($buff,$from+$bl-$streamedLength);
                	// If buffer is going beyond $to, remove extra data at the end
                	if($from+strlen($buff)>$to) $buff=substr($buff,0,$to-$from);
                }
                // Got beyond $to for the 1st time
                elseif ($streamedLength>$to && $streamedLength-$bl<=$to) $buff=substr($buff,0,$to+$bl-$streamedLength);
                // Over $to limit: stop streaming
                elseif ($streamedLength>$to) {$buff=''; break;}
                else $touched=false;

                // Recompute buffer length if needed
                if($touched) $bl=strlen($buff);
            }
            if($getTotal) $outputLength+=$bl;

            // Debug output to file
            if (isset($extraOptions['debugOutput'])) {
            	$fh=fopen($extraOptions['debugOutput'],'a');
            	fwrite($fh,$buff);
            	fclose($fh);
            }

            // flush data to output
            if($outputProcess=='stdout') {
            	if(isset($extraOptions['initialBuffer']) && $outputLength<$extraOptions['initialBuffer']){
            		$buffer.=$buff;
            	}
            	else{
            		if($buffer!='') {echo $buffer;$buffer='';}
            		echo $buff;
            		flush();
            	}
            }
            // concatenate to buffer
            elseif($outputProcess=='return') $buffer.=$buff;

            // Speed limitation
            if($speedLimit) $limit->addData(strlen($buff));
            // Ping app
            cfPingUpdate(3);

            usleep(1000);

            if(isset($haltOnSeq) && substr($buff,-strlen($haltOnSeq))==$haltOnSeq) break(2);
            if(connection_aborted() && !isset($extraOptions['ignoreConnectionAbort'])) break(2);
        }

        if($pipe==$pipes[1]) unset($std['stdout']); else unset($std['stderr']);
        fclose($pipe);
    }
    // if "break(2)" exit
    @fclose($pipe);

    if($speedLimit) unset($limit);

    $status=proc_get_status($process);

    // Kill process if not not terminated
    if(is_array($status) && $status['running']) {
        // Always use Kill method as proc_terminate seems to hang sometimes...
        if(0 && $noCmd) proc_terminate($process);// Terminate process
        else cfTerminateProcess($status['pid']);// Terminate cmd process and it's children
        usleep(5000);
    }

    // Close process
    proc_close($process);

    // Reset settings
    set_time_limit(ini_get('max_execution_time'));
    if(!isset($extraOptions['ignoreConnectionAbort'])) ignore_user_abort(0);

    // Restart session if needed
    if(isset($restartSession)) {
        @wSession_start();
        if(isset($activeResourceId)) $_SESSION['activeResourceId']=$activeResourceId;
    }

    if($outputProcess=='return') return $buffer;
    if($outputProcess && $outputProcess!='stdout') call_user_func($outputProcess,null);
}

/**
 * @desc Execute a process and wait till it has returned
 *
 * @param string $exeCompleteFilename: complete filename of file to execute
 * @param string $mode: 'SW_MINIMIZE', 'SW_HIDE', 'SW_SHOWNORMAL', 'SW_SHOWMINNOACTIVE', 'SW_SHOWDEFAULT'
 * @param string $commandLine: arguments
 * @param string $maxExecutionTime: maximum exection time, in seconds
 * @return boolean: true if function executed
 */
function cfExecNoFork($exeCompleteFilename,$mode='SW_SHOW_NORMAL',$commandLine='',$maxExecutionTime=0){
    if(function_exists('customExecNoFork')) return customExecNoFork($exeCompleteFilename,$mode,$commandLine,$maxExecutionTime);
    shell_exec($exeCompleteFilename.(($commandLine)?' '.$commandLine:''));
}

/**
 * @desc Execute a process but don't wait till it has returned
 *
 * @param string $exeCompleteFilename: complete filename of file to execute
 * @param string $mode: 'SW_SHOWNORMAL', 'SW_HIDE'
 * @param string $commandLine: arguments
 * @param boolean $idle: set to true to run idle, 0 to run with normal priority
 * @return boolean: true if function executed
 */
function cfExecFork($exeCompleteFilename,$mode='SW_SHOW_NORMAL',$commandLine='',$idle=1){
    if(function_exists('customExecFork')) return customExecFork($exeCompleteFilename,$mode,$commandLine,$idle);
}

/**
 * @desc Async Exec a script on server. This script must ignore user abort and should not open session
 *
 * @param string $URL
 * @param integer $maxWait: set this parameter to wait script's end if less than $maxWait ms AFTER SOCKET CONNECTION (0 for unlinmited)
 * @param string $callbackFunction: if set, this function will be called whenever data is read. Use 'return' to return data
 * @param array $option: string 'post': encoded post data, array 'headers': http out headers
 * @return read data (if $callbackFunction is set to 'return');
 */
function cfPHPAsyncScript($URI,$maxWait=50,$callbackFunction=false,$options=array()){
	$data='';

    // If called from server
	if($host=cfLocalhostName(true)){
		// Add cookie header
		if(WHeadersIn::get('Cookie')) $headers=array('Cookie'=>WHeadersIn::get('Cookie')); else $headers=array();

		// Add other headers
		if(isset($options['headers']) && is_array($options['headers'])){
			foreach ($options['headers'] as $k=>$v) $headers[$k]=$v;
		}
		// Automatically add a content-type header for POST request if not set
		if(isset($options['post']) && !isset($options['headers']['Content-Type'])) $headers['Content-Type']='application/x-www-form-urlencoded';
		if(isset($options['post']) && !isset($options['headers']['Content-Length'])) $headers['Content-Length']=strlen($options['post']);

		// Launch request
        if(!($fp=cfSocketHTTPRequest($host.$URI,4,false,$foo,$foo,false,true,$headers,@$options['post']))) return false;
        $t=0;  $headerRemoved=false;

        while ((!$maxWait || $t<1000*$maxWait) && !feof($fp)) {
			// If a callback function is defined, call it with read data (else don't try to read data as it may hang)
			if($callbackFunction) {
				// 1st remove HTTP header
				if(!$headerRemoved){
					$data.=fread($fp,8162);
					if($pos=strpos($data,"\r\n\r\n")){
						$data=substr($data,$pos+4);
						$headerRemoved=true;
						if($callbackFunction!=='return') call_user_func($callbackFunction,$data);
					}
				}
				// Call callback function with data
				elseif($callbackFunction!=='return') call_user_func($callbackFunction,fread($fp,8162));
			}
			usleep(10000);
			$t+=10000;
        }
        usleep(50000);
        fclose($fp);
    }
    // Called from CLI
    else {
        if(strpos($URI,'?')){
            list($URI,$get)=explode('?',$URI,2);
            parse_str($get,$_GET);
        }
        require(cfAppDocRoot().$URI);
    }

    // Return read data if requested
    if($callbackFunction==='return') return $data;
}

/**
 * @return string : truncated string
 * @param string $str : string to truncate
 * @param int maxLen : max len of output string
 * @desc return input string if len<maxLen, or truncated string, ended by '...' if len>=maxLen
*/
function cfStrTruncate($str, $maxLen=0){
    if($maxLen==0) return $str;
    if(strlen($str) <= $maxLen) return $str;
    return substr($str,0,$maxLen-3).'...';
}

/**
 * @desc put values as keys
 *
 * @param array $in
 * @return array
 */
function cfArrayValuesToKeys($in){
    if(!is_array($in)) return array($in=>$in);
    $out=array();
    foreach ($in as $k=>$v) if(is_numeric($k)) $out[$v]=$v; else $out[$k]=$v;
    return $out;
}
/**
 * @desc Exchange keys and valued
 *
 * @param array $in
 * @return array
 */
function cfArraySwapKeysValues($in){
	if(!is_array($in)) return $in;
    foreach ($in as $k=>$v) $out[$v]=$k;
    return $out;
}

/**
 * @desc Convert an XML string to an array
 *
 * @param string $xmlstr
 * @return array
 */
function cfXmlToArray($xmlstr) {
	if(is_string($xmlstr)){
		$doc = new DOMDocument();
		$doc->loadXML($xmlstr);
		return cfXmlToArray($doc->documentElement);
	}

	$node=$xmlstr;
	switch ($node->nodeType) {
		case XML_CDATA_SECTION_NODE:
		case XML_TEXT_NODE:
			return trim($node->textContent);
			break;
		case XML_ELEMENT_NODE:
			$out = array();
			for ($i=0, $m=$node->childNodes->length; $i<$m; $i++) {
				$child = $node->childNodes->item($i);
				$v = cfXmlToArray($child);
				if(isset($child->tagName)) {
					$t = $child->tagName;
					if(!isset($out[$t])) $out[$t] = array();
					$out[$t][]=$v;
				}
				elseif($v) $out=(string) $v;
			}
			if(is_array($out)) {
				if($node->attributes->length) {
					$a = array();
					foreach($node->attributes as $attrName => $attrNode) $a[$attrName] = (string) $attrNode->value;
					$out['@attributes'] = $a;
				}
				foreach ($out as $t => $v) {
					if(is_array($v) && count($v)==1 && $t!='@attributes') $out[$t]=$v[0];
				}
			}
			return $out;
			break;
	}
}

/**
 * @desc Add $value as value for $key to $array, without erasing previous values
 */
function cfParse_ini_fileAddElt($key,$value,&$array){
	if(is_array($value) && isset($array[$key])){
		$k=array_keys($value);$k=$k[0];
		cfParse_ini_fileAddElt($k,$value[$k],$array[$key]);
	}
	else $array[$key]=$value;
}


/**
 * @return array : result of parsing
 * @param : string $completeFilename : path and file name of file to parse
 * @param : bool $process_sections : if set to true, sections are passed as sub arrays
 * @param : bool $$verifyVariableName : if set to true, key format is checked with cfIniVariableNameIsValid() function
 * @desc equivalent to parse_ini_file, but doesn't need to put "" around non alpha-numeric data
*/
function cfParse_ini_file($completeFilename,$process_sections=true, $verifyVariableName=true){

    if(!file_exists($completeFilename) || !is_readable($completeFilename)) return false;
    if(!($handle = @fopen($completeFilename, 'r'))) return false;

    $parsed=array();
    $sectionName=false;
    $element=array();
    // Browse lines
    while (!feof($handle)) {
        $line=trim(fgets($handle));
        // If not commented
        if(substr($line,0,1)==';' || substr($line,0,1)=='#') continue;

      	// Section
        if(substr($line,0,1)=='[' && substr($line,-1)==']' && (!$verifyVariableName || cfIniVariableNameIsValid(trim(substr($line,1,strlen($line)-2))))){
            if($sectionName!==false && count($element)){
                $parsed[$sectionName]=$element;
                unset($element);$element=array();
            }
            $sectionName=substr($line,1,strlen($line)-2);
        }
        else{
            if($pos=strpos($line,'=')){
                $key=trim(substr($line,0,$pos));
                $value=trim(substr($line,$pos+1));
                if(strtolower($value)==='false') $value=false;
                elseif(strtolower($value)==='true') $value=true;
                elseif($value==='0') $value=0;
                elseif($value==='1') $value=1;

                // Sub array: key is separated by /  => transform $value into an array
                if(strpos($key,'/')){
                	$key=explode('/',$key);
                	for($i=count($key)-1;$i>0;$i--) $value=array($key[$i]=>$value);
                	$key=$key[0];
                }
                // Add $key / $value
                if(!$verifyVariableName || cfIniVariableNameIsValid($key)){
                    if(!$process_sections || !$sectionName) {
                    	cfParse_ini_fileAddElt($key,$value,$parsed);
                    }
                    else {
                    	cfParse_ini_fileAddElt($key,$value,$element);
                    }
                }
            }
        }
    }
    fclose($handle);

    if($sectionName!==false && count($element)){
        $parsed[$sectionName]=$element;
    }
    unset($element);
    return $parsed;
}
/**
 * @desc Return true if .ini file variable name is correct
 *
 * @param string $variable
 * @return bool
 */
function cfIniVariableNameIsValid($variable) {
	for($i=0;$i<strlen($variable);$i++) {
		$a=$variable[$i];
		$c=ord($a);
		if(!(($c>64 && $c<91)||($c>96 && $c<123)||($c>47 && $c<58)) && $a!='|' && $a!='_' && $a!='@') return false;
	}
	return $i>0;
	//	return (ereg("^([a-zA-Z0-9]|@|_)+$", $variable));
}

/**
 * @return boolean : true if success, false if user file couldn't be written
 * @param mixed array $params : arg / value array to write
 * @param string $includeWarning : if true, include a commented "Automaticaly generated file" warning message at begining of file
 * @param string $completeFilename : file name.
 * @desc Write ini file (arg=value), from $params array of parameters
*/
function cfWriteIniFile($params, $completeFilename=false,$includeWarning=true){
    if(!($handle= fopen($completeFilename,'w'))) return false;
    if($includeWarning) fwrite($handle, "; Automaticaly generated file\n; Manual modifications might (or might not) be erased...\n;\n");
    foreach ($params as $key => $value){
        if(!is_array($value)){
            if($value===true) fwrite($handle,$key." = true\n");
            elseif($value===false) fwrite($handle,$key." = false\n");
            else fwrite($handle,$key.' = '.str_replace("\n","\r",$value)."\n");
        }
    }
    foreach ($params as $key => $value){
        if(is_array($value)){
            fwrite($handle,"\n".'['.$key.']'."\n");
            foreach ($value as $key2 => $value2){
                if($value2===true) fwrite($handle,$key2." = true\n");
                elseif($value2===false) fwrite($handle,$key2." = false\n");
                else fwrite($handle,$key2.' = '.str_replace("\n",'',$value2)."\n");
            }
        }
    }
    fclose($handle);
    return true;
}

/**
 * @return string : browser name
 * @desc return browser description (name) baset on HTTP_USER_AGENT
*/
function cfGetBrowser(){
    if(isset($_ENV['cfGetBrowserResult'])) return $_ENV['cfGetBrowserResult'];

    if(!isset($_SERVER['HTTP_USER_AGENT'])) return false;
    $ua=strtolower($_SERVER['HTTP_USER_AGENT']);

    if(strpos($ua, "opera")!==false) $_ENV['cfGetBrowserResult']='opera';
    elseif(strpos(($ua), "webkit")!==false)  $_ENV['cfGetBrowserResult']='webkit';
    elseif(strpos(($ua), "gecko")!==false) $_ENV['cfGetBrowserResult']='gecko';
    elseif(strpos(($ua), "msie")!==false)  {
    	$v=substr(cfBGetVar('name'),2);
    	// For IE9+, set browser to ie+ to activate css stuff (except in https where it doesn't work so far)
    	$_ENV['cfGetBrowserResult']=($v>8 && !cfIsInApp() && !@$_SERVER['HTTPS'])?'ie+':'ie';
    }
    else $_ENV['cfGetBrowserResult']='other';
    return $_ENV['cfGetBrowserResult'];
}
/**
 * @desc return first language supported by Browser and Weezo
 *
 * @return string : ISO (2 letters) language code
 */
function cfGetBrowserLng(){
    if(!count($l = split(",", $_SERVER['HTTP_ACCEPT_LANGUAGE']))) return 'en';
    foreach ($l as $lng){
        if(file_exists(cfAppDocRoot().'/includes/lng/'.substr($lng,0,2).'.php')) return substr($lng,0,2);
    }
    return 'en';

}

/**
 * @desc Return host OS type ("windows", "osx", "linux")
 * @return string
 */
function cfGetHostOS(){
	static $hostOS=''; if($hostOS) return $hostOS; // Use static cache 1st
	if(cfGGetVar('hostOS')) $hostOS=cfGGetVar('hostOS'); // Guess from value set by app

	// If not set, try to guess from filesystem
	elseif (is_dir('C:/')) $hostOS='windows';
	elseif (is_dir('/Library')) $hostOS='osx';
	else $hostOS='linux';

	return $hostOS;
}

/**
 * @desc Return Host OS version
 *
 * @return string (osx, linux, windows)
 */
function cfGetHostOSVersion(){if(function_exists('customGetOS')) return customGetOS(); else return cfGGetVar('OSFamily');}

/**
 * @return void
 * @desc Add "chrono point"
 * @param string label : label of chrono point
*/
function cfChronoAddPoint($label=false){
    static $lb;
    if(!$label) $label='point:'.@$lb++;
    if(!isset($_ENV['chrono'])) $_ENV['chrono']=array();
    $_ENV['chrono'][count($_ENV['chrono'])]['label']=$label;
    $_ENV['chrono'][count($_ENV['chrono'])-1]['time']=microtime(true);
}
function cfChronoFormat($delta){
    if($delta>1) return (floor(1000*$delta)/1000).'s'; elseif($delta>0.001) return floor($delta*1000).'ms';else return floor($delta*1000000).'&micro;s';
    return $output;
}

/**
 * @desc start ot stop "interval" execution time computing
 *
 * @param srting $label : interval label
 * @param string $action : 's' to indicate than chrono must start at this point, 'e' to indicate than chrono must stop at this point
 */
function cfChronoInt($label,$action){
    if(!isset($_ENV['chronoInt']['int'][$label])) $_ENV['chronoInt']['int'][$label]=array('time'=>0,'nb'=>0);
    if($action=='s') $_ENV['chronoInt']['tmp'][$label]=microtime(true);
    if($action=='e'){
        $_ENV['chronoInt']['int'][$label]['time']+=microtime(true)-$_ENV['chronoInt']['tmp'][$label];
        $_ENV['chronoInt']['int'][$label]['nb']++;
    }
}

/**
 * @desc get a string with execution time between "chrono points" and total time spent into "intervals"
 *
 * @param boolean $total: set to true to return total script execution time
 * @return string : XML JS code or plain text result
 */
function cfChrono($total=false){
    if($total) return (microtime(true)-$_ENV['chrono'][0]['time']);

    cfChronoAddPoint("End");
    $output='';$sum=0;
    foreach ($_ENV['chrono'] as $key=>$value) if(isset($_ENV['chrono'][($key)]['time'])) {
        if($key!=0) $output.=$prevLabel.' <-> '.$value['label'].' : '.cfChronoFormat($_ENV['chrono'][($key)]['time']-$_ENV['chrono'][($key-1)]['time'])."<br>\n";
        $prevLabel=$value['label'];
    }
    $output.=' TOTAL:'.cfChronoFormat($_ENV['chrono'][($key)]['time']-$_ENV['chrono'][0]['time'])."<br>\n\n";
    if(isset($_ENV['chronoInt']['int'])) foreach ($_ENV['chronoInt']['int'] as $key=>$value) $output.='<br>'.$key.': '.$value['nb'].' x '. cfChronoFormat($value['time']/$value['nb']).' = '.cfChronoFormat($value['time']).' / ';

    return $output;
}

/**
 * @desc Check if a process is running
 *
 * @param mixed $processname : exe name of process (including ".exe"), or PID
 * @return mixed PID if named process exists, name if PID exists, else return false
 */
function cfProcessExists($processname){
    if(is_integer($processname)){
        foreach (cfProcList() as $value){if(strtolower(basename($value['pid']))==$processname) return $value['exe'];}
    }
    else{
        $processname=strtolower(str_replace('/','\\',$processname));
        // Search for process with full path name
        if(strpos($processname,'\\')!==false)
            foreach (cfProcList() as $value){if(strtolower($value['exe'])==$processname) return $value['pid'];}
        // Search for process basename only
        else
            foreach (cfProcList() as $value){if(strtolower(basename($value['exe']))==$processname) return $value['pid'];}
    }
    return false;
}

/**
 * @desc check if client is a Wii
 *
 * @return bool result
 */
function cfIsWII(){
    if(isset($_SERVER['HTTP_USER_AGENT']) && stripos($_SERVER['HTTP_USER_AGENT'], "wii")!==false) return true; else return false;
}

/**
 * @desc Return true if mobile device
 *
 * @param $options: 'iPhone' to exclude iPhone/iPod touch, wii to exclude wii
 * @return boolean
 */
function cfIsMobile(){
    $options=cfArrayValuesToKeys(func_get_args());
    if(isset($options['iPhone']) && preg_match('/i[Pp]od|i[Pp]hone/',$_SERVER['HTTP_USER_AGENT'])) return false;
    if(isset($options['wii']) && stripos($_SERVER['HTTP_USER_AGENT'],'wii')) return false;
    if(isset($options[cfBGetVar('name')])) return false;
    if(cfBGetVar('type')=='mobile'||cfGGetVar('forceMobile')||isset($_GET['forceMobile'])) return true;
    return false;
}

/**
 * @desc Tell if this connection processes a resource
 *
 * @return bool: true if resource
 */
function cfIsResource(){return isset($_ENV['isResource']);/* $_ENV set by security.php */}

/**
 * @desc Return true if embeded in application
 *
 * @return boolean
 */
function cfIsInApp($recompute=false){
    static $cache;

    if(!isset($cache)||$recompute){
        $cache=(isset($_ENV['configurationEnvironment']) && $_ENV['configurationEnvironment']=='application') || (cfGGetVar('configurationEnvironment')=='application') || (isset($_GET['weezoKey']) && cfServerKeyCheck($_GET['weezoKey'])) || (isset($_SESSION['weezoKey']) && cfServerKeyCheck($_SESSION['weezoKey']));
    }
    return $cache;
}

/**
 * @desc Return true if CLI
 *
 * @return boolean
 */
function cfIsCLI(){return !isset($_SERVER['SERVER_NAME']);}

/**
 * @desc Return true if UAC is present on host computer (Vista/7)
 *
 */
function cfUACPresent(){
	return (cfGetHostOSVersion()=='OS_WIN32_WINDOWS_VISTA' || cfGetHostOSVersion()=='OS_WIN32_WINDOWS_SEVEN' || WEnv::config()->getVar('OSMajorVersion')>5);
}

/**
 * @desc Return script inclusion code (for a js located in /js dir)
 *
 * @param string $script: script name
 * @return string code
 */
function cfScriptLink($script,$embed=false){
    if($embed||cfBGetVar('inlineJS')) return '<script type="text/javascript">'.file_get_contents(cfAppDocRoot().'/js/'.$script).'</script>'."\n";
    return '<script src="/js/'.$script.'?v='.WHostInfo::appVersion().((cfGGetVar('jsDebug2')?'&rnd='.rand():'')).'" type="text/javascript" language="javascript"></script>'."\n";
}

/**
 * @desc Return lower bitrate
 *
 * @param mixed $br1: 32,64,128,original
 * @param mixed $br2: 32,64,128,original
 * @return mixed
 */
function cfBitrateMin($br1=false,$br2=false){
	if(!in_array($br1,array('32','64','128','original'))) $br1='original';
	if(!in_array($br2,array('32','64','128','original'))) $br2='original';
	if($br1==='original') return $br2;
	if($br2==='original') return $br1;
	return min($br1,$br2);
}

/**
 * @desc use socket to connect, send an HTTP request (using proxy settings) and get result
 *
 * @param mixed $URL: array: parsed URL, or string: plain text URL
 * @param boolean $removeHeader: set to true to remove response's HTTP header, set to false to get full response
 * @param string $error: error description
 * @param array $cleanedURL: parsed & cleaned URL
 * @param integer $maxDataLength: Maximum received data (bytes)
 * @param boolean $handleOnly: if set to true, data will not be read, and connection not closed. Socket handle is returned
 * @param array $sentHeaders: array of headers to send
 *                     (key is name, value is content, if value is array, send multiple headers with same name)
 * @param string $POSTDATA: false for a GET request or encoded POST value for POST requests. Note: Content-Type header must be manualy set
 * @return mixed: string result (or false if invalid url or socket couldn't be opened), or socket handle if $handleOnly is set to true
 */
function cfSocketHTTPRequest($URL, $timeout=7, $removeHeader=true, &$error=false, &$cleanedURL=false, $maxDataLength=false, $handleOnly=false, $sentHeaders=array(), $POSTDATA=false, $downloadCallback=false){
    if(!is_array($URL)) $cnx=@parse_url($URL); else $cnx=$URL;
    if(!isset($cnx['host'])) {
        $error='Invalid URL';
        return false;
    }
    if(!isset($cnx['path'])) $cnx['path']='/';

    // Set port and scheme
    if(!isset($cnx['port']) && isset($cnx['scheme']) && $cnx['scheme']=='https') $cnx['port']=443;
    elseif(!isset($cnx['port'])) $cnx['port']=80;
    if(!isset($cnx['scheme'])){if($cnx['port']==443) $cnx['scheme']='https'; else $cnx['scheme']='http';}
    $cleanedURL=$cnx;

    // Stealth mode: cancel connection
    if($cnx['host']!='localhost' && $cnx['host']!='127.0.0.1' && cfGGetVar('stealth')) return false; // prod

    // Proxy settings
    $auth_string=false;
    if($cnx['host']!='localhost' && $cnx['host']!='127.0.0.1' && substr($cnx['host'],0,7)!='192.168' && substr($cnx['host'],0,3)!='10.' && cfGGetVar('proxyEnabled') && cfGGetVar('proxyIP') && cfGGetVar('proxyPort')) { // prod
        $proxy=true;
        $host=cfGGetVar('proxyIP');
        $port=cfGGetVar('proxyPort');
        if(cfGGetVar('proxyUsername')) $auth_string = "\r\nProxy-authorization: Basic ".base64_encode(cfGGetVar('proxyUsername').':'.cfGGetVar('proxyPassword'));
    }
    else {$proxy=false; $host=$cnx['host']; $port=$cnx['port'];}

    /**
     * Open socket
     */
    if(!($handle=@fsockopen((($cnx['scheme']=='https')?'ssl://':'').$host,$port,$errno,$errstr,$timeout))){$error=$errstr;return false;}

    // Send HTTP request
    $request=(($POSTDATA)?'POST ':'GET ').(($proxy)?$cnx['host'].':'.$cnx['port']:'').$cnx['path'].((isset($cnx['query']))?'?'.$cnx['query']:'')." HTTP/1.0\r\n";
    $request.="Host: ".$cnx['host'].$auth_string."\r\n";
    if(is_array($sentHeaders) && count($sentHeaders)) {
        foreach ($sentHeaders as $key=>$value) if(strtolower($key)!='host') {
            if(is_array($value)) {foreach ($value as $v) $request.=ucfirst($key).': '.$v."\r\n";}
            else $request.=ucfirst($key).': '.$value."\r\n";
        }
    }
    else $request.="User-Agent: Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1)\r\n";

    // POST data
    if($POSTDATA) $request.="\r\n".$POSTDATA;

    /**
     * Send request
     */
    @fwrite($handle, $request."\r\n");

    if($handleOnly) return $handle;

    // Read response
    $data='';$totalSize=false;
    while(!feof($handle) && ((!$maxDataLength) || ($len=strlen($data))<$maxDataLength)) {
        if($downloadCallback) call_user_func($downloadCallback,$len);
        $data.=fread($handle, 8192);
    }
    fclose($handle);

    if($maxDataLength) $data=substr($data,0,$maxDataLength-1);
    if(!$removeHeader) return $data;
    else return substr($data,strpos($data,"\r\n\r\n")+4);
}

/**
 * @desc Send parallel HTTP requests
 *
 * @param mixed $urls: id=>url array or single URL string
 * @param array $extraOptions: request options (see http://php.net/manual/en/function.curl-setopt.php for description)
 * @param array redir: array filled with redirected urls (if CURLOPT_FOLLOWLOCATION and CURLOPT_HEADER set)
 * @return array $id=>$result (or empty array if failed)
 */
function cfCURLMultiRequests($urls, $extraOptions = array(),&$redir=array()) {
    if(!$handle = curl_multi_init()) return array();
    if(!is_array($urls)) $urls=array('singleURL'=>$urls);

    // Default options
    $options=array(CURLOPT_FAILONERROR=>1, CURLOPT_HEADER=>0,CURLOPT_RETURNTRANSFER=>1,CURLOPT_FOLLOWLOCATION=>1,CURLOPT_MAXREDIRS=>3,CURLOPT_FRESH_CONNECT=>1,CURLOPT_TIMEOUT=>7,CURLOPT_SSL_VERIFYHOST => 0,CURLOPT_SSL_VERIFYPEER => false);

    // Proxy settings
    if(cfGGetVar('proxyEnabled')) {
        $options=$options+array(CURLOPT_PROXY=>cfGGetVar('proxyIP'),CURLOPT_PROXYPORT=>cfGGetVar('proxyPort'));
        if(cfGGetVar('proxyUsername')) $options=$options+array(CURLOPT_PROXYUSERPWD=>cfGGetVar('proxyUsername').':'.cfGGetVar('proxyPassword'));
    }
    // Merge with extraOptions
    $options=$extraOptions+$options;
    unset($options['callback']);

    // Add urls
    $requests = array();
    foreach ($urls as $id => $url) {
    	if(!strpos($url,'127.0.0.1') && !strpos($url,'localhost') && cfGGetVar('stealth')){ // prod
    		unset($urls[$id]);
    	}
    	else{
	        $requests[$id] = curl_init($url);
	        curl_setopt_array($requests[$id], $options);
	        curl_multi_add_handle($handle, $requests[$id]);
    	}
    }

    // Retrieve requests
    $start=microtime(true); $nb = count($urls); $cycle=0; while($nb>0) {
        curl_multi_exec($handle,$nb);
        usleep(50000);
        if(isset($extraOptions['callback']) && ++$cycle>20) {
            call_user_func($extraOptions['callback'],$nb,(microtime(true)-$start)/CURLOPT_TIMEOUT);
            $cycle=0;
        }
    }

    // Get results
    $results = array();
    foreach($requests as $id => $response) {
        $results[$id] = curl_multi_getcontent($response);
        curl_multi_remove_handle($handle, $response);
    }
    curl_multi_close($handle);

    // Remove redirection headers
    if($options[CURLOPT_FOLLOWLOCATION] && $options[CURLOPT_HEADER]) foreach ($results as $k=>$v) if($v[9]=="3"){
        cfParseHTTPResponse($v,$status,$body=null,$headers);
        if(isset($headers['location'])) {
            $l=$headers['location'];
            if(substr($l,0,4)=='http') $redir[$k]=$l;
        }
        if(strpos($v,"\r\n\r\n")) $results[$k]=substr($v,strpos($v,"\r\n\r\n")+4);
        elseif(strpos($v,"\n\r\n\r")) $results[$k]=substr($v,strpos($v,"\n\r\n\r")+4);
    }

    // If single URL passed as text string, return as text string
    if(count($urls)==1 && isset($urls['singleURL'])) return $results['singleURL'];
    // else return array of results
    return $results;
}

/**
 * @desc Parse an HTTP response (headers + body)
 *
 * @param string $response: HTTP message
 * @param ingteger $HTTPCode : (return value) HTTP code
 * @param string $body : (return value), set to 'discard' to discard
 * @param array $headers : (return value) lowercased HTTP Headers
 * @return boolean true if message parsed OK, false if not OK
 */
function cfParseHTTPResponse($response, &$statusCode, &$body, &$headers, &$fullStatus=null){
    $headers=array();

    if(strpos($response,"\r\n")) $sep="\r\n";
    elseif(strpos($response,"\n\r")) $sep="\n\r";
    else return false;


    // Get HTTP status code
    $resp=substr($response,0,strpos($response,$sep));
    if($fullStatus!==null) $fullStatus=$resp;
    $resp=explode(' ',$resp,3);
    if(count($resp)<2 || !is_numeric($resp[1])) return false;
    $statusCode=$resp[1];

    // Separate body and headers
    $response=substr($response,strpos($response,$sep)+2);
    $sep.=$sep;

    // Get body
    if($body!=='discard'){
        if(!strpos($response,$sep)) {
            if(!strpos($response,'<')) return false;
            $body=substr($response,strpos($response,'<')+1);
        }
        else $body=substr($response,strpos($response,$sep)+strlen($sep));
    }

    // Parse headers
    $httpHeaders=explode(substr($sep,0,2),substr($response,0,strpos($response,$sep)));
    //for($i=0;$i<strlen($response);$i++) echo ' '.$response[$i].':'.ord($response[$i]);
    foreach ($httpHeaders as $value){
        if(strpos($value,':')) {
            $name=strtolower(substr($value,0,strpos($value,':')));
            // If header is sent multiple times, turn into an array
            if(isset($headers[$name])){
                if(!is_array($headers[$name])) $headers[$name]=array(0=>$headers[$name],1=>trim(substr($value,strpos($value,':')+1)));
                else $headers[$name][]=trim(substr($value,strpos($value,':')+1));
            }
            // Else just create header
            else $headers[$name]=trim(substr($value,strpos($value,':')+1));
        }
    }
    return true;
}

/**
 * @desc check if user uses a Weezo.net account
 * @param string $item: name of registration property to get, false to get all
 * @return mixed : array : registration info if registered, false if not registered
 */
function cfRegistrationData($item=false){
    $regInfo=cfMGetVar('weezoRegInfo');
    if(isset($regInfo['regName']) && (!isset($regInfo['noRegistration']) || !$regInfo['noRegistration'])) return ($item)?@$regInfo[$item]:$regInfo;
    return false;
}

/**
 * Detect browser from user-agent header and store it into weezoBrowser general var
 *
 * @param string $ua: user agent (overrides auto-detection, used for API login)
 * @return string browser's name
 */
function cfSetBrowserCaps($ua=false){
    // Get browsers list
    $browsers=cfMGetVar('weezoBrowsers');

    if($ua){}
    elseif(isset($_GET['HTTP_USER_AGENT'])) $ua=$_GET['HTTP_USER_AGENT']; // Debug
    elseif(isset($_SERVER['HTTP_USER_AGENT'])) $ua=$_SERVER['HTTP_USER_AGENT'];
    else{
        $header=getallheaders();
        if(isset($header['User-Agent']))  $ua=$header['User-Agent']; else $ua='default';
    }


    // Opera mini for iPhone (and maybe other phones): concatenate original phone to user agent
    if(isset($_SERVER['HTTP_X_OPERAMINI_PHONE_UA'])) $ua.=$_SERVER['HTTP_X_OPERAMINI_PHONE_UA'];
	$ua=strtolower($ua);

	$caps=array('name'=>'unknown browser');

    // Skyfire browser: no specific signature in UA
    if(isset($_SERVER['HTTP_X_SKYFIRE_VERSION']) && isset($browsers['Skyfire'])){
        $caps=$browsers['Skyfire'];
        $caps['name']='Skyfire';
    }

    // search for user-agent signature into "known" browsers (Default browser signature is ".")
    else foreach ($browsers as $name=>$caps) {
        if(isset($caps['signature']) && preg_match('/'.strtolower($caps['signature']).'/',$ua)) {
        	// Check this user agent is not explicitly excluded
        	if(!isset($caps['signatureExcluded']) || !preg_match('/'.strtolower($caps['signatureExcluded']).'/',$ua)){
	            // Include name
	            $caps['name']=$name;
	            break;
        	}
        }
    }

    // API connection from unknown client: switch to API browser
    if(defined('API_LOADED') && strtolower($caps['name']=='default')) {
    	$caps=$browsers['API'];
    	$caps['name']='API';
    }

    // Detect browser version
    if (isset($caps['versionMask'])) {
    	if(preg_match_all($caps['versionMask'].'i',$ua,$matches)){
    		$ver=@$matches[1][0];
    		$ver=str_replace('_','.',@$matches[1][0]);
    		while(strlen(str_replace('.','',$ver))<strlen($ver)-1) $ver=substr($ver,0,strrpos($ver,'.')-1).substr($ver,strrpos($ver,'.')); // Keep only one dot
    		$caps['version']=$ver;
    		// And replace version-specific values
    		// 1st search for data that apply to a minimum version or maximum version
    		if (is_numeric($ver) && is_array(@$caps['v'])){
				foreach ($caps['v'] as $version=>$versionData) if(
					(substr($version,-1)=='+' && $caps['version']>=substr($version,0,strlen($version)-1)) ||
					(substr($version,-1)=='-' && $caps['version']<=substr($version,0,strlen($version)-1))){
						foreach ($versionData as $k=>$v) $caps[$k]=$v;
				}
    		}
    		// Then search for data specific to this version
    		if(isset($caps['v'][$caps['version']])){
    			foreach ($caps['v'][$caps['version']] as $k=>$v) $caps[$k]=$v;
    		}
    	}
    }
    // Remove versions-specific info
    unset($caps['v']);

    // Store in general variable
    cfGSetVar('browserCaps',$caps);

    // Apply XHTML theme/scripts if mobile device
    if(@$caps['type']=='mobile' && $caps['theme']==false) cfGSetVar('theme','mobile');

    return $caps['name'];
}

/**
 * @desc display error page
 *
 * @param integer $errorCode : HTTP error code
 */
function cfHTTPError($errorCode){
    require_once(INCLUDE_DIR.'outputFunctions.php');

    switch ($errorCode){
        case 403;
            $message='403 Forbidden';
            break;
        case 404:
        default:
            $message='404 Not Found';
            break;
    }
    header('HTTP/1.1 '.$message,true,$errorCode);

    cfLog($message .' - '.$_SERVER["REQUEST_URI"],LOG_DBG);
    wSession_write_close();
    outDisplayErrorPage('extAccess - '.$message .' - '.$_SERVER["REQUEST_URI"]);
    exit();
}

/**
 * @desc Return path to ffmpeg executable
 *
 * @return string: complete filename
 */
function cfFfmpegExe(){
	$exe=cfAppBinDir().'/'.((cfFfmpegVersion()==='GPL')?'ffmpeg':'ffmpegLGPL').'/weezoFfmpeg';
	if(WEnv::host()->isWindows()) return str_replace('/','\\',$exe).'.exe'; else return str_replace('\\','/',$exe);
}

/**
 * @desc Exec an ffmpeg command line
 *
 * @param string $cl: command line
 */
function cfFfmpegExec($cl){
	cfExecNoFork(cfFfmpegExe(),'SW_HIDE',$cl);
}

/**
 * @desc Return ffmpeg version (GPL or LGPL)
 * @return string: GPL or LGPL
 */
function cfFfmpegVersion(){
	$versionFile=cfAppBinDir().'/ffmpeg/version.txt';
    if(file_exists($versionFile) && file_get_contents($versionFile)>='1.1.2') return 'GPL'; else return 'LGPL';
}

/**
 * @desc Log ffmpeg command lines
 *
 * @param string $cl: ffmpeg command line, with or without the .exe part
 * @param string $action: text string indicating what is being encoded
 */
function cfFfmpegLog($cl,$action=''){
	/*
	if(!cfGGetVar('ffmpegDebug')) return;
	cfAppendTextToFile($action.":\n".$cl."\n",cfAppLogDir().'/ffmpegDebug.txt');
	*/
	// Prepend ffmpeg exe if not set in command line
	if(!cfCmpLeft($cl,'"'.cfFfmpegExe())) $cl='"'.cfFfmpegExe().'" '.$cl;
	file_put_contents(cfAppLogDir().'/ffmpegDebug.txt',$action.":\n".$cl."\n");
}

/*
function cfStreamRegisteredProcessCheck($processExeName,$pid){
	// Retreive list of registered processes for current session
	$registeredProcessList=cfMGetVar('registeredProcessList'.wSession_id());

	// Check if other process with same name are running for this session and for this resource
	if(isset($registeredProcessList[$processExeName][cfRGetVar('id')])){
		foreach ($registeredProcessList[$processExeName][cfRGetVar('id')] as $kpid=>$registeredProcess) {

			// If another process is found, marked for deletion and is old-enough, kill
			if($registeredProcess['status']=='delete' && $registeredProcess['time']<time()-REGISTERED_PROCESS_OVERLAPING_MAX_DURATION){
				unset($registeredProcessList[$processExeName][cfRGetVar('id')][$kpid]);
				@customTerminateProcess($kpid);
				$update=true;
			}
			// Else mark process for deletion (if it's not current process)
			elseif ($registeredProcess['status']!='delete' && $kpid!=$pid){
				$registeredProcessList[$processExeName][cfRGetVar('id')][$kpid]=array('status'=>'delete','time'=>time());
				$update=true;
			}
		}
	}
	if(isset($update)) cfMSetVar('registeredProcessList',$registeredProcessList);
}

function cfStreamRegisteredProcessCreate($processExeName,$pid){
	// Check if other process with same name are running for this session and for this resource. If so, eventually kill them
	cfStreamRegisteredProcessCheck($processExeName,$pid);

	// Retreive list of registered processes for current session
	$registeredProcessList=cfMGetVar('registeredProcessList'.wSession_id());

	// Add process to registered process list for this session & this resource
	$registeredProcessList[$processExeName][cfRGetVar('id')][$pid]=array('status'=>'running','time'=>time());
}
*/

/**
 * Check if mysql is installed
 *
 * @return boolean
 */
function cfMySQLInstalled(){
	require_once(INCLUDE_DIR.'mySQLFunctions.php');
	return (mySQLExe())?true:false;
}

/**
 * @desc check if client IP matches with an masked ip (using wildcard caracters)
 *
 * @param string $maskIP: masked IP
 * @param string $ip: checked IP
 * @return boolean result
 */
function cfIPMatch($maskIP,$ip=false){
    if(!$ip) $ip=$_SERVER['REMOTE_ADDR'];
    $cip=explode('.',$ip);
    $i=0;
    foreach (explode('.',$maskIP) as $byte) {
        if ($byte!='*' && 0+$byte!=0+$cip[$i]) return false;
        $i++;
    }
    return true;
}

/**
 * @desc Verify that remote IP is allowed to log to this account
 *
 * @param array $userData: array of user's properties. If not set, just check general-level rights
 * @param string $ip: checked IP. If not set, use $_SERVER['REMOTE_ADDR']
 * @return boolean: true if allowed
 */
function cfIPFilterCheck($userData=false,$ip=false){
    if($ip===false) $ip=$_SERVER['REMOTE_ADDR'];

    // 1st check against all-users policy
    if(cfGGetVar('IPFilter') && cfGGetVar('IPFilter')!='no'){
        if(cfGGetVar('IPFilter')=='include'){
            if(!($IPFilterIncluded=cfGGetVar('IPFilterIncluded'))) return false;
            $included=false;
            foreach (explode(';',$IPFilterIncluded) as $mip) if(cfIPMatch($mip,$ip)){$included=true;break;}
            if(!$included) return false;
        }
        else{
            if(($IPFilterExcluded=cfGGetVar('IPFilterExcluded'))){
                foreach (explode(';',$IPFilterExcluded) as $mip) if(cfIPMatch($mip,$ip)) return false;
            }
        }
    }
    if(!$userData) return true;

    // Then check user-specific IP policy
    if(isset($userData['IPFilter']) && $userData['IPFilter']!='no'){
        if($userData['IPFilter']=='include'){
            if(!isset($userData['IPFilterIncluded'])) return false;
            foreach (explode(';',$userData['IPFilterIncluded']) as $mip) if(cfIPMatch($mip,$ip)) return true;
            return false;
        }
        else{
            if(!isset($userData['IPFilterExcluded'])) return true;
            foreach (explode(';',$userData['IPFilterExcluded']) as $mip) if(cfIPMatch($mip,$ip)) return false;
            return true;
        }
    }
    return true;
}


/**
 * @desc Return true if an IP filter applies (global-level and user-level if userData is provided)
 *
 * @param array $userData: user config
 * @return boolean
 */
function cfIPFilterIsset($userData=false){
    if(cfGGetVar('IPFilter') && cfGGetVar('IPFilter')!='no') return true;
    if(isset($userData['IPFilter']) && $userData['IPFilter']!='no') return true;
    return false;
}

/**
 * @desc return an array containing session data
 *
 * @param string $sessionData : session serialized data
 * @return array : session data
 */
function cfUnserializeSession($sessionData){
    return unserialize($sessionData);
    $sess=array();
    $data = preg_split('/([A-Za-z_][A-Za-z0-9_]*)\|/',$sessionData,-1, PREG_SPLIT_DELIM_CAPTURE|PREG_SPLIT_NO_EMPTY);
    for ($i=0;$i<count($data)/2;$i++) $sess[$data[$i*2]]=@unserialize($data[$i*2+1]);
    return $sess;
}

/**
 * @desc Log user access to a given file, so it can be monitored by admin
 *
 * @param string $content: name of accessed content (file name, tv channel name...), not UTF8 encoded
 */
function cfLogContentAccess($content){
    if(!cfGGetVar('historyLogViewedContent')) return;
    require_once(INCLUDE_DIR.'databaseFunctions.php');
    dbLogContentAccess($content);
    cfLog(cfUTF8Decode(cfCaption('logFileView',cfUTF8Encode($content),false,false,true)),LOG_DET);
}

/**
 * @desc Return .lnk target
 *         http://www.i2s-lab.com/Papers/The_Windows_Shortcut_File_Format.pdf
 *
 * @param string $linkCompleteFilename: .lnk file
 * @return string: target file
 */
function cfShortcutResolve($linkCompleteFilename){
    if(!($fp=fopen($linkCompleteFilename,'rb'))) return false;
    // Check header
    $str=fread($fp,4);
    if($str!="L\0\0\0") {fclose($fp);return false;}
    fseek($fp,20,SEEK_SET);

    // Get Flags
    $flags=unpack('L',fread($fp,4));
    $flags=str_pad(decbin($flags[1]),'8','0');

    // Has a shell item IDList
    if($flags[0]=='1'){
        fseek($fp,76,SEEK_SET);
        $shellItemIDListLength=unpack('S',fread($fp,2));
        $shellItemIDListLength=$shellItemIDListLength[1];
        $fileLocationInfoPos = 79 + $shellItemIDListLength;
    }
    else $fileLocationInfoPos = 79;
    fseek($fp,$fileLocationInfoPos+15,SEEK_SET);
    $oBasePath=@unpack('L',fread($fp,4));$oBasePath=isset($oBasePath[1])?$oBasePath[1]:'';
    /*
    $oNetwork=unpack('L',fread($fp,4));$oNetwork=$oNetwork[1];
    $oRemaining=unpack('L',fread($fp,4));$oRemaining=$oRemaining[1];
    */
    if($oBasePath){
        fseek($fp,$fileLocationInfoPos+$oBasePath-1,SEEK_SET);
        $shortcut='';
        while(($c=fread($fp,1))!="\0") $shortcut.=$c;
        fclose($fp);
        return str_replace('\\','/',$shortcut);
    }
    // Try something else...
    fseek($fp,101,SEEK_SET);
    $shortcut='';
    while(!feof($fp) && ($c=fread($fp,1))!="\0") $shortcut.=$c;
    fclose($fp);
    if(is_file($shortcut) || is_dir($shortcut)) return str_replace('\\','/',$shortcut);
    return false;
}

/**
 * @desc load RSA keys if needed (i.e. loginKeyLength!=0)
 * @return array including key length, private and public exponents, modulo and maxDigits.
 *             If loginKeyLength is 0, return only keylength
 *             If error reading keypair, return false
 *
 */
function cfRSALoadKeyPair(){
    if(!cfGGetVar('loginKeyLength')) return array('keyLength' => 0);

    $keyFile=cfAppDataDir().'/RSAKey.cnf';

    // Read file
    if(!file_exists($keyFile)){
    	// Try to regenerate now the keys
    	require(cfAppDocRoot().'/local/genRSAKey.php');

    	// If keys could not be generated, abort
    	if(!file_exists($keyFile)){
        	cfLog('login.php: Missing RSAKey.cnf file. Relaunch application to generate file.',LOG_ER);
	        return false;
    	}
    }
    $kp=parse_ini_file($keyFile);
    if(!isset($kp['keyLength']) || !isset($kp['modulo']) || !isset($kp['publicExponent']) || !isset($kp['privateExponent'])){
        cfLog('login.php: corrupted RSAKey.cnf file. Delete file and relaunch application.',LOG_ER);
        return false;
    }
    // Set maxDigits
    if($kp['keyLength']<=128) $kp['maxDigits']=19;
    elseif($kp['keyLength']<=384) $kp['maxDigits']=57;
    elseif($kp['keyLength']<=512) $kp['maxDigits']=76;
    elseif($kp['keyLength']<=1024) $kp['maxDigits']=154;
    else $kp['maxDigits']=308;
    return $kp;
}

/**
 * @desc Decipher JS RSA encoded string (using RSACrypt from BigInt-RSA.js, included by outRSAScripts() function)
 *
 * @param string $ciphered
 * @return string
 */
function cfRSADecrypt($ciphered,&$wasCiphered=null){
    require_once(INCLUDE_DIR.'Crypt/RSA/Math/BCMath.php');
    require_once(INCLUDE_DIR.'Crypt/RSA.php');

    $wasCiphered=false;
    if(!cfCmpLeft($ciphered,'rsa:')) return $ciphered;
    $wasCiphered=true; $ciphered=substr($ciphered,4);

    if(!($RSAKeyPair=cfRSALoadKeyPair())) return false;

    $dec=new Crypt_RSA(null,'BCMath');
    $bcm= new Crypt_RSA_Math_BCMath;

    $decKey = new Crypt_RSA_Key($bcm->int2bin($RSAKeyPair['modulo']),$bcm->int2bin($RSAKeyPair['privateExponent']),'private','BCMath');

    // Decipher returned string
    $plain='';
    foreach (explode(';',$ciphered) as $block) {
        $bytes = split(',', $block);
        $msg = ''; foreach($bytes as $byte) $msg .= chr((int)$byte);
        if(strlen($block)>0) $plain.=($dec->alt_decryptBinary($msg,$decKey));
    }

    return $plain;
}

/**
 * @desc Generate random ID
 *
 * @param integer $lenght
 * @return string
 */
function cfGenerateID($length=16){
    $id='';
    for ($i=0;$i<$length;$i++) {
        $r=rand(0,62);
        if($r>36) $id.=chr($r+60);
        elseif($r>10) $id.=chr($r+54);
        else $id.=$r;
    }
    return $id;
}


/**
 * @desc Manage resource-level variables that will be memorized when user will return.
 * 		 This function must be called on every script exec (not only once at resource init)
 *
 * @param String list of cfRGetVar names, insert 'add' keyword just to add given names to list without commit
 */
function cfSetSavedRVar(){
	$accountType=cfUGetVar('accountType');
    // Only single-user accounts may save session vars
    if(($accountType!='singleUser' && $accountType!='list') || !cfIsResource() /*|| cfIsMobile()???*/) return;

    $rid=cfRGetVar('id');

    if(!isset($_ENV['savedRVars'])) $_ENV['savedRVars']=array();

    // Retrieve function parameters
    $list=array_flip(func_get_args())+$_ENV['savedRVars'];

    // If 'add' keyword, just add to list and exit
    if(isset($list['add'])){
        unset($list['add']);
        $_ENV['savedRVars']=$list;
        return;
    }

    // Retrieve last saved state
    if($accountType=='list')
    	$saved=array($rid=>WEnv::user()->subUser()->getRVar());
    else
		$saved=@unserialize(cfUGetVar('savedRVars'));

    // 1st resource access: restore saved vars
    if(!cfRGetVar('savedRVars')){
        if(isset($saved[$rid]) && is_array($saved[$rid])){
            foreach ($saved[$rid] as $k=>$v) if(isset($list[$k])) cfRSetVar($k,$v);
        }
        cfRSetVar('savedRVars',1);
    }

    // Memorize initial state vars
    if(isset($saved[$rid])) $_ENV['savedRVars']=$saved[$rid]; else $_ENV['savedRVars']=array();
    foreach ($list as $k=>$v) if(!isset($_ENV['savedRVars'][$k])) $_ENV['savedRVars'][$k]=cfRGetVar($k,false,false,null);

    // Register function that will check at end of script wether vars have been changed or not
    wSession_setBeforeWriteClose('cfSetSavedRVarC');
}

/**
 * @desc Save modified savable resource var
 *
 */
function cfSetSavedRVarC(){
    // Search for modified savable vars
    $mod=false;
    foreach ($_ENV['savedRVars'] as $k=>$v) if(($nv=cfRGetVar($k))!=$v) $mod[$k]=$nv;

    // If any var is modified
    if($mod){
    	// SubUser
    	if(cfUGetVar('accountType')=='list'){
    		$saved=WEnv::user()->subUser()->getRVar();
    		if(!is_array($saved)) $saved=array();
    		$saved=$mod+$saved;
    		WEnv::user()->subUser()->updateRVar($saved);
    	}
    	// Single-user group
    	else{
	        $saved=@unserialize(WEnv::user()->getVar('savedRVars'));
	        $saved[cfRGetVar('id')]=$mod+$_ENV['savedRVars'];
	        $saved=serialize($saved);

	        // Update session var (will be commited to file at logout)
	        WEnv::user()->setVar('savedRVars',$saved);
    	}
    }
}

/**
 * @desc Update / save group-level or single-user-level general var
 *
 * @param string $dataName
 * @param mixed $dataValue
 */
function cfSaveUserVar($dataName, $dataValue){
	$accountType=WEnv::user()->getVar('accountType');
	// Save at subUser level
	if($accountType=='list'){
		if(WEnv::user()->subUser()->getGVar($dataName)!=$dataValue) WEnv::user()->subUser()->updateGVar($dataName,$dataValue);
	}
	// Save at group level
	elseif($accountType=='singleUser'){
		if(WEnv::user()->getGVar($dataName)!=$dataValue) WEnv::user()->updateGVar($dataName,$dataValue);
	}
}

/**
 * @desc Crypt password with weezoPwdKey for storage
 *
 * @param string $pwd
 * @return string
 */
function cfStoredPasswordCrypt($pwd){
    $key=substr(cfMGetVar('weezoPwdKey'),0,8);
    $iv =substr(cfMGetVar('weezoPwdKey'),8);
    return base64_encode(@mcrypt_encrypt(MCRYPT_TRIPLEDES,$key,'PWD'.$pwd.chr(0),MCRYPT_MODE_CBC,$iv));
}

/**
 * Decrypt password encrypted by cfStoredPasswordCrypt
 *
 * @param string $pwd
 * @return mixed decrypted password or false if error
 */
function cfStoredPasswordDecrypt($pwd){
    $key=substr(cfMGetVar('weezoPwdKey'),0,8);
    $iv =substr(cfMGetVar('weezoPwdKey'),8);
    $clear=@mcrypt_decrypt(MCRYPT_TRIPLEDES,$key,base64_decode($pwd),MCRYPT_MODE_CBC,$iv);
    if(substr($clear,0,3)!=='PWD') return false;
    return substr($clear,3,strpos($clear,chr(0))-3);
}

/**
 * @desc Check if a password matches with a hashed one (default hash is md5, but hashed password may be prefixed by md5: or sha1:)
 */
function cfHashedPasswordCheck($clear,$hashed){
	// Correct password typed
	if(cfCmpLeft($hashed,'sha1:'))	return sha1($clear)===substr($hashed,5);
	if(cfCmpLeft($hashed,'md5:'))	return md5($clear)===substr($hashed,5);
	return md5($clear)===$hashed;
}

/**
 * @desc Hash a password and indicate hash method into result (to be checked with cfHashedPasswordCheck)
 *
 * @param string $clear: clear password
 * @return string hashmethod:hashed password
 */
function cfHashPassword($clear){
	return 'sha1:'.sha1($clear);
}

/**
 * Return an array of $id=>$WUserConfig, ordered according to general.ini "user" value
 *
 * @return array
 */
function cfUsersConfigs(){
    $r=array();
    $memUsers=cfMGetVar('weezoUsers');
    foreach (explode(',',cfGGetVar('users')) as $filename){
        foreach ($memUsers as $id=>$u) {
            if(isset($u['configFilename']) && $u['configFilename']==$filename){
                $uc=new WUserConfig($id,$u);
                if($uc->isValid()) $r[$id]=$uc;
            }
        }
    }
    return $r;
}

/**
 * @desc Return Content Delivery Network prefix URL, or '' if none set.
 *          This URL must be prefixed before content (gfx and css)
 *          CDN must be enabled in advanced config.
 *          CDN is disabled for localhost and for in-app
 *
 * @return string
 */
function cfCDNPrefix(){
    static $CDN=-1;

    // Use Content Delivery Network
    if($CDN===-1) $CDN=(cfGGetVar('CDN') && cfGGetVar('useCDN')/* && !cfIsInApp() && $_SERVER['REMOTE_ADDR']!=='127.0.0.1'*/ && !isset($_GET['noCDN']))?cfGGetVar('CDN'):'';
    return $CDN;
}

/**
 * @desc bas64-url encode string
 *
 * @param string $data
 * @return string
 */
function cfBase64_url_encode($data){return strtr(base64_encode($data), '+/=', '-_,');}

/**
 * @desc bas64-url decode string
 *
 * @param string $data
 * @return string
 */
function cfBase64_url_decode($data){return base64_decode(strtr($data, '-_,', '+/='));}


/**
 * @desc list data on system processes (win32_ps_list_procs wrapper)
 *
 * @return array
 */
function cfProcList(){
	if(function_exists('win32_ps_list_procs')) return @win32_ps_list_procs();
	$raw=shell_exec('ps -A --no-headers -o pid,ppid,cutime,cstime,size,comm,cmd');
	$proc=array();
	foreach (explode("\n",$raw) as $line){
		// Remove consecutive spaces
		$line=trim($line);
		$l=strlen($line);
		$newLine="";
		$sp=0;
		for($i=0;$i<$l;$i++){
			if(($c=substr($line,$i,1))==' '){
				if(!$sp) $newLine.=$c;
				$sp=1;
			}
			else {
				$newLine.=$c;
				$sp=0;
			}
		}
		// Parse
		@list($pid,$parentPid,$userTime,$kernelTime,$workingSet,$exe,$cmd)=explode(' ',$newLine,7);
		if(@$cmd){
			$exe=substr($cmd,0,strpos($cmd,$exe)).$exe; // Get path & file name, without command line
			if(substr($exe,0,1)=='[') $exe=substr($exe,1);
			if($kernelTime==='-') $kernelTime=0;
			if($userTime==='-') $userTime=0;
			$proc[]=array(
				'exe'=>$exe,
				'pid'=>$pid,
				'parentPid'=>$parentPid,
				'stat'=>array(	'tms'=>array('kernel'=>$kernelTime,'user'=>$userTime),
								'mem'=>$workingSet)
			);
		}
	}
	return $proc;
}


/**
 * @desc Return an array of pid=>parentPID:childExeName
 *
 * @return array
 */
function cfProcParentPID(){
	if(function_exists('customParentPIDs')) return customParentPIDs();
	foreach (cfProcList() as $proc){
		$array[$proc['pid']]=$proc['parentPid'].':'.$proc['exe'];
	}
}

/**
 * @desc kill a process by PID
 *
 * @param integer $pid
 * @return bool result
 */
function cfTerminateProcess($pid,$killSubprocesses=false){
	if(function_exists('customTerminateProcess')) return customTerminateProcess($pid,$killSubprocesses);
	$ret=shell_exec('kill -9 '.$pid);
	return true;
}

/**
 * @desc Useless wrapper for gethostbyname
 *
 * @param string $hostName
 * @return string
 */
function cfGethostbyname($hostName){
	if(cfGGetVar('stealth')) return false;
	return gethostbyname($hostName);
}

/**
 * @desc Return true if passed string has a short link format
 *
 * @param string $string
 */
function cfMightBeShortLink($string){
	return (preg_match('/^[a-z0-9]+$/i',$string));
}

/**
 * @desc Return true if short links are enabled
 *
 * @return bool
 */
function cfShortLinkEnabled(){
	return is_numeric(cfGGetVar('directLinkLength')) && cfGGetVar('directLinkLength')>2;
}


/**
 * @desc Global env class (in construction)
 *
 */
Class WEnv {
    static private $config; // Global session environment (general vars)
    static private $user; // Connected user
    static private $res; // Active linked resource
    static private $userConfigs; // Array of users configurations
    static private $resConfigs; // Array of resources configurations
    static private $usersLogged; // Array of logged users
    static private $resLinkedArray; // Array of linked resources
    static private $session; // Current session data
    static private $host; // Info on host (OS, exe version...)

    private function __construct() {}

    /**
     * @desc Current general config
     *
     * @return WConfig
     */
    static function config() {
        if (empty(self::$config))    self::$config = new WConfig();
        return self::$config;
    }

    /**
     * @desc Current session vars
     *
     * @return WSession
     */
    static function session() {
        if (empty(self::$session))    self::$session = new WSession();
        return self::$session;
    }

    /**
     * @desc Return host information object
     *
     * @return WHostInfo
     */
    static function host() {
        if(isset(self::$host)) return self::$host;
        self::$host=new WHostInfo();
        return self::$host;
    }

    /**
     * @desc Return true if connection uses SSL
     *
     * @return bool
     */
    static function SSL(){
    	return isset($_SERVER['HTTPS']);
    }

    /**
     * @desc Connected user object
     *
     * @return WUser
     */
    static function user() {
        if (empty(self::$user)) self::$user = new WUser();
        return self::$user;
    }

    /**
     * @desc Current resource object
     *
     * @return WResLinked
     */
    static function res($dataName=false) {
        if(!empty(self::$res)) return ($dataName)?self::$res->getVar($dataName):self::$res;

        // If not in app or not logged user, exit
        if(!cfIsInApp() && !WEnv::user()->isValid()) return false;
        if(isset($_SESSION['activeResourceId']))
            self::$res = new WResLinked($_SESSION['res'][$_SESSION['activeResourceId']]['id']);
        elseif(isset($_ENV['weezoSession']['activeResourceId']))
            self::$res = new WResLinked($_ENV['weezoSession']['res'][$_ENV['weezoSession']['activeResourceId']]['id']);
        else return false;
        return ($dataName)?self::$res->getVar($dataName):self::$res;
    }

    /**
     * @desc Return a resource linked to logged user
     *
     * @return WResLinked
     */
    static function resLinked($id) {
        if(isset(self::$resLinkedArray[$id])) return self::$resLinkedArray[$id];
        self::$resLinkedArray[$id]=new WResLinked($id);
        return self::$resLinkedArray[$id];
    }

    /**
     * @desc return an array of $id=>WConfig of all created resources
     *
     * @return WResConfig array
     */
    static function resConfigs(){
        if (empty(self::$resConfigs))    {
            self::$resConfigs = array();
            foreach (cfMGetVar('weezoResourcesList') as $id=>$res) self::$resConfigs[$id]=new WResConfig($id);
        }
        return self::$resConfigs;
    }

    /**
     * @desc return an array of $id=>WUserConfig of all created users (except invisible users), or given user config if id passed
     * @param $userId (optional): id or config filename of user
     * @return WUserConfig
     */
    static function userConfigs($userId=false){
        if (empty(self::$userConfigs))    {
            self::$userConfigs = array();
            foreach (explode(',',cfGGetVar('users')) as $filename){
	            foreach (cfMGetVar('weezoUsers') as $id=>$usr) if(!@$usr['invisible']){
	            	if(isset($usr['configFilename']) && $usr['configFilename']==$filename){
	                	self::$userConfigs[$id]=new WUserConfig($id);
	            	}
	            }
            }
        }
        // Single user requested
        if($userId) {
            // Filename
            if(strpos($userId,'.')){
                foreach (self::$userConfigs as $id=>$user) if($user->filename()==$userId) return $user;
            }
            // Id
            return (isset(self::$userConfigs[$userId]))?self::$userConfigs[$userId]:null;
        }
        // Users list
        return self::$userConfigs;
    }

    /**
     * @desc return an array of $session_id=>$user_config_id of all logged users (except invisible users)
     *
     * @return WUsersLoggedList
     */
    static function usersLogged(){
        if (empty(self::$userLogged))    {
            self::$usersLogged = new WUsersLoggedList();
            /*
            foreach (cfGlob(cfAppDataDir().'/sessiondata/sess_*') as $cfn){
                // Remove application session
                if(cfCmpLeft(basename($cfn),'sess_UI')) continue;
                $usr=@unserialize(file_get_contents($cfn));
                if(@$usr['user']['id'] && $usr['user']['id']!=='standalone') self::$usersLogged[basename($cfn)]=$usr['user']['id'];
            }
			*/
        }
        return self::$usersLogged;
    }
}



/**
 * @desc List of logged users
 *
 */
class WUsersLoggedList{
	private $usersLogged;
	public $lastUpdate; // Time or last major update (user logged in or out)
	public $lastPingUpdate; // Time of last update due to a ping

	/**
	 * Build users list from saved MVar
	 *
	 */
	function __construct(){
		@list($this->usersLogged,$this->lastUpdate,$this->lastPingUpdate)=cfMGetVar('usersLoggedList');

		if(!is_array($this->usersLogged)) $this->usersLogged=array();
	}

	/**
	 * @desc Reload data from memory (used by long-time running daemon(s))
	 *
	 */
	function refresh(){$this->__construct();}

	/**
	 * @desc Rebuild logged users list from saved state in case of server failure
	 *
	 */
	public function rebuild(){
		$sessSavePath=cfAppDataDir().'/sessiondata/';

		// Restore config from file
		if(is_file($this->backupFile())){
			list($this->usersLogged,$this->lastUpdate,$this->lastPingUpdate)=@unserialize(file_get_contents($this->backupFile()));
		}
		// If no file or invalid content, reset values
		if(!is_numeric($this->lastPingUpdate) || !is_numeric($this->lastUpdate) || !is_array($this->usersLogged)){
			$this->lastPingUpdate=$this->lastUpdate=time();
			$this->usersLogged=array();
		}
		// Reset pings to current time to prevent disconnection (as pings are not saved to file to save disk access)
		else foreach ($this->usersLogged as $sessId=>$loggedUser) {
			// Check session file is still here, and if not, dump this one
			if (is_file($sessSavePath.'sess_'.$sessId)) $this->usersLogged[$sessId]->ping();
			else unset($this->usersLogged[$sessId]);
		}

		// Save to memory
		cfMSetVar('usersLoggedList',array(($this->usersLogged),$this->lastUpdate,$this->lastPingUpdate));
	}

	/**
	 * @desc Return filename of file used to backup current users list state in case of server failure
	 *
	 * @return string
	 */
	public function backupFile(){return cfAppTempDir().'/usersLoggedList';}

	/**
	 * @desc add current user to list, based on session data
	 *
	 * @return WUserLogged simplified user;
	 */
	public function addCurrentUser(){
		if(!wSession_id()) return false;
		// Add user
		$this->usersLogged[wSession_id()]=new WUserLogged();

		// Commit to memory and to backup file
		$this->lastUpdate=time();
		cfMSetVar('usersLoggedList',array(($this->usersLogged),$this->lastUpdate,$this->lastPingUpdate));
		file_put_contents($this->backupFile(),serialize(array($this->usersLogged,$this->lastUpdate,$this->lastPingUpdate)));
	}

	/**
	 * @desc Set current user as disconnected
	 *
	 */
	public function disconnectCurrentUser(){$this->disconnectUser(wSession_id());}

	/**
	 * @desc Disconnect a logged user
	 *
	 * @param string $sessionId: session id of user to disconnect, empty for currently logged user
	 * @param boolean $removeSessionFile: set to true to also (try to) delete session file. Usefull to timeout-logout an user
	 */
	public function disconnectUser($sessionId){
		if(!isset($this->usersLogged[$sessionId])) return ;

		// Do all the cleanup
		$this->usersLogged[$sessionId]->logout();

		// Remove from connected users list
		unset($this->usersLogged[$sessionId]);

		// Commit to memory and to backup file
		$this->lastUpdate=time();
		cfMSetVar('usersLoggedList',array(($this->usersLogged),$this->lastUpdate,$this->lastPingUpdate));
		file_put_contents($this->backupFile(),serialize(array($this->usersLogged,$this->lastUpdate,$this->lastPingUpdate)));
	}

	/**
	 * @desc Memorize user ping
	 *
	 * @param string $sessionId: session id of user to disconnect, empty for currently logged user
	 * @param integer $newDisconnectionInterval
	 * @return true if user exists
	 */
	public function pingUser($sessionId=false,$newDisconnectionInterval=0){
		if(!$sessionId) $sessionId=wSession_id();
		if(!isset($this->usersLogged[$sessionId])) return false;
		$this->usersLogged[$sessionId]->ping($newDisconnectionInterval);

		// Commit to memory
		$this->lastPingUpdate=time();
		cfMSetVar('usersLoggedList',array(($this->usersLogged),$this->lastUpdate,$this->lastPingUpdate));
		return true;
	}

	/**
	 * @desc Return complete list
	 *
	 * @return WUserLogged array;
	 */
	public function getUsers($removeInvisible=false){
		if(!$removeInvisible) return $this->usersLogged;
		$ret=array();
		foreach ($this->usersLogged as $sessId=>$userLogged) if(!$userLogged->invisible) $ret[$sessId]=$userLogged;
		return $ret;
	}

	/**
	 * @desc Return user based on session Id
	 *
	 * @param string $sessionId
	 * @return WUserLogged
	 */
	public function getUser($sessionId){return @$this->usersLogged[$sessionId];}

	/**
	 * @desc Return number of connected users
	 *
	 * @return integer
	 */
	public function nb(){
		$nb=0;
		foreach ($this->usersLogged as $sid=>$wul) if(!$wul->invisible) $nb++;
		return $nb;
	}
}

/**
 * @desc Simplified info on a connected user (name, pseudo, session ID, IP, connection time, browser...)
 *
 */
class WUserLogged{
	public $sessionId;
	public $connectionTime;	// Timestamp of connection
	public $lastPingTime;	// Timestamp of last user ping
	public $groupId;
	public $groupName;
	public $pseudo;
	public $subUserId;		// Id of subUser (for list type groups)
	public $icon;			// User's icon
	public $browserName;	// Browser's name (see /bin/browsers.txt) for list
	public $dbId=0;			// SQlite Row ID of activity logging (only set if user activity is logged)
	public $ip;				// IP address
	public $type='user';	// 'user' or 'standalone'
	public $invisible;		// true if type is 'standalone'
	public $administrator;	// true if user is administrator
	public $timeout;		// max alive time without timeout
	public $hasChat;		// false if user doesn't have chat resources, comma separated list of chat_resource_id/char_resource_filename if user has chat(s)
	public $hasWebcam;		// true of false depending on wether user needs webcam or not
	public $range;			// 'localhost', 'lan', 'web' // prod

	/**
	 * @desc Add current user to list, based on session data
	 *
	 */
	function __construct(){
		$user=new WUser();
		$this->connectionTime=$this->lastPingTime=time();
		$this->sessionId=wSession_id();
		$this->groupId=$user->id();
		$this->groupName=$user->getVar('name');
		$this->pseudo=$user->getVar('pseudo');
		$this->subUserId=$user->getVar('subUserId');
		$this->icon=$user->getVar('icon');
		$this->browserName=cfBGetVar('name');
		$this->dbId=cfGGetVar('dbId');
		$this->ip=$_SESSION['accountIP'];
		if($this->groupId==='standalone'){
			$this->type='standalone';
			$this->invisible=true;
		}
		else{
			$this->type='user';
			$this->invisible=false;
		}
		$this->administrator=$user->isAdministrator();

		// Check resources for chat and webcam resources
		$this->hasChat=''; $this->hasWebcam=false;
		foreach ($user->getResources() as $rid=>$rfilename){
			if($res=cfMGetVar('weezoResData'.$rid)){
				if($res['type']=='webcam' && $res['subType']=='chat') $this->hasChat.=(($this->hasChat)?',':'').$rid.'/'.	$rfilename;
				if($res['type']=='webcam' && $res['subType']=='std') $this->hasWebcam=true;
			}
		}
		// Timeout detection length
		$this->timeout=cfGGetVar('inactivityTimeBeforeDisconnect');

		// Increase for mobiles
		if(cfIsMobile('iPhone')) $this->timeout*=3;
		elseif($this->type=='standalone') {
			$res=@$_SESSION['res'][0];
			// Increase timeout detection margin for non-server-pinging external resources
			if(@$res['type']=='misc' || (@$res['type']=='website' && @$res['subType']=='html')) $this->timeout*=3;
			// and decrease it for other published resources
			else $this->timeout=ceil($this->timeout/2);
		}

		// Client location (localhost, web,
		if($_SERVER['REMOTE_ADDR']=='127.0.0.1') $this->range='localhost'; // prod
		elseif(cfIsOnLAN()) $this->range='lan';
		else $this->range='web';
	}

	/**
	 * @desc Logout user and do all the cleaning stuff. WARNING: this function should only be called through WUsersLoggedList::disconnectUser
	 *
	 */
	function logout(){
		// Log disconnection
		cfLog(cfCaption('logUserLogout',false,false,false,true).' ('.cfUTF8Encode($this->groupName.')'.(($this->pseudo)?' - '.$this->pseudo:'')),LOG_INF,'usr');

		// Delete session file
		wSession_destroy($this->sessionId);

		// Delete in-memory variables
		foreach ($vars=cfMGetVarList() as $varName=>$vN) if(cfCmpLeft($varName,'SR.'.$this->sessionId)) cfMUnsetVar($varName);
		if(function_exists('xcache_unset_by_prefix')) xcache_unset_by_prefix('SR.'.$this->sessionId);

		// Log disconnection into stats database
		if($this->dbId) {
			require_once(INCLUDE_DIR.'databaseFunctions.php');
			dbLogDisconnection($this->dbId);
		}

		// Log it as event
		if(!$this->invisible) cfLogEvent(cfCaption('logUserLogout',false,false,false,true).' ('.cfUTF8Encode($this->groupName).')',EVENT_CONNECTION,S_EVENT_LOGOUT);

		// destroy session directory
		if(cfAppUserTempDir(false,$this->sessionId)) cfUnlinkDir(cfAppUserTempDir(false,$this->sessionId));

		// Inform application that user has logged out
		cfServerSendCmd('disconnect',array('disconnectSessionId'=>$this->sessionId,'id'=>$this->config()->id(),'name'=>str_replace('"','',$this->groupName),'icon'=>$this->config()->getVar('icon')));

		// remove access to doc root subdirs (deprecated, I think...)
		// cfHtaccessGrant(false,'remove');
	}

	/**
	 * Cast to string
	 *
	 * @return string
	 */
	function __toString(){
		$s='';
		foreach($this as $k=>$v) $s.=$k.'='.(($v===true||$v===false)?(($v)?'TRUE':'FALSE'):$v)."\n";
		return $s;
	}

	/**
	 * @desc Memorize user ping
	 * @param integer $updatedTimeout: if !=0,  new timeout length in seconds
	 *
	 */
	function ping($updatedTimeout=0){
		// Update timeout length
		if(is_numeric($updatedTimeout) && $updatedTimeout>0) $this->timeout=$updatedTimeout;
		$this->lastPingTime=time();
	}

	/**
	 * @desc Return true if user should be disconnected because of timeout
	 *
	 * @return boolean
	 */
	function isTimedOut(){if(time()-$this->lastPingTime>$this->timeout) return true; else return false;}

	/**
	 * @desc Return true if user should be disconnected because of timeout
	 *
	 * @return boolean
	 */
	function timeBeforeDisconnect(){return $this->timeout-time()+$this->lastPingTime;}

	/**
	 * @desc Return logged user's config
	 *
	 * @return WUserConfig
	 */
	function config(){return new WUserConfig($this->groupId);}
}

/**
 * @desc Display information about host
 *
 */
class WHostInfo{
	function osFamily(){return WEnv::config()->getVar('OSFamily');}
	function isWindows(){return WEnv::config()->getVar('OSFamily')=='windows';}
	function isLinux(){return WEnv::config()->getVar('OSFamily')=='linux';}
	function isOSX(){return WEnv::config()->getVar('OSFamily')=='osx';}
	// Return true if executable is built on Qt, false if built on VB
	function isQt(){return WEnv::config()->getVar('appType')=='Qt';}
	// Return LAN IP
	function lanIP(){
		$ip=WEnv::config()->getVar('LANIPForced');
		if(!$ip) $ip=WEnv::config()->getVar('LANIPComputed');

		return $ip;
	}
	// Return External IP
	function externalIP(){return WEnv::config()->getVar('externalIP');}

	// Return application (weezo) version
	static function appVersion(){return cfGGetVar('appVersion');}

	// Return host OS architecture (32 or 64, or empty for windows)
	static function osArch(){return cfGGetVar('arch');}

	// Return apache version
	static function apacheVersion(){
		foreach (apache_get_modules() as $moduleName) if($moduleName=='mod_access_compat') return 2.4;
		return 2.2;
	}

	// Return true if host OS support feature. See bin/default/osFeatures for disabled features list
	function hasFeature($featureName){return (cfArrayItem(cfMGetVar('osDisabledFeatures'),$featureName))?false:true;	}
	function disabledFeatures(){return cfMGetVar('osDisabledFeatures');}

	/**
	 * @desc Return true if resource is not supported on this OS
	 * @param string $type: resource type
	 * @param string $subType: resource sub-type
	 * @return bool
	 */
	function disabledResource($type,$subType){
		$res=cfMGetVar('osDisabledFeatures');
		return isset($res['res'][$type][$subType]);
	}

	/**
	 * Return path to user's home/documents/music/pictures/video/favorites folder
	 */
	function specialFolderHome(){return cfGGetVar('specialFolderHome');}
	function specialFolderDocuments(){return cfGGetVar('specialFolderHome').'/Documents';}
	function specialFolderMusic(){return cfGGetVar('specialFolderHome').'/Music';}
	function specialFolderPictures(){return cfGGetVar('specialFolderHome').'/Pictures';}
	function specialFolderVideos(){return cfGGetVar('specialFolderHome').'/Videos';}
	function specialFolderFavorites(){return cfGGetVar('specialFolderHome').'/Favorites';}
}


/**
 * General configuration
 *
 */
class WConfig{
    function __construct(){}

    /**
     * @desc Retreive config var
     *
     * @param string $dataName
     * @param mixed $dataValue
     * @param mixed $notFound: value returned if not found
     * @return mixed
     */
    function getVar($dataName=false,$subDataName=false,$notFound=false){
        if(!$dataName) return (array)@$_ENV['weezoGeneral']+(array)@$_SESSION['weezoGeneral'];
        if    ($subDataName===false && isset($_SESSION['weezoGeneral'][$dataName])) $data=$_SESSION['weezoGeneral'][$dataName];
        elseif($subDataName!==false && isset($_SESSION['weezoGeneral'][$dataName][$subDataName])) $data=$_SESSION['weezoGeneral'][$dataName][$subDataName];
        elseif($subDataName===false && isset($_ENV['weezoGeneral'][$dataName])) $data=$_ENV['weezoGeneral'][$dataName];
        elseif($subDataName!==false && isset($_ENV['weezoGeneral'][$dataName][$subDataName])) $data=$_ENV['weezoGeneral'][$dataName][$subDataName];
        else return $notFound;
        if(!is_array($data) && strtolower($data)=='false') return false;
        if(!is_array($data) && strtolower($data)=='true') return true;
        return $data;
    }

    /**
     * @desc Set/update config var for current session
     *
     * @param string $dataName
     * @param mixed $dataValue
     */
    function setVar($dataName,$dataValue){cfGSetVar($dataName,$dataValue);}

    /**
     * @desc Update/Save config var to general.ini file, and update all necessary stuff
     *
     * @param string $dataName
     * @param mixed $dataValue
     */
    function updateVar($dataName,$dataValue,$immediateCommit=true){cfGUpdateVar($dataName,$dataValue,$immediateCommit);}

    /**
     * @desc Unset config var
     *
     * @param string $dataName: name of data to unset
     */
    function unsetVar($dataName){cfGUnsetVar($dataName);}


    /**
     * @desc Return 16x16 icon URI
     *
     * @return string: path to icon from document root
     */
    function icon16(){return $this->getVar('resourceIconSmall');}

    /**
     * @desc Return 16x16 icon URI
     *
     * @return string: path to icon from document root
     */
    function icon32(){return $this->getVar('resourceIcon');}
}

/**
 * @desc Session wrapper. Used to simply access session var, from plugins or genuine weezo scripts. Do not use if perf needed
 *
 */
class WSession{
    protected $useEnv=false; // True to use $_ENV['weezoSession'], false to use $_SESSION
    function __construct(){
        if(isset($_ENV['weezoSession'])) $this->useEnv=true;
    }

    /**
     * @desc Get a session var
     *
     * @param string $dataName
     * @param string $subDataName
     * @param string $subSubDataName
     * @return mixed
     */
    function getVar($dataName,$subDataName=null,$subSubDataName=null){
        if($this->useEnv){
            if(!isset($subDataName)) return @$_ENV['weezoSession'][$dataName];
            if(!isset($subSubDataName)) return @$_ENV['weezoSession'][$dataName][$subDataName];
            return @$_ENV['weezoSession'][$dataName][$subDataName][$subSubDataName];
        }
        if(!isset($subDataName)) return @$_SESSION[$dataName];
        if(!isset($subSubDataName)) return @$_SESSION[$dataName][$subDataName];
        return @$_SESSION[$dataName][$subDataName][$subSubDataName];
    }
}

/**
 * @desc User configuration class
 *
 */
class WUserConfig{
    protected $id=0;
    protected $filename;
    public $data;
    protected $modifiedData=false;
    protected $modifiedName=false;
    protected $modifiedResources=false; // True if resource(s) added/removed
    protected $new=false; // True if newly created user
    protected $valid=false; // True if user successfully loaded
    protected $invisible=false; // True if user is not a regular logged user (UI, standalone)

    /**
     * @desc Constructor
     *
     * @param string $id: user unique ID or config filename, or false to create new user
     */
    function __construct($id=false,$data=false){
        if($id==='standalone'){
            $this->id='standalone';
            $this->valid=true;
            $this->invisible=true;
            return;
        }
        if($id&&$data) {
            if(!isset($data['configFilename'])) return;
            $this->id=$id;
            $this->filename=$data['configFilename'];
            $this->data=$data;
            $this->valid=true;
            return true;
        }

        $users=cfMGetVar('weezoUsers');

        // Filename passed
        if($id && strpos($id,'.usr')) {
            $this->filename=$id;
            foreach ($users as $uid=>$user) if(isset($user['configFilename']) && $user['configFilename']==$this->filename){
                $this->id=$uid;
                break;
            }
            if(!$this->id) return;
        }
        // Id passed
        elseif ($id){
            if(!isset($users[$id])) return;
            $this->id=$id;
            $this->filename=@$users[$id]['configFilename'];
        }
        // Nothing passed: user creation
        else{
            // Gen ID
            $this->id=cfGenerateID(10);

            // Filename
            $i=0;while(file_exists(cfAppDataDir().'/groups/account'.$i.'.usr')) $i++;
            $this->filename='account'.$i.'.usr';

            // Name
            $this->setVar('name',cfUTF8Decode(cfCaption('userDefaultName')));

            // Other values
            $this->setVar('icon','default.jpg');
            $this->setVar('authenticationMethod','noAuthentication');
            $this->setVar('administrator',false);
            $this->setVar('hidden',false);
            $this->setVar('accountType','anonymous');
            $this->setVar('audioProfile','noSound');
            $this->setVar('sNotes',1);
            $this->setVar('configFilename',$this->filename);
            $this->setVar('activated',true);
            $this->setVar('id',$this->id);
            $this->modifiedName=true;
            $this->modifiedData=true;
            $this->new=1;
            $this->valid=true;

            return;
        }
        $this->data=$users[$this->id];
        $this->valid=true;
    }

    /**
     * @desc User unique ID
     *
     * @return string
     */
    function id(){return $this->id;}

    /**
     * @desc Return user config file name (without path)
     *
     * @return string
     */
    function filename(){return $this->filename;}

    /**
     * @desc Return true if user config exists
     *
     * @return bool
     */
    function isValid(){return $this->valid;}


    /**
     * @desc Set default data for a newly created user, from /bin/default/user.ini file
     *
     */
    function setDefaultData(){
    	if($dud=@cfParse_ini_file(cfAppBinDir().'/default/user.ini'))
    		foreach ($dud as $k=>$v) $this->data[$k]=$v;
    }

    /**
     * Get all configuration data
     *
     * @return array: user configuration data
     */
    function getData(){return $this->data;}

    /**
     * @desc Get a var
     *
     * @param string $dataName
     * @return mixed
     */
    function getVar($dataName){return @$this->data[$dataName];}

    /**
     * @desc Set/update a var. Must use save() to commit to file/memory
     *
     * @param string $dataName
     * @param mixed $value
     */
    function setVar($dataName,$value){
        if(!isset($this->data[$dataName]) || $this->data[$dataName]!=$value) {
            $this->modifiedData=true;
            if($dataName=='name') $this->modifiedName=true;
        }
        $this->data[$dataName]=$value;
    }

	/**
	 * @desc Get general-level group configuration data (client-side saved data)
	 *
	 * @param string $dataName
	 * @return mixed
	 */
	function getGVar($dataName=false){
		if(!$dataName) return @unserialize($this->getVar('savedGVars'));
		return cfArrayItem(@unserialize($this->getVar('savedGVars')),$dataName);
	}

	/**
	 * @desc Update and save general-level user configuration data
	 *
	 * @param string $dataName
	 * @param string $dataValue: new value
	 */
	function updateGVar($dataName, $dataValue){
		$gData=@unserialize($this->getVar('savedGVars'));
		if(!is_array($gData)) $gData=array();
		$gData[$dataName]=$dataValue;
		$this->setVar('savedGVars',serialize($gData));
		$this->saveVar('savedGVars',true);
	}


    /**
     * Doesn't work, and actually unused
     */
    function getDefinition($dataName=false){
        if(!$dataName) return @$this->data['definition'];
        return @$this->data['definition'][$dataName];
    }

    /**
     * @desc Return true if use is invisible (technical account)
     *
     * @return bool
     */
    function isInvisible(){return @$this->data['invisible'];}

    /**
     * @desc Return true if user is administrator
     *
     * @return bool
     */
    function isAdministrator(){return @$this->data['administrator'];}

    /**
     * @desc Return path to icon
     *
     * @return bool
     */
    function iconPath(){return '/gfx/icons/'.$this->data['icon'];}

    /**
     * @desc Return path to an icon for account type
     *
     * @return bool
     */
    function altIconPath(){
    	if($this->isAdministrator()) return outIcon('users/admin');
    	else return outIcon('users/'.$this->getVar('accountType'));
    }

    /**
     * @desc Return array of id=>subUser name
     *
     * @return array
     */
    function getSubUsers(){
    	$subUsers=array();

    	foreach ($this->getSubUserNames() as $id=>$name){
    		if(cfMIssetVar('subUser'.$id)) $subUsers[$id]=new WSubUser($id);
    	}
    	return $subUsers;
    }
    /**
     * @desc Return array of id=>subUser name
     *
     * @return array
     */
    function getSubUserNames(){
    	if($this->data['accountType']!='list') return array();
    	if(!@$this->data['subUsers']) return array();
    	return unserialize($this->data['subUsers']);
    }

    /**
     * @desc Return array of id=>subUser name
     *
     * @return array
     */
    function createSubUser($name,$password){
		$subUsers=$this->getSubUserNames();

		// Generate subUser file
		while (file_exists(cfAppDataDir().'/users/'.($id=cfGenerateID(11)).'.subuser')) {}
		$data['password']=(($password)?sha1($password):'');
		$data['name']=$name;
		cfWriteIniFile($data,cfAppDataDir().'/users/'.$id.'.subuser',false);

		// Add to group's subUsers list
		$subUsers[$id]=$name;
		$this->setVar('subUsers',serialize($subUsers));
		$this->save();

		// Cache subUser into memory
		cfMSetVar('subUser'.$id,$data);
    }

    /**
     * @desc Return array of id=>subUser name
     */
    function deleteSubUser($subUserId){
    	// Update group data
		$subUsers=$this->getSubUserNames();
		if(!isset($subUsers[$subUserId])) return false;
		unset($subUsers[$subUserId]);
		$this->setVar('subUsers',serialize($subUsers));
		$this->save();

		// Remove subUser settings file
		if(file_exists(cfAppDataDir().'/users/'.$subUserId.'.subuser')) @unlink(cfAppDataDir().'/users/'.$subUserId.'.subuser');
		// Erase from memory cache
		cfMUnsetVar('subUser'.$subUserId);
    }

    /**
     * @desc Return an array of id=>resourceFilename or $id=>WResConfig
     *
     * @param bool: $returnObjects: true to return WResConfig instead of filenames
     * @return array
     */
    function getResources($returnObjects=false){
        $ret=array();
        $res=cfArraySwapKeysValues(cfMGetVar('weezoResourcesList'));

        // Browse user's resources
        for($i=0;true;$i++){
            if(!isset($this->data['resource'.$i])) return $ret;
            $file=$this->data['resource'.$i]['file'];
            if(isset($res[$file])) {
                $rid=$res[$file];
                if($returnObjects)
                    $ret[$rid]=new WResConfig($rid);
                else
                    $ret[$rid]=$file;
            }
        }
        return $ret;
    }

    /**
     * @desc Return an array of resources linked to user
     *
     * @return array of id=>resourceFilename or $id=>WResLinked
     */
    function getResourcesLinked(){
        $ret=array();
        $res=cfArraySwapKeysValues(cfMGetVar('weezoResourcesList'));

        // Browse user's resources
        for($i=0;true;$i++){
            if(!isset($this->data['resource'.$i])) return $ret;
            $file=$this->data['resource'.$i]['file'];
            if(isset($res[$file])) {
                $rid=$res[$file];
                $ret[$rid]=new WResLinked($rid);
            }
        }
        return $ret;
    }

    /**
     * @desc Swap 2 bound resources
     *
     * @param $r1: id of 1st res
     * @param $r2: id of 2nd res
     */
    function swapResources($r1,$r2){
        $res=array();
        $prev=cfArraySwapKeysValues($this->getResources());
        $prevD=array();
        for($i=0;true;$i++){
            if(!isset($this->data['resource'.$i])) break;
            $prevD[$prev[$this->data['resource'.$i]['file']]]=$this->data['resource'.$i];
        }
        $i=0;
        foreach ($prevD as $rid=>$r){
            if($rid==$r1) $this->setVar('resource'.$i,$prevD[$r2]);
            elseif($rid==$r2) $this->setVar('resource'.$i,$prevD[$r1]);
            else $this->setVar('resource'.$i,$r);
            $i++;
        }

        $this->modifiedData=true;
        $this->modifiedResources=true;
    }

    /**
     * @desc Move a resource at given position
     *
     * @param string $resId
     * @param integer $pos
     * @return true if anything updated
     */
    function setResourcePos($resId,$pos){
    	$res=$this->getResources(); // id=>filename
    	$inv=cfArraySwapKeysValues($res); // filename=>id
    	if(!isset($res[$resId]) || !is_numeric($pos) || $pos<0 || $pos>count($res)-1) return false;

    	// Store resources data
    	$nb=0; while (isset($this->data['resource'.$nb])) {
    		$d=$this->data['resource'.$nb];
    		$data[$inv[$d['file']]]=$d;
    		$nb++;
    	}


    	$new=array(); // $id=>$filename
    	$mod=false;

    	// Reorder
    	$nb=0; foreach ($res as $id=>$file){
    		if($nb==$pos) {
    			if($id!=$resId) $mod=true;
    			$new[$resId]=$data[$resId];
    			$nb++;
    		}
    		if($id!=$resId) {$new[$id]=$data[$id];$nb++;} else $mod=true;
    	}
    	if(!isset($new[$resId])) $new[$resId]=$data[$resId];

    	// If modified, save into resourceX data
    	if($mod){
    		$nb=0;
    		foreach ($new as $id=>$data){
    			$this->setVar('resource'.$nb,$data);
    			$nb++;
    		}
	        $this->modifiedData=true;
			$this->modifiedResources=true;
    	}
    	// Return true if modified
    	return $mod;
    }

    /**
     * @desc Remove resource
     *
     * @param string $filename: resource config filename or id
     * @return boolean true if resource found and removed
     */
    function removeResource($filename){
        // If not a filename, convert to id
        if(!strpos($filename,'.res') && !($filename=cfArrayItem(cfMGetVar('weezoResData'.$filename),'resourceFilename'))) return;
        $found=0;
        for($i=0;true;$i++){
            if(!isset($this->data['resource'.$i])) break;
            $file=$this->data['resource'.$i]['file'];
            if($found) {
                $this->data['resource'.($i-1)]=$this->data['resource'.$i];
                unset($this->data['resource'.$i]);
            }
            if(!$found && $file==$filename){
                unset($this->data['resource'.$i]);
                $found=1;
            }
        }
        if($found) {
            $this->modifiedData=true;
            $this->modifiedResources=true;
        }
        return $found;
    }

    /**
     * @desc Add a resource
     *
     * @param string $rid: resource id
     */
    function addResource($rid){
        if(!($res=cfMGetVar('weezoResData'.$rid))) return;
        $i=0;while ($this->getVar('resource'.(int)$i)) $i++;
        $this->setVar('resource'.(int)$i,array('file'=>$res['resourceFilename'],'type'=>$res['type'],'subType'=>$res['subType']));
        $this->modifiedData=true;
        $this->modifiedResources=true;
    }

    /**
     * @desc Update a resource
     *
     * @param string $rid
     * @param string $dataName
     * @param mixed $dataValue
     */
    function updateResource($rid,$dataName,$dataValue,$fromWUser=false){
        if(!($res=cfMGetVar('weezoResData'.$rid))) return;
        if(!($resourceFilename=cfArrayItem(cfMGetVar('weezoResourcesList'),$rid))) return;
        $i=0;
        while ($ures=$this->getVar('resource'.(int)$i)) {
            if(@$ures['file']==$resourceFilename){
                if(@$ures[$dataName]!==$dataValue){
                    $ures[$dataName]=$dataValue;
                    // Update var
                    $this->setVar('resource'.(int)$i,$ures);

                    // If resource update is called from WUser object, apply to WUserConfig object
                    if($fromWUser) {
                    	$this->setVar('resource'.(int)$i,$ures);
                    	$this->saveVar('resource'.(int)$i);
                    }
                }
                return ;
            }
            $i++;
        }
    }

    // Commit changes to file
    function save(){
        // Don't save if not modified
        if(!$this->modifiedData) return ;

        // Save to file
        cfWriteIniFile($this->data,cfAppDataDir().'/groups/'.$this->filename);

        // Update in-memory data
        $users=cfMGetVar('weezoUsers');
        $users[$this->id]=$this->data;
        cfMSetVar('weezoUsers',$users);

        // Update database
        if($this->modifiedName) {
            require_once('databaseFunctions.php');
            $db=dbOpenDB();
            $query="INSERT INTO account VALUES ('".$this->id()."' ,'".$this->getVar('name')."','".(int)($this->isAdministrator())."','".time()."')";
            dbExec($query, $db);
            $query="UPDATE account SET name='".$this->getVar('name')."' WHERE id='".$this->id()."'";
            dbExec($query, $db);
            dbClose($db);
        }
        // Update opened sessions
        if($this->modifiedResources){
            require_once(INCLUDE_DIR.'initFunctions.php');
            ifResetResourcesUsers();
        }

        // New user: add to users list in general.ini
        if($this->new)    cfGUpdateVar('users',cfGGetVar('users').','.$this->filename,true);

        $this->modifiedResources=false;
        $this->modifiedData=false;
        $this->modifiedName=false;
        $this->new=false;
    }

    // Destroy user
    function del(){
        // Remove config file
        @unlink(cfAppDataDir().'/groups/'.$this->filename);

        // Update general.ini
        $u=array();
        foreach (explode(',',cfGGetVar('users')) as $ufn) if($ufn!=$this->filename) $u[]=$ufn;
        cfGUpdateVar('users',implode(',',$u));

        // Remove in-memory user
        $u=cfMGetVar('weezoUsers');
        unset($u[$this->id]);
        cfMSetVar('weezoUsers',$u);

        // Inform app
        cfServerSendCmd('userDeleted',array('file'=>$this->filename));
    }
}

/**
 * @desc Currently connected user. Accessed through WEnv
 *
 */
class WUser extends WUserConfig {
    protected $valid=true;
    protected $subUser;

    function __construct(){
        // Construct from session (plugins)
        if(isset($_ENV['weezoSession']['user']['id'])) parent::__construct($_ENV['weezoSession']['user']['id']);
        // Construct from session
        elseif(isset($_SESSION['user']['id'])) parent::__construct($_SESSION['user']['id']);
        // Not logged
        else $this->valid=false;
    }

    /**
     * @desc Return true if user is logged
     *
     * @return bool
     */
    function isLogged(){
        return isset($_SESSION['userLogged']) && $this->valid;
    }

    /**
     * @desc Get var
     *
     * @param string $dataName
     * @return mixed
     */
    function getVar($dataName){
        // Session-level (plugins)
        if(isset($_ENV['weezoSession']['user'][$dataName])) return $_ENV['weezoSession']['user'][$dataName];
        // Session-level
        if(isset($_SESSION['user'][$dataName])) return $_SESSION['user'][$dataName];
        // User-config level
        return @$this->data[$dataName];
    }

    /**
     * @desc Set/update for this session
     *
     * @param string $dataName: name of data to save
     * @param mixed $dataValue
     */
    function setVar($dataName,$dataValue){
        // Save for this session
        $_SESSION['user'][$dataName]=$dataValue;
    }

    /**
     * @desc Update/save to file a given data
     *
     * @param string $dataName: name of data to save
     * @param bool $commit: true to save now, false to wait for a call to save()
     */
    function saveVar($dataName,$commit=true){
        parent::setVar($dataName,$this->getVar($dataName));
        if($commit) parent::save();
    }

    /**
     * @desc Return user's label (group name + pseudo=
     *
     * @return string
     */
    function label(){
    	return $this->getVar('name').(($this->getVar('pseudo'))?' - '.$this->getVar('pseudo'):'');
    }

    /**
     * @desc Return group account type (singleUser, anonymous, named, list, facebook)
     *
     * @return string
     */
    function accountType(){return $this->getVar('accountType');}
    /**
     * @desc Return connected user's name
     *
     * @return string
     */
    function name(){
    	switch($this->getVar('accountType')){
    		case 'singleUser':return $this->getVar('name');
    		case 'named':return $this->getVar('pseudo');
    		case 'list':return $this->getVar('pseudo');
    		case 'anonymous':return '';
    	}
    }

    function updateResource($rid,$dataName,$dataValue,$foo=false){
        parent::updateResource($rid,$dataName,$dataValue,true);
    }

    /**
     * @desc Return logged subUser
     *
     * @return WSubUser
     */
    function subUser(){
    	if(!$this->getVar('subUserId')) return false;
    	if(!$this->subUser) $this->subUser=new WSubUser($this->getVar('subUserId'));
    	return $this->subUser;
    }

    /**
     * @desc Return true if it's a standalone resource access
     *
     * @return bool
     */
    function isStandalone(){return $this->getVar('id')==='standalone';}
}


/**
 * SubUser Object
 *
 */
class WSubUser{
	private $name;
	private $data;
	private $id;

	/**
	 * @desc Constructor
	 *
	 * @param string $id
	 */
	function __construct($id){
		if(!cfMIssetVar('subUser'.$id)) return;

		$this->id=$id;
		$this->data=cfMGetVar('subUser'.$id);

		// Browse all groups to find subUser name
		foreach (WEnv::userConfigs() as $uc){
			if(0) $uc=new WUserConfig();
			foreach ($uc->getSubUserNames() as $uid=>$name) if($uid==$id){
				$this->name=$name;
				break(2);
			}
		}
	}

	/**
	 * @desc Return subUser name
	 *
	 * @return string
	 */
	function name(){
		return $this->name;
	}

	/**
	 * @desc Return subUser data
	 *
	 * @param string $dataName: name of data
	 * @return mixed (null if not found)
	 */
	function getData($dataName=false){
		if(!$this->id) return null;
		if($dataName===false) return $this->data;
		if(isset($this->data[$dataName])) return $this->data[$dataName];
		return null;
	}

	/**
	 * @desc Update data, and save to file
	 *
	 * @param string $dataName: name of data
	 * @return mixed (null if not found)
	 */
	function updateData($dataName, $dataValue){
		if(!$this->id) return false;
//cfDbg('update '.$dataName.' with '.$dataValue.' in file '.cfAppDataDir().'/users/'.$this->id.'.subuser');
		// Update data in object
		$this->data[$dataName]=$dataValue;
		// Update data in memory
		cfMSetVar('subUser'.$this->id,$this->data);
		// Update data on file
		cfWriteIniFile($this->data, cfAppDataDir().'/users/'.$this->id.'.subuser', false);
		return true;
	}

	/**
	 * @desc Check if password exists
	 *
	 * @param string $password: plain text password
	 * @return bool
	 */
	function checkPassword($password){
		// No password
//cfDbg($password.' => '.sha1($password).' <=> '.$this->getData('password'));
		if(!$password && !$this->getData('password')) return true;
		return sha1($password)===$this->getData('password');
	}

	/**
	 * @desc Update password
	 *
	 * @param string $newPassword: plain text new password
	 */
	function updatePassword($newPassword){
		$this->updateData('password',sha1($newPassword));
	}

	/**
	 * @desc Get general-level user configuration data
	 *
	 * @param string $dataName
	 * @return mixed
	 */
	function getGVar($dataName=false){
		if(!$dataName) return @unserialize($this->getData('general'));
		return cfArrayItem(@unserialize($this->getData('general')),$dataName);
	}

	/**
	 * @desc Update and save general-level user configuration data
	 *
	 * @param string $dataName
	 * @param string $dataValue: new value
	 */
	function updateGVar($dataName, $dataValue){
		$gData=@unserialize($this->getData('general'));
		if(!is_array($gData)) $gData=array();
		$gData[$dataName]=$dataValue;
		$this->updateData('general',serialize($gData));
	}

	/**
	 * @desc Get resource-level user configuration data
	 *
	 * @param string $resourceId: resource id, or false to use active resource
	 * @return mixed
	 */
	function getRVar($resourceId=false){
		if(!$resourceId) $resourceId=WEnv::res('id');
		$rData=@unserialize($this->getData('res'.$resourceId));
		return $rData;
	}

	/**
	 * @desc Update and save resource-level user configuration data
	 *
	 * @param string $dataName
	 * @param string $dataValue: new value
	 * @param string $resourceId: resource id, or false to use active resource
	 */
	function updateRVar($dataValue, $resourceId=false){
		if(!$resourceId) $resourceId=WEnv::res('id');
		$rData=$dataValue;
		$this->updateData('res'.$resourceId,serialize($rData));
	}
}


/**
 * @desc Resource definition class
 *
 */
class WResDefinition{
    protected $data;
    protected $type;
    protected $subType;

    /**
     * @desc Constructor
     *
     * @param string $type
     * @param string $subType
     */
    function __construct($type,$subType){
        $this->data=cfMGetVar('weezoResourceDefinition'.strtolower($type).strtolower($subType));
        $this->type=$type;
        $this->subType=$subType;
    }

    /**
     * @desc Return true if resource definition successfully loaded
     *
     * @return bool
     */
    function isValid(){
        if($this->data) return true; else return false;
    }

    /**
     * @desc Return resource's data
     *
     * @param string $dataName: name of data
     * @return mixed data value
     */
    function getVar($dataName=false){
        if(!$dataName) return $this->data;
        return @$this->data[$dataName];
    }

    /**
     * @desc Return resource's describer or describer item
     *
     * @param string $dataName: name of describer's data. If omitted, return whole describer
     * @param string $subDataName: name of describer's data
     * @return mixed describer or data value
     */
    function getDescriber($dataName=false,$subDataName=false){
        if($dataName && $subDataName) return @$this->data['describer'][$dataName][$subDataName];
        if($dataName) return @$this->data['describer'][$dataName];
        return $this->data['describer'];
    }

    /**
     * @desc Return 16x16 icon URI
     *
     * @return string: path to icon from document root
     */
    function icon16(){return $this->data['resourceIconSmall'];}

    /**
     * @desc Return 16x16 icon URI
     *
     * @return string: path to icon from document root
     */    function icon32(){return $this->data['resourceIcon'];}

    /**
     * @desc Return preview URI
     *
     * @return string: path to preview image from document root
     */    function previewImage(){return $this->data['resourcePreviewImage'];}

    /**
     * @desc Return resource's label, in user's language
     *
     * @return string
     */
    function label(){
        if(cfCaptionExist(strtolower($this->type).'_'.strtolower($this->subType).'-name')) return cfCaption(strtolower($this->type).'_'.strtolower($this->subType).'-name');
        $lng=WEnv::config()->getVar((cfIsInApp())?'languageUI':'language');
        if($label=$this->getDescriber($lng,'name')) return $label;
        if($label=$this->getDescriber('en','name')) return $label;
        return $this->subType;
    }

    /**
     * @desc Return resource's description, in user's language
     *
     * @return string
     */
    function description(){
        if(cfCaptionExist(strtolower($this->type).'_'.strtolower($this->subType).'-description')) return cfCaption(strtolower($this->type).'_'.strtolower($this->subType).'-description');
        $lng=WEnv::config()->getVar((cfIsInApp())?'languageUI':'language');
        if($label=$this->getDescriber($lng,'description')) return $label;
        if($label=$this->getDescriber('en','description')) return $label;
        return $this->subType;
    }


    /**
     * @desc Return API script filename if resource supports API calls, else return false
     *
     * @return string API script filename
     */
    function API(){
    	static $APIFile=-1;
    	if($APIFile!==-1) return $APIFile;
    	$APIFile=cfAppDocRoot().'/res/'.$this->type.'/'.$this->subType.'/API.php';
    	if(!is_file($APIFile)) $APIFile=false;
    	return $APIFile;
    }

}

/**
 * @desc Configured resource class
 *
 */
class WResConfig {
    protected $data; // Resource config data
    protected $modified=false; // True if any modified
    protected $def; // WResDefinition
    protected $dataDir;

    /**
     * @desc Constructor
     *
     * @param string $idOrFilename: resource id or config filename (use false to make false object, used for IDE autocompletition)
     */
    function __construct($idOrFilename=false){
        if(!$idOrFilename) return ;
        // Treat $idOrFilename as id
        $this->data=cfMGetVar('weezoResData'.$idOrFilename);
        if(!$this->data){
            // If not found,try as filename
            if(!cfCmpRight($idOrFilename,'.res')) return;
            if($id=cfArrayItem(cfArraySwapKeysValues(cfMGetVar('weezoResourcesList')),$idOrFilename))
                $this->data=cfMGetVar('weezoResData'.$id);
        }

		$this->def=new WResDefinition($this->getVar('type'),$this->getVar('subType'));
    }

    /**
     * @desc Cast object to string
     *
     * @return string
     */
    function __toString() {
        if(!$this->data) return 'invalid WResConfig';
        return "WResConfig Object:\nid=".@$this->data['id']."\nname=".@$this->data['name']."\nfilename=".@$this->data['resourceFilename']."\ns/st=".@$this->data['type'].'/'.$this->data['type'];
    }


    /**
     * @desc Return true if resource config successfully loaded
     *
     * @return bool
     */
    function isValid(){if($this->data) return true; return false;}

    /**
     * @desc Return configuration filename
     *
     * @return string
     */
    function filename(){return $this->getVar('resourceFilename');}

    /**
     * @desc Return resource's data
     *
     * @param string $dataName: name of data
     * @return mixed data value
     */
    function getVar($dataName=false){
        if(!$dataName) return $this->data;
        if(isset($this->data[$dataName])) return $this->data[$dataName];
        return $this->def->getVar($dataName);
    }

    /**
     * @desc Return resource's data
     *
     * @param string $dataName: name of data
     * @return mixed data value
     */
    function setVar($dataName, $dataValue){
        if($dataName=='id' || $dataName=='filename') return ;
        if(@$this->data[$dataName]===$dataValue) return ;
        $this->$modified=true;
        $this->data[$dataName]=$dataValue;
    }

    /**
     * @desc Return resource id
     *
     * @return string
     */
    function id(){return $this->getVar('id');}

    /**
     * @desc Return resource name
     *
     * @return string
     */
    function name(){return $this->getVar('name');}

    /**
     * @desc Return resource's definition (or resource's definition item if dataName passed)
     *
     * @param string $dataName
     * @return WResDefinition
     */
    function definition($dataName=false){
        if($dataName) return $this->def->getVar($dataName);
        return $this->def;
    }


    /**
     * @desc Return resource's data directory (/data/res/{type}/{subtype}/{config_filename_without_extension)
     *
     * @return string
     */
    function dataDir(){
        // Cached result
        if(isset($this->dataDir)) return $this->dataDir;
        $this->dataDir=cfAppDataDir().'/res/'.$this->getVar('type').'/'.$this->getVar('subType').'/'.cfFileWithoutExtension($this->filename());
        // Try to create resource directory if needed
        if(!is_dir($this->dataDir)) @mkdir($this->dataDir);
        return $this->dataDir;
    }

    /**
     * @desc Return 16x16 icon URI
     *
     * @return string: path to icon from document root
     */
    function icon16(){
    	$ci=$this->getVar('customIcon');
    	if($ci && file_exists(cfAppDocRoot().'/gfx/res/'.$ci.'_16.png')) return '/gfx/res/'.$ci.'_16.png';
    	return $this->def->icon16();
    }

    /**
     * @desc Return 32x32 icon URI
     *
     * @return string: path to icon from document root
     */
    function icon32(){
    	$ci=$this->getVar('customIcon');
    	if($ci && file_exists(cfAppDocRoot().'/gfx/res/'.$ci.'.png')) return '/gfx/res/'.$ci.'.png';
    	return $this->def->icon32();
    }

    /**
     * @desc Return 16x16 user-interface flat icon URI
     *
     * @return string: path to icon from document root
     */
    function uiIcon16(){
    	$ci=$this->getVar('uiResourceIconSmall');
    	if($ci) return $ci;
    	return cfFilteredImage($this->icon16(),0,0,array('r'=>36,'g'=>101,'b'=>130,'p'=>50),255,255);
    }
}

/**
 * @desc Function wrapper for WResConfig, used for fast single access to a method.
 *
 * @param string $idOrFilename
 * @return WResConfig
 */
function wResConfigNew($idOrFilename=false){return new WResConfig($idOrFilename);}

/**
 * @desc Return a resource (object) linked to currently logged user
 *
 */
class WResLinked{
    protected $id; // Resource id
    protected $nid; // Resource numeric id (sequential id in session)
    protected $isActive ; // True if linked resource is active resource
    protected $data; // Linked resource data (from session), set only if resource is not active resource
    protected $config; // Resource config object
    protected $valid=true;

    /**
     * @desc Direct access to getVar
     *
     * @param string $dataName
     * @return mixed
     */
    function __invoke($dataName){
        return cfRGetVar($dataName,false,false,null);
    }

    /**
     * @desc Creator
     *
     * @param string $rid: id of linked resource
     */
    function __construct($rid=false){
        if(!$rid){
            $nid=((isset($_SESSION['activeResourceId']))?$_SESSION['activeResourceId']:((isset($_ENV['weezoSession']['activeResourceId']))?$_ENV['weezoSession']['activeResourceId']:false));
            if(!$nid) return;
            $this->id=$rid;
            $this->nid=$nid;
            $this->isActive=true;
            return;
        }
        else{
            foreach (WEnv::session()->getVar('res') as $nid=>$resArr) if($resArr['id']===$rid){
                $this->id=$rid;
                $this->nid=$nid;
                $this->isActive=false;
                $this->data=WEnv::session()->getVar('res',$nid);
                return;
            }
        }
        $this->valid=false;
    }

    /**
     * @desc Return resource's data
     *
     * @param string $dataName: name of data
     * @return mixed data value
     */
    function getVar($dataName){
        if(!$this->valid) return null;
        if($this->isActive) return cfRGetVar($dataName,false,false,null);
        return isset($this->data[$dataName])?$this->data[$dataName]:$this->config()->getVar($dataName);
    }

    /**
     * @desc Set a resource data
     *
     * @param string $dataName: name of data
     * @return mixed data value: new value
     */
    function setVar($dataName, $dataValue){
        if($dataName=='id' || $dataName=='filename') return ;
        if($this->isActive) cfRSetVar($dataName,$dataValue);
        else{
            // Save to object
            $this->data['dataName']=$dataValue;
            // Save to session
            $_SESSION['res'][$this->nid]['dataName']=$dataValue;
        }
    }

    /**
     * @desc Set a persistent (memory) variable for this session/resource
     *
     * @param string $dataName
     * @param string $dataValue
     */
    function getMVar($dataName){return cfMGetVar('SR.'.wSession_id().'.'.$this->id.'.'.$dataName);}

    /**
     * @desc Set a persistent (memory) variable for this session/resource
     *
     * @param string $dataName
     * @param string $dataValue
     */
    function setMVar($dataName, $dataValue){cfMSetVar('SR.'.wSession_id().'.'.$this->id.'.'.$dataName,$dataValue);}

    /**
     * @desc Set a persistent (memory) variable for this session/resource
     *
     * @param string $dataName
     * @param string $dataValue
     */
    function issetMVar($dataName){return cfMIssetVar('SR.'.wSession_id().'.'.$this->id.'.'.$dataName);}

    /**
     * @desc return link to index file
     *
     * @return string
     */
    function resourceBaseURL(){return $this->data['resourceBaseURL'];}

    /**
     * @desc Return resource's config object
     *
     * @return WResConfig
     */
    function config(){
        if(!isset($this->config)) $this->config=new WResConfig($this->id);
        return $this->config;
    }

    function __toString(){return $this->config()->__toString();}
}

/**
 * @desc HTTP outgoing headers
 *
 */
class WHeaders{
    /**
     * @desc Send no-cache headers
     *
     */
    static function noCache(){
        header('Expires: '.gmdate("D, d M Y H:i:s",0).' GMT');
        header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
        header("Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0");
        header("Pragma: no-cache");
    }

    /**
     * @desc Send cache headers
     *
     * @param string $completeFilename: if set, use file mtime for last modification date
     */
    static function cache($completeFilename=false){
        if($completeFilename) header('Last-Modified: '.gmdate("D, d M Y H:i:s",@filemtime($completeFilename)).' GMT');
        header('Expires: '.gmdate("D, d M Y H:i:s",time()+3600*24*100).' GMT');
        header('Pragma:');
        header('Cache-Control: private');
        header('Etag: "'.md5($_SERVER['REQUEST_URI']).'"');
    }

    /**
     * @desc Send Content-Range, and Accept-Range  headers
     *
     * @param intgeger $contentLength: total content size
     */
    static function contentRange($contentLength=false){
    	// If those headers have already been sent, don't send twice
    	if (WHeaders::sent('Content-Range')) return ;

    	// Get requested range
    	list($from,$to)=WHeadersIn::getRange();
    	if($from!==false || $to!==false){
    		header('HTTP/1.1 206 Partial Content');
    		if($to===false && $contentLength) $to=$contentLength-1;
    		if($to!==false) header('Content-Range: bytes '.$from.'-'.$to.'/'.(($contentLength===false)?'*':$contentLength));

    		// Compute sent length
    		if($from!==false && $to!==false) $contentLength=1+$to-$from;
    		elseif($from!==false && $contentLength) $contentLength-=$from;
    		else $contentLength=false;
    	}
    	if($contentLength) header('Content-Length: '.$contentLength);
    	//header('Accept-Ranges: bytes');
    }


    static function contentRangeNo(){
    	header('Accept-Ranges: none');
    }

    /**
     * @desc Send content-type header
     *
     * @param string $completeFilename
     */
    static function contentType($completeFilename){
    	// Count nb of /
        str_replace('/','/',$completeFilename,$c);

        // If completeFilename is the mime type
        if($c==1 && !strpos($completeFilename,'.'))
            header('Content-Type: "'.$completeFilename);
        // Actual filename
        else{
        	if(!strpos($completeFilename,'.')) $completeFilename='.'.$completeFilename;
            require_once(INCLUDE_DIR.'explorerFunctions.php');
            header('Content-Type: '.efFileMimeType($completeFilename));
        }
    }

    /**
     * @desc Return headers sent/to be sent, with keys turned to lowercase
     * @param srting $headerName: if set, return only this header (case insensitive)
     */
    static function sent($headerName=false){
    	$h=array();
    	foreach (headers_list() as $k=>$v) $h[strtolower($k)]=$v;
    	return ($headerName)?@$h[strtolower($headerName)]:$h;
    }
}

/**
 * @desc HTTP incoming headers
 *
 */
class WHeadersIn{
	static private $headersIn;

	/**
	 * Retreive headers and set keys to lowercase
	 *
	 */
	static private function init(){
		if (empty(self::$headersIn)) {
			foreach (getallheaders() as $k=>$v) self::$headersIn[strtolower($k)]=$v;
		}
	}

	/**
	 * @desc Return header value, false if not set
	 *
	 * @param string $headerName: header name (case insensitive)
	 * @return string (false if not set)
	 */
	static function get($headerName=false){
		self::init();
		$headerName=strtolower($headerName);
		if(!$headerName) return self::$headersIn;
		return (isset(self::$headersIn[$headerName]))?self::$headersIn[$headerName]:false;
	}

	/**
	 * @desc Get Range requested by client, from "Range" HTTP header
	 *
	 * @return array(from,to) (from and to are FALSE if not set)
	 */
	static function getRange(){
		self::init();
		if(!isset(self::$headersIn['range']) || strpos(self::$headersIn['range'],'-')===false || strpos(self::$headersIn['range'],'bytes=')===false) return array(false,false);
		list($from,$to)=explode('-',str_replace('bytes=','',self::$headersIn['range']),2);
		if($from==='') $from=false;
		if($to==='') $to=false;
		return array($from,$to);
	}
}

?>